@@ -13,15 +13,17 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef __KONTOURIMPORT_H__
 #define __KONTOURIMPORT_H__
 
-#include <koFilter.h>
+#include <KoFilter.h>
 #include <qdom.h>
+//Added by qt3to4:
+#include <Q3CString>
 #include <core/vdocument.h>
 
 class KontourImport : public KoFilter
@@ -29,10 +31,10 @@ class KontourImport : public KoFilter
 	Q_OBJECT
 
 public:
-	KontourImport(KoFilter *parent, const char *name, const QStringList&);
+	KontourImport(QObject* parent, const QStringList&);
 	virtual ~KontourImport();
 
-	virtual KoFilter::ConversionStatus convert(const QCString& from, const QCString& to);
+	virtual KoFilter::ConversionStatus convert(const QByteArray& from, const QByteArray& to);
 
 protected:
 	QDomDocument inpdoc;
