@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef __SVGGRAPHICSCONTEXT_H__
@@ -35,12 +35,14 @@ public:
 		stroke.setLineJoin( VStroke::joinMiter );
 		fill.setColor( VColor( Qt::black ) );
 		fillRule = winding;
+		color = Qt::black;
 	}
 	VFill		fill;
 	VFillRule	fillRule;
 	VStroke		stroke;
-	QWMatrix	matrix;
+	QMatrix	matrix;
 	QFont		font;
+	QColor		color;
 };
 
 #endif
