@@ -17,12 +17,12 @@
  * Boston, MA 02110-1301, USA.
 */
 
-#include <qcstring.h>
-#include <qdatastream.h>
+#include <q3cstring.h>
+#include <QDataStream>
 #include <qdom.h>
-#include <qfile.h>
-#include <qstring.h>
-#include <qvaluelist.h>
+#include <QFile>
+#include <QString>
+#include <q3valuelist.h>
 
 #include <kgenericfactory.h>
 #include <KoFilter.h>
@@ -41,19 +41,19 @@ const unsigned XcfExport::m_tileWidth  = 64;
 const unsigned XcfExport::m_tileHeight = 64;
 
 
-typedef KGenericFactory<XcfExport, KoFilter> XcfExportFactory;
+typedef KGenericFactory<XcfExport> XcfExportFactory;
 K_EXPORT_COMPONENT_FACTORY( libkarbonxcfexport, XcfExportFactory( "kofficefilters" ) )
 
 
-XcfExport::XcfExport( KoFilter*, const char*, const QStringList& )
-	: KoFilter()
+XcfExport::XcfExport( QObject*parent, const QStringList& )
+	: KoFilter(parent)
 {
 	m_zoomX = 1.0;
 	m_zoomY = 1.0;
 }
 
 KoFilter::ConversionStatus
-XcfExport::convert( const QCString& from, const QCString& to )
+XcfExport::convert( const QByteArray& from, const QByteArray& to )
 {
 	if( to != "image/x-xcf-gimp" || from != "application/x-karbon" )
 	{
@@ -69,7 +69,7 @@ XcfExport::convert( const QCString& from, const QCString& to )
 
 	QFile fileOut( m_chain->outputFile() );
 
-	if( !fileOut.open( IO_WriteOnly ) )
+	if( !fileOut.open( QIODevice::WriteOnly ) )
 		return KoFilter::StupidError;
 
 
@@ -98,9 +98,9 @@ void
 XcfExport::visitVDocument( VDocument& document )
 {
 	// Offsets.
-	QIODevice::Offset current = 0;
-	QIODevice::Offset start = 0;
-	QIODevice::Offset end = 0;
+	qlonglong current = 0;
+	qlonglong start = 0;
+	qlonglong end = 0;
 
 	// Save width and height for layer saving.
 	m_width  = static_cast<unsigned>( document.width()  * m_zoomX );
@@ -111,20 +111,20 @@ XcfExport::visitVDocument( VDocument& document )
 	m_stream->writeRawBytes( "gimp xcf file", 14 );
 
 	// Image width.
-	*m_stream << static_cast<Q_UINT32>( m_width );
+	*m_stream << static_cast<quint32>( m_width );
 
 	// Image height.
-	*m_stream << static_cast<Q_UINT32>( m_height );
+	*m_stream << static_cast<quint32>( m_height );
 
 	// Image type = RGB.
-	*m_stream << static_cast<Q_UINT32>( 0 );
+	*m_stream << static_cast<quint32>( 0 );
 
 	// Do not save any properties currently.
 	*m_stream
 		// "END".
-		<< static_cast<Q_UINT32>( 0 )
+		<< static_cast<quint32>( 0 )
 		// Property size in bytes.
-		<< static_cast<Q_UINT32>( 0 );
+		<< static_cast<quint32>( 0 );
 
 
 	// Save current offset.
@@ -170,113 +170,113 @@ XcfExport::visitVDocument( VDocument& document )
 	m_stream->device()->at( current );
 
 	// Append a zero offset to indicate end of layer offsets.
-	*m_stream << static_cast<Q_UINT32>( 0 );
+	*m_stream << static_cast<quint32>( 0 );
 
 
 	// Return to end offset.
 	m_stream->device()->at( end );
 
 	// Append a zero offset to indicate end of channel offsets.
-	*m_stream << static_cast<Q_UINT32>( 0 );
+	*m_stream << static_cast<quint32>( 0 );
 }
 
 void
 XcfExport::visitVLayer( VLayer& layer )
 {
 	// Layer width = image width.
-	*m_stream << static_cast<Q_UINT32>( m_width );
+	*m_stream << static_cast<quint32>( m_width );
 
 	// Layer height = image height.
-	*m_stream << static_cast<Q_UINT32>( m_height );
+	*m_stream << static_cast<quint32>( m_height );
 
 	// Layer type = RGBA.
-	*m_stream << static_cast<Q_UINT32>( 1 );
+	*m_stream << static_cast<quint32>( 1 );
 
 	// Layer name.
 	*m_stream << layer.name().latin1();
 
 	// Layer opacity.
-	*m_stream << static_cast<Q_UINT32>( 6 );
+	*m_stream << static_cast<quint32>( 6 );
 	// Property size in bytes.
-	*m_stream << static_cast<Q_UINT32>( 4 );
+	*m_stream << static_cast<quint32>( 4 );
 	// Fully opaque = 255.
-	*m_stream << static_cast<Q_UINT32>( 255 );
+	*m_stream << static_cast<quint32>( 255 );
 
 	// Layer visible?
-	*m_stream << static_cast<Q_UINT32>( 8 );
+	*m_stream << static_cast<quint32>( 8 );
 	// Property size in bytes.
-	*m_stream << static_cast<Q_UINT32>( 4 );
+	*m_stream << static_cast<quint32>( 4 );
 	// True.
-	*m_stream << static_cast<Q_UINT32>( 1 );
+	*m_stream << static_cast<quint32>( 1 );
 
 	// Layer linked?
-	*m_stream << static_cast<Q_UINT32>( 9 );
+	*m_stream << static_cast<quint32>( 9 );
 	// Property size in bytes.
-	*m_stream << static_cast<Q_UINT32>( 4 );
+	*m_stream << static_cast<quint32>( 4 );
 	// False.
-	*m_stream << static_cast<Q_UINT32>( 0 );
+	*m_stream << static_cast<quint32>( 0 );
 
 	// Preserve transparency?
-	*m_stream << static_cast<Q_UINT32>( 10 );
+	*m_stream << static_cast<quint32>( 10 );
 	// Property size in bytes.
-	*m_stream << static_cast<Q_UINT32>( 4 );
+	*m_stream << static_cast<quint32>( 4 );
 	// False.
-	*m_stream << static_cast<Q_UINT32>( 0 );
+	*m_stream << static_cast<quint32>( 0 );
 
 	// Apply mask?
-	*m_stream << static_cast<Q_UINT32>( 11 );
+	*m_stream << static_cast<quint32>( 11 );
 	// Property size in bytes.
-	*m_stream << static_cast<Q_UINT32>( 4 );
+	*m_stream << static_cast<quint32>( 4 );
 	// False.
-	*m_stream << static_cast<Q_UINT32>( 0 );
+	*m_stream << static_cast<quint32>( 0 );
 
 	// Edit mask?
-	*m_stream << static_cast<Q_UINT32>( 12 );
+	*m_stream << static_cast<quint32>( 12 );
 	// Property size in bytes.
-	*m_stream << static_cast<Q_UINT32>( 4 );
+	*m_stream << static_cast<quint32>( 4 );
 	// False.
-	*m_stream << static_cast<Q_UINT32>( 0 );
+	*m_stream << static_cast<quint32>( 0 );
 
 	// Show mask?
-	*m_stream << static_cast<Q_UINT32>( 13 );
+	*m_stream << static_cast<quint32>( 13 );
 	// Property size in bytes.
-	*m_stream << static_cast<Q_UINT32>( 4 );
+	*m_stream << static_cast<quint32>( 4 );
 	// False.
-	*m_stream << static_cast<Q_UINT32>( 0 );
+	*m_stream << static_cast<quint32>( 0 );
 
 	// Layer offsets.
-	*m_stream << static_cast<Q_UINT32>( 15 );
+	*m_stream << static_cast<quint32>( 15 );
 	// Property size in bytes.
-	*m_stream << static_cast<Q_UINT32>( 8 );
+	*m_stream << static_cast<quint32>( 8 );
 	// X-Offset.
-	*m_stream << static_cast<Q_UINT32>( 0 );
+	*m_stream << static_cast<quint32>( 0 );
 	// Y-Offset.
-	*m_stream << static_cast<Q_UINT32>( 0 );
+	*m_stream << static_cast<quint32>( 0 );
 
 	// Layer mode.
-	*m_stream << static_cast<Q_UINT32>( 7 );
+	*m_stream << static_cast<quint32>( 7 );
 	// Property size in bytes.
-	*m_stream << static_cast<Q_UINT32>( 4 );
+	*m_stream << static_cast<quint32>( 4 );
 	// Normal mode.
-	*m_stream << static_cast<Q_UINT32>( 0 );
+	*m_stream << static_cast<quint32>( 0 );
 
 	// TODO: Tattoo.
-	*m_stream << static_cast<Q_UINT32>( 20 );
+	*m_stream << static_cast<quint32>( 20 );
 	// Property size in bytes.
-	*m_stream << static_cast<Q_UINT32>( 4 );
+	*m_stream << static_cast<quint32>( 4 );
 	// False.
-	*m_stream << static_cast<Q_UINT32>( 0 );
+	*m_stream << static_cast<quint32>( 0 );
 
 	// Layer properties end.
-	*m_stream << static_cast<Q_UINT32>( 0 );
+	*m_stream << static_cast<quint32>( 0 );
 	// Property size in bytes.
-	*m_stream << static_cast<Q_UINT32>( 0 );
+	*m_stream << static_cast<quint32>( 0 );
 
 
 	// Offsets.
-	QIODevice::Offset current = 0;
-	QIODevice::Offset start = 0;
-	QIODevice::Offset end = 0;
+	qlonglong current = 0;
+	qlonglong start = 0;
+	qlonglong end = 0;
 
 	// Save current offset.
 	current = m_stream->device()->at();
@@ -303,16 +303,16 @@ XcfExport::visitVLayer( VLayer& layer )
 
 
 	// Append a zero offset to indicate end of layer mask offsets.
-	*m_stream << static_cast<Q_UINT32>( 0 );
+	*m_stream << static_cast<quint32>( 0 );
 }
 
 void
 XcfExport::writeHierarchy()
 {
 	// Offsets.
-	QIODevice::Offset current = 0;
-	QIODevice::Offset start = 0;
-	QIODevice::Offset end = 0;
+	qlonglong current = 0;
+	qlonglong start = 0;
+	qlonglong end = 0;
 
 	// Width (again?).
 	*m_stream << m_width;
@@ -321,13 +321,13 @@ XcfExport::writeHierarchy()
 	*m_stream << m_height;
 
 	// Color depth.
-	*m_stream << static_cast<Q_UINT32>( 3 );
+	*m_stream << static_cast<quint32>( 3 );
 
 
 	// Calculate level number.
 	int levX = levels( m_width, m_tileWidth );
 	int levY = levels( m_height, m_tileHeight );
-	int levels = QMAX( levX, levY );
+	int levels = qMax( levX, levY );
 
 	int width = m_width;
 	int height = m_height;
@@ -354,9 +354,9 @@ XcfExport::writeHierarchy()
 			width  /= 2;
 			height /= 2;
 
-			*m_stream << static_cast<Q_UINT32>( width );
-			*m_stream << static_cast<Q_UINT32>( height );
-			*m_stream << static_cast<Q_UINT32>( 0 );
+			*m_stream << static_cast<quint32>( width );
+			*m_stream << static_cast<quint32>( height );
+			*m_stream << static_cast<quint32>( 0 );
 		}
 
 		// Save end offset.
@@ -379,19 +379,19 @@ XcfExport::writeHierarchy()
 	m_stream->device()->at( current );
 
 	// Append a zero offset to indicate end of level offsets.
-	*m_stream << static_cast<Q_UINT32>( 0 );
+	*m_stream << static_cast<quint32>( 0 );
 }
 
 void
 XcfExport::writeLevel()
 {
 	// Offsets.
-	QIODevice::Offset current = 0;
-	QIODevice::Offset start = 0;
-	QIODevice::Offset end = 0;
+	qlonglong current = 0;
+	qlonglong start = 0;
+	qlonglong end = 0;
 
-	*m_stream << static_cast<Q_UINT32>( m_width );
-	*m_stream << static_cast<Q_UINT32>( m_height );
+	*m_stream << static_cast<quint32>( m_width );
+	*m_stream << static_cast<quint32>( m_height );
 
 	int rows = ( m_height + m_tileHeight - 1 ) / m_tileHeight;
 	int cols = ( m_width  + m_tileWidth  - 1 ) / m_tileWidth;
@@ -410,18 +410,18 @@ XcfExport::writeLevel()
 
 
 		// TODO: Save tile.
-		*m_stream << static_cast<Q_UINT8>( 1 );
-		*m_stream << static_cast<Q_UINT8>( 1 );
-		*m_stream << static_cast<Q_UINT8>( 1 );
-		*m_stream << static_cast<Q_UINT8>( 1 );
-		*m_stream << static_cast<Q_UINT8>( 1 );
-		*m_stream << static_cast<Q_UINT8>( 1 );
-		*m_stream << static_cast<Q_UINT8>( 1 );
-		*m_stream << static_cast<Q_UINT8>( 1 );
-		*m_stream << static_cast<Q_UINT8>( 1 );
-		*m_stream << static_cast<Q_UINT8>( 1 );
-		*m_stream << static_cast<Q_UINT8>( 1 );
-		*m_stream << static_cast<Q_UINT8>( 1 );
+		*m_stream << static_cast<quint8>( 1 );
+		*m_stream << static_cast<quint8>( 1 );
+		*m_stream << static_cast<quint8>( 1 );
+		*m_stream << static_cast<quint8>( 1 );
+		*m_stream << static_cast<quint8>( 1 );
+		*m_stream << static_cast<quint8>( 1 );
+		*m_stream << static_cast<quint8>( 1 );
+		*m_stream << static_cast<quint8>( 1 );
+		*m_stream << static_cast<quint8>( 1 );
+		*m_stream << static_cast<quint8>( 1 );
+		*m_stream << static_cast<quint8>( 1 );
+		*m_stream << static_cast<quint8>( 1 );
 
 
 		// Save end offset.
