@@ -16,16 +16,19 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  */
- 
+
 #include "kis_jpeg_converter.h"
 
 #include <stdio.h>
+#include <stdint.h>
 
 extern "C" {
 #include <iccjpeg.h>
 }
 
-#include <qfile.h>
+#include <exiv2/jpgimage.hpp>
+
+#include <QFile>
 
 #include <kapplication.h>
 #include <kmessagebox.h>
@@ -34,51 +37,53 @@ extern "C" {
 #include <KoDocumentInfo.h>
 
 #include <kio/netaccess.h>
+#include <kio/deletejob.h>
 
-#include <kis_abstract_colorspace.h>
-#include <kis_colorspace_factory_registry.h>
-#include <kis_doc.h>
+#include <KoColorSpaceRegistry.h>
+#include <kis_doc2.h>
 #include <kis_image.h>
 #include <kis_iterators_pixel.h>
 #include <kis_paint_layer.h>
 #include <kis_group_layer.h>
-#include <kis_meta_registry.h>
-#include <kis_profile.h>
+#include <kis_meta_data_entry.h>
+#include <kis_meta_data_value.h>
+#include <kis_meta_data_store.h>
+#include <kis_meta_data_io_backend.h>
 
-#include <kis_exif_io.h>
-
-extern "C" {
-#include <libexif/exif-loader.h>
-#include <libexif/exif-utils.h>
-}
+#include <colorprofiles/KoIccColorProfile.h>
 
 #define ICC_MARKER  (JPEG_APP0 + 2) /* JPEG marker code for ICC */
 #define ICC_OVERHEAD_LEN  14    /* size of non-profile data in APP2 */
 #define MAX_BYTES_IN_MARKER  65533  /* maximum data len of a JPEG marker */
 #define MAX_DATA_BYTES_IN_MARKER  (MAX_BYTES_IN_MARKER - ICC_OVERHEAD_LEN)
 
+const char photoshopMarker[] = "Photoshop 3.0\0";
+const char photoshopBimId_[] = "8BIM";
+const uint16_t photoshopIptc = 0x0404;
+const QByteArray photoshopIptc_((char*)&photoshopIptc, 2);
+
 namespace {
-    
-    J_COLOR_SPACE getColorTypeforColorSpace( KisColorSpace * cs)
+
+    J_COLOR_SPACE getColorTypeforColorSpace( KoColorSpace * cs)
     {
-        if ( cs->id() == KisID("GRAYA") || cs->id() == KisID("GRAYA16") )
+        if ( KoID(cs->id()) == KoID("GRAYA") || KoID(cs->id()) == KoID("GRAYA16") )
         {
             return JCS_GRAYSCALE;
         }
-        if ( cs->id() == KisID("RGBA") || cs->id() == KisID("RGBA16") )
+        if ( KoID(cs->id()) == KoID("RGBA") || KoID(cs->id()) == KoID("RGBA16") )
         {
             return JCS_RGB;
         }
-        if ( cs->id() == KisID("CMYK") || cs->id() == KisID("CMYK16") )
+        if ( KoID(cs->id()) == KoID("CMYK") || KoID(cs->id()) == KoID("CMYK16") )
         {
             return JCS_CMYK;
         }
-        KMessageBox::error(0, i18n("Cannot export images in %1.\n").arg(cs->id().name()) ) ;
+        KMessageBox::error(0, i18n("Cannot export images in %1.\n",cs->name()) ) ;
         return JCS_UNKNOWN;
     }
 
     QString getColorSpaceForColorType(J_COLOR_SPACE color_type) {
-        kdDebug(41008) << "color_type = " << color_type << endl;
+        kDebug(41008) <<"color_type =" << color_type;
         if(color_type == JCS_GRAYSCALE)
         {
             return "GRAYA";
@@ -92,7 +97,7 @@ namespace {
 
 }
 
-KisJPEGConverter::KisJPEGConverter(KisDoc *doc, KisUndoAdapter *adapter)
+KisJPEGConverter::KisJPEGConverter(KisDoc2 *doc, KisUndoAdapter *adapter)
 {
     m_doc = doc;
     m_adapter = adapter;
@@ -104,14 +109,14 @@ KisJPEGConverter::~KisJPEGConverter()
 {
 }
 
-KisImageBuilder_Result KisJPEGConverter::decode(const KURL& uri)
+KisImageBuilder_Result KisJPEGConverter::decode(const KUrl& uri)
 {
     struct jpeg_decompress_struct cinfo;
     struct jpeg_error_mgr jerr;
-    
+
     cinfo.err = jpeg_std_error(&jerr);
     jpeg_create_decompress(&cinfo);
-    
+
     // open the file
     FILE *fp = fopen(QFile::encodeName(uri.path()), "rb");
     if (!fp)
@@ -119,31 +124,31 @@ KisImageBuilder_Result KisJPEGConverter::decode(const KURL& uri)
         return (KisImageBuilder_RESULT_NOT_EXIST);
     }
     jpeg_stdio_src(&cinfo, fp);
-    
+
     jpeg_save_markers (&cinfo, JPEG_COM, 0xFFFF);
     /* Save APP0..APP15 markers */
     for (int m = 0; m < 16; m++)
         jpeg_save_markers (&cinfo, JPEG_APP0 + m, 0xFFFF);
 
-    
+
 //     setup_read_icc_profile(&cinfo);
     // read header
     jpeg_read_header(&cinfo, true);
-    
+
     // start reading
     jpeg_start_decompress(&cinfo);
-    
+
     // Get the colorspace
     QString csName = getColorSpaceForColorType(cinfo.out_color_space);
     if(csName.isEmpty()) {
-        kdDebug(41008) << "unsupported colorspace : " << cinfo.out_color_space << endl;
+        kDebug(41008) <<"unsupported colorspace :" << cinfo.out_color_space;
         jpeg_destroy_decompress(&cinfo);
         fclose(fp);
         return KisImageBuilder_RESULT_UNSUPPORTED_COLORSPACE;
     }
     uchar* profile_data;
     uint profile_len;
-    KisProfile* profile = 0;
+    KoColorProfile* profile = 0;
     QByteArray profile_rawdata;
     if( read_icc_profile (&cinfo, &profile_data, &profile_len))
     {
@@ -152,96 +157,96 @@ KisImageBuilder_Result KisJPEGConverter::decode(const KURL& uri)
         cmsHPROFILE hProfile = cmsOpenProfileFromMem(profile_data, (DWORD)profile_len);
 
         if (hProfile != (cmsHPROFILE) NULL) {
-            profile = new KisProfile( profile_rawdata);
+            profile = new KoIccColorProfile( profile_rawdata);
             Q_CHECK_PTR(profile);
-            kdDebug(41008) << "profile name: " << profile->productName() << " profile description: " << profile->productDescription() << " information sur le produit: " << profile->productInfo() << endl;
+//             kDebug(41008) <<"profile name:" << profile->productName() <<" profile description:" << profile->productDescription() <<" information sur le produit:" << profile->productInfo();
             if(!profile->isSuitableForOutput())
             {
-                kdDebug(41008) << "the profile is not suitable for output and therefore cannot be used in krita, we need to convert the image to a standard profile" << endl; // TODO: in ko2 popup a selection menu to inform the user
+                kDebug(41008) <<"the profile is not suitable for output and therefore cannot be used in krita, we need to convert the image to a standard profile"; // TODO: in ko2 popup a selection menu to inform the user
             }
         }
     }
-    
+
     // Retrieve a pointer to the colorspace
-    KisColorSpace* cs;
+    KoColorSpace* cs;
     if (profile && profile->isSuitableForOutput())
     {
-        kdDebug(41008) << "image has embedded profile: " << profile -> productName() << "\n";
-        cs = KisMetaRegistry::instance()->csRegistry()->getColorSpace(csName, profile);
+        kDebug(41008) <<"image has embedded profile:" << profile -> name() <<"";
+        cs = KoColorSpaceRegistry::instance()->colorSpace(csName, profile);
     }
     else
-        cs = KisMetaRegistry::instance()->csRegistry()->getColorSpace(KisID(csName,""),"");
+        cs = KoColorSpaceRegistry::instance()->colorSpace(KoID(csName,""),"");
 
     if(cs == 0)
     {
-        kdDebug(41008) << "unknown colorspace" << endl;
+        kDebug(41008) <<"unknown colorspace";
         jpeg_destroy_decompress(&cinfo);
         fclose(fp);
         return KisImageBuilder_RESULT_UNSUPPORTED_COLORSPACE;
     }
-    
-    // Create the cmsTransform if needed 
-    
+    // TODO fixit
+    // Create the cmsTransform if needed
+
     cmsHTRANSFORM transform = 0;
+#if 0
     if(profile && !profile->isSuitableForOutput())
     {
         transform = cmsCreateTransform(profile->profile(), cs->colorSpaceType(),
-                                       cs->getProfile()->profile() , cs->colorSpaceType(),
+                                       cs->profile()->profile() , cs->colorSpaceType(),
                                        INTENT_PERCEPTUAL, 0);
     }
-    
+#endif
+
     // Creating the KisImageSP
     if( ! m_img) {
         m_img = new KisImage(m_doc->undoAdapter(),  cinfo.image_width,  cinfo.image_height, cs, "built image");
         Q_CHECK_PTR(m_img);
         if(profile && !profile->isSuitableForOutput())
         {
-            m_img -> addAnnotation( new KisAnnotation( profile->productName(), "", profile_rawdata) );
+            m_img -> addAnnotation( KisAnnotationSP(new KisAnnotation( profile->name(), "", profile_rawdata)) );
         }
     }
 
-    KisPaintLayerSP layer = new KisPaintLayer(m_img, m_img -> nextLayerName(), Q_UINT8_MAX);
-    
-    // Read exif information if any
-    
+    KisPaintLayerSP layer = KisPaintLayerSP(new KisPaintLayer(m_img.data(), m_img -> nextLayerName(), quint8_MAX));
+
     // Read data
-    JSAMPROW row_pointer = new JSAMPLE[cinfo.image_width *cinfo.num_components];
-    
+    JSAMPROW row_pointer = new JSAMPLE[cinfo.image_width*cinfo.num_components];
+
     for (; cinfo.output_scanline < cinfo.image_height;) {
-        KisHLineIterator it = layer->paintDevice()->createHLineIterator(0, cinfo.output_scanline, cinfo.image_width, true);
+        KisHLineIterator it = layer->paintDevice()->createHLineIterator(0, cinfo.output_scanline, cinfo.image_width);
         jpeg_read_scanlines(&cinfo, &row_pointer, 1);
-        Q_UINT8 *src = row_pointer;
+        quint8 *src = row_pointer;
         switch(cinfo.out_color_space)
         {
             case JCS_GRAYSCALE:
                 while (!it.isDone()) {
-                    Q_UINT8 *d = it.rawData();
+                    quint8 *d = it.rawData();
                     d[0] = *(src++);
                     if(transform) cmsDoTransform(transform, d, d, 1);
-                    d[1] = Q_UINT8_MAX;
+                    d[1] = quint8_MAX;
                     ++it;
                 }
                 break;
             case JCS_RGB:
                 while (!it.isDone()) {
-                    Q_UINT8 *d = it.rawData();
+                    quint8 *d = it.rawData();
                     d[2] = *(src++);
                     d[1] = *(src++);
                     d[0] = *(src++);
                     if(transform) cmsDoTransform(transform, d, d, 1);
-                    d[3] = Q_UINT8_MAX;
+                    d[3] = quint8_MAX;
                     ++it;
                 }
                 break;
             case JCS_CMYK:
                 while (!it.isDone()) {
-                    Q_UINT8 *d = it.rawData();
-                    d[0] = Q_UINT8_MAX - *(src++);
-                    d[1] = Q_UINT8_MAX - *(src++);
-                    d[2] = Q_UINT8_MAX - *(src++);
-                    d[3] = Q_UINT8_MAX - *(src++);
+                    quint8 *d = it.rawData();
+                    d[0] = quint8_MAX - *(src++);
+                    d[1] = quint8_MAX - *(src++);
+                    d[2] = quint8_MAX - *(src++);
+                    d[3] = quint8_MAX - *(src++);
                     if(transform) cmsDoTransform(transform, d, d, 1);
-                    d[4] = Q_UINT8_MAX;
+                    d[4] = quint8_MAX;
                     ++it;
                 }
                 break;
@@ -249,15 +254,16 @@ KisImageBuilder_Result KisJPEGConverter::decode(const KURL& uri)
                 return KisImageBuilder_RESULT_UNSUPPORTED;
         }
     }
-    
-    m_img->addLayer(layer.data(), m_img->rootLayer(), 0);
-    
-    // Read exif informations
 
-    kdDebug(41008) << "Looking for exif information" << endl;
-    
+    m_img->addLayer(KisLayerSP(layer.data()), m_img->rootLayer(), KisLayerSP(0));
+    layer->setDirty();
+
+    // Read exif information
+
+    kDebug(41008) <<"Looking for exif information";
+
     for (jpeg_saved_marker_ptr marker = cinfo.marker_list; marker != NULL; marker = marker->next) {
-        kdDebug(41008) << "Marker is " << marker->marker << endl;
+        kDebug(41008) <<"Marker is" << marker->marker;
         if (marker->marker != (JOCTET) (JPEG_APP0 + 1) ||
             marker->data_length < 14)
             continue; /* Exif data is in an APP1 marker of at least 14 octets */
@@ -269,58 +275,103 @@ KisImageBuilder_Result KisJPEGConverter::decode(const KURL& uri)
             GETJOCTET (marker->data[4]) != (JOCTET) 0x00 ||
             GETJOCTET (marker->data[5]) != (JOCTET) 0x00)
             continue; /* no Exif header */
-        kdDebug(41008) << "Found exif information of length : "<< marker->data_length << endl;
-        KisExifIO exifIO(layer->paintDevice()->exifInfo());
-        exifIO.readExifFromMem( marker->data , marker->data_length );
+        kDebug(41008) <<"Found exif information of length :"<< marker->data_length;
+        KisMetaData::IOBackend* exifIO = KisMetaData::IOBackendRegistry::instance()->value("exif");
+        Q_ASSERT(exifIO);
+        QByteArray byteArray( (const char*)marker->data + 6, marker->data_length - 6);
+        exifIO->loadFrom( layer->metaData(), new QBuffer( &byteArray ) );
         // Interpret orientation tag
-        ExifValue v;
-        if( layer->paintDevice()->exifInfo()->getValue("Orientation", v) && v.type() == ExifValue::EXIF_TYPE_SHORT)
+        if( layer->metaData()->containsEntry("http://ns.adobe.com/tiff/1.0/", "Orientation"))
         {
-            switch(v.asShort(0)) //
+            KisMetaData::Entry& entry = layer->metaData()->getEntry("http://ns.adobe.com/tiff/1.0/", "Orientation");
+            if(entry.value().type() == KisMetaData::Value::Variant)
             {
-                case 2:
-                    layer->paintDevice()->mirrorY();
-                    break;
-                case 3:
-                    image()->rotate(M_PI, 0);
-                    break;
-                case 4:
-                    layer->paintDevice()->mirrorX();
-                    break;
-                case 5:
-                    image()->rotate(M_PI/2, 0);
-                    layer->paintDevice()->mirrorY();
-                    break;
-                case 6:
-                    image()->rotate(M_PI/2, 0);
-                    break;
-                case 7:
-                    image()->rotate(M_PI/2, 0);
-                    layer->paintDevice()->mirrorX();
-                    break;
-                case 8:
-                    image()->rotate(-M_PI/2 + 2*M_PI, 0);
-                    break;
-                default:
-                    break;
+                switch(entry.value().asVariant().toInt() )
+                {
+                    case 2:
+                        layer->paintDevice()->mirrorY();
+                        break;
+                    case 3:
+                        image()->rotate(M_PI, 0);
+                        break;
+                    case 4:
+                        layer->paintDevice()->mirrorX();
+                        break;
+                    case 5:
+                        image()->rotate(M_PI/2, 0);
+                        layer->paintDevice()->mirrorY();
+                        break;
+                    case 6:
+                        image()->rotate(M_PI/2, 0);
+                        break;
+                    case 7:
+                        image()->rotate(M_PI/2, 0);
+                        layer->paintDevice()->mirrorX();
+                        break;
+                    case 8:
+                        image()->rotate(-M_PI/2+M_PI*2, 0);
+                        break;
+                    default:
+                        break;
+                }
             }
-            v.setValue(0, (Q_UINT16)1);
-            layer->paintDevice()->exifInfo()->setValue("Orientation", v);
+            entry.value().setVariant(1);
         }
         break;
     }
 
+    kDebug(41008) <<"Looking for IPTC information";
+
+    for (jpeg_saved_marker_ptr marker = cinfo.marker_list; marker != NULL; marker = marker->next) {
+        kDebug(41008) <<"Marker is" << marker->marker;
+        if (marker->marker != (JOCTET) (JPEG_APP0 + 13) ||
+            marker->data_length < 14)
+            continue; /* IPTC data is in an APP13 marker of at least 16 octets */
+
+        if( memcmp(marker->data, photoshopMarker, 14) != 0 )
+        {
+            for(int i = 0; i < 14; i++)
+            {
+                kDebug() << (int)(*(marker->data+i)) <<"" << (int)(photoshopMarker[i]);
+            }
+            kDebug(41008) <<"No photoshop marker";
+            break; /* No IPTC Header */
+        }
+
+        kDebug(41008) <<"Found Photoshop information of length :"<< marker->data_length;
+        KisMetaData::IOBackend* iptcIO = KisMetaData::IOBackendRegistry::instance()->value("iptc");
+        Q_ASSERT(iptcIO);
+        const Exiv2::byte *record = 0;
+        uint32_t sizeIptc = 0;
+        uint32_t sizeHdr = 0;
+        // Find actual Iptc data within the APP13 segment
+        if (!Exiv2::Photoshop::locateIptcIrb((Exiv2::byte*)(marker->data + 14),
+                                marker->data_length - 14, &record, &sizeHdr, &sizeIptc ) )
+        {
+            if (sizeIptc) {
+                // Decode the IPTC data
+                QByteArray byteArray( (const char*)(record + sizeHdr), sizeIptc );
+                iptcIO->loadFrom( layer->metaData(), new QBuffer( &byteArray ) );
+            } else {
+                kDebug() <<"IPTC Not found in Photoshop marker";
+            }
+        }
+        break;
+    }
+    // Dump loaded metadata
+    layer->metaData()->debugDump();
+
     // Finish decompression
     jpeg_finish_decompress(&cinfo);
     jpeg_destroy_decompress(&cinfo);
     fclose(fp);
-    delete []row_pointer;
+    delete [] row_pointer;
     return KisImageBuilder_RESULT_OK;
 }
 
 
 
-KisImageBuilder_Result KisJPEGConverter::buildImage(const KURL& uri)
+KisImageBuilder_Result KisJPEGConverter::buildImage(const KUrl& uri)
 {
     if (uri.isEmpty())
         return KisImageBuilder_RESULT_NO_URI;
@@ -334,7 +385,7 @@ KisImageBuilder_Result KisJPEGConverter::buildImage(const KURL& uri)
     QString tmpFile;
 
     if (KIO::NetAccess::download(uri, tmpFile, qApp -> mainWidget())) {
-        KURL uriTF;
+        KUrl uriTF;
         uriTF.setPath( tmpFile );
         result = decode(uriTF);
         KIO::NetAccess::removeTempFile(tmpFile);
@@ -350,12 +401,12 @@ KisImageSP KisJPEGConverter::image()
 }
 
 
-KisImageBuilder_Result KisJPEGConverter::buildFile(const KURL& uri, KisPaintLayerSP layer, vKisAnnotationSP_it annotationsStart, vKisAnnotationSP_it annotationsEnd, KisJPEGOptions options, KisExifInfo* exifInfo)
+KisImageBuilder_Result KisJPEGConverter::buildFile(const KUrl& uri, KisPaintLayerSP layer, vKisAnnotationSP_it annotationsStart, vKisAnnotationSP_it annotationsEnd, KisJPEGOptions options, KisMetaData::Store* metaData)
 {
     if (!layer)
         return KisImageBuilder_RESULT_INVALID_ARG;
 
-    KisImageSP img = layer -> image();
+    KisImageSP img = KisImageSP(layer -> image());
     if (!img)
         return KisImageBuilder_RESULT_EMPTY;
 
@@ -380,63 +431,112 @@ KisImageBuilder_Result KisJPEGConverter::buildFile(const KURL& uri, KisPaintLaye
     cinfo.err = jpeg_std_error(&jerr);
     // Initialize output stream
     jpeg_stdio_dest(&cinfo, fp);
-    
+
     cinfo.image_width = width;  // image width and height, in pixels
     cinfo.image_height = height;
-    cinfo.input_components = img->colorSpace()->nColorChannels(); // number of color channels per pixel */
+    cinfo.input_components = img->colorSpace()->colorChannelCount(); // number of color channels per pixel */
     J_COLOR_SPACE color_type = getColorTypeforColorSpace(img->colorSpace());
     if(color_type == JCS_UNKNOWN)
     {
-        KIO::del(uri);
+        KIO::del(uri); // async, but I guess that's ok
         return KisImageBuilder_RESULT_UNSUPPORTED_COLORSPACE;
     }
     cinfo.in_color_space = color_type;   // colorspace of input image
 
-    
+
     // Set default compression parameters
     jpeg_set_defaults(&cinfo);
     // Customize them
     jpeg_set_quality(&cinfo, options.quality, true);
-    
+
     if(options.progressive)
     {
         jpeg_simple_progression (&cinfo);
     }
-    
+
     // Start compression
     jpeg_start_compress(&cinfo, true);
-    // Save exif information if any available
-    if(exifInfo)
+    // Save exif and iptc information if any available
+
+    if(metaData and not metaData->empty())
     {
-        kdDebug(41008) << "Trying to save exif information" << endl;
-        KisExifIO exifIO(exifInfo);
-        unsigned char* exif_data;
-        unsigned int exif_size;
-        exifIO.saveExifToMem( &exif_data, &exif_size);
-        kdDebug(41008) << "Exif informations size is " << exif_size << endl;
-        if (exif_size < MAX_DATA_BYTES_IN_MARKER)
+        // Save EXIF
         {
-            jpeg_write_marker(&cinfo, JPEG_APP0 + 1, exif_data, exif_size);
-        } else {
-            kdDebug(41008) << "exif informations couldn't be saved." << endl;
+            kDebug(41008) <<"Trying to save exif information";
+
+            KisMetaData::IOBackend* exifIO = KisMetaData::IOBackendRegistry::instance()->value("exif");
+            Q_ASSERT(exifIO);
+
+            QBuffer buffer;
+            exifIO->saveTo( metaData, &buffer);
+
+            kDebug(41008) <<"Exif information size is" << buffer.data().size();
+            QByteArray header(6,0);
+            header[0] = 0x45;
+            header[1] = 0x78;
+            header[2] = 0x69;
+            header[3] = 0x66;
+            header[4] = 0x00;
+            header[5] = 0x00;
+
+            QByteArray data = buffer.data();
+            data.prepend(header);
+            if (data.size() < MAX_DATA_BYTES_IN_MARKER)
+            {
+                jpeg_write_marker(&cinfo, JPEG_APP0 + 1, (const JOCTET*)data.data(), data.size());
+            } else {
+                kDebug(41008) <<"EXIF information couldn't be saved."; // TODO: warn the user ?
+            }
+        }
+        // Save IPTC
+        {
+            kDebug(41008) <<"Trying to save exif information";
+            KisMetaData::IOBackend* iptcIO = KisMetaData::IOBackendRegistry::instance()->value("iptc");
+            Q_ASSERT(iptcIO);
+
+            QBuffer buffer;
+            iptcIO->saveTo( metaData, &buffer);
+
+            QByteArray header;
+            header.append( photoshopMarker );
+            header.append( QByteArray(1, 0) ); // Null terminated string
+            header.append( photoshopBimId_ );
+            header.append( photoshopIptc_ );
+            header.append( QByteArray(2, 0) );
+            qint32 size = buffer.size();
+            QByteArray sizeArray(4,0);
+            sizeArray[0] = (char)((size & 0xff000000) >> 24);
+            sizeArray[1] = (char)((size & 0x00ff0000) >> 16);
+            sizeArray[2] = (char)((size & 0x0000ff00) >> 8);
+            sizeArray[3] =  (char)(size & 0x000000ff);
+            header.append( sizeArray);
+
+            kDebug(41008) <<"IPTC information size is" << buffer.data().size() <<" and header is of size =" << header.size();
+            QByteArray data = buffer.data();
+            data.prepend(header);
+            if (data.size() < MAX_DATA_BYTES_IN_MARKER)
+            {
+                jpeg_write_marker(&cinfo, JPEG_APP0 + 13, (const JOCTET*)data.data(), data.size());
+            } else {
+                kDebug(41008) <<"IPTC information couldn't be saved."; // TODO: warn the user ?
+            }
         }
     }
-    
 
     // Save annotation
     vKisAnnotationSP_it it = annotationsStart;
     while(it != annotationsEnd) {
         if (!(*it) || (*it) -> type() == QString()) {
-            kdDebug(41008) << "Warning: empty annotation" << endl;
+            kDebug(41008) <<"Warning: empty annotation";
             ++it;
             continue;
         }
 
-        kdDebug(41008) << "Trying to store annotation of type " << (*it) -> type() << " of size " << (*it) -> annotation() . size() << endl;
+        kDebug(41008) <<"Trying to store annotation of type" << (*it) -> type() <<" of size" << (*it) -> annotation() . size();
 
         if ((*it) -> type().startsWith("krita_attribute:")) { // Attribute
             // FIXME
-            kdDebug(41008) << "can't save this annotation : " << (*it) -> type() << endl;
+            kDebug(41008) <<"can't save this annotation :" << (*it) -> type();
         } else { // Profile
             //char* name = new char[(*it)->type().length()+1];
             write_icc_profile(& cinfo, (uchar*)(*it)->annotation().data(), (*it)->annotation().size());
@@ -444,28 +544,28 @@ KisImageBuilder_Result KisJPEGConverter::buildFile(const KURL& uri, KisPaintLaye
         ++it;
     }
 
-    
+
     // Write data information
-    
+
     JSAMPROW row_pointer = new JSAMPLE[width*cinfo.input_components];
-    int color_nb_bits = 8 * layer->paintDevice()->pixelSize() / layer->paintDevice()->nChannels();
-    
+    int color_nb_bits = 8 * layer->paintDevice()->pixelSize() / layer->paintDevice()->channelCount();
+
     for (; cinfo.next_scanline < height;) {
-        KisHLineIterator it = layer->paintDevice()->createHLineIterator(0, cinfo.next_scanline, width, false);
-        Q_UINT8 *dst = row_pointer;
+        KisHLineConstIterator it = layer->paintDevice()->createHLineConstIterator(0, cinfo.next_scanline, width);
+        quint8 *dst = row_pointer;
         switch(color_type)
         {
             case JCS_GRAYSCALE:
                 if(color_nb_bits == 16)
                 {
                     while (!it.isDone()) {
-                        const Q_UINT16 *d = reinterpret_cast<const Q_UINT16 *>(it.rawData());
-                        *(dst++) = d[0] / Q_UINT8_MAX;
+                        const quint16 *d = reinterpret_cast<const quint16 *>(it.rawData());
+                        *(dst++) = d[0] / quint8_MAX;
                         ++it;
                     }
                 } else {
                     while (!it.isDone()) {
-                        const Q_UINT8 *d = it.rawData();
+                        const quint8 *d = it.rawData();
                         *(dst++) = d[0];
                         ++it;
                     }
@@ -475,15 +575,15 @@ KisImageBuilder_Result KisJPEGConverter::buildFile(const KURL& uri, KisPaintLaye
                 if(color_nb_bits == 16)
                 {
                     while (!it.isDone()) {
-                        const Q_UINT16 *d = reinterpret_cast<const Q_UINT16 *>(it.rawData());
-                        *(dst++) = d[2] / Q_UINT8_MAX;
-                        *(dst++) = d[1] / Q_UINT8_MAX;
-                        *(dst++) = d[0] / Q_UINT8_MAX;
+                        const quint16 *d = reinterpret_cast<const quint16 *>(it.rawData());
+                        *(dst++) = d[2] / quint8_MAX;
+                        *(dst++) = d[1] / quint8_MAX;
+                        *(dst++) = d[0] / quint8_MAX;
                         ++it;
                     }
                 } else {
                     while (!it.isDone()) {
-                        const Q_UINT8 *d = it.rawData();
+                        const quint8 *d = it.rawData();
                         *(dst++) = d[2];
                         *(dst++) = d[1];
                         *(dst++) = d[0];
@@ -495,40 +595,42 @@ KisImageBuilder_Result KisJPEGConverter::buildFile(const KURL& uri, KisPaintLaye
                 if(color_nb_bits == 16)
                 {
                     while (!it.isDone()) {
-                        const Q_UINT16 *d = reinterpret_cast<const Q_UINT16 *>(it.rawData());
-                        *(dst++) = Q_UINT8_MAX - d[0] / Q_UINT8_MAX;
-                        *(dst++) = Q_UINT8_MAX - d[1] / Q_UINT8_MAX;
-                        *(dst++) = Q_UINT8_MAX - d[2] / Q_UINT8_MAX;
-                        *(dst++) = Q_UINT8_MAX - d[3] / Q_UINT8_MAX;
+                        const quint16 *d = reinterpret_cast<const quint16 *>(it.rawData());
+                        *(dst++) = quint8_MAX - d[0] / quint8_MAX;
+                        *(dst++) = quint8_MAX - d[1] / quint8_MAX;
+                        *(dst++) = quint8_MAX - d[2] / quint8_MAX;
+                        *(dst++) = quint8_MAX - d[3] / quint8_MAX;
                         ++it;
                     }
                 } else {
                     while (!it.isDone()) {
-                        const Q_UINT8 *d = it.rawData();
-                        *(dst++) = Q_UINT8_MAX - d[0];
-                        *(dst++) = Q_UINT8_MAX - d[1];
-                        *(dst++) = Q_UINT8_MAX - d[2];
-                        *(dst++) = Q_UINT8_MAX - d[3];
+                        const quint8 *d = it.rawData();
+                        *(dst++) = quint8_MAX - d[0];
+                        *(dst++) = quint8_MAX - d[1];
+                        *(dst++) = quint8_MAX - d[2];
+                        *(dst++) = quint8_MAX - d[3];
                         ++it;
                     }
                 }
                 break;
             default:
-                KIO::del(uri);
+                KIO::del(uri); // asynchronous, but I guess that's ok
+                delete [] row_pointer;
+                jpeg_destroy_compress(&cinfo);
                 return KisImageBuilder_RESULT_UNSUPPORTED;
         }
         jpeg_write_scanlines(&cinfo, &row_pointer, 1);
     }
-    
 
-    // Writting is over
+
+    // Writing is over
     jpeg_finish_compress(&cinfo);
     fclose(fp);
-    
+
     delete [] row_pointer;
     // Free memory
     jpeg_destroy_compress(&cinfo);
-    
+
     return KisImageBuilder_RESULT_OK;
 }
 
