@@ -16,72 +16,63 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  */
-#include "config.h" 
- 
-#ifdef HAVE_SYS_TYPES_H 
-   #include <sys/types.h> 
-#endif 
 
 #include <sys/types.h>
 #include <netinet/in.h>
 
-#include <qstring.h>
-#include <qfile.h>
-#include <qimage.h>
-#include <qradiobutton.h>
-#include <qgroupbox.h>
-#include <qbuttongroup.h>
-#include <qpushbutton.h>
-#include <qlabel.h>
-#include <qcheckbox.h>
-#include <qapplication.h>
-#include <qcursor.h>
-#include <qeventloop.h>
-#include <qprogressdialog.h>
-#include <qtimer.h>
+#include <QString>
+#include <QFile>
+#include <QImage>
+#include <QRadioButton>
+#include <q3groupbox.h>
+#include <q3buttongroup.h>
+#include <QPushButton>
+#include <QLabel>
+#include <QCheckBox>
+#include <QApplication>
+#include <QCursor>
+#include <QEventLoop>
+#include <QProgressDialog>
+#include <QTimer>
 
 #include <kglobal.h>
 #include <kconfig.h>
 #include <knuminput.h>
 #include <kgenericfactory.h>
-#include <kdialogbase.h>
 #include <kdialog.h>
 #include <kmessagebox.h>
 #include <klocale.h>
-#include <kprocess.h>
+#include <k3process.h>
 
 #include <KoDocument.h>
 #include <KoFilterChain.h>
+#include <KoCompositeOp.h>
 
-#include "imageviewer.h"
 #include "kis_config.h"
 #include "kis_cmb_idlist.h"
 #include "kis_types.h"
 #include "kis_raw_import.h"
-#include "kis_doc.h"
+#include "kis_doc2.h"
 #include "kis_image.h"
-#include "kis_meta_registry.h"
 #include "kis_layer.h"
 #include "kis_annotation.h"
-#include "kis_profile.h"
-#include "kis_colorspace_factory_registry.h"
+#include "KoColorProfile.h"
+#include "KoColorSpaceRegistry.h"
 #include "kis_iterators_pixel.h"
-#include "kis_abstract_colorspace.h"
 #include "kis_paint_device.h"
 #include "kis_paint_layer.h"
-#include "wdgrawimport.h"
+#include "kis_undo_adapter.h"
 
-typedef KGenericFactory<KisRawImport, KoFilter> KisRawImportFactory;
+typedef KGenericFactory<KisRawImport> KisRawImportFactory;
 K_EXPORT_COMPONENT_FACTORY(libkrita_raw_import, KisRawImportFactory("kofficefilters"))
 
-KisRawImport::KisRawImport(KoFilter *, const char *, const QStringList&)
-    : KoFilter()
+KisRawImport::KisRawImport(QObject *parent, const QStringList&)
+    : KoFilter(parent)
     , m_data(0)
     , m_process(0)
     , m_progress(0)
-    , m_err(false)
 {
-    m_dialog = new KDialogBase();
+    m_dialog = new KDialog();
     m_dialog->enableButtonApply(false);
     m_page = new WdgRawImport(m_dialog);
     m_dialog -> setMainWidget(m_page);
@@ -92,7 +83,7 @@ KisRawImport::KisRawImport(KoFilter *, const char *, const QStringList&)
 
     KisConfig cfg;
     QString monitorProfileName = cfg.monitorProfile();
-    m_monitorProfile = KisMetaRegistry::instance()->csRegistry()->getProfileByName(monitorProfileName);
+    m_monitorProfile = KoColorSpaceRegistry::instance()->profileByName(monitorProfileName);
 
     slotFillCmbProfiles();
 }
@@ -103,19 +94,15 @@ KisRawImport::~KisRawImport()
     delete m_process;
 }
 
-KoFilter::ConversionStatus KisRawImport::convert(const QCString& from, const QCString& to)
+KoFilter::ConversionStatus KisRawImport::convert(const QByteArray& from, const QByteArray& to)
 {
-    if (from != "image/x-raw" || to != "application/x-krita") {
+    if (from != "image/x-dcraw" || to != "application/x-krita") {
         return KoFilter::NotImplemented;
     }
 
-    if (m_err) {
-        return KoFilter::CreationError;
-    }
+    kDebug(41008) <<"Krita importing from Raw";
 
-    kdDebug(41008) << "Krita importing from Raw\n";
-
-    KisDoc * doc = dynamic_cast<KisDoc*>(m_chain -> outputDocument());
+    KisDoc2 * doc = dynamic_cast<KisDoc2*>(m_chain -> outputDocument());
     if (!doc) {
         return KoFilter::CreationError;
     }
@@ -134,29 +121,29 @@ KoFilter::ConversionStatus KisRawImport::convert(const QCString& from, const QCS
     m_dialog->setCursor(Qt::ArrowCursor);
     QApplication::setOverrideCursor(Qt::ArrowCursor);
 
-    KConfig * cfg = KGlobal::config();
+    KSharedConfig::Ptr cfg = KGlobal::config();
     cfg->setGroup("rawimport");
-    
-    m_page->radioGray->setChecked(cfg->readBoolEntry("gray", false));
-    m_page->radioRGB->setChecked(cfg->readBoolEntry("rgb", true));
-    m_page->radio8->setChecked(cfg->readBoolEntry("8bit", false));
-    m_page->radio16->setChecked(cfg->readBoolEntry("16bit", true));
-    m_page->chkFourColorRGB->setChecked( cfg->readBoolEntry("four_color_rgb", false));
-    m_page->chkCameraColors->setChecked( cfg->readBoolEntry("camera_colors", false));
-    m_page->chkBrightness->setChecked( cfg->readBoolEntry("do_brightness", false));
-    m_page->chkBlackpoint->setChecked( cfg->readBoolEntry("do_blackpoint", false));
-    m_page->chkRed->setChecked( cfg->readBoolEntry("do_red", false));
-    m_page->chkBlue->setChecked( cfg->readBoolEntry("do_blue", false));
-    m_page->radioFixed->setChecked( cfg->readBoolEntry("fixed_wb", true));
-    m_page->radioAutomatic->setChecked( cfg->readBoolEntry("automatic_wb", false));
-    m_page->radioCamera->setChecked( cfg->readBoolEntry("camera_wb", false));
-    m_page->chkClip->setChecked( cfg->readBoolEntry("clip", true));
-    m_page->chkProfile->setChecked(cfg->readBoolEntry("useprofile", false));
-    m_page->dblBrightness->setValue(cfg->readDoubleNumEntry("brightness", 1.0));
-    m_page->dblBlackpoint->setValue(cfg->readDoubleNumEntry("blackpoint", 0));
-    m_page->dblRed->setValue(cfg->readDoubleNumEntry("red", 1.0));
-    m_page->dblBlue->setValue(cfg->readDoubleNumEntry("blue", 1.0));
-    
+
+    m_page->radioGray->setChecked(cfg->readEntry("gray", false));
+    m_page->radioRGB->setChecked(cfg->readEntry("rgb", true));
+    m_page->radio8->setChecked(cfg->readEntry("8bit", false));
+    m_page->radio16->setChecked(cfg->readEntry("16bit", true));
+    m_page->chkFourColorRGB->setChecked( cfg->readEntry("four_color_rgb", false));
+    m_page->chkCameraColors->setChecked( cfg->readEntry("camera_colors", false));
+    m_page->chkBrightness->setChecked( cfg->readEntry("do_brightness", false));
+    m_page->chkBlackpoint->setChecked( cfg->readEntry("do_blackpoint", false));
+    m_page->chkRed->setChecked( cfg->readEntry("do_red", false));
+    m_page->chkBlue->setChecked( cfg->readEntry("do_blue", false));
+    m_page->radioFixed->setChecked( cfg->readEntry("fixed_wb", true));
+    m_page->radioAutomatic->setChecked( cfg->readEntry("automatic_wb", false));
+    m_page->radioCamera->setChecked( cfg->readEntry("camera_wb", false));
+    m_page->chkClip->setChecked( cfg->readEntry("clip", true));
+    m_page->chkProfile->setChecked(cfg->readEntry("useprofile", false));
+    m_page->dblBrightness->setValue(cfg->readEntry("brightness", 1.0));
+    m_page->dblBlackpoint->setValue(cfg->readEntry("blackpoint", 0));
+    m_page->dblRed->setValue(cfg->readEntry("red", 1.0));
+    m_page->dblBlue->setValue(cfg->readEntry("blue", 1.0));
+
     if (m_dialog->exec() == QDialog::Accepted) {
 
         cfg->writeEntry("gray", m_page->radioGray->isChecked());
@@ -179,10 +166,10 @@ KoFilter::ConversionStatus KisRawImport::convert(const QCString& from, const QCS
         cfg->writeEntry("red", m_page->dblRed->value());
         cfg->writeEntry("blue", m_page->dblBlue->value());
 
-        QApplication::setOverrideCursor(Qt::waitCursor);
+        QApplication::setOverrideCursor(Qt::WaitCursor);
         // Create a busy indicator to show that we didn't die or so
         m_progress = new QProgressDialog();
-        m_progress -> setTotalSteps(0);
+        m_progress -> setMaximum(0);
         m_progress -> setCancelButton(0);
         QTimer timer;
         connect(&timer, SIGNAL(timeout()), this, SLOT(incrementProgress()));
@@ -192,9 +179,9 @@ KoFilter::ConversionStatus KisRawImport::convert(const QCString& from, const QCS
 
         getImageData(createArgumentList(false));
 
-        KisImageSP image = 0;
-        KisPaintLayerSP layer = 0;
-        KisPaintDeviceSP device = 0;
+        KisImageSP image = KisImageSP(0);
+        KisPaintLayerSP layer = KisPaintLayerSP(0);
+        KisPaintDeviceSP device = KisPaintDeviceSP(0);
 
         QApplication::restoreOverrideCursor();
 
@@ -207,34 +194,34 @@ KoFilter::ConversionStatus KisRawImport::convert(const QCString& from, const QCS
             QImage img;
             img.loadFromData(*m_data);
 
-            KisColorSpace * cs = 0;
+            KoColorSpace * cs = 0;
             if (m_page->radioGray->isChecked()) {
-                cs  = KisMetaRegistry::instance()->csRegistry()->getColorSpace( KisID("GRAYA"), profile() );
+                cs  = KoColorSpaceRegistry::instance()->colorSpace( "GRAYA", profile() );
             }
             else {
-               cs  = KisMetaRegistry::instance()->csRegistry()->getColorSpace( KisID("RGBA"), profile() );
+               cs  = KoColorSpaceRegistry::instance()->colorSpace( "RGBA", profile() );
             }
-            if (cs == 0) { kdDebug() << "No CS\n"; return KoFilter::InternalError; }
+            if (cs == 0) { kDebug() <<"No CS"; return KoFilter::InternalError; }
 
             image = new KisImage(doc->undoAdapter(), img.width(), img.height(), cs, filename);
-            if (image == 0) return KoFilter::CreationError;
-            image->blockSignals(true); // Don't send out signals while we're building the image
-            
-            layer = dynamic_cast<KisPaintLayer*>( image->newLayer(image -> nextLayerName(), OPACITY_OPAQUE).data() );
-            if (layer == 0) return KoFilter::CreationError;
+            if (image.isNull()) return KoFilter::CreationError;
+            image->lock();
+
+            layer = dynamic_cast<KisPaintLayer*>( image->newLayer(image -> nextLayerName(), OPACITY_OPAQUE, COMPOSITE_OVER, cs).data());
+            if (layer.isNull()) return KoFilter::CreationError;
 
             device = layer->paintDevice();
-            if (device == 0) return KoFilter::CreationError;
+            if (device.isNull()) return KoFilter::CreationError;
 
             device->convertFromQImage(img, "");
 
         } else {
         // 16 bits
 
-            Q_UINT32 startOfImagedata = 0;
+            quint32 startOfImagedata = 0;
             QSize sz = determineSize(startOfImagedata);
 
-            kdDebug(41008) << "Total bytes: " << m_data->size()
+            kDebug(41008) <<"Total bytes:" << m_data->size()
                     << "\n start of image data: " << startOfImagedata
                     << "\n bytes for pixels left: " << m_data->size() - startOfImagedata
                     << "\n total pixels: " << sz.width() * sz.height()
@@ -245,52 +232,53 @@ KoFilter::ConversionStatus KisRawImport::convert(const QCString& from, const QCS
 
             char * data = m_data->data() + startOfImagedata;
 
-            KisColorSpace * cs = 0;
+            KoColorSpace * cs = 0;
             if (m_page->radioGray->isChecked()) {
-                cs  = KisMetaRegistry::instance()->csRegistry()->getColorSpace( KisID("GRAYA16"), profile() );
+                cs  = KoColorSpaceRegistry::instance()->colorSpace( "GRAYA16", profile() );
             }
             else {
-                cs = KisMetaRegistry::instance()->csRegistry()->getColorSpace( KisID("RGBA16"), profile() );
+                cs = KoColorSpaceRegistry::instance()->colorSpace( "RGBA16", profile() );
             }
             if (cs == 0) return KoFilter::InternalError;
 
             image = new KisImage( doc->undoAdapter(), sz.width(), sz.height(), cs, filename);
-            if (image == 0)return KoFilter::CreationError;
+            if (image.isNull()) return KoFilter::CreationError;
+            image->lock();
 
-            layer = dynamic_cast<KisPaintLayer*> (image->newLayer(image -> nextLayerName(), OPACITY_OPAQUE).data());
-            if (layer == 0) return KoFilter::CreationError;
+            layer = dynamic_cast<KisPaintLayer*> (image->newLayer(image -> nextLayerName(), OPACITY_OPAQUE, COMPOSITE_OVER, cs).data());
+            if (layer.isNull()) return KoFilter::CreationError;
 
             device = layer->paintDevice();
-            if (device == 0) return KoFilter::CreationError;
+            if (device.isNull()) return KoFilter::CreationError;
 
             // Copy the colordata to the pixels
             int pos = 0;
 
             for (int line = 0; line < sz.height(); ++line) {
-                KisHLineIterator it = device->createHLineIterator(0, line, sz.width(), true);
+                KisHLineIterator it = device->createHLineIterator(0, line, sz.width());
 
                 while (!it.isDone()) {
                     if (m_page->radioGray->isChecked()) {
-                        Q_UINT16 d = (Q_INT16)*(data + pos);
+                        quint16 d = (qint16)*(data + pos);
                         d = ntohs(d);
                         memcpy(it.rawData(), &d, 2);
                         pos += 2;
                     }
                     else {
                         // Red
-                        Q_UINT16 d = (Q_INT16)*(data + pos);
+                        quint16 d = (qint16)*(data + pos);
                         d = ntohs(d);
                         memcpy(it.rawData() + 4, &d, 2);
-                        
+
                         // Green
                         pos += 2;
-                        d = (Q_INT16)*(data + pos );
+                        d = (qint16)*(data + pos );
                         d = ntohs(d);
                         memcpy(it.rawData() + 2, &d, 2);
 
                         // Blue
                         pos += 2;
-                        d = (Q_INT16)*(data + pos );
+                        d = (qint16)*(data + pos );
                         d = ntohs(d);
                         memcpy(it.rawData(), &d, 2);
 
@@ -302,13 +290,14 @@ KoFilter::ConversionStatus KisRawImport::convert(const QCString& from, const QCS
             }
         }
         layer->setDirty();
-        kdDebug() << "going to set image\n";
+        kDebug() <<"going to set image";
         doc -> setCurrentImage(image);
         doc -> undoAdapter() -> setUndo(true);
         doc -> setModified(false);
-        kdDebug() << "everything ok\n";
+        kDebug() <<"everything ok";
 
         QApplication::restoreOverrideCursor();
+        image->unlock();
         return KoFilter::OK;
     }
 
@@ -318,16 +307,16 @@ KoFilter::ConversionStatus KisRawImport::convert(const QCString& from, const QCS
 
 void KisRawImport::incrementProgress()
 {
-    m_progress -> setProgress(m_progress -> progress() + 10);
+    m_progress -> setValue(m_progress -> value() + 10);
 }
 
 
 void KisRawImport::slotUpdatePreview()
 {
-    QApplication::setOverrideCursor(Qt::waitCursor);
+    QApplication::setOverrideCursor(Qt::WaitCursor);
     getImageData(createArgumentList(true));
 
-    kdDebug(41008) << "Retrieved " << m_data->size() << " bytes of image data\n";
+    kDebug(41008) <<"Retrieved" << m_data->size() <<" bytes of image data";
 
     if (m_data->isNull()) return;
 
@@ -340,10 +329,10 @@ void KisRawImport::slotUpdatePreview()
     } else {
         // 16 bits
 
-        Q_UINT32 startOfImagedata = 0;
+        quint32 startOfImagedata = 0;
         QSize sz = determineSize(startOfImagedata);
 
-        kdDebug(41008) << "Total bytes: " << m_data->size()
+        kDebug(41008) <<"Total bytes:" << m_data->size()
                   << "\n start of image data: " << startOfImagedata
                   << "\n bytes for pixels left: " << m_data->size() - startOfImagedata
                   << "\n total pixels: " << sz.width() * sz.height()
@@ -353,42 +342,42 @@ void KisRawImport::slotUpdatePreview()
 
         char * data = m_data->data() + startOfImagedata;
 
-        KisColorSpace * cs = 0;
+        KoColorSpace * cs = 0;
         if (m_page->radioGray->isChecked()) {
-            cs  = KisMetaRegistry::instance()->csRegistry()->getColorSpace( KisID("GRAYA16"), profile() );
+            cs  = KoColorSpaceRegistry::instance()->colorSpace( "GRAYA16", profile() );
         }
         else {
-            cs = KisMetaRegistry::instance()->csRegistry()->getColorSpace( KisID("RGBA16"), profile() );
+            cs = KoColorSpaceRegistry::instance()->colorSpace( "RGBA16", profile() );
         }
         KisPaintDevice * dev = new KisPaintDevice(cs, "preview");
             // Copy the colordata to the pixels
         int pos = 0;
 
         for (int line = 0; line < sz.height(); ++line) {
-            KisHLineIterator it = dev->createHLineIterator(0, line, sz.width(), true);
+            KisHLineIterator it = dev->createHLineIterator(0, line, sz.width());
 
             while (!it.isDone()) {
                 if (m_page->radioGray->isChecked()) {
-                    Q_UINT16 d = (Q_INT16)*(data + pos);
+                    quint16 d = (qint16)*(data + pos);
                     d = ntohs(d);
                     memcpy(it.rawData(), &d, 2);
                     pos += 2;
                 }
                 else {
                             // Red
-                        Q_UINT16 d = (Q_INT16)*(data + pos);
+                        quint16 d = (qint16)*(data + pos);
                         d = ntohs(d);
                         memcpy(it.rawData() + 4, &d, 2);
-                            
+
                             // Green
                         pos += 2;
-                        d = (Q_INT16)*(data + pos );
+                        d = (qint16)*(data + pos );
                         d = ntohs(d);
                         memcpy(it.rawData() + 2, &d, 2);
-    
+
                             // Blue
                         pos += 2;
-                        d = (Q_INT16)*(data + pos );
+                        d = (qint16)*(data + pos );
                         d = ntohs(d);
                         memcpy(it.rawData(), &d, 2);
 
@@ -412,8 +401,8 @@ void KisRawImport::getImageData( QStringList arguments )
     //    delete m_process;
     delete m_data;
 
-    kdDebug(41008) << "getImageData " << arguments.join(" ") << "\n";
-    KProcess process (this);
+    kDebug(41008) <<"getImageData" << arguments.join("") <<"";
+    K3Process process (this);
     m_data = new QByteArray(0);
 
     for (QStringList::iterator it = arguments.begin(); it != arguments.end(); ++it) {
@@ -421,28 +410,27 @@ void KisRawImport::getImageData( QStringList arguments )
     }
 
     process.setUseShell(true);
-    connect(&process, SIGNAL(receivedStdout(KProcess *, char *, int)), this, SLOT(slotReceivedStdout(KProcess *, char *, int)));
-    connect(&process, SIGNAL(receivedStderr(KProcess *, char *, int)), this, SLOT(slotReceivedStderr(KProcess *, char *, int)));
-    connect(&process, SIGNAL(processExited(KProcess *)), this, SLOT(slotProcessDone()));
+    connect(&process, SIGNAL(receivedStdout(K3Process *, char *, int)), this, SLOT(slotReceivedStdout(K3Process *, char *, int)));
+    connect(&process, SIGNAL(receivedStderr(K3Process *, char *, int)), this, SLOT(slotReceivedStderr(K3Process *, char *, int)));
+    connect(&process, SIGNAL(processExited(K3Process *)), this, SLOT(slotProcessDone()));
 
 
-    kdDebug(41008) << "Starting process\n";
+    kDebug(41008) <<"Starting process";
 
-    if (!process.start(KProcess::NotifyOnExit, KProcess::AllOutput)) {
+    if (!process.start(K3Process::NotifyOnExit, K3Process::AllOutput)) {
         KMessageBox::error( 0, i18n("Cannot convert RAW files because the dcraw executable could not be started."));
     }
     while (process.isRunning()) {
-        //kdDebug(41008) << "Waiting...\n";
-        qApp->eventLoop()->processEvents(QEventLoop::ExcludeUserInput);
+        //kDebug(41008) <<"Waiting...";
+        qApp->processEvents(QEventLoop::ExcludeUserInput);
         //process.wait(2);
     }
 
     if (process.normalExit()) {
-        kdDebug(41008) << "Return value of process: " << process.exitStatus() << "\n";
+        kDebug(41008) <<"Return value of process:" << process.exitStatus() <<"";
     }
     else {
-        kdDebug(41008) << "Process did not exit normally. Exit signal: " << process.exitSignal() << "\n";
-        m_err = true;
+        kDebug(41008) <<"Process did not exit normally. Exit signal:" << process.exitSignal() <<"";
     }
 
 }
@@ -450,25 +438,24 @@ void KisRawImport::getImageData( QStringList arguments )
 
 void KisRawImport::slotProcessDone()
 {
-    kdDebug(41008) << "process done!\n";
+    kDebug(41008) <<"process done!";
 }
 
-void KisRawImport::slotReceivedStdout(KProcess *, char *buffer, int buflen)
+void KisRawImport::slotReceivedStdout(K3Process *, char *buffer, int buflen)
 {
-    //kdDebug(41008) << "stdout received " << buflen << " bytes on stdout.\n";
-    //kdDebug(41008) << QString::fromAscii(buffer, buflen) << "\n";
+    //kDebug(41008) <<"stdout received" << buflen <<" bytes on stdout.";
+    //kDebug(41008) << QString::fromAscii(buffer, buflen) <<"";
     int oldSize = m_data->size();
-    m_data->resize(oldSize + buflen, QGArray::SpeedOptim);
+    m_data->resize(oldSize + buflen);
     memcpy(m_data->data() + oldSize, buffer, buflen);
 }
 
-void KisRawImport::slotReceivedStderr(KProcess *, char *buffer, int buflen)
+void KisRawImport::slotReceivedStderr(K3Process *, char *buffer, int buflen)
 {
     QByteArray b(buflen);
     memcpy(b.data(), buffer, buflen);
-    kdDebug(41008) << QString(b) << "\n";
-    KMessageBox::error(0, i18n("Error: Dcraw cannot load this image. Message: ") + QString(b));
-    m_err = true;
+    kDebug(41008) << QString(b) <<"";
+    //KMessageBox::error(0, i18n("dcraw says: ") + QString(b));
 }
 
 
@@ -520,7 +507,7 @@ QStringList KisRawImport::createArgumentList(bool forPreview)
     if (m_page->chkBrightness->isChecked()) {
         args.append("-b " + QString::number(m_page->dblBrightness->value()));
     }
-    
+
     if (m_page->chkBlackpoint->isChecked()) {
         args.append("-k " + QString::number(m_page->dblBlackpoint->value()));
     }
@@ -528,19 +515,19 @@ QStringList KisRawImport::createArgumentList(bool forPreview)
     if (m_page->chkRed->isChecked()) {
         args.append("-r " + QString::number(m_page->dblRed->value()));
     }
-    
+
     if (m_page->chkBlue->isChecked()) {
         args.append("-l " + QString::number(m_page->dblBlue->value()));
     }
 
-    
-    KisProfile * pf  = profile();
+
+    KoColorProfile * pf  = profile();
     if (m_page->chkProfile->isChecked()) {
-        if (!pf->filename().isNull()) {
+        if (!pf->fileName().isNull()) {
             // Use the user-set profile, if it's not an lcms internal
             // profile. This does not add the profile to the image, we
             // need to do that later.
-            args.append("-p \"" + pf->filename() + "\"");
+            args.append("-p \"" + pf->fileName() + "\"");
         }
     }
 
@@ -550,7 +537,7 @@ QStringList KisRawImport::createArgumentList(bool forPreview)
     return args;
 }
 
-QSize KisRawImport::determineSize(Q_UINT32& startOfImageData)
+QSize KisRawImport::determineSize(quint32& startOfImageData)
 {
     if (m_data->isNull() || m_data->size() < 2048) {
         startOfImageData = 0;
@@ -559,14 +546,14 @@ QSize KisRawImport::determineSize(Q_UINT32& startOfImageData)
 
     QString magick = QString::fromAscii(m_data->data(), 2);
     if (magick != "P6") {
-        kdDebug(41008) << " Bad magick! " << magick << "\n";
+        kDebug(41008) <<" Bad magick!" << magick <<"";
         startOfImageData = 0;
         return QSize(0,0);
     }
 
     // Find the third newline that marks the header end in a dcraw generated ppm.
-    Q_UINT32 i = 0;
-    Q_UINT32 counter = 0;
+    quint32 i = 0;
+    quint32 counter = 0;
 
     while (true) {
         if (counter == 3) break;
@@ -577,20 +564,20 @@ QSize KisRawImport::determineSize(Q_UINT32& startOfImageData)
     }
 
     QString size = QStringList::split("\n", QString::fromAscii(m_data->data(), i))[1];
-    kdDebug(41008) << "Header: " << QString::fromAscii(m_data->data(), i) << "\n";
+    kDebug(41008) <<"Header:" << QString::fromAscii(m_data->data(), i) <<"";
     QStringList sizelist = QStringList::split(" ", size);
-    Q_INT32 w = sizelist[0].toInt();
-    Q_INT32 h = sizelist[1].toInt();
+    qint32 w = sizelist[0].toInt();
+    qint32 h = sizelist[1].toInt();
 
     startOfImageData = i;
     return QSize(w, h);
 
 }
 
-KisProfile * KisRawImport::profile()
+KoColorProfile * KisRawImport::profile()
 {
     if (m_page->chkProfile->isChecked()) {
-        return KisMetaRegistry::instance()->csRegistry()->getProfileByName(m_page->cmbProfile->currentText());
+        return KoColorSpaceRegistry::instance()->profileByName(m_page->cmbProfile->currentText());
     }
     else
         return 0;
@@ -598,33 +585,33 @@ KisProfile * KisRawImport::profile()
 
 void KisRawImport::slotFillCmbProfiles()
 {
-    KisID s = getColorSpace();
+    KoID s = colorSpace();
 
-    KisColorSpaceFactory * csf = KisMetaRegistry::instance()->csRegistry() -> get(s);
+    KoColorSpaceFactory * csf = KoColorSpaceRegistry::instance() -> value(s.id());
     m_page -> cmbProfile -> clear();
-    QValueVector<KisProfile *>  profileList = KisMetaRegistry::instance()->csRegistry()->profilesFor( csf );
-        QValueVector<KisProfile *> ::iterator it;
-        for ( it = profileList.begin(); it != profileList.end(); ++it ) {
-        m_page -> cmbProfile -> insertItem((*it) -> productName());
+    QList<KoColorProfile *>  profileList = KoColorSpaceRegistry::instance()->profilesFor( csf );
+
+    foreach (KoColorProfile *profile, profileList) {
+        m_page->cmbProfile->addItem(profile->name());
     }
 }
 
-KisID KisRawImport::getColorSpace()
+KoID KisRawImport::colorSpace()
 {
     if (m_page->radioRGB->isChecked()) {
         if (m_page->radio16->isChecked()) {
-            return KisID( "RGBA16" );
+            return KoID( "RGBA16" );
         }
     }
     else {
         if (m_page->radio16->isChecked()) {
-            return KisID( "GRAYA16" );
+            return KoID( "GRAYA16" );
         }
         else {
-            return KisID( "GRAYA" );
+            return KoID( "GRAYA" );
         }
     }
-    return KisID("RGBA");
+    return KoID("RGBA");
 }
 
 #include "kis_raw_import.moc"
