@@ -16,40 +16,38 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  */
- 
+
 #include "kis_tiff_converter.h"
 
 #include <stdio.h>
 
-#include <config.h>
-#include LCMS_HEADER
+#include <lcms.h>
 
-#include <qfile.h>
+#include <QFile>
 
 #include <kapplication.h>
 #include <KoDocumentInfo.h>
 
 #include <kio/netaccess.h>
+#include <kio/deletejob.h>
 
-#include <kis_abstract_colorspace.h>
-#include <kis_colorspace_factory_registry.h>
-#include <kis_doc.h>
+#include <KoColorSpaceRegistry.h>
+#include <kis_doc2.h>
 #include <kis_image.h>
 #include <kis_iterators_pixel.h>
 #include <kis_layer.h>
-#include <kis_meta_registry.h>
-#include <kis_profile.h>
+#include <colorprofiles/KoIccColorProfile.h>
 #include <kis_group_layer.h>
 #include <kis_paint_layer.h>
 
 #include "kis_tiff_reader.h"
 #include "kis_tiff_ycbcr_reader.h"
-#include "kis_tiff_stream.h"
+#include "kis_buffer_stream.h"
 #include "kis_tiff_writer_visitor.h"
 
 namespace {
 
-    QString getColorSpaceForColorType(uint16 color_type, uint16 color_nb_bits, TIFF *image, uint16 &nbchannels, uint16 &extrasamplescount, uint8 &destDepth, uint16 sampletype) {
+    QString getColorSpaceForColorType(uint16 sampletype, uint16 color_type, uint16 color_nb_bits, TIFF *image, uint16 &nbchannels, uint16 &extrasamplescount, uint8 &destDepth) {
         if(color_type == PHOTOMETRIC_MINISWHITE || color_type == PHOTOMETRIC_MINISBLACK)
         {
             if(nbchannels == 0) nbchannels = 1;
@@ -99,26 +97,26 @@ namespace {
             }
         } else if(color_type == PHOTOMETRIC_SEPARATED ) {
             if(nbchannels == 0) nbchannels = 4;
-            // SEPARATED is in general CMYK but not allways, so we check
+            // SEPARATED is in general CMYK but not always, so we check
             uint16 inkset;
             if((TIFFGetField(image, TIFFTAG_INKSET, &inkset) == 0)){
-                kdDebug(41008) <<  "Image does not define the inkset." << endl;
+                kDebug(41008) <<"Image does not define the inkset.";
                 inkset = 2;
             }
             if(inkset !=  INKSET_CMYK)
             {
-                kdDebug(41008) << "Unsupported inkset (right now, only CMYK is supported)" << endl;
+                kDebug(41008) <<"Unsupported inkset (right now, only CMYK is supported)";
                 char** ink_names;
                 uint16 numberofinks;
                 if( TIFFGetField(image, TIFFTAG_INKNAMES, &ink_names) && TIFFGetField(image, TIFFTAG_NUMBEROFINKS, &numberofinks) )
                 {
-                    kdDebug(41008) << "Inks are : " << endl;
+                    kDebug(41008) <<"Inks are :";
                     for(uint i = 0; i < numberofinks; i++)
                     {
-                        kdDebug(41008) << ink_names[i] << endl;
+                        kDebug(41008) << ink_names[i];
                     }
                 } else {
-                    kdDebug(41008) << "inknames aren't defined !" << endl;
+                    kDebug(41008) <<"inknames aren't defined !";
                     // To be able to read stupid adobe files, if there are no information about inks and four channels, then it's a CMYK file :
                     if( nbchannels - extrasamplescount != 4)
                     {
@@ -134,11 +132,7 @@ namespace {
                 destDepth = 16;
                 return "CMYKA16";
             }
-        } else if(color_type == PHOTOMETRIC_CIELAB
-#ifdef PHOTOMETRIC_ICCLAB
-	 || color_type == PHOTOMETRIC_ICCLAB
-#endif
-	 ) {
+        } else if(color_type == PHOTOMETRIC_CIELAB || color_type == PHOTOMETRIC_ICCLAB ) {
             destDepth = 16;
             if(nbchannels == 0) nbchannels = 3;
             extrasamplescount = nbchannels - 3; // FIX the extrasamples count in case of
@@ -147,14 +141,14 @@ namespace {
             destDepth = 16;
             if(nbchannels == 0) nbchannels = 2;
             extrasamplescount = nbchannels - 2; // FIX the extrasamples count in case of
-            // <-- we will convert the index image to RGBA16 as the palette is allways on 16bits colors
+            // <-- we will convert the index image to RGBA16 as the palette is always on 16bits colors
             return "RGBA16";
         }
         return "";
     }
 }
 
-KisTIFFConverter::KisTIFFConverter(KisDoc *doc, KisUndoAdapter *adapter)
+KisTIFFConverter::KisTIFFConverter(KisDoc2 *doc, KisUndoAdapter *adapter)
 {
     m_doc = doc;
     m_adapter = adapter;
@@ -166,18 +160,18 @@ KisTIFFConverter::~KisTIFFConverter()
 {
 }
 
-KisImageBuilder_Result KisTIFFConverter::decode(const KURL& uri)
+KisImageBuilder_Result KisTIFFConverter::decode(const KUrl& uri)
 {
-    kdDebug(41008) << "Start decoding TIFF File" << endl;
+    kDebug(41008) <<"Start decoding TIFF File";
     // Opent the TIFF file
     TIFF *image = 0;
     if((image = TIFFOpen(QFile::encodeName(uri.path()), "r")) == NULL){
-        kdDebug(41008) << "Could not open the file, either it doesn't exist, either it is not a TIFF : " << uri.path() << endl;
+        kDebug(41008) <<"Could not open the file, either it doesn't exist, either it is not a TIFF :" << uri.path();
 
         return (KisImageBuilder_RESULT_BAD_FETCH);
     }
     do {
-        kdDebug(41008) << "Read new sub-image" << endl;
+        kDebug(41008) <<"Read new sub-image";
         KisImageBuilder_Result result = readTIFFDirectory(image);
         if(result != KisImageBuilder_RESULT_OK){
             return result;
@@ -193,29 +187,29 @@ KisImageBuilder_Result KisTIFFConverter::readTIFFDirectory( TIFF* image)
     // Read information about the tiff
     uint32 width, height;
     if(TIFFGetField(image, TIFFTAG_IMAGEWIDTH, &width) == 0){
-        kdDebug(41008) <<  "Image does not define its width" << endl;
+        kDebug(41008) <<"Image does not define its width";
         TIFFClose(image);
         return KisImageBuilder_RESULT_INVALID_ARG;
     }
     if(TIFFGetField(image, TIFFTAG_IMAGELENGTH, &height) == 0){
-        kdDebug(41008) <<  "Image does not define its height" << endl;
+        kDebug(41008) <<"Image does not define its height";
         TIFFClose(image);
         return KisImageBuilder_RESULT_INVALID_ARG;
     }
     uint16 depth;
     if((TIFFGetField(image, TIFFTAG_BITSPERSAMPLE, &depth) == 0)){
-        kdDebug(41008) <<  "Image does not define its depth" << endl;
+        kDebug(41008) <<"Image does not define its depth";
         depth = 1;
     }
     uint16 sampletype;
     if((TIFFGetField(image, TIFFTAG_SAMPLEFORMAT, &sampletype) == 0)){
-        kdDebug(41008) <<  "Image does not define its sample type" << endl;
+        kDebug(41008) <<"Image does not define its sample type";
         sampletype =  SAMPLEFORMAT_UINT;
     }
-    // Determine the number of channels (usefull to know if a file has an alpha or not
+    // Determine the number of channels (useful to know if a file has an alpha or not
     uint16 nbchannels;
     if(TIFFGetField(image, TIFFTAG_SAMPLESPERPIXEL, &nbchannels) == 0){
-        kdDebug(41008) << "Image has an undefined number of samples per pixel" << endl;
+        kDebug(41008) <<"Image has an undefined number of samples per pixel";
         nbchannels = 0;
     }
     // Get the number of extrasamples and information about them
@@ -227,77 +221,80 @@ KisImageBuilder_Result KisTIFFConverter::readTIFFDirectory( TIFF* image)
     // Determine the colorspace
     uint16 color_type;
     if(TIFFGetField(image, TIFFTAG_PHOTOMETRIC, &color_type) == 0){
-        kdDebug(41008) << "Image has an undefined photometric interpretation" << endl;
+        kDebug(41008) <<"Image has an undefined photometric interpretation";
         color_type = PHOTOMETRIC_MINISWHITE;
     }
     uint8 dstDepth;
-    QString csName = getColorSpaceForColorType(color_type, depth, image, nbchannels, extrasamplescount, dstDepth,sampletype);
+    QString csName = getColorSpaceForColorType(sampletype, color_type, depth, image, nbchannels, extrasamplescount, dstDepth);
     if(csName.isEmpty()) {
-        kdDebug(41008) << "Image has an unsupported colorspace : " << color_type << " for this depth : "<< depth << endl;
+        kDebug(41008) <<"Image has an unsupported colorspace :" << color_type <<" for this depth :"<< depth;
         TIFFClose(image);
         return KisImageBuilder_RESULT_UNSUPPORTED_COLORSPACE;
     }
-    kdDebug(41008) << "Colorspace is : " << csName << " with a depth of " << depth << " and with a nb of channels of " << nbchannels << endl;
-    
+    kDebug(41008) <<"Colorspace is :" << csName <<" with a depth of" << depth <<" and with a nb of channels of" << nbchannels;
+
     // Read image profile
-    kdDebug() << "Reading profile" << endl;
-    KisProfile* profile = 0;
+    kDebug() <<"Reading profile";
+    KoColorProfile* profile = 0;
     DWORD EmbedLen;
     LPBYTE EmbedBuffer;
 
     if (TIFFGetField(image, TIFFTAG_ICCPROFILE, &EmbedLen, &EmbedBuffer)) {
-        kdDebug(41008) << "Profile found" << endl;
+        kDebug(41008) <<"Profile found";
         QByteArray rawdata;
         rawdata.resize(EmbedLen);
         memcpy(rawdata.data(), EmbedBuffer, EmbedLen);
-        profile = new KisProfile(rawdata);
+        profile = new KoIccColorProfile(rawdata);
     } else {
-        kdDebug(41008) << "No Profile found" << endl;
+        kDebug(41008) <<"No Profile found";
     }
-    
+
     // Retrieve a pointer to the colorspace
-    KisColorSpace* cs = 0;
+    KoColorSpace* cs = 0;
     if (profile && profile->isSuitableForOutput())
     {
-        kdDebug(41008) << "image has embedded profile: " << profile -> productName() << "\n";
-        cs = KisMetaRegistry::instance()->csRegistry()->getColorSpace(csName, profile);
+        kDebug(41008) <<"image has embedded profile:" << profile -> name() <<"";
+        cs = KoColorSpaceRegistry::instance()->colorSpace(csName, profile);
     }
     else
-        cs = KisMetaRegistry::instance()->csRegistry()->getColorSpace(KisID(csName,""),"");
+        cs = KoColorSpaceRegistry::instance()->colorSpace(KoID(csName,""),"");
 
     if(cs == 0) {
-        kdDebug(41008) << "Colorspace " << csName << " is not available, please check your installation." << endl;
+        kDebug(41008) <<"Colorspace" << csName <<" is not available, please check your installation.";
         TIFFClose(image);
         return KisImageBuilder_RESULT_UNSUPPORTED_COLORSPACE;
     }
-    
-    // Create the cmsTransform if needed 
+
+    // Create the cmsTransform if needed
     cmsHTRANSFORM transform = 0;
+#if 0
+    // TODO: fixit See also: [Bug 148864] New: CMYK colors distorted when loading / saving
     if(profile && !profile->isSuitableForOutput())
     {
-        kdDebug(41008) << "The profile can't be used in krita, need conversion" << endl;
+        kDebug(41008) <<"The profile can't be used in krita, need conversion";
         transform = cmsCreateTransform(profile->profile(), cs->colorSpaceType(),
-                                       cs->getProfile()->profile() , cs->colorSpaceType(),
+                                       cs->profile()->profile() , cs->colorSpaceType(),
                                        INTENT_PERCEPTUAL, 0);
     }
+#endif
+
 
-    
     // Check if there is an alpha channel
     int8 alphapos = -1; // <- no alpha
     // Check which extra is alpha if any
-    kdDebug(41008) << "There are " << nbchannels << " channels and " << extrasamplescount << " extra channels" << endl;
+    kDebug(41008) <<"There are" << nbchannels <<" channels and" << extrasamplescount <<" extra channels";
     if(sampleinfo) // index images don't have any sampleinfo, and therefor sampleinfo == 0
     {
         for(int i = 0; i < extrasamplescount; i ++)
         {
-            kdDebug(41008) << i << " " << extrasamplescount << " "  << (cs->nColorChannels()) <<  nbchannels << " " << sampleinfo[i] << endl;
+            kDebug(41008) << i <<"" << extrasamplescount <<""  << (cs->colorChannelCount()) <<  nbchannels <<"" << sampleinfo[i];
             if(sampleinfo[i] == EXTRASAMPLE_ASSOCALPHA)
             {
                 // XXX: dangelo: the color values are already multiplied with
                 // the alpha value.  This needs to be reversed later (postprocessor?)
                 alphapos = i;
             }
-    
+
             if (sampleinfo[i] == EXTRASAMPLE_UNASSALPHA)
             {
                 // color values are not premultiplied with alpha, and can be used as they are.
@@ -305,58 +302,63 @@ KisImageBuilder_Result KisTIFFConverter::readTIFFDirectory( TIFF* image)
             }
         }
     }
-    
+
     // Read META Information
     KoDocumentInfo * info = m_doc->documentInfo();
-    KoDocumentInfoAbout * aboutPage = static_cast<KoDocumentInfoAbout *>(info->page( "about" ));
-    KoDocumentInfoAuthor * authorPage = static_cast<KoDocumentInfoAuthor *>(info->page( "author"));
     char* text;
     if (TIFFGetField(image, TIFFTAG_ARTIST, &text)) {
-        authorPage->setFullName(text);
+        info->setAuthorInfo("creator", text);
     }
     if (TIFFGetField(image, TIFFTAG_DOCUMENTNAME, &text)) {
-        aboutPage->setTitle(text);
+        info->setAboutInfo("title", text);
     }
     if (TIFFGetField(image,TIFFTAG_IMAGEDESCRIPTION,&text) ) {
-        aboutPage->setAbstract( text );
+        info->setAboutInfo("description", text);
     }
-    
-    
+
+
     // Get the planar configuration
     uint16 planarconfig;
     if(TIFFGetField(image, TIFFTAG_PLANARCONFIG, &planarconfig) == 0)
     {
-        kdDebug(41008) <<  "Plannar configuration is not define" << endl;
+        kDebug(41008) <<"Plannar configuration is not define";
         TIFFClose(image);
         return KisImageBuilder_RESULT_INVALID_ARG;
     }
     // Creating the KisImageSP
     if( ! m_img ) {
         m_img = new KisImage(m_doc->undoAdapter(), width, height, cs, "built image");
+        m_img->lock();
         Q_CHECK_PTR(m_img);
-        m_img->blockSignals(true); // Don't send out signals while we're building the image
         if(profile)
         {
-            m_img -> addAnnotation( profile->annotation() );
+            KisAnnotationSP annotation;
+            // XXX we hardcode icc, this is correct for lcms?
+            // XXX productName(), or just "ICC Profile"?
+            KoIccColorProfile* iccprofile = dynamic_cast<KoIccColorProfile*>(profile);
+            if ( iccprofile and !iccprofile->rawData().isEmpty())
+                annotation = new  KisAnnotation("icc", iccprofile->name(), iccprofile->rawData());
+
+            m_img -> addAnnotation( annotation );
         }
     } else {
-        if( m_img->width() < (Q_INT32)width || m_img->height() < (Q_INT32)height)
+        if( m_img->width() < (qint32)width || m_img->height() < (qint32)height)
         {
-            Q_UINT32 newwidth = (m_img->width() < (Q_INT32)width) ? width : m_img->width();
-            Q_UINT32 newheight = (m_img->height() < (Q_INT32)height) ? height : m_img->height();
+            quint32 newwidth = (m_img->width() < (qint32)width) ? width : m_img->width();
+            quint32 newheight = (m_img->height() < (qint32)height) ? height : m_img->height();
             m_img->resize(newwidth, newheight, false);
         }
     }
-    KisPaintLayer* layer = new KisPaintLayer(m_img, m_img -> nextLayerName(), Q_UINT8_MAX);
+    KisPaintLayer* layer = new KisPaintLayer(m_img.data(), m_img -> nextLayerName(), quint8_MAX);
     tdata_t buf = 0;
-    tdata_t* ps_buf = 0; // used only for planar configuration seperated
-    TIFFStreamBase* tiffstream;
-    
+    tdata_t* ps_buf = 0; // used only for planar configuration separated
+    KisBufferStreamBase* tiffstream;
+
     KisTIFFReaderBase* tiffReader = 0;
-    
-    Q_UINT8 poses[5];
+
+    quint8 poses[5];
     KisTIFFPostProcessor* postprocessor = 0;
-    
+
     // Configure poses
     uint8 nbcolorsamples = nbchannels - extrasamplescount;
     switch(color_type)
@@ -374,19 +376,17 @@ KisImageBuilder_Result KisTIFFConverter::readTIFFDirectory( TIFF* image)
         }
         break;
         case PHOTOMETRIC_CIELAB:
-        {
-            poses[0] = 0; poses[1] = 1; poses[2] = 2; poses[3] = 3;
-            postprocessor = new KisTIFFPostProcessor(nbcolorsamples);
-        }
-        break;
-#ifdef PHOTOMETRIC_ICCLAB
-        case PHOTOMETRIC_ICCLAB:
         {
             poses[0] = 0; poses[1] = 1; poses[2] = 2; poses[3] = 3;
             postprocessor = new KisTIFFPostProcessorICCLABtoCIELAB(nbcolorsamples);
         }
         break;
-#endif
+        case PHOTOMETRIC_ICCLAB:
+        {
+            poses[0] = 0; poses[1] = 1; poses[2] = 2; poses[3] = 3;
+            postprocessor = new KisTIFFPostProcessor(nbcolorsamples);
+        }
+        break;
         case PHOTOMETRIC_RGB:
         {
             poses[0] = 2; poses[1] = 1; poses[2] = 0; poses[3] = 3;
@@ -402,8 +402,8 @@ KisImageBuilder_Result KisTIFFConverter::readTIFFDirectory( TIFF* image)
         default:
         break;
     }
-    
-    
+
+
     // Initisalize tiffReader
     uint16 * lineSizeCoeffs = new uint16[nbchannels];
     uint16 vsubsampling = 1;
@@ -419,7 +419,7 @@ KisImageBuilder_Result KisTIFFConverter::readTIFFDirectory( TIFF* image)
         uint16 *blue;
         if ((TIFFGetField(image, TIFFTAG_COLORMAP, &red, &green, &blue)) == 0)
         {
-            kdDebug(41008) <<  "Indexed image does not define a palette" << endl;
+            kDebug(41008) <<"Indexed image does not define a palette";
             TIFFClose(image);
             return KisImageBuilder_RESULT_INVALID_ARG;
         }
@@ -433,10 +433,10 @@ KisImageBuilder_Result KisTIFFConverter::readTIFFDirectory( TIFF* image)
         TIFFGetFieldDefaulted( image, TIFFTAG_YCBCRPOSITIONING, &position  );
         if( dstDepth == 8 )
         {
-            tiffReader = new KisTIFFYCbCrReaderTarget8Bit(layer->paintDevice(), poses, alphapos, depth, nbcolorsamples, extrasamplescount, transform, postprocessor, hsubsampling, vsubsampling, (KisTIFFYCbCr::Position)position);
+            tiffReader = new KisTIFFYCbCrReaderTarget8Bit(layer->paintDevice(), layer->image()->width(), layer->image()->height(), poses, alphapos, depth, nbcolorsamples, extrasamplescount, transform, postprocessor, hsubsampling, vsubsampling, (KisTIFFYCbCr::Position)position);
         } else if( dstDepth == 16 )
         {
-            tiffReader = new KisTIFFYCbCrReaderTarget16Bit( layer->paintDevice(), poses, alphapos, depth, nbcolorsamples, extrasamplescount, transform, postprocessor, hsubsampling, vsubsampling, (KisTIFFYCbCr::Position)position);
+            tiffReader = new KisTIFFYCbCrReaderTarget16Bit( layer->paintDevice(), layer->image()->width(), layer->image()->height(), poses, alphapos, depth, nbcolorsamples, extrasamplescount, transform, postprocessor, hsubsampling, vsubsampling, (KisTIFFYCbCr::Position)position);
         }
     } else if(dstDepth == 8)
     {
@@ -446,10 +446,10 @@ KisImageBuilder_Result KisTIFFConverter::readTIFFDirectory( TIFF* image)
     } else if(dstDepth == 32) {
         tiffReader = new KisTIFFReaderTarget32bit( layer->paintDevice(), poses, alphapos, depth, nbcolorsamples, extrasamplescount, transform, postprocessor);
     }
-    
+
     if(TIFFIsTiled(image))
     {
-        kdDebug(41008) << "tiled image" << endl;
+        kDebug(41008) <<"tiled image";
         uint32 tileWidth, tileHeight;
         uint32 x, y;
         TIFFGetField(image, TIFFTAG_TILEWIDTH, &tileWidth);
@@ -460,12 +460,12 @@ KisImageBuilder_Result KisTIFFConverter::readTIFFDirectory( TIFF* image)
             buf = _TIFFmalloc(TIFFTileSize(image));
             if(depth < 16)
             {
-                tiffstream = new TIFFStreamContigBelow16((uint8*)buf, depth, linewidth);
+                tiffstream = new KisBufferStreamContigBelow16((uint8*)buf, depth, linewidth);
             } else if(depth < 32)
             {
-                tiffstream = new TIFFStreamContigBelow32((uint8*)buf, depth, linewidth);
+                tiffstream = new KisBufferStreamContigBelow32((uint8*)buf, depth, linewidth);
             } else {
-                tiffstream = new TIFFStreamContigAbove32((uint8*)buf, depth, linewidth);
+                tiffstream = new KisBufferStreamContigAbove32((uint8*)buf, depth, linewidth);
             }
         } else {
             ps_buf = new tdata_t[nbchannels];
@@ -476,15 +476,15 @@ KisImageBuilder_Result KisTIFFConverter::readTIFFDirectory( TIFF* image)
                 ps_buf[i] = _TIFFmalloc(baseSize);
                 lineSizes[i] = baseSize / lineSizeCoeffs[i];
             }
-            tiffstream = new TIFFStreamSeperate( (uint8**) ps_buf, nbchannels, depth, lineSizes);
+            tiffstream = new KisBufferStreamSeperate( (uint8**) ps_buf, nbchannels, depth, lineSizes);
             delete [] lineSizes;
         }
-        kdDebug(41008) << linewidth << " " << nbchannels << " " << layer->paintDevice()->colorSpace()->nColorChannels() << endl;
+        kDebug(41008) << linewidth <<"" << nbchannels <<"" << layer->paintDevice()->colorSpace()->colorChannelCount();
         for (y = 0; y < height; y+= tileHeight)
         {
             for (x = 0; x < width; x += tileWidth)
             {
-                kdDebug(41008) << "Reading tile x = " << x << " y = " << y << endl;
+                kDebug(41008) <<"Reading tile x =" << x <<" y =" << y;
                 if( planarconfig == PLANARCONFIG_CONTIG )
                 {
                     TIFFReadTile(image, buf, x, y, 0, (tsample_t) -1);
@@ -496,7 +496,7 @@ KisImageBuilder_Result KisTIFFConverter::readTIFFDirectory( TIFF* image)
                 }
                 uint32 realTileWidth =  (x + tileWidth) < width ? tileWidth : width - x;
                 for (uint yintile = 0; y + yintile < height && yintile < tileHeight/vsubsampling; ) {
-                    uint linesreaded = tiffReader->copyDataToChannels( x, y + yintile , realTileWidth, tiffstream);
+                    tiffReader->copyDataToChannels( x, y + yintile , realTileWidth, tiffstream);
                     yintile += 1;
                     tiffstream->moveToLine( yintile );
                 }
@@ -504,41 +504,41 @@ KisImageBuilder_Result KisTIFFConverter::readTIFFDirectory( TIFF* image)
             }
         }
     } else {
-        kdDebug(41008) << "striped image" << endl;
+        kDebug(41008) <<"striped image";
         tsize_t stripsize = TIFFStripSize(image);
         uint32 rowsPerStrip;
         TIFFGetFieldDefaulted(image, TIFFTAG_ROWSPERSTRIP, &rowsPerStrip);
-        kdDebug() << rowsPerStrip << " " << height << endl;
-        rowsPerStrip = QMIN(rowsPerStrip, height); // when TIFFNumberOfStrips(image) == 1 it might happen that rowsPerStrip is incorrectly set
+        kDebug() << rowsPerStrip <<"" << height;
+        rowsPerStrip = qMin(rowsPerStrip, height); // when TIFFNumberOfStrips(image) == 1 it might happen that rowsPerStrip is incorrectly set
         if(planarconfig == PLANARCONFIG_CONTIG)
         {
             buf = _TIFFmalloc(stripsize);
             if(depth < 16)
             {
-                tiffstream = new TIFFStreamContigBelow16((uint8*)buf, depth, stripsize/rowsPerStrip);
+                tiffstream = new KisBufferStreamContigBelow16((uint8*)buf, depth, stripsize/rowsPerStrip);
             } else if(depth < 32)
             {
-                tiffstream = new TIFFStreamContigBelow32((uint8*)buf, depth, stripsize/rowsPerStrip);
+                tiffstream = new KisBufferStreamContigBelow32((uint8*)buf, depth, stripsize/rowsPerStrip);
             } else {
-                tiffstream = new TIFFStreamContigAbove32((uint8*)buf, depth, stripsize/rowsPerStrip);
+                tiffstream = new KisBufferStreamContigAbove32((uint8*)buf, depth, stripsize/rowsPerStrip);
             }
         } else {
             ps_buf = new tdata_t[nbchannels];
             uint32 scanLineSize = stripsize/rowsPerStrip;
-            kdDebug(41008) << " scanLineSize for each plan = " << scanLineSize << endl;
+            kDebug(41008) <<" scanLineSize for each plan =" << scanLineSize;
             uint32 * lineSizes = new uint32[nbchannels];
             for(uint i = 0; i < nbchannels; i++)
             {
                 ps_buf[i] = _TIFFmalloc(stripsize);
                 lineSizes[i] = scanLineSize / lineSizeCoeffs[i];
             }
-            tiffstream = new TIFFStreamSeperate( (uint8**) ps_buf, nbchannels, depth, lineSizes);
+            tiffstream = new KisBufferStreamSeperate( (uint8**) ps_buf, nbchannels, depth, lineSizes);
             delete [] lineSizes;
         }
 
-        kdDebug(41008) << "Scanline size = " << TIFFRasterScanlineSize(image) << " / strip size = " << TIFFStripSize(image) << " / rowsPerStrip = " << rowsPerStrip << " stripsize/rowsPerStrip = " << stripsize/rowsPerStrip << endl;
+        kDebug(41008) <<"Scanline size =" << TIFFRasterScanlineSize(image) <<" / strip size =" << TIFFStripSize(image) <<" / rowsPerStrip =" << rowsPerStrip <<" stripsize/rowsPerStrip =" << stripsize/rowsPerStrip;
         uint32 y = 0;
-        kdDebug(41008) << " NbOfStrips = " << TIFFNumberOfStrips(image) << " rowsPerStrip = " << rowsPerStrip << " stripsize = " << stripsize << endl;
+        kDebug(41008) <<" NbOfStrips =" << TIFFNumberOfStrips(image) <<" rowsPerStrip =" << rowsPerStrip <<" stripsize =" << stripsize;
         for (uint32 strip = 0; y < height; strip++)
         {
             if( planarconfig == PLANARCONFIG_CONTIG )
@@ -574,17 +574,19 @@ KisImageBuilder_Result KisTIFFConverter::readTIFFDirectory( TIFF* image)
         }
         delete[] ps_buf;
     }
-    
-    m_img->addLayer(layer, m_img->rootLayer(), 0);
+
+    m_img->addLayer(KisLayerSP(layer), m_img->rootLayer(), KisLayerSP(0));
+    layer->setDirty();
+    m_img->unlock();
     return KisImageBuilder_RESULT_OK;
 }
 
-KisImageBuilder_Result KisTIFFConverter::buildImage(const KURL& uri)
+KisImageBuilder_Result KisTIFFConverter::buildImage(const KUrl& uri)
 {
     if (uri.isEmpty())
         return KisImageBuilder_RESULT_NO_URI;
 
-    if (!KIO::NetAccess::exists(uri, false, qApp -> mainWidget())) {
+    if (!KIO::NetAccess::exists(uri, false, qApp -> activeWindow())) {
         return KisImageBuilder_RESULT_NOT_EXIST;
     }
 
@@ -592,8 +594,8 @@ KisImageBuilder_Result KisTIFFConverter::buildImage(const KURL& uri)
     KisImageBuilder_Result result = KisImageBuilder_RESULT_FAILURE;
     QString tmpFile;
 
-    if (KIO::NetAccess::download(uri, tmpFile, qApp -> mainWidget())) {
-        KURL uriTF;
+    if (KIO::NetAccess::download(uri, tmpFile, qApp -> activeWindow())) {
+        KUrl uriTF;
         uriTF.setPath( tmpFile );
         result = decode(uriTF);
         KIO::NetAccess::removeTempFile(tmpFile);
@@ -609,9 +611,9 @@ KisImageSP KisTIFFConverter::image()
 }
 
 
-KisImageBuilder_Result KisTIFFConverter::buildFile(const KURL& uri, KisImageSP img, KisTIFFOptions options)
+KisImageBuilder_Result KisTIFFConverter::buildFile(const KUrl& uri, KisImageSP img, KisTIFFOptions options)
 {
-    kdDebug(41008) << "Start writing TIFF File" << endl;
+    kDebug(41008) <<"Start writing TIFF File";
     if (!img)
         return KisImageBuilder_RESULT_EMPTY;
 
@@ -620,36 +622,33 @@ KisImageBuilder_Result KisTIFFConverter::buildFile(const KURL& uri, KisImageSP i
 
     if (!uri.isLocalFile())
         return KisImageBuilder_RESULT_NOT_LOCAL;
-    
+
     // Open file for writing
     TIFF *image;
     if((image = TIFFOpen(QFile::encodeName(uri.path()), "w")) == NULL){
-        kdDebug(41008) << "Could not open the file for writting " << uri.path() << endl;
+        kDebug(41008) <<"Could not open the file for writing" << uri.path();
         TIFFClose(image);
         return (KisImageBuilder_RESULT_FAILURE);
     }
 
-    // Set the document informations
+    // Set the document information
     KoDocumentInfo * info = m_doc->documentInfo();
-    KoDocumentInfoAbout * aboutPage = static_cast<KoDocumentInfoAbout *>(info->page( "about" ));
-    QString title = aboutPage->title();
+    QString title = info->aboutInfo("title");
     if(!title.isEmpty())
     {
-        TIFFSetField(image, TIFFTAG_DOCUMENTNAME, title.ascii());
+        TIFFSetField(image, TIFFTAG_DOCUMENTNAME, title.toAscii().data());
     }
-    QString abstract = aboutPage->abstract();
+    QString abstract = info->aboutInfo("description");
     if(!abstract.isEmpty())
     {
-        TIFFSetField(image, TIFFTAG_IMAGEDESCRIPTION, abstract.ascii());
+        TIFFSetField(image, TIFFTAG_IMAGEDESCRIPTION, abstract.toAscii().data());
     }
-    KoDocumentInfoAuthor * authorPage = static_cast<KoDocumentInfoAuthor *>(info->page( "author" ));
-    QString author = authorPage->fullName();
+    QString author = info->authorInfo("creator");
     if(!author.isEmpty())
     {
-        TIFFSetField(image, TIFFTAG_ARTIST, author.ascii());
+        TIFFSetField(image, TIFFTAG_ARTIST, author.toAscii().data());
     }
-    
-    KisTIFFWriterVisitor* visitor = new KisTIFFWriterVisitor(image, &options);
+
     KisGroupLayer* root = dynamic_cast<KisGroupLayer*>(img->rootLayer().data());
     if(root == 0)
     {
@@ -657,13 +656,14 @@ KisImageBuilder_Result KisTIFFConverter::buildFile(const KURL& uri, KisImageSP i
         TIFFClose(image);
         return KisImageBuilder_RESULT_FAILURE;
     }
+    KisTIFFWriterVisitor* visitor = new KisTIFFWriterVisitor(image, &options);
     if(!visitor->visit( root ))
     {
         KIO::del(uri);
         TIFFClose(image);
         return KisImageBuilder_RESULT_FAILURE;
     }
-    
+
     TIFFClose(image);
     return KisImageBuilder_RESULT_OK;
 }
