@@ -13,23 +13,24 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include <opencalcstyleexport.h>
 
-#include <koGlobal.h>
+#include <KoGlobal.h>
 
-#include <kspread_cell.h>
-#include <kspread_doc.h>
-#include <kspread_format.h>
-#include <kspread_sheet.h>
-#include <kspread_style.h>
-#include <kspread_style_manager.h>
+#include <kspread/Cell.h>
+#include <kspread/Doc.h>
+#include <kspread/Sheet.h>
+#include <kspread/Style.h>
+#include <kspread/StyleManager.h>
 
 #include <qdom.h>
 
+using namespace KSpread;
+
 OpenCalcStyles::OpenCalcStyles()
 {
   m_cellStyles.setAutoDelete( true );
@@ -135,7 +136,7 @@ QString OpenCalcStyles::columnStyle( ColumnStyle const & cs )
   return t->name;
 }
 
-QString OpenCalcStyles::numberStyle( NumberStyle const & ns )
+QString OpenCalcStyles::numberStyle( NumberStyle const & )
 {
   return "";
 }
@@ -192,6 +193,7 @@ QString convertPenToString( QPen const & pen )
 
 void OpenCalcStyles::addCellStyles( QDomDocument & doc, QDomElement & autoStyles )
 {
+
     CellStyle * t = m_cellStyles.first();
     while ( t )
     {
@@ -231,25 +233,25 @@ void OpenCalcStyles::addCellStyles( QDomDocument & doc, QDomElement & autoStyles
         if ( t->bgColor.name() != "#ffffff" )
             prop.setAttribute( "fo:background-color", t->bgColor.name() );
 
-        if ( t->alignX != KSpreadFormat::Undefined )
+        if ( t->alignX != KSpread::Style::HAlignUndefined )
         {
             QString value;
-            if ( t->alignX == KSpreadFormat::Center )
+            if ( t->alignX == KSpread::Style::Center )
                 value = "center";
-            else if ( t->alignX == KSpreadFormat::Right )
+            else if ( t->alignX == KSpread::Style::Right )
                 value = "end";
-            else if ( t->alignX == KSpreadFormat::Left )
+            else if ( t->alignX == KSpread::Style::Left )
                 value = "start";
             prop.setAttribute( "fo:text-align", value );
         }
 
-        if ( t->alignY != KSpreadFormat::Bottom ) // default in OpenCalc
-            prop.setAttribute( "fo:vertical-align", ( t->alignY == KSpreadFormat::Middle ? "middle" : "top" ) );
+        if ( t->alignY != KSpread::Style::Bottom ) // default in OpenCalc
+            prop.setAttribute( "fo:vertical-align", ( t->alignY == KSpread::Style::Middle ? "middle" : "top" ) );
 
         if ( t->indent > 0.0 )
         {
             prop.setAttribute( "fo:margin-left", QString( "%1pt" ).arg( t->indent ) );
-            if ( t->alignX == KSpreadFormat::Undefined )
+            if ( t->alignX == KSpread::Style::HAlignUndefined )
                 prop.setAttribute( "fo:text-align", "start" );
         }
 
@@ -319,8 +321,8 @@ void OpenCalcStyles::addColumnStyles( QDomDocument & doc, QDomElement & autoStyl
     ts.setAttribute( "style:family", "table-column" );
 
     QDomElement prop = doc.createElement( "style:properties" );
-    if ( t->breakB != Style::none )
-      prop.setAttribute( "fo:break-before", ( t->breakB == Style::automatic ? "auto" : "page" ) );
+    if ( t->breakB != ::Style::none )
+      prop.setAttribute( "fo:break-before", ( t->breakB == ::Style::automatic ? "auto" : "page" ) );
     prop.setAttribute( "style:column-width", QString( "%1cm" ).arg( t->size ) );
 
     ts.appendChild( prop );
@@ -330,7 +332,7 @@ void OpenCalcStyles::addColumnStyles( QDomDocument & doc, QDomElement & autoStyl
   }
 }
 
-void OpenCalcStyles::addNumberStyles( QDomDocument & doc, QDomElement & autoStyles )
+void OpenCalcStyles::addNumberStyles( QDomDocument & /*doc*/, QDomElement & /*autoStyles*/ )
 {
 }
 
@@ -345,8 +347,8 @@ void OpenCalcStyles::addRowStyles( QDomDocument & doc, QDomElement & autoStyles
 
     QDomElement prop = doc.createElement( "style:properties" );
     prop.setAttribute( "style:row-height", QString( "%1cm" ).arg( t->size ) );
-    if ( t->breakB != Style::none )
-      prop.setAttribute( "fo:break-before", ( t->breakB == Style::automatic ? "auto" : "page" ) );
+    if ( t->breakB != ::Style::none )
+      prop.setAttribute( "fo:break-before", ( t->breakB == ::Style::automatic ? "auto" : "page" ) );
 
     ts.appendChild( prop );
     autoStyles.appendChild( ts );
@@ -398,8 +400,8 @@ CellStyle::CellStyle()
     hideAll( false ),
     hideFormula( false ),
     notProtected ( false ),
-    alignX( KSpreadFormat::Undefined ),
-    alignY( KSpreadFormat::Middle )
+    alignX( KSpread::Style::HAlignUndefined ),
+    alignY( KSpread::Style::Middle )
 {
 }
 
@@ -443,68 +445,64 @@ bool CellStyle::isEqual( CellStyle const * const t1, CellStyle const & t2 )
 }
 
 // all except the number style
-void CellStyle::loadData( CellStyle & cs, KSpreadCell const * const cell )
+void CellStyle::loadData( CellStyle & cs, const Cell& cell )
 {
-  int col = cell->column();
-  int row = cell->row();
+  const KSpread::Style style = cell.style();
+  const KSpread::Style* defaultStyle = cell.sheet()->doc()->styleManager()->defaultStyle();
 
-  KSpreadFormat * f = new KSpreadFormat( 0, cell->sheet()->doc()->styleManager()->defaultStyle() );
-
-  QFont font = cell->textFont( col, row );
-  if ( font != f->font() )
+  QFont font = style.font();
+  if ( font != defaultStyle->font() )
     cs.font = font;
 
-  QColor color = cell->textColor( col, row );
-  if ( color != f->textColor( col, row ) )
+  QColor color = style.fontColor();
+  if ( color != defaultStyle->fontColor() )
     cs.color   = color;
 
-  QColor bgColor = cell->bgColor( col, row );
-  if ( bgColor != f->bgColor( col, row ) )
+  QColor bgColor = style.backgroundColor();
+  if ( bgColor != defaultStyle->backgroundColor() )
     cs.bgColor = bgColor;
 
-  if ( cell->hasProperty( KSpreadFormat::PAlign ) || !cell->hasNoFallBackProperties( KSpreadFormat::PAlign ) )
-    cs.alignX = cell->align( col, row );
+  if ( style.hasAttribute( KSpread::Style::HorizontalAlignment ) )
+    cs.alignX = style.halign();
 
-  if ( cell->hasProperty( KSpreadFormat::PAlignY ) || !cell->hasNoFallBackProperties( KSpreadFormat::PAlignY ) )
-    cs.alignY = cell->alignY( col, row );
+  if ( style.hasAttribute( KSpread::Style::VerticalAlignment ) )
+    cs.alignY = style.valign();
 
-  if ( cell->hasProperty( KSpreadFormat::PIndent ) || !cell->hasNoFallBackProperties( KSpreadFormat::PIndent ) )
-    cs.indent = cell->getIndent( col, row );
+  if ( style.hasAttribute( KSpread::Style::Indentation ) )
+    cs.indent = style.indentation();
 
-  if ( cell->hasProperty( KSpreadFormat::PAngle ) || !cell->hasNoFallBackProperties( KSpreadFormat::PAngle ) )
-    cs.angle  = -cell->getAngle( col, row );
+  if ( style.hasAttribute( KSpread::Style::Angle ) )
+    cs.angle  = -style.angle();
 
-  if ( cell->hasProperty( KSpreadFormat::PMultiRow ) || !cell->hasNoFallBackProperties( KSpreadFormat::PMultiRow ) )
-    cs.wrap   = cell->multiRow( col, row );
+  if ( style.hasAttribute( KSpread::Style::MultiRow ) )
+    cs.wrap   = style.wrapText();
 
-  if ( cell->hasProperty( KSpreadFormat::PVerticalText )
-       || !cell->hasNoFallBackProperties( KSpreadFormat::PVerticalText ) )
-    cs.vertical = cell->verticalText( col, row );
+  if ( style.hasAttribute( KSpread::Style::VerticalText ) )
+    cs.vertical = style.verticalText();
 
-  if ( cell->hasProperty( KSpreadFormat::PDontPrintText )
-       || !cell->hasNoFallBackProperties( KSpreadFormat::PDontPrintText ) )
-    cs.print = !cell->getDontprintText( col, row );
+  if ( style.hasAttribute( KSpread::Style::DontPrintText ) )
+    cs.print = style.printText();
 
-  if ( cell->hasProperty( KSpreadFormat::PLeftBorder ) || !cell->hasNoFallBackProperties( KSpreadFormat::PLeftBorder ) )
-    cs.left  = cell->leftBorderPen( col, row );
+  if ( style.hasAttribute( KSpread::Style::LeftPen ) )
+    cs.left  = style.leftBorderPen();
 
-  if ( cell->hasProperty( KSpreadFormat::PRightBorder ) || !cell->hasNoFallBackProperties( KSpreadFormat::PRightBorder ) )
-    cs.right = cell->rightBorderPen( col, row );
+  if ( style.hasAttribute( KSpread::Style::RightPen ) )
+    cs.right = style.rightBorderPen();
 
-  if ( cell->hasProperty( KSpreadFormat::PTopBorder ) || !cell->hasNoFallBackProperties( KSpreadFormat::PTopBorder ) )
-    cs.top  = cell->topBorderPen( col, row );
+  if ( style.hasAttribute( KSpread::Style::TopPen ) )
+    cs.top  = style.topBorderPen();
 
-  if ( cell->hasProperty( KSpreadFormat::PBottomBorder ) || !cell->hasNoFallBackProperties( KSpreadFormat::PBottomBorder ) )
-    cs.bottom  = cell->bottomBorderPen( col, row );
+  if ( style.hasAttribute( KSpread::Style::BottomPen ) )
+    cs.bottom  = style.bottomBorderPen();
 
-  if ( cell->hasProperty( KSpreadFormat::PNotProtected ) || !cell->hasNoFallBackProperties( KSpreadFormat::PNotProtected ) )
-    cs.notProtected = cell->notProtected( col, row );
+  if ( style.hasAttribute( KSpread::Style::NotProtected ) )
+    cs.notProtected = style.notProtected();
 
-  if ( cell->hasProperty( KSpreadFormat::PHideAll ) || !cell->hasNoFallBackProperties( KSpreadFormat::PHideAll ) )
-    cs.hideAll = cell->isHideAll( col, row );
+  if ( style.hasAttribute( KSpread::Style::HideAll ) )
+    cs.hideAll = style.hideAll();
 
-  if ( cell->hasProperty( KSpreadFormat::PHideFormula ) || !cell->hasNoFallBackProperties( KSpreadFormat::PHideFormula ) )
-    cs.hideFormula = cell->isHideFormula( col, row );
+  if ( style.hasAttribute( KSpread::Style::HideFormula ) )
+    cs.hideFormula = style.hideFormula();
 }
 
 bool NumberStyle::isEqual( NumberStyle const * const t1, NumberStyle const & t2 )
