@@ -13,21 +13,23 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
-#include <config.h>
-
-#ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-
-#include <qmessagebox.h>
-#include <qlist.h>
+#include <QMessageBox>
+#include <q3ptrlist.h>
+#include <QTextStream>
+#include <QByteArray>
 #include <applixwordimport.h>
 #include <applixwordimport.moc>
 #include <kdebug.h>
+#include <KoFilterChain.h>
+#include <kgenericfactory.h>
+
+typedef KGenericFactory<APPLIXWORDImport> APPLIXWORDImportFactory;
+K_EXPORT_COMPONENT_FACTORY( libapplixwordimport, APPLIXWORDImportFactory( "kofficefilters" ) )
+
 
 /******************************************************************************
  *  class: APPLIXWORDImport        function: APPLIXWORDImport                 *
@@ -37,8 +39,8 @@
  *                                                                            *
  *                                                                            *
  ******************************************************************************/
-APPLIXWORDImport::APPLIXWORDImport (KoFilter *parent, const char *name) :
-                     KoFilter(parent, name)
+APPLIXWORDImport::APPLIXWORDImport (QObject *parent, const QStringList& ) :
+                     KoFilter( parent )
 {
 }
 
@@ -50,7 +52,7 @@ APPLIXWORDImport::APPLIXWORDImport (KoFilter *parent, const char *name) :
  *                                                                            *
  *                                                                            *
  ******************************************************************************/
-QString 
+QString
 APPLIXWORDImport::nextLine (QTextStream & stream)
 {
     QString s;
@@ -58,14 +60,14 @@ APPLIXWORDImport::nextLine (QTextStream & stream)
     // Read one Line
     s = stream.readLine();
 
-    m_instep += s.length(); 
-    if (m_instep > m_stepsize) 
-    { 
-        m_instep    = 0; 
-        m_progress += 2; 
-        emit sigProgress (m_progress) ; 
-    } 
- 
+    m_instep += s.length();
+    if (m_instep > m_stepsize)
+    {
+        m_instep    = 0;
+        m_progress += 2;
+        emit sigProgress (m_progress) ;
+    }
+
     return s;
 }
 
@@ -79,21 +81,18 @@ APPLIXWORDImport::nextLine (QTextStream & stream)
  *                                                                            *
  *                                                                            *
  ******************************************************************************/
-bool 
-APPLIXWORDImport::filter (const QString &fileIn, const QString &fileOut,
-                          const QString &from,   const QString &to,
-                          const QString &)
+KoFilter::ConversionStatus APPLIXWORDImport::convert( const QByteArray& from, const QByteArray& to )
 {
 
-    if (to!="application/x-kword" || from!="application/x-applixword")
-        return false;
+    if (to!="application/x-kword" || from!="application/x-applix-word")
+        return KoFilter::NotImplemented;
 
-    QFile in(fileIn);
-    if (!in.open (IO_ReadOnly)) 
+    QFile in(m_chain->inputFile());
+    if (!in.open (QIODevice::ReadOnly))
     {
-        kdError(30502) << "Unable to open input file!" << endl;
+        kError(30517) << "Unable to open input file!" << endl;
         in.close();
-        return false;
+        return KoFilter::FileNotFound;
     }
 
 
@@ -104,12 +103,12 @@ APPLIXWORDImport::filter (const QString &fileIn, const QString &fileOut,
     str += " <PAPER format=\"1\" ptWidth=\"595\" ptHeight=\"841\" mmWidth =\"210\" mmHeight=\"297\" inchWidth =\"8.26772\" inchHeight=\"11.6929\" orientation=\"0\" columns=\"1\" ptColumnspc=\"2\" mmColumnspc=\"1\" inchColumnspc=\"0.0393701\" hType=\"0\" fType=\"0\" ptHeadBody=\"9\" ptFootBody=\"9\" mmHeadBody=\"3.5\" mmFootBody=\"3.5\" inchHeadBody=\"0.137795\" inchFootBody=\"0.137795\">\n";
     str += "  <PAPERBORDERS mmLeft=\"10\" mmTop=\"15\" mmRight=\"10\" mmBottom=\"15\" ptLeft=\"28\" ptTop=\"42\" ptRight=\"28\" ptBottom=\"42\" inchLeft=\"0.393701\" inchTop=\"0.590551\" inchRight=\"0.393701\" inchBottom=\"0.590551\"/>\n";
     str += " </PAPER>\n";
-    str += " <ATTRIBUTES processing=\"0\" standardpage=\"1\" hasHeader=\"0\" hasFooter=\"0\" unit=\"mm\"/>\n";
+    str += " <ATTRIBUTES processing=\"0\" standardpage=\"1\" hasHeader=\"0\" hasFooter=\"0\" />\n";
     str += " <FRAMESETS>\n";
     str += "  <FRAMESET frameType=\"1\" autoCreateNewFrame=\"1\" frameInfo=\"0\" removeable=\"0\">\n";
     str += "   <FRAME left=\"28\" top=\"42\" right=\"566\" bottom=\"798\" runaround=\"1\" runaGapPT=\"2\" runaGapMM=\"1\" runaGapINCH=\"0.0393701\"  lWidth=\"1\" lRed=\"255\" lGreen=\"255\" lBlue=\"255\" lStyle=\"0\"  rWidth=\"1\" rRed=\"255\" rGreen=\"255\" rBlue=\"255\" rStyle=\"0\"  tWidth=\"1\" tRed=\"255\" tGreen=\"255\" tBlue=\"255\" tStyle=\"0\"  bWidth=\"1\" bRed=\"255\" bGreen=\"255\" bBlue=\"255\" bStyle=\"0\" bkRed=\"255\" bkGreen=\"255\" bkBlue=\"255\" bleftpt=\"0\" bleftmm=\"0\" bleftinch=\"0\" brightpt=\"0\" brightmm=\"0\" brightinch=\"0\" btoppt=\"0\" btopmm=\"0\" btopinch=\"0\" bbottompt=\"0\" bbottommm=\"0\" bbottominch=\"0\"/>\n";
 
- 
+
     QTextStream stream (&in);
 
     m_stepsize = in.size()/50;
@@ -120,13 +119,13 @@ APPLIXWORDImport::filter (const QString &fileIn, const QString &fileOut,
     int  pos, ok;
     char stylename[100];
     QString           mystr, textstr;
-    QList<t_mycolor>  mcol;
+    Q3PtrList<t_mycolor>  mcol;
     QStringList       mcoltxt;
 
     /**************************************************************************
      * Read header                                                            *
      **************************************************************************/
-    if (! readHeader (stream, in)) return false;
+    if (! readHeader (stream, in)) return KoFilter::StupidError;
 
 
     while (!stream.atEnd())
@@ -143,14 +142,14 @@ APPLIXWORDImport::filter (const QString &fileIn, const QString &fileOut,
           printf ("Start styles\n");
           t_mycolor *col = new t_mycolor; // delete is in place
           QString    coltxt ;
-          int zaehler = 0;
+          int zaehler = 0; // Note: "zaehler" means "counter" in English
           do
 	  {
             mystr = readTagLine (stream, in);
             if (mystr == "<end_styles>")
 	    {
              ok = false;
-             printf ("End styles\n\n");
+             kDebug(30517)<<"End styles";
 	    }
 	    else
 	    {
@@ -163,9 +162,7 @@ APPLIXWORDImport::filter (const QString &fileIn, const QString &fileOut,
                 rueck = sscanf ((const char *) mystr.latin1() ,
                                 ":%d:%d:%d:%d>",
 	                         &col->c, &col->m, &col->y, &col->k);
-		printf ("  Color %3d: %3d %3d %3d %3d %s\n",
-	                zaehler, col->c, col->m, col->y, col->k,
-	                (const char *)  coltxt.latin1());
+		kDebug(30517)<<"  Color" <<  zaehler<<"  :"<<col->c <<"" << col->m<<""<< col->y<<""<< col->k<<""<<coltxt<<"";
                 zaehler ++;
 
                 // Color transformation cmyk -> rgb
@@ -191,18 +188,18 @@ APPLIXWORDImport::filter (const QString &fileIn, const QString &fileOut,
          ***********************************************************************/
         else if (mystr == "<start_data Applix>")
 	{
-          printf ("\nEmbedded Applix object starts:\n");
+          kDebug(30517)<<"\nEmbedded Applix object starts:";
           do
 	  {
             mystr = readTagLine (stream, in);
             if (mystr == "<end_data>") ok = false;
 	    else
 	    {
-              printf ("   %s\n", (const char *)  mystr.latin1());
+              kDebug(30517)<<""<<mystr;
 	    }
 	  }
           while (ok == true);
-          printf ("Embedded Applix object ends\n\n");
+          kDebug(30517)<<"Embedded Applix object ends";
 
         }
         /**********************************************************************
@@ -210,28 +207,28 @@ APPLIXWORDImport::filter (const QString &fileIn, const QString &fileOut,
          **********************************************************************/
         else if (mystr.startsWith ("<start_hdrftr "))
 	{
-          printf ("\nHeader/Footer starts:\n");
+          kDebug(30517)<<"\nHeader/Footer starts:";
           do
 	  {
             mystr = readTagLine (stream, in);
             if (mystr == "<end_hdrftr>") ok = false;
 	    else
 	    {
-              printf ("    %s\n", (const char *)  mystr.latin1());
+              kDebug(30517)<<""<<mystr;
 	    }
 	  }
           while (ok == true);
-          printf ("\nHeader/Footer ends\n");
+          kDebug(30517)<<"\nHeader/Footer ends";
         }
         /**********************************************************************
          * found a paragraph string                                           *
          **********************************************************************/
         else if (mystr.startsWith ("<P "))
 	{
-	   sscanf ( (const char *) mystr.latin1(), "<P \"%s\"", stylename);
+	   sscanf ( (const char *) mystr.latin1(), "<P \"%99s\"", stylename);
            mystr.remove (0, 5+strlen(stylename));
-           printf (" Para  Name: %s\n", stylename);
-           printf ("       Rest: %s\n", (const char *) mystr.latin1());
+           kDebug(30517)<<" Para  Name:"<< stylename;
+           kDebug(30517)<<"       Rest:"<<mystr;
 	}
         /**********************************************************************
          * found a textstring                                                 *
@@ -246,22 +243,23 @@ APPLIXWORDImport::filter (const QString &fileIn, const QString &fileOut,
           // Remove ending >
           mystr.remove (mystr.length()-1, 1);
 
-          // Seperate textstring "
+          // Separate textstring "
           ok = true;
           int y=0;
           do
 	  {
              pos = mystr.find ("\"", y);
-             printf ("POS:%d  length:%d y:%d\n", pos, mystr.length(), y);
-             printf ("<%s>", (const char *) mystr.latin1() );
+	     kDebug(30517)<<"POS:"<<pos<<" length:"<< mystr.length()<<" y:"<<y;
+
+             kDebug(30517)<<"<"<<mystr<<" >";
              if(  (pos-1 > -1) && (mystr[pos-1] == '\\'))
              {
-               printf (" No string end - but Gnsefsschen\n");
+               kDebug(30517)<<" No string end - but Gnsefsschen";
                y=pos+1;
              }
              else
              {
-               printf (" String end //\n");
+               kDebug(30517)<<" String end //";
                ok = false;
              }
 	  }
@@ -269,10 +267,8 @@ APPLIXWORDImport::filter (const QString &fileIn, const QString &fileOut,
 
           textstr = mystr.left (pos);
           mystr.remove (0, pos+1);
-          mystr.stripWhiteSpace();
-          printf ("Text:<%s> %d  Rest:<%s> \n",
-                  (const char *) textstr.latin1(), pos,
-                  (const char *) mystr.latin1() );
+          mystr.trimmed();
+	  kDebug(30517) <<"Text:<" <<textstr <<" >"<< pos<<"  Rest:<"<< mystr<<">";
 
           // split format
           QStringList typeList;
@@ -283,53 +279,51 @@ APPLIXWORDImport::filter (const QString &fileIn, const QString &fileOut,
           int nn=0;
           for (QStringList::Iterator it = typeList.begin(); it != typeList.end(); ++it )
           {
-            printf ("   No: %2d   >%s< = ",
-                    nn, (*it).latin1() );
-            nn++;
+            kDebug(30517) <<"   No:"<< nn<<"   >"<< (*it)<<"< =";
 
             // Looking for bold
             if      ((*it) == "bold")
             {
               bold = 1;
-              printf ("bold\n");
+              kDebug(30517)<<"bold";
 	    }
             else if ((*it) == "no-bold")
             {
               bold = 0;
-              printf ("no bold\n");
+              kDebug(30517)<<"no bold";
 	    }
             else if ((*it) == "italic")
             {
               italic = 1;
-              printf ("italic\n");
+              kDebug(30517)<<"italic";
 	    }
             else if ((*it) == "no-italic")
             {
               italic = 0;
-              printf ("no italic\n");
+              kDebug(30517) <<"no italic";
 	    }
             else if ((*it) == "underline")
             {
               underline = 1;
-              printf ("underline\n");
+              kDebug(30517)<<"underline";
 	    }
             else if ((*it) == "no-underline")
             {
               underline = 0;
-              printf ("no underline\n");
+              kDebug(30517) <<"no underline";
 	    }
             else if ((*it).startsWith ("size"))
             {
               (*it).remove (0, 5);
 	      sscanf ( (const char *) (*it).latin1(), "%d", &fontsize);
-              printf ("fontsize: %d\n", fontsize);
+              kDebug(30517)<<"fontsize:"<< fontsize;
 	    }
             else if ((*it).startsWith ("face"))
             {
               (*it).remove (0, 6);
 	      (*it).remove ((*it).length()-1, 1);
   	      fontname = *it;
-              printf ("fontname: %s\n", (const char *) fontname.latin1());
+              kDebug(30517)<<"fontname:"<<fontname;
 	    }
             else if ((*it).startsWith ("color:"))
             {
@@ -337,17 +331,16 @@ APPLIXWORDImport::filter (const QString &fileIn, const QString &fileOut,
 	      (*it).remove ((*it).length()-1, 1);
               colname = *it;
               colpos = mcoltxt.findIndex (colname);
-              printf ("  Color: %s %d \n", (const char *) colname.latin1(),
-                                           colpos );
+	      kDebug(30517) <<"  Color:"<< colname<<""<< colpos <<"";
 	    }
             else
             {
-	      printf  ("%s\n", (const char *) (*it).latin1());
+	      kDebug(30517)<<""<< (*it);
             }
 
 
 	  }
-          printf ("\n");
+          kDebug(30517) <<"";
 
           // Replaces Part for & <>, applixwear special characters and qouts
           replaceSpecial (textstr);
@@ -359,7 +352,7 @@ APPLIXWORDImport::filter (const QString &fileIn, const QString &fileOut,
           str += textstr;
           str += "</TEXT>\n";
 
-          if (bold == 1 || underline == 1 || italic == 1 || fontsize != 12 || 
+          if (bold == 1 || underline == 1 || italic == 1 || fontsize != 12 ||
               colpos != -1 || !fontname.isEmpty())
 	  {
             str += "     <LAYOUT>\n";
@@ -395,8 +388,7 @@ APPLIXWORDImport::filter (const QString &fileIn, const QString &fileOut,
 
             if (colpos != -1)
 	    {
-              t_mycolor *mc = new t_mycolor; // delete is in place
-              mc = mcol.at(colpos);
+              t_mycolor *mc = mcol.at(colpos);
               str += "       <COLOR red=\"";
 
               str += QString::number (mc->r);
@@ -405,7 +397,6 @@ APPLIXWORDImport::filter (const QString &fileIn, const QString &fileOut,
               str += "\" blue=\"";
               str += QString::number (mc->b);
               str += "\" />\n";
-              delete mc;
 	    }
 
             str += "      </FORMAT>\n";
@@ -420,24 +411,22 @@ APPLIXWORDImport::filter (const QString &fileIn, const QString &fileOut,
     str += "  </FRAMESET>\n";
     str += " </FRAMESETS>\n";
     str += "</DOC>\n";
-    printf ("Text %s\n", (const char *) str.utf8());
+    kDebug(30517)<<"Text"<< str;
 
-    KoStore out = KoStore (QString(fileOut), KoStore::Write);
-    if (!out.open ("root"))
+    KoStoreDevice* out = m_chain->storageFile( "root", KoStore::Write );
+    if (!out)
     {
-        kdError(30502) << "Unable to open output file!" << endl;
+        kError(30517) << "Unable to open output file!" << endl;
         in.close  ();
-        out.close ();
-        return false;
+        return KoFilter::StorageCreationError;
     }
 
-    QCString cstring = str.utf8 ();
+    QByteArray cstring = str.toUtf8 ();
 
-    out.write ((const char*) cstring, cstring.length());
+    out->write ((const char*) cstring, cstring.length());
 
-    out.close ();
     in.close ();
-    return true;
+    return KoFilter::OK;
 }
 
 
@@ -611,7 +600,7 @@ APPLIXWORDImport::specCharfind (QChar a, QChar b)
 
    else if ( (a == 'n') && (b == 'h') ) chr = '';
 
-   else if ( (a == 'k') && (b == 'a') ) chr = '';
+   else if ( (a == 'k') && (b == 'a') ) chr = ' ';
 
    else if ( (a == 'a') && (b == 'j') ) chr = '!';
 
@@ -637,10 +626,10 @@ APPLIXWORDImport::readTagLine (QTextStream &stream, QFile &in)
   int     ok, pos;
 
    // Read one line
-   mystr = nextLine (stream); 
+   mystr = nextLine (stream);
 
    // Delete whitespaces
-   mystr.stripWhiteSpace();
+   mystr.trimmed();
 
    // Look if the tag continues on the next line
    if ((mystr.length() == 80) && (mystr[mystr.length()-1] == '\\') )
@@ -652,7 +641,7 @@ APPLIXWORDImport::readTagLine (QTextStream &stream, QFile &in)
        pos = in.at ();
 
        // Read next line
-       mystrn = nextLine (stream); 
+       mystrn = nextLine (stream);
 
        // Is the new line a new tag line
        if (mystrn[0] == ' ')
@@ -696,9 +685,9 @@ APPLIXWORDImport::replaceSpecial (QString &textstr)
   int ok, pos;
 
    // 1. Replace Part for this characters: <, >, &
-   textstr.replace (QRegExp ("&"), "&amp;");
-   textstr.replace (QRegExp ("<"), "&lt;");
-   textstr.replace (QRegExp (">"), "&gt;");
+   textstr.replace ('&', "&amp;");
+   textstr.replace ('<', "&lt;");
+   textstr.replace ('>', "&gt;");
 
 
    // 2. Replace part for this characters: applixwear qoutes
@@ -761,12 +750,12 @@ APPLIXWORDImport::replaceSpecial (QString &textstr)
  *                                                                            *
  ******************************************************************************/
 int
-APPLIXWORDImport::readHeader (QTextStream &stream, QFile &in)  
+APPLIXWORDImport::readHeader (QTextStream &stream, QFile &in)
 {
   QString mystr;
   int     rueck;
-  int     vers[3] = { 0, 0, 0 }; 
-                       
+  int     vers[3] = { 0, 0, 0 };
+
     // Read Headline
     mystr = readTagLine (stream, in);
 
