@@ -14,8 +14,8 @@
 ** Library General Public License for more details.
 **
 ** To receive a copy of the GNU Library General Public License, write to the
-** Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-** Boston, MA  02111-1307, USA.
+** Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 **
 */
 
@@ -23,12 +23,14 @@
 #define __KWORD_LISTTABLE_H__
 
 #include "table.h"
+//Added by qt3to4:
+#include <Q3PtrList>
 
 /**
  * This class hold a list of tables. It just a wrapper for \verbatim QPtrList<Table> \endverbatim
  * to add a frame in a table if the table exists else to create a new table.
  */
-class ListTable: public QPtrList<Table>
+class ListTable: public Q3PtrList<Table>
 {
 	public:
 		/**
