@@ -1,5 +1,3 @@
-/* $Id: mswriteexport.h 204223 2003-02-01 19:49:14Z dang $ */
-
 /* This file is part of the KDE project
    Copyright (C) 2002-2003 Clarence Dang <dang@kde.org>
 
@@ -14,24 +12,26 @@
 
    You should have received a copy of the GNU Library General Public License
    Version 2 along with this library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc.,	59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   write to the Free Software Foundation, Inc.,	51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef MSWRITEEXPORT_H
 #define MSWRITEEXPORT_H
 
-#include <koFilter.h>
+#include <KoFilter.h>
+//Added by qt3to4:
+#include <QByteArray>
 
 class MSWriteExport : public KoFilter
 {
 	Q_OBJECT
 
 public:
-	MSWriteExport (KoFilter *parent, const char *name, const QStringList &);
+	MSWriteExport (QObject* parent, const QStringList &);
 	virtual ~MSWriteExport ();
 
-	KoFilter::ConversionStatus convert (const QCString &from, const QCString &to);
+	KoFilter::ConversionStatus convert (const QByteArray &from, const QByteArray &to);
 };
 
 #endif // MSWRITEEXPORT_H
