@@ -22,15 +22,16 @@
 #include "ooutils.h"
 #include <KoDocument.h>
 #include <KoStyleStack.h>
+#include <KoXmlReader.h>
 #include <qdom.h>
-#include <qcolor.h>
-#include <qimage.h>
+#include <QColor>
+#include <QImage>
 #include <KoUnit.h>
-#include <qregexp.h>
+#include <QRegExp>
 #include <kdebug.h>
 #include <kzip.h>
 #include <KoDom.h>
-#include <qxml.h>
+#include <QtXml>
 
 const char* const ooNS::office="http://openoffice.org/2000/office";
 const char* const ooNS::style="http://openoffice.org/2000/style";
@@ -46,13 +47,13 @@ const char* const ooNS::dc="http://purl.org/dc/elements/1.1/";
 const char* const ooNS::meta="http://openoffice.org/2000/meta";
 const char* const ooNS::config="http://openoffice.org/2001/config";
 
-QString OoUtils::expandWhitespace(const QDomElement& tag)
+QString OoUtils::expandWhitespace(const KoXmlElement& tag)
 {
     //tags like <text:s text:c="4">
 
     int howmany=1;
     if (tag.hasAttributeNS( ooNS::text, "c"))
-        howmany = tag.attributeNS( ooNS::text, "c", QString::null).toInt();
+        howmany = tag.attributeNS( ooNS::text, "c", QString()).toInt();
 
     QString result;
     return result.fill(32, howmany);
@@ -94,20 +95,20 @@ bool OoUtils::parseBorder(const QString & tag, double * width, int * style, QCol
 
 void OoUtils::importIndents( QDomElement& parentElement, const KoStyleStack& styleStack )
 {
-    if ( styleStack.hasAttributeNS( ooNS::fo, "margin-left" ) || // 3.11.19
-         styleStack.hasAttributeNS( ooNS::fo, "margin-right" ) )
+    if ( styleStack.hasProperty( ooNS::fo, "margin-left" ) || // 3.11.19
+         styleStack.hasProperty( ooNS::fo, "margin-right" ) )
          // *text-indent must always be bound to either margin-left or margin-right
     {
-        double marginLeft = KoUnit::parseValue( styleStack.attributeNS( ooNS::fo, "margin-left" ) );
-        double marginRight = KoUnit::parseValue( styleStack.attributeNS( ooNS::fo, "margin-right" ) );
+        double marginLeft = KoUnit::parseValue( styleStack.property( ooNS::fo, "margin-left" ) );
+        double marginRight = KoUnit::parseValue( styleStack.property( ooNS::fo, "margin-right" ) );
         double first = 0;
-        if (styleStack.attributeNS( ooNS::style, "auto-text-indent") == "true") // style:auto-text-indent takes precedence
+        if (styleStack.property( ooNS::style, "auto-text-indent") == "true") // style:auto-text-indent takes precedence
             // ### "indented by a value that is based on the current font size"
             // ### and "requires margin-left and margin-right
             // ### but how much is the indent?
             first = 10;
-        else if (styleStack.hasAttributeNS( ooNS::fo, "text-indent"))
-            first = KoUnit::parseValue( styleStack.attributeNS( ooNS::fo, "text-indent"));
+        else if (styleStack.hasProperty( ooNS::fo, "text-indent"))
+            first = KoUnit::parseValue( styleStack.property( ooNS::fo, "text-indent"));
 
         if ( marginLeft != 0 || marginRight != 0 || first != 0 )
         {
@@ -125,10 +126,10 @@ void OoUtils::importIndents( QDomElement& parentElement, const KoStyleStack& sty
 
 void OoUtils::importLineSpacing( QDomElement& parentElement, const KoStyleStack& styleStack )
 {
-    if( styleStack.hasAttributeNS( ooNS::fo, "line-height") )
+    if( styleStack.hasProperty( ooNS::fo, "line-height") )
     {
         // Fixed line height
-        QString value = styleStack.attributeNS( ooNS::fo, "line-height" ); // 3.11.1
+        QString value = styleStack.property( ooNS::fo, "line-height" ); // 3.11.1
         if ( value != "normal" )
         {
             QDomElement lineSpacing = parentElement.ownerDocument().createElement( "LINESPACING" );
@@ -138,7 +139,7 @@ void OoUtils::importLineSpacing( QDomElement& parentElement, const KoStyleStack&
                 lineSpacing.setAttribute("type","oneandhalf");
             else if( value=="200%")
                 lineSpacing.setAttribute("type","double");
-            else if ( value.find('%') > -1 )
+            else if ( value.contains('%') )
             {
                 double percent = value.toDouble();
                 lineSpacing.setAttribute("type", "multiple");
@@ -146,19 +147,19 @@ void OoUtils::importLineSpacing( QDomElement& parentElement, const KoStyleStack&
             }
             else // fixed value (use KoUnit::parseValue to get it in pt)
             {
-                kdWarning(30519) << "Unhandled value for fo:line-height: " << value << endl;
+                kWarning(30519) << "Unhandled value for fo:line-height: " << value;
             }
             parentElement.appendChild( lineSpacing );
         }
     }
     // Line-height-at-least is mutually exclusive with line-height
-    else if ( styleStack.hasAttributeNS( ooNS::style, "line-height-at-least") ) // 3.11.2
+    else if ( styleStack.hasProperty( ooNS::style, "line-height-at-least") ) // 3.11.2
     {
-        QString value = styleStack.attributeNS( ooNS::style, "line-height-at-least" );
+        QString value = styleStack.property( ooNS::style, "line-height-at-least" );
         // kotext has "at least" but that's for the linespacing, not for the entire line height!
         // Strange. kotext also has "at least" for the whole line height....
         // Did we make the wrong choice in kotext?
-        //kdWarning(30519) << "Unimplemented support for style:line-height-at-least: " << value << endl;
+        //kWarning(30519) << "Unimplemented support for style:line-height-at-least: " << value;
         // Well let's see if this makes a big difference.
         QDomElement lineSpacing = parentElement.ownerDocument().createElement("LINESPACING");
         lineSpacing.setAttribute("type", "atleast");
@@ -166,9 +167,9 @@ void OoUtils::importLineSpacing( QDomElement& parentElement, const KoStyleStack&
         parentElement.appendChild(lineSpacing);
     }
     // Line-spacing is mutually exclusive with line-height and line-height-at-least
-    else if ( styleStack.hasAttributeNS( ooNS::style, "line-spacing") ) // 3.11.3
+    else if ( styleStack.hasProperty( ooNS::style, "line-spacing") ) // 3.11.3
     {
-        double value = KoUnit::parseValue( styleStack.attributeNS( ooNS::style, "line-spacing" ) );
+        double value = KoUnit::parseValue( styleStack.property( ooNS::style, "line-spacing" ) );
         if ( value != 0.0 )
         {
             QDomElement lineSpacing = parentElement.ownerDocument().createElement( "LINESPACING" );
@@ -182,11 +183,11 @@ void OoUtils::importLineSpacing( QDomElement& parentElement, const KoStyleStack&
 
 void OoUtils::importTopBottomMargin( QDomElement& parentElement, const KoStyleStack& styleStack )
 {
-    if( styleStack.hasAttributeNS( ooNS::fo, "margin-top") || // 3.11.22
-        styleStack.hasAttributeNS( ooNS::fo, "margin-bottom"))
+    if( styleStack.hasProperty( ooNS::fo, "margin-top") || // 3.11.22
+        styleStack.hasProperty( ooNS::fo, "margin-bottom"))
     {
-        double mtop = KoUnit::parseValue( styleStack.attributeNS( ooNS::fo, "margin-top" ) );
-        double mbottom = KoUnit::parseValue( styleStack.attributeNS( ooNS::fo, "margin-bottom" ) );
+        double mtop = KoUnit::parseValue( styleStack.property( ooNS::fo, "margin-top" ) );
+        double mbottom = KoUnit::parseValue( styleStack.property( ooNS::fo, "margin-bottom" ) );
         if( mtop != 0 || mbottom != 0 )
         {
             QDomElement offset = parentElement.ownerDocument().createElement( "OFFSETS" );
@@ -201,15 +202,15 @@ void OoUtils::importTopBottomMargin( QDomElement& parentElement, const KoStyleSt
 
 void OoUtils::importTabulators( QDomElement& parentElement, const KoStyleStack& styleStack )
 {
-    if ( !styleStack.hasChildNodeNS( ooNS::style, "tab-stops" ) ) // 3.11.10
+    if ( !styleStack.hasChildNode( ooNS::style, "tab-stops" ) ) // 3.11.10
         return;
-    QDomElement tabStops = styleStack.childNodeNS( ooNS::style, "tab-stops" );
-    //kdDebug(30519) << k_funcinfo << tabStops.childNodes().count() << " tab stops in layout." << endl;
-    for ( QDomNode it = tabStops.firstChild(); !it.isNull(); it = it.nextSibling() )
+    KoXmlElement tabStops = styleStack.childNode( ooNS::style, "tab-stops" );
+    //kDebug(30519) << tabStops.childNodes().count() <<" tab stops in layout.";
+    for ( KoXmlNode it = tabStops.firstChild(); !it.isNull(); it = it.nextSibling() )
     {
-        QDomElement tabStop = it.toElement();
+        KoXmlElement tabStop = it.toElement();
         Q_ASSERT( tabStop.tagName() == "style:tab-stop" );
-        QString type = tabStop.attributeNS( ooNS::style, "type", QString::null ); // left, right, center or char
+        QString type = tabStop.attributeNS( ooNS::style, "type", QString() ); // left, right, center or char
 
         QDomElement elem = parentElement.ownerDocument().createElement( "TABULATOR" );
         int kOfficeType = 0;
@@ -220,24 +221,24 @@ void OoUtils::importTabulators( QDomElement& parentElement, const KoStyleStack&
         else if ( type == "right" )
             kOfficeType = 2;
         else if ( type == "char" ) {
-            QString delimiterChar = tabStop.attributeNS( ooNS::style, "char", QString::null ); // single character
+            QString delimiterChar = tabStop.attributeNS( ooNS::style, "char", QString() ); // single character
             elem.setAttribute( "alignchar", delimiterChar );
             kOfficeType = 3; // "alignment on decimal point"
         }
 
         elem.setAttribute( "type", kOfficeType );
 
-        double pos = KoUnit::parseValue( tabStop.attributeNS( ooNS::style, "position", QString::null ) );
+        double pos = KoUnit::parseValue( tabStop.attributeNS( ooNS::style, "position", QString() ) );
         elem.setAttribute( "ptpos", pos );
 
         // TODO Convert leaderChar's unicode value to the KOffice enum
         // (blank/dots/line/dash/dash-dot/dash-dot-dot, 0 to 5)
-        QString leaderChar = tabStop.attributeNS( ooNS::style, "leader-char", QString::null ); // single character
+        QString leaderChar = tabStop.attributeNS( ooNS::style, "leader-char", QString() ); // single character
         if ( !leaderChar.isEmpty() )
         {
             int filling = 0;
             QChar ch = leaderChar[0];
-            switch (ch.latin1()) {
+            switch (ch.toLatin1()) {
             case '.':
                 filling = 1; break;
             case '-':
@@ -257,12 +258,12 @@ void OoUtils::importTabulators( QDomElement& parentElement, const KoStyleStack&
 
 void OoUtils::importBorders( QDomElement& parentElement, const KoStyleStack& styleStack )
 {
-    if (styleStack.hasAttributeNS( ooNS::fo, "border","left"))
+    if (styleStack.hasProperty( ooNS::fo, "border","left"))
     {
         double width;
         int style;
         QColor color;
-        if (OoUtils::parseBorder(styleStack.attributeNS( ooNS::fo, "border", "left"), &width, &style, &color))
+        if (OoUtils::parseBorder(styleStack.property( ooNS::fo, "border", "left"), &width, &style, &color))
         {
             QDomElement lbElem = parentElement.ownerDocument().createElement("LEFTBORDER");
             lbElem.setAttribute("width", width);
@@ -276,12 +277,12 @@ void OoUtils::importBorders( QDomElement& parentElement, const KoStyleStack& sty
         }
     }
 
-    if (styleStack.hasAttributeNS( ooNS::fo, "border", "right"))
+    if (styleStack.hasProperty( ooNS::fo, "border", "right"))
     {
         double width;
         int style;
         QColor color;
-        if (OoUtils::parseBorder(styleStack.attributeNS( ooNS::fo, "border", "right"), &width, &style, &color))
+        if (OoUtils::parseBorder(styleStack.property( ooNS::fo, "border", "right"), &width, &style, &color))
         {
             QDomElement lbElem = parentElement.ownerDocument().createElement("RIGHTBORDER");
             lbElem.setAttribute("width", width);
@@ -295,12 +296,12 @@ void OoUtils::importBorders( QDomElement& parentElement, const KoStyleStack& sty
         }
     }
 
-    if (styleStack.hasAttributeNS( ooNS::fo, "border", "top"))
+    if (styleStack.hasProperty( ooNS::fo, "border", "top"))
     {
         double width;
         int style;
         QColor color;
-        if (OoUtils::parseBorder(styleStack.attributeNS( ooNS::fo, "border", "top"), &width, &style, &color))
+        if (OoUtils::parseBorder(styleStack.property( ooNS::fo, "border", "top"), &width, &style, &color))
         {
             QDomElement lbElem = parentElement.ownerDocument().createElement("TOPBORDER");
             lbElem.setAttribute("width", width);
@@ -314,12 +315,12 @@ void OoUtils::importBorders( QDomElement& parentElement, const KoStyleStack& sty
         }
     }
 
-    if (styleStack.hasAttributeNS( ooNS::fo, "border", "bottom"))
+    if (styleStack.hasProperty( ooNS::fo, "border", "bottom"))
     {
         double width;
         int style;
         QColor color;
-        if (OoUtils::parseBorder(styleStack.attributeNS( ooNS::fo, "border", "bottom"), &width, &style, &color))
+        if (OoUtils::parseBorder(styleStack.property( ooNS::fo, "border", "bottom"), &width, &style, &color))
         {
             QDomElement lbElem = parentElement.ownerDocument().createElement("BOTTOMBORDER");
             lbElem.setAttribute("width", width);
@@ -375,7 +376,7 @@ void OoUtils::importUnderline( const QString& in, QString& underline, QString& s
         styleline = "solid";
     }
     else
-        kdWarning(30519) << k_funcinfo << " unsupported text-underline value: " << in << endl;
+        kWarning(30519) << " unsupported text-underline value: " << in;
 }
 
 void OoUtils::importTextPosition( const QString& text_position, QString& value, QString& relativetextsize )
@@ -383,19 +384,19 @@ void OoUtils::importTextPosition( const QString& text_position, QString& value,
     //OO: <vertical position (% or sub or super)> [<size as %>]
     //Examples: "super" or "super 58%" or "82% 58%" (where 82% is the vertical position)
     // TODO in kword: vertical positions other than sub/super
-    QStringList lst = QStringList::split( ' ', text_position );
+    QStringList lst = text_position.split( ' ' );
     if ( !lst.isEmpty() )
     {
-        QString textPos = lst.front().stripWhiteSpace();
+        QString textPos = lst.front().trimmed();
         QString textSize;
         lst.pop_front();
         if ( !lst.isEmpty() )
-            textSize = lst.front().stripWhiteSpace();
+            textSize = lst.front().trimmed();
         if ( !lst.isEmpty() )
-            kdWarning(30519) << "Strange text position: " << text_position << endl;
+            kWarning(30519) << "Strange text position: " << text_position;
         bool super = textPos == "super";
         bool sub = textPos == "sub";
-        if ( textPos.endsWith("%") )
+        if ( textPos.endsWith('%') )
         {
             textPos.truncate( textPos.length() - 1 );
             // This is where we interpret the text position into kotext's simpler
@@ -412,7 +413,7 @@ void OoUtils::importTextPosition( const QString& text_position, QString& value,
             value = "1";
         else
             value = "0";
-        if ( !textSize.isEmpty() && textSize.endsWith("%") )
+        if ( !textSize.isEmpty() && textSize.endsWith('%') )
         {
             textSize.truncate( textSize.length() - 1 );
             double textSizeValue = textSize.toDouble() / 100; // e.g. 0.58
@@ -423,16 +424,16 @@ void OoUtils::importTextPosition( const QString& text_position, QString& value,
         value = "0";
 }
 
-void OoUtils::createDocumentInfo(QDomDocument &_meta, QDomDocument & docinfo)
+void OoUtils::createDocumentInfo(KoXmlDocument &_meta, QDomDocument & docinfo)
 {
-    QDomNode meta   = KoDom::namedItemNS( _meta, ooNS::office, "document-meta" );
-    QDomNode office = KoDom::namedItemNS( meta, ooNS::office, "meta" );
+    KoXmlNode meta   = KoXml::namedItemNS( _meta, ooNS::office, "document-meta" );
+    KoXmlNode office = KoXml::namedItemNS( meta, ooNS::office, "meta" );
 
     if ( office.isNull() )
         return;
     QDomElement elementDocInfo  = docinfo.documentElement();
 
-    QDomElement e = KoDom::namedItemNS( office, ooNS::dc, "creator" );
+    KoXmlElement e = KoXml::namedItemNS( office, ooNS::dc, "creator" );
     if ( !e.isNull() && !e.text().isEmpty() )
     {
         QDomElement author = docinfo.createElement( "author" );
@@ -442,7 +443,7 @@ void OoUtils::createDocumentInfo(QDomDocument &_meta, QDomDocument & docinfo)
         elementDocInfo.appendChild( author);
     }
 
-    e = KoDom::namedItemNS( office, ooNS::dc, "title" );
+    e = KoXml::namedItemNS( office, ooNS::dc, "title" );
     if ( !e.isNull() && !e.text().isEmpty() )
     {
         QDomElement about = docinfo.createElement( "about" );
@@ -452,7 +453,7 @@ void OoUtils::createDocumentInfo(QDomDocument &_meta, QDomDocument & docinfo)
         elementDocInfo.appendChild( about );
     }
 
-    e = KoDom::namedItemNS( office, ooNS::dc, "description" );
+    e = KoXml::namedItemNS( office, ooNS::dc, "description" );
     if ( !e.isNull() && !e.text().isEmpty() )
     {
         QDomElement about = elementDocInfo.namedItem( "about" ).toElement();
@@ -464,7 +465,7 @@ void OoUtils::createDocumentInfo(QDomDocument &_meta, QDomDocument & docinfo)
         about.appendChild( title );
         title.appendChild( docinfo.createTextNode( e.text() ) );
     }
-    e = KoDom::namedItemNS( office, ooNS::dc, "subject" );
+    e = KoXml::namedItemNS( office, ooNS::dc, "subject" );
     if ( !e.isNull() && !e.text().isEmpty() )
     {
         QDomElement about = elementDocInfo.namedItem( "about" ).toElement();
@@ -476,7 +477,7 @@ void OoUtils::createDocumentInfo(QDomDocument &_meta, QDomDocument & docinfo)
         about.appendChild( subject );
         subject.appendChild( docinfo.createTextNode( e.text() ) );
     }
-    e = KoDom::namedItemNS( office, ooNS::meta, "keywords" );
+    e = KoXml::namedItemNS( office, ooNS::meta, "keywords" );
     if ( !e.isNull() )
     {
         QDomElement about = elementDocInfo.namedItem( "about" ).toElement();
@@ -484,7 +485,7 @@ void OoUtils::createDocumentInfo(QDomDocument &_meta, QDomDocument & docinfo)
             about = docinfo.createElement( "about" );
             elementDocInfo.appendChild( about );
         }
-        QDomElement tmp = KoDom::namedItemNS( e, ooNS::meta, "keyword" );
+        KoXmlElement tmp = KoDom::namedItemNS( e, ooNS::meta, "keyword" );
         if ( !tmp.isNull() && !tmp.text().isEmpty() )
         {
             QDomElement keyword = docinfo.createElement( "keyword" );
@@ -494,13 +495,13 @@ void OoUtils::createDocumentInfo(QDomDocument &_meta, QDomDocument & docinfo)
     }
 }
 
-KoFilter::ConversionStatus OoUtils::loadAndParse(const QString& fileName, QDomDocument& doc, KoStore *m_store )
+KoFilter::ConversionStatus OoUtils::loadAndParse(const QString& fileName, KoXmlDocument& doc, KoStore *m_store )
 {
-    kdDebug(30518) << "loadAndParse: Trying to open " << fileName << endl;
+    kDebug(30518) <<"loadAndParse: Trying to open" << fileName;
 
     if (!m_store->open(fileName))
     {
-        kdWarning(30519) << "Entry " << fileName << " not found!" << endl;
+        kWarning(30519) << "Entry " << fileName << " not found!";
         return KoFilter::FileNotFound;
     }
     KoFilter::ConversionStatus convertStatus = loadAndParse( m_store->device(),doc, fileName );
@@ -509,7 +510,7 @@ KoFilter::ConversionStatus OoUtils::loadAndParse(const QString& fileName, QDomDo
 
 }
 
-KoFilter::ConversionStatus OoUtils::loadAndParse(QIODevice* io, QDomDocument& doc, const QString & fileName)
+KoFilter::ConversionStatus OoUtils::loadAndParse(QIODevice* io, KoXmlDocument& doc, const QString & fileName)
 {
     QXmlInputSource source( io );
     // Copied from QDomDocumentPrivate::setContent, to change the whitespace thing
@@ -521,42 +522,42 @@ KoFilter::ConversionStatus OoUtils::loadAndParse(QIODevice* io, QDomDocument& do
     int errorLine, errorColumn;
     if ( !doc.setContent( &source, &reader, &errorMsg, &errorLine, &errorColumn ) )
     {
-        kdError(30519) << "Parsing error in " << fileName << "! Aborting!" << endl
+        kError(30519) << "Parsing error in " << fileName << "! Aborting!" << endl
             << " In line: " << errorLine << ", column: " << errorColumn << endl
             << " Error message: " << errorMsg << endl;
         return KoFilter::ParsingError;
     }
 
-    kdDebug(30519) << "File " << fileName << " loaded and parsed!" << endl;
+    kDebug(30519) <<"File" << fileName <<" loaded and parsed!";
 
     return KoFilter::OK;
 
 }
 
-KoFilter::ConversionStatus OoUtils::loadAndParse(const QString& filename, QDomDocument& doc, KZip * m_zip)
+KoFilter::ConversionStatus OoUtils::loadAndParse(const QString& filename, KoXmlDocument& doc, KZip * m_zip)
 {
-    kdDebug(30519) << "Trying to open " << filename << endl;
+    kDebug(30519) <<"Trying to open" << filename;
 
     if (!m_zip)
     {
-        kdError(30519) << "No ZIP file!" << endl;
+        kError(30519) << "No ZIP file!" << endl;
         return KoFilter::CreationError; // Should not happen
     }
 
     const KArchiveEntry* entry = m_zip->directory()->entry( filename );
     if (!entry)
     {
-        kdWarning(30519) << "Entry " << filename << " not found!" << endl;
+        kWarning(30519) << "Entry " << filename << " not found!";
         return KoFilter::FileNotFound;
     }
     if (entry->isDirectory())
     {
-        kdWarning(30519) << "Entry " << filename << " is a directory!" << endl;
+        kWarning(30519) << "Entry " << filename << " is a directory!";
         return KoFilter::WrongFormat;
     }
     const KZipFileEntry* f = static_cast<const KZipFileEntry *>(entry);
-    kdDebug(30519) << "Entry " << filename << " has size " << f->size() << endl;
-    QIODevice* io = f->device();
+    kDebug(30519) <<"Entry" << filename <<" has size" << f->size();
+    QIODevice* io = f->createDevice();
     KoFilter::ConversionStatus convertStatus = loadAndParse( io,doc, filename );
     delete io;
     return convertStatus;
@@ -565,58 +566,55 @@ KoFilter::ConversionStatus OoUtils::loadAndParse(const QString& filename, QDomDo
 KoFilter::ConversionStatus OoUtils::loadThumbnail( QImage& thumbnail, KZip * m_zip )
 {
     const QString filename( "Thumbnails/thumbnail.png" );
-    kdDebug(30519) << "Trying to open thumbnail " << filename << endl;
+    kDebug(30519) <<"Trying to open thumbnail" << filename;
 
     if (!m_zip)
     {
-        kdError(30519) << "No ZIP file!" << endl;
+        kError(30519) << "No ZIP file!" << endl;
         return KoFilter::CreationError; // Should not happen
     }
 
     const KArchiveEntry* entry = m_zip->directory()->entry( filename );
     if (!entry)
     {
-        kdWarning(30519) << "Entry " << filename << " not found!" << endl;
+        kWarning(30519) << "Entry " << filename << " not found!";
         return KoFilter::FileNotFound;
     }
     if (entry->isDirectory())
     {
-        kdWarning(30519) << "Entry " << filename << " is a directory!" << endl;
+        kWarning(30519) << "Entry " << filename << " is a directory!";
         return KoFilter::WrongFormat;
     }
     const KZipFileEntry* f = static_cast<const KZipFileEntry *>(entry);
-    QIODevice* io=f->device();
-    kdDebug(30519) << "Entry " << filename << " has size " << f->size() << endl;
+    QIODevice* io = f->createDevice();
+    kDebug(30519) <<"Entry" << filename <<" has size" << f->size();
 
-    if ( ! io->open( IO_ReadOnly ) )
+    if ( ! io->open( QIODevice::ReadOnly ) )
     {
-        kdWarning(30519) << "Thumbnail could not be opened!" <<endl;
+        kWarning(30519) << "Thumbnail could not be opened!";
         delete io;
         return KoFilter::StupidError;
     }
 
-    QImageIO imageIO( io, "PNG" );
-    if ( ! imageIO.read() )
+    if ( ! thumbnail.load( io, "PNG" ) )
     {
-        kdWarning(30519) << "Thumbnail could not be read!" <<endl;
+        kWarning(30519) << "Thumbnail could not be read!";
         delete io;
         return KoFilter::StupidError;
     }
 
     io->close();
 
-    thumbnail = imageIO.image();
-
     if ( thumbnail.isNull() )
     {
-        kdWarning(30519) << "Read thumbnail is null!" <<endl;
+        kWarning(30519) << "Read thumbnail is null!";
         delete io;
         return KoFilter::StupidError;
     }
 
     delete io;
 
-    kdDebug(30519) << "File " << filename << " loaded!" << endl;
+    kDebug(30519) <<"File" << filename <<" loaded!";
 
     return KoFilter::OK;
 }
