@@ -18,12 +18,12 @@
 
 #include "koChart.h"
 
-#include <qobjectlist.h>
+#include <qobject.h>
 
 using namespace KoChart;
 
-WizardExtension::WizardExtension( Part *part, const char *name )
-    : QObject( part, name )
+WizardExtension::WizardExtension( Part *part )
+    : QObject( part )
 {
     m_part = part;
 }
@@ -32,10 +32,10 @@ WizardExtension::~WizardExtension()
 {
 }
 
-Part::Part( QWidget *parentWidget, const char *widgetName,
-            QObject *parent, const char *name,
+Part::Part( QWidget *parentWidget,
+            QObject *parent,
             bool singleViewMode )
-    : KoDocument( parentWidget, widgetName, parent, name, singleViewMode )
+    : KoDocument( parentWidget, parent, singleViewMode )
 {
 }
 
@@ -45,12 +45,22 @@ Part::~Part()
 
 WizardExtension *Part::wizardExtension()
 {
-    QObjectListIt it( *QObject::children() );
-    for (; it.current(); ++it )
-        if ( it.current()->inherits( "KoChart::WizardExtension" ) )
-            return static_cast<WizardExtension *>( it.current() );
+    QObjectList::ConstIterator end( QObject::children().end() );
+    for (QObjectList::ConstIterator it( QObject::children().begin() ); it != end; ++it ) {
+      WizardExtension* we = ::qobject_cast<WizardExtension *>( *it );
+      if ( we )
+          return we;
+    }
 
     return 0;
 }
 
+ChartInterface::ChartInterface()
+{
+}
+
+ChartInterface::~ChartInterface()
+{
+}
+
 #include "koChart.moc"
