@@ -14,14 +14,14 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef __VTEXTCMD_H__
 #define __VTEXTCMD_H__
 
-#include <qfont.h>
+#include <QFont>
 
 #include "vshapecmd.h"
 
