@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef __VCLIP_H__
@@ -22,7 +22,9 @@
 
 #include "vgroup.h"
 #include "vvisitor.h"
-#include <koffice_export.h>
+#include <karbon_export.h>
+
+class QRectF;
 class VPainter;
 
 /**
@@ -38,12 +40,12 @@ public:
 
 	virtual ~VClipGroup();
 
-	virtual void draw( VPainter* painter, const KoRect* rect = 0L ) const;
+	virtual void draw( VPainter* painter, const QRectF* rect = 0L ) const;
 
 	virtual VClipGroup* clone() const;
 
 	virtual void save( QDomElement& element ) const;
-	virtual void load( const QDomElement& element );
+	virtual void load( const KoXmlElement& element );
 };
 
 
