@@ -14,17 +14,17 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include <qdom.h>
 #include <kdebug.h>
 
-#include <koGenStyles.h>
-#include <kooasiscontext.h>
-#include <koOasisStyles.h>
-#include <koxmlns.h>
+#include <KoGenStyles.h>
+#include <KoOasisLoadingContext.h>
+#include <KoOasisStyles.h>
+#include <KoXmlNS.h>
 
 #include "vfill.h"
 
@@ -33,17 +33,17 @@ VFill::VFill()
 {
 	/*m_gradient.addStop( VColor( Qt::red.rgb() ), 0.0 );
 	m_gradient.addStop( VColor( Qt::yellow.rgb() ), 1.0 );
-	m_gradient.setOrigin( KoPoint( 0, 0 ) );
-	m_gradient.setVector( KoPoint( 0, 50 ) );
+	m_gradient.setOrigin( QPointF( 0, 0 ) );
+	m_gradient.setVector( QPointF( 0, 50 ) );
 	m_gradient.setSpreadMethod( gradient_spread_reflect );*/
-	//kdDebug(38000) << "Size of VFill : " << sizeof(*this) << endl;
+	//kDebug(38000) <<"Size of VFill :" << sizeof(*this);
 }
 
 VFill::VFill( const VColor &c )
 	: m_type( solid )
 {
 	m_color = c;
-	//kdDebug(38000) << "Size of VFill : " << sizeof(*this) << endl;
+	//kDebug(38000) <<"Size of VFill :" << sizeof(*this);
 }
 
 VFill::VFill( const VFill& fill )
@@ -100,43 +100,40 @@ VFill::saveOasis( KoGenStyles &mainStyles, KoGenStyle &style ) const
 }
 
 void
-VFill::loadOasis( const QDomElement &object, KoOasisContext &context )
+VFill::loadOasis( const KoXmlElement &/*object*/, KoOasisLoadingContext &context, VObject* parent )
 {
 	KoStyleStack &stack = context.styleStack();
-	if( stack.hasAttributeNS( KoXmlNS::draw, "fill" ) )
+	if( stack.hasProperty( KoXmlNS::draw, "fill" ) )
 	{
-		if( stack.attributeNS( KoXmlNS::draw, "fill" ) == "solid" )
+		if( stack.property( KoXmlNS::draw, "fill" ) == "solid" )
 		{
 			setType( VFill::solid );
-			setColor( QColor( stack.attributeNS( KoXmlNS::draw, "fill-color" ) ) );
+			setColor( QColor( stack.property( KoXmlNS::draw, "fill-color" ) ) );
 		}
-		else if( stack.attributeNS( KoXmlNS::draw, "fill" ) == "gradient" )
+		else if( stack.property( KoXmlNS::draw, "fill" ) == "gradient" )
 		{
 			setType( VFill::grad );
-			QString style = stack.attributeNS( KoXmlNS::draw, "fill-gradient-name" );
-			kdDebug()<<" style gradient name :"<<style<<endl;
-			QDomElement *grad = context.oasisStyles().drawStyles()[ style ];
-			kdDebug()<<" style gradient name :"<< grad <<endl;
+			QString style = stack.property( KoXmlNS::draw, "fill-gradient-name" );
+			kDebug()<<" style gradient name :"<<style;
+			KoXmlElement *grad = context.oasisStyles().drawStyles()[ style ];
+			kDebug()<<" style gradient name :"<< grad;
 			if( grad )
-				m_gradient.loadOasis( *grad, stack );
+				m_gradient.loadOasis( *grad, stack, parent );
 		}
-		if( stack.hasAttributeNS( KoXmlNS::draw, "opacity" ) )
-			m_color.setOpacity( stack.attributeNS( KoXmlNS::draw, "opacity" ).remove( '%' ).toFloat() / 100. );
+		if( stack.hasProperty( KoXmlNS::draw, "opacity" ) )
+			m_color.setOpacity( stack.property( KoXmlNS::draw, "opacity" ).remove( '%' ).toFloat() / 100. );
 	}
 }
 
 void
-VFill::load( const QDomElement& element )
+VFill::load( const KoXmlElement& element )
 {
 	m_type = none;
 
 	// load color:
-	QDomNodeList list = element.childNodes();
-	for( uint i = 0; i < list.count(); ++i )
+	KoXmlElement e;
+	forEachElement(e, element)
 	{
-		if( list.item( i ).isElement() )
-		{
-			QDomElement e = list.item( i ).toElement();
 			if( e.tagName() == "COLOR" )
 			{
 				m_type = solid;
@@ -152,7 +149,6 @@ VFill::load( const QDomElement& element )
 				m_type = patt;
 				m_pattern.load( e );
 			}
-		}
 	}
 }
 
@@ -161,7 +157,7 @@ VFill::operator=( const VFill& fill )
 {
 	if( this != &fill )
 	{
-		// dont copy the parent!
+		// do not copy the parent!
 		m_type = fill.m_type;
 		m_color = fill.m_color;
 		m_gradient = fill.m_gradient;
@@ -171,4 +167,11 @@ VFill::operator=( const VFill& fill )
 	return *this;
 }
 
-
+void 
+VFill::transform( const QMatrix& m )
+{
+	if( type() == VFill::grad )
+		gradient().transform( m );
+	else if( type() == VFill::patt )
+		pattern().transform( m );
+}
