@@ -13,33 +13,36 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef __VGRADIENT_H__
 #define __VGRADIENT_H__
 
-#include <qptrlist.h>
-#include <qptrvector.h>
+#include <q3ptrlist.h>
+#include <q3ptrvector.h>
 
-#include <koffice_export.h>
-#include <koPoint.h>
+#include <karbon_export.h>
+#include <QPointF>
+
+#include <KoXmlReader.h>
 
 #include "vcolor.h"
 
-class QDomElement;
+class QMatrix;
 class KoGenStyle;
 class KoGenStyles;
 class KoStyleStack;
+class VObject;
 
 class VColorStop
 {
 	public:
 		VColorStop( double r, double m, VColor c )
-			{ rampPoint = r; midPoint = m; color = c; };
+			{ rampPoint = r; midPoint = m; color = c; }
 		VColorStop( const VColorStop& colorStop )
-			{ rampPoint = colorStop.rampPoint; midPoint = colorStop.midPoint; color = colorStop.color; };
+			{ rampPoint = colorStop.rampPoint; midPoint = colorStop.midPoint; color = colorStop.color; }
 
 		VColor color;
 
@@ -51,7 +54,7 @@ class VColorStop
 		float midPoint;
 
 		friend inline bool operator== ( VColorStop& s1, VColorStop& s2 )
-				{ return s1.rampPoint == s2.rampPoint; };
+				{ return s1.rampPoint == s2.rampPoint; }
 }; // VColorStop
 
 class KARBONBASE_EXPORT VGradient
@@ -73,10 +76,10 @@ public:
 		repeat  = 2
 	};
 
-	class VColorStopList : public QPtrList<VColorStop>
+	class VColorStopList : public Q3PtrList<VColorStop>
 	{
 		protected:
-			virtual int compareItems( QPtrCollection::Item item1, QPtrCollection::Item item2 );
+			virtual int compareItems( Q3PtrCollection::Item item1, Q3PtrCollection::Item item2 );
 	}; // VColorStopList
 
 	VGradient( VGradientType type = linear );
@@ -90,27 +93,27 @@ public:
 	VGradientRepeatMethod repeatMethod() const { return m_repeatMethod; }
 	void setRepeatMethod( VGradientRepeatMethod repeatMethod ) { m_repeatMethod = repeatMethod; }
 
-	const QPtrVector<VColorStop> colorStops() const;
+	const Q3PtrVector<VColorStop> colorStops() const;
 	void addStop( const VColorStop& colorStop );
 	void addStop( const VColor &color, float rampPoint, float midPoint );
 	void removeStop( const VColorStop& colorStop );
 	void clearStops();
 
-	KoPoint origin() const { return m_origin; }
-	void setOrigin( const KoPoint &origin ) { m_origin = origin; }
+	QPointF origin() const { return m_origin; }
+	void setOrigin( const QPointF &origin ) { m_origin = origin; }
 
-	KoPoint focalPoint() const { return m_focalPoint; }
-	void setFocalPoint( const KoPoint &focalPoint ) { m_focalPoint = focalPoint; }
+	QPointF focalPoint() const { return m_focalPoint; }
+	void setFocalPoint( const QPointF &focalPoint ) { m_focalPoint = focalPoint; }
 
-	KoPoint vector() const { return m_vector; }
-	void setVector( const KoPoint &vector ) { m_vector = vector; }
+	QPointF vector() const { return m_vector; }
+	void setVector( const QPointF &vector ) { m_vector = vector; }
 
 	void save( QDomElement& element ) const;
 	QString saveOasis( KoGenStyles &mainStyles ) const;
-	void load( const QDomElement& element );
-	void loadOasis( const QDomElement &object, KoStyleStack &stack );
+	void load( const KoXmlElement& element );
+	void loadOasis( const KoXmlElement &object, KoStyleStack &stack, VObject* parent = 0L );
 
-	void transform( const QWMatrix& m );
+	void transform( const QMatrix& m );
 
 protected:
 	VColorStopList        m_colorStops;
@@ -120,9 +123,9 @@ private:
 	VGradientRepeatMethod m_repeatMethod	: 2;
 
 	// coordinates:
-	KoPoint m_origin;
-	KoPoint m_focalPoint;
-	KoPoint m_vector;
+	QPointF m_origin;
+	QPointF m_focalPoint;
+	QPointF m_vector;
 }; // VGradient
 
 #endif /* __VGRADIENT_H__ */
