@@ -13,17 +13,16 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 
 #include <dcopclient.h>
 
-#include "vlayer.h"
 #include "vlayer_iface.h"
 
-
+/*
 VLayerIface::VLayerIface( VLayer* layer )
 	: VGroupIface( layer ), m_layer( layer )
 {
@@ -52,4 +51,4 @@ VLayerIface::selected() const
 {
 	return m_layer->selected();
 }
-
+*/
