@@ -22,7 +22,6 @@
 #include "vdocument.h"
 #include "vfill.h"
 #include "vobject.h"
-#include "vobject_iface.h"
 #include "vstroke.h"
 
 #include <KoStore.h>
@@ -33,7 +32,7 @@
 #include <KoOasisLoadingContext.h>
 #include <KoOasisStyles.h>
 
-VObject::VObject( VObject* parent, VState state ) : m_dcop( 0L )
+VObject::VObject( VObject* parent, VState state )
 {
 	m_stroke = 0L;
 	m_fill = 0L;
@@ -53,8 +52,8 @@ VObject::VObject( const VObject& obj )
 	m_state = obj.m_state;
 
 	invalidateBoundingBox();
-	m_dcop = 0L;
 
+	/* TODO: porting to flake
 	VDocument *srcDoc = obj.document();
 	if( srcDoc && !srcDoc->objectName( &obj ).isEmpty() )
 	{
@@ -62,22 +61,13 @@ VObject::VObject( const VObject& obj )
 		if( dstDoc )
 			dstDoc->setObjectName( this, srcDoc->objectName( &obj ) );
 	}
+	*/
 }
 
 VObject::~VObject()
 {
 	delete( m_stroke );
 	delete( m_fill );
-	delete m_dcop;
-}
-
-DCOPObject *
-VObject::dcopObject()
-{
-    if ( !m_dcop )
-		m_dcop = new VObjectIface( this );
-
-    return m_dcop;
 }
 
 void
@@ -107,9 +97,11 @@ VObject::save( QDomElement& element ) const
 	if( m_fill )
 		m_fill->save( element );
 
+	/* TODO: porting to flake
 	VDocument *doc = document();
 	if( doc && !doc->objectName( this ).isEmpty() )
 		element.setAttribute( "ID", QString( doc->objectName( this ) ) );
+	*/
 }
 
 void
@@ -118,11 +110,11 @@ VObject::saveOasis( KoStore *, KoXmlWriter *docWriter, KoGenStyles &mainStyles,
 	if( !name().isEmpty() )
 		docWriter->addAttribute( "draw:name", name() );
 
-	QWMatrix mat;
+	QMatrix mat;
 	mat.scale( 1, -1 );
-	mat.translate( 0, -document()->height() );
+    mat.translate( 0, -document()->pageSize().height() );
 
-	KoGenStyle styleobjectauto( VDocument::STYLE_GRAPHICAUTO, "graphic" );
+    KoGenStyle styleobjectauto( KoGenStyle::StyleGraphicAuto, "graphic" );
 	saveOasisFill( mainStyles, styleobjectauto );
 	if( m_stroke )
 	{
@@ -142,9 +134,9 @@ VObject::saveOasisFill( KoGenStyles &mainStyles, KoGenStyle &stylesobjectauto )
 {
 	if( m_fill )
 	{
-		QWMatrix mat;
+		QMatrix mat;
 		mat.scale( 1, -1 );
-		mat.translate( 0, -document()->height() );
+        mat.translate( 0, -document()->pageSize().height() );
 
 		// mirror fill before saving
 		VFill fill( *m_fill );
@@ -154,7 +146,7 @@ VObject::saveOasisFill( KoGenStyles &mainStyles, KoGenStyle &stylesobjectauto )
 }
 
 void
-VObject::load( const QDomElement& element )
+VObject::load( const KoXmlElement& element )
 {
 	if( !m_stroke )
 		m_stroke = new VStroke( this );
@@ -172,13 +164,15 @@ VObject::load( const QDomElement& element )
 		m_fill->load( element );
 	}
 
+	/* TODO: porting to flake
 	VDocument *doc = document();
 	if( doc && !element.attribute( "ID" ).isEmpty() )
 		doc->setObjectName( this, element.attribute( "ID" ) );
+	*/
 }
 
 bool
-VObject::loadOasis( const QDomElement &object, KoOasisLoadingContext &context )
+VObject::loadOasis( const KoXmlElement &object, KoOasisLoadingContext &context )
 {
 	if( !m_stroke )
 		m_stroke = new VStroke( this );
@@ -195,19 +189,19 @@ VObject::loadOasis( const QDomElement &object, KoOasisLoadingContext &context )
 	m_fill->loadOasis( object, context, this );
 
 	if( object.hasAttributeNS( KoXmlNS::draw, "name" ) )
-		setName( object.attributeNS( KoXmlNS::draw, "name", QString::null ) );
+		setName( object.attributeNS( KoXmlNS::draw, "name", QString() ) );
 
 	return true;
 }
 
 void
-VObject::addStyles( const QDomElement* style, KoOasisLoadingContext & context )
+VObject::addStyles( const KoXmlElement* style, KoOasisLoadingContext & context )
 {
 	if(style)
 	{
 		// this function is necessary as parent styles can have parents themself
 		if( style->hasAttributeNS( KoXmlNS::style, "parent-style-name" ) )
-			addStyles( context.oasisStyles().findStyle( style->attributeNS( KoXmlNS::style, "parent-style-name", QString::null ) ), context );
+			addStyles( context.oasisStyles().findStyle( style->attributeNS( KoXmlNS::style, "parent-style-name", QString() ) ), context );
 		context.addStyles( style, "style-name" );
 	}
 }
@@ -224,13 +218,18 @@ VObject::document() const
 QString
 VObject::name() const
 {
-	return document() ? document()->objectName( this ) : QString();
+	return QString();
+	// TODO: porting to flake
+	//return document() ? document()->objectName( this ) : QString();
 }
 
 void
 VObject::setName( const QString &s )
 {
+	// TODO: porting to flake
+	/*
 	if( document() )
 		document()->setObjectName( this, s );
+	*/
 }
 
