@@ -13,20 +13,23 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
+#include <config-karbon.h>
 #include <qdom.h>
-#include <qfile.h>
+#include <QFile>
+#include <Q3ValueList>
+#include <QPointF>
+#include <QRectF>
 
 #include <kdebug.h>
-#include <koPoint.h>
-#include <koRect.h>
+
+#include <math.h>
 
 #include "vpath.h"
 #include "vtext.h"
-#include "vtext_iface.h"
 #include "vstroke.h"
 #include "vfill.h"
 #include "vvisitor.h"
@@ -57,8 +60,8 @@ int traceMoveto( FT_Vector *to, VPath *composite )
 	double toy = ( -to->y / 64.0 );
 
 	//QString add = "M" + QString::number(tox) + "," + QString::number(toy) + " ";
-	//kdDebug(38000) << add.latin1() << endl;
-	composite->moveTo( KoPoint( tox, toy ) );
+	//kDebug(38000) << add.latin1();
+	composite->moveTo( QPointF( tox, toy ) );
 
 	return 0;
 }
@@ -69,12 +72,12 @@ int traceLineto( FT_Vector *to, VPath *composite )
 	double toy = ( -to->y / 64.0 );
 
 	//QString add = "L" + QString::number(tox) + "," + QString::number(toy) + " ";
-	//kdDebug(38000) << add.latin1() << endl;
+	//kDebug(38000) << add.latin1();
 
-	composite->lineTo( KoPoint( tox, toy ) );
+	composite->lineTo( QPointF( tox, toy ) );
 
 	return 0;
-};
+}
 
 int traceQuadraticBezier( FT_Vector *control, FT_Vector *to, VPath *composite )
 {
@@ -84,12 +87,12 @@ int traceQuadraticBezier( FT_Vector *control, FT_Vector *to, VPath *composite )
 	double y2 = ( -to->y / 64.0 );
 
 	//QString add = "Q" + QString::number(x1) + "," + QString::number(y1) + "," + QString::number(x2) + "," + QString::number(y2) + " ";
-	//kdDebug(38000) << add.latin1() << endl;
-	composite->curveTo( KoPoint( x1, y1 ), KoPoint( x2, y2 ), KoPoint( x2, y2 ) );
-	//composite->curve2To( KoPoint( x1, y1 ), KoPoint( x2, y2 ) );
+	//kDebug(38000) << add.latin1();
+	composite->curveTo( QPointF( x1, y1 ), QPointF( x2, y2 ), QPointF( x2, y2 ) );
+	//composite->curve2To( QPointF( x1, y1 ), QPointF( x2, y2 ) );
 
 	return 0;
-};
+}
 
 int traceCubicBezier( FT_Vector *p, FT_Vector *q, FT_Vector *to, VPath *composite )
 {
@@ -101,12 +104,12 @@ int traceCubicBezier( FT_Vector *p, FT_Vector *q, FT_Vector *to, VPath *composit
 	double y3 = ( -to->y / 64.0 );
 
 	//QString add = "C" + QString::number(x1) + "," + QString::number(y1) + "," + QString::number(x2) + "," + QString::number(y2) + "," + QString::number(x3) + "," + QString::number(y3);
-	//kdDebug(38000) << add.latin1() << endl;
+	//kDebug(38000) << add.latin1();
 
-	composite->curveTo( KoPoint( x1, y1 ), KoPoint( x2, y2 ), KoPoint( x3, y3 ) );
+	composite->curveTo( QPointF( x1, y1 ), QPointF( x2, y2 ), QPointF( x3, y3 ) );
 
 	return 0;
-};
+}
 
 FT_Outline_Funcs OutlineMethods =
 {
@@ -133,6 +136,7 @@ VText::VText( VObject* parent, VState state )
 	m_translucentShadow	= false;
 	m_shadowAngle		= 0;
 	m_shadowDistance	= 0;
+	m_offset			= 0.0;
 }
 
 
@@ -143,10 +147,11 @@ VText::VText( const QFont &font, const VSubpath& basePath, Position position, Al
 	m_boundingBoxIsInvalid = true;
 	m_stroke = new VStroke( this );
 	m_fill = new VFill();
+	m_offset = 0.0;
 }
 
 VText::VText( const VText& text )
-	: VObject( text ), m_font( text.m_font ), m_basePath( text.m_basePath ), m_position( text.m_position ), m_alignment( text.m_alignment ), m_text( text.m_text ), m_shadow( text.m_shadow ), m_translucentShadow( text.m_translucentShadow ), m_shadowDistance( text.m_shadowDistance ), m_shadowAngle( text.m_shadowAngle )
+	: VObject( text ), m_font( text.m_font ), m_basePath( text.m_basePath ), m_position( text.m_position ), m_alignment( text.m_alignment ), m_text( text.m_text ), m_shadow( text.m_shadow ), m_translucentShadow( text.m_translucentShadow ), m_shadowDistance( text.m_shadowDistance ), m_shadowAngle( text.m_shadowAngle ), m_offset( text.m_offset )
 {
 	m_stroke = new VStroke( *text.m_stroke );
 	m_stroke->setParent( this );
@@ -168,17 +173,8 @@ VText::~VText()
 {
 }
 
-DCOPObject* VText::dcopObject()
-{
-	if( !m_dcop )
-		m_dcop = new VTextIface( this );
-
-	return m_dcop;
-}
-
-
 void
-VText::draw( VPainter* painter, const KoRect* /*rect*/ ) const
+VText::draw( VPainter* painter, const QRectF* /*rect*/ ) const
 {
 	if(
 		state() == deleted ||
@@ -213,15 +209,15 @@ VText::draw( VPainter* painter, const KoRect* /*rect*/ ) const
 			int shadowDx = int( m_shadowDistance * cos( m_shadowAngle / 360. * 6.2832 ) );
 			int shadowDy = int( m_shadowDistance * sin( m_shadowAngle / 360. * 6.2832 ) );
 
-			VTransformCmd trafo( 0L, QWMatrix() );
+			VTransformCmd trafo( 0L, QMatrix() );
 			for( itr.toFirst(); itr.current(); ++itr )
 			{
-				trafo.setMatrix( QWMatrix( 1, 0, 0, 1, shadowDx, shadowDy ) );
+				trafo.setMatrix( QMatrix( 1, 0, 0, 1, shadowDx, shadowDy ) );
 				trafo.visit( *( itr.current() ) );
 				itr.current()->setFill( VFill( color ) );
 				itr.current()->setStroke( VStroke( color ) );
 				itr.current()->draw( painter );
-				trafo.setMatrix( QWMatrix( 1, 0, 0, 1, -shadowDx, -shadowDy ) );
+				trafo.setMatrix( QMatrix( 1, 0, 0, 1, -shadowDx, -shadowDy ) );
 				trafo.visit( *( itr.current() ) );
 			}
 		}
@@ -238,8 +234,9 @@ VText::draw( VPainter* painter, const KoRect* /*rect*/ ) const
 	if( state() == edit )//|| state() == selected )
 	{
 		painter->newPath();
-		painter->setRasterOp( Qt::XorROP );
-		painter->setPen( Qt::yellow );
+		// TODO: Needs porting to Qt4
+		// painter->setRasterOp( Qt::XorROP );
+		painter->setPen( QColor( "yellow" ) );
 		painter->setBrush( Qt::NoBrush );
 
 		for( itr.toFirst(); itr.current(); ++itr )
@@ -251,7 +248,7 @@ VText::draw( VPainter* painter, const KoRect* /*rect*/ ) const
 	painter->restore();
 }
 
-const KoRect&
+const QRectF&
 VText::boundingBox() const
 {
 	if( m_boundingBoxIsInvalid )
@@ -259,7 +256,7 @@ VText::boundingBox() const
 		VPathListIterator itr( m_glyphs );
 		itr.toFirst();
 		// clear:
-		m_boundingBox = itr.current() ? itr.current()->boundingBox() : KoRect();
+		m_boundingBox = itr.current() ? itr.current()->boundingBox() : QRectF();
 		for( ++itr; itr.current(); ++itr )
 			if( !itr.current()->boundingBox().isEmpty() )
 				m_boundingBox |= itr.current()->boundingBox();
@@ -326,7 +323,7 @@ VText::save( QDomElement& element ) const
 		me.setAttribute( "translucentshadow",	m_translucentShadow );
 		me.setAttribute( "shadowangle",			m_shadowAngle );
 		me.setAttribute( "shadowdist",			m_shadowDistance );
-
+		me.setAttribute( "offset",				m_offset );
 		element.appendChild( me );
 
 		// save all glyphs / paths
@@ -337,7 +334,7 @@ VText::save( QDomElement& element ) const
 }
 
 void
-VText::load( const QDomElement& element )
+VText::load( const KoXmlElement& element )
 {
 	m_glyphs.clear();
 
@@ -352,13 +349,12 @@ VText::load( const QDomElement& element )
 	m_translucentShadow	= ( element.attribute( "translucentshadow" ).toInt() == 1 );
 	m_shadowAngle		= element.attribute( "shadowangle" ).toInt();
 	m_shadowDistance	= element.attribute( "shadowdist" ).toInt();
-
+	m_offset			= element.attribute( "offset" ).toDouble();
 	m_text = element.attribute( "text", "" );
 
 	VObject::load( element );
 
-	QDomNodeList list = element.childNodes();
-	QDomElement e = list.item( 0 ).toElement();
+	KoXmlElement e = element.firstChild().toElement();
 	
 	// element to start with reading glyph paths and stroke, fill, etc.
 	uint startElement = 0;
@@ -372,11 +368,8 @@ VText::load( const QDomElement& element )
 	}
 
 	// load text glyphs:
-	for( uint i = startElement; i < list.count(); ++i )
+	forEachElement(e, element)
 	{
-		if( list.item( i ).isElement() )
-		{
-			e = list.item( i ).toElement();
 			if( e.tagName() == "PATH" )
 			{
 				VPath *composite = new VPath( this );
@@ -387,7 +380,6 @@ VText::load( const QDomElement& element )
 				m_stroke->load( e );
 			if( e.tagName() == "FILL" )
 				m_fill->load( e );
-		}
 	}
 	// if no glyphs yet, trace them
 #ifdef HAVE_KARBONTEXT
@@ -436,7 +428,7 @@ VText::traceText()
 {
 	if( m_basePath.count() == 0 )
 	{
-		kdDebug(38000) << "Can't draw a text without base path (was: " << m_text << ")." << endl;
+		kDebug(38000) <<"Can't draw a text without base path (was:" << m_text <<").";
 		return;
 	}
 
@@ -454,7 +446,7 @@ VText::traceText()
 	QString filename = buildRequest( m_font.family(), weight, slant, m_font.pointSize(), id );
 	m_glyphs.clear();
 
-	kdDebug(38000) << "Loading " << filename.latin1() << " for requested font \"" << m_font.family().latin1() << "\", " << m_font.pointSize() << " pt." << endl;
+	kDebug(38000) <<"Loading" << filename.toLatin1() <<" for requested font \"" << m_font.family().toLatin1() <<"\"," << m_font.pointSize() <<" pt.";
 
 	FT_UInt glyphIndex;
 	FT_Face fontFace;
@@ -465,11 +457,13 @@ VText::traceText()
 
 	if( error )
 	{
-		kdDebug(38000) << "traceText(), could not load font. Aborting!" << endl;
+		kDebug(38000) <<"traceText(), could not load font. Aborting!";
 		return;
 	}
 
-	// Choose unicode charmap
+	bool foundCharmap = false;
+
+	// Try to choose unicode charmap
 	for( int charmap = 0; charmap < fontFace->num_charmaps; charmap++ )
 	{
 		if( fontFace->charmaps[charmap]->encoding == ft_encoding_unicode )
@@ -477,46 +471,86 @@ VText::traceText()
 			FT_Error error = FT_Set_Charmap( fontFace, fontFace->charmaps[charmap] );
 			if( error )
 			{
-				kdDebug(38000) << "traceText(), unable to select unicode charmap. Aborting!" << endl;
-				FT_Done_Face( fontFace );
-				return;
+				kDebug(38000) <<"traceText(), unable to select unicode charmap.";
+				continue;
 			}
+			foundCharmap = true;
 		}
 	}
 
-	FT_Set_Char_Size( fontFace, FT_FROMFLOAT( m_font.pointSize() ), FT_FROMFLOAT( m_font.pointSize() ), 0, 0 );
+	// Choose first charmap if no unicode charmap was found
+	if( ! foundCharmap )
+	{
+		error = FT_Set_Charmap( fontFace, fontFace->charmaps[0] );
+		if( error )
+		{
+			kDebug(38000) <<"traceText(), unable to select charmap. Aborting!";
+			FT_Done_Face( fontFace );
+			FT_Done_FreeType( library );
+			return;
+		}
+	}
+
+	error = FT_Set_Char_Size( fontFace, FT_FROMFLOAT( m_font.pointSize() ), FT_FROMFLOAT( m_font.pointSize() ), 0, 0 );
+	if( error )
+	{
+		kDebug(38000) <<"traceText(), unable to set font size. Aborting!";
+		FT_Done_Face( fontFace );
+		FT_Done_FreeType( library );
+		return;
+	}
 
 		// storing glyphs.
 	float l = 0;
-	QValueList<float> glyphXAdvance;
-	QValueList<float> glyphYAdvance;
-	for( unsigned int i = 0; i < m_text.length(); i++ )
+	Q3ValueList<float> glyphXAdvance;
+	Q3ValueList<float> glyphYAdvance;
+	for( int i = 0; i < m_text.length(); i++ )
 	{
 		// get the glyph index for the current character
 		QChar character = m_text.at( i );
 		glyphIndex = FT_Get_Char_Index( fontFace, character.unicode() );
-		//kdDebug(38000) << "glyphIndex : " << glyphIndex << endl;
+		if( ! glyphIndex ) 
+		{
+			kDebug(38000) <<"traceText(), unable get index of char :" << character;
+			continue;
+		}
+		//kDebug(38000) <<"glyphIndex :" << glyphIndex;
 		FT_Error error = FT_Load_Glyph( fontFace, glyphIndex, FT_LOAD_NO_HINTING | FT_LOAD_NO_BITMAP );
 		if( error )
 		{
-			kdDebug(38000) << "Houston, we have a problem : " << error << endl;
+			kDebug(38000) <<"traceText(), unable to load glyph :" << error;
 			continue;
 		}
 
 		// decompose to vpaths
 		FT_OutlineGlyph g;
-		FT_Get_Glyph( fontFace->glyph, reinterpret_cast<FT_Glyph *>( &g ) );
+		error = FT_Get_Glyph( fontFace->glyph, reinterpret_cast<FT_Glyph *>( &g ) );
+		if( error )
+		{
+			kDebug(38000) <<"traceText(), unable to get glyph:" << error;
+			continue;
+		}
+
 		VPath *composite = new VPath( this );
-		//VFill *fill = composite->fill();
-		//fill->setFillRule( VFill::evenOdd );
-		//composite->setFill( *fill );
-		FT_Outline_Decompose(&g->outline, &OutlineMethods, composite );
-		//composite->close();
+		error = FT_Outline_Check( &g->outline );
+		if( error ) 
+		{
+			kDebug(38000) <<"traceText(), outline is broken :" << error;
+			continue;
+		}
+
+		error = FT_Outline_Decompose(&g->outline, &OutlineMethods, composite );
+		if( error )
+		{
+			kDebug(38000) <<"traceText(), unable to decompose outline :" << error;
+			continue;
+		}
 
 		m_glyphs.append( composite );
 		glyphXAdvance.append( FT_TOFLOAT( fontFace->glyph->advance.x ) );
 		glyphYAdvance.append( FT_TOFLOAT( fontFace->glyph->advance.y ) );
 		l += FT_TOFLOAT( fontFace->glyph->advance.x );
+		FT_Done_Glyph( reinterpret_cast<FT_Glyph>( g ) );
 	}
 
 	 // Placing the stored glyphs.
@@ -528,35 +562,39 @@ VText::traceText()
 		if( (seg = pIt.current() ) ) 
 			pathLength += seg->length();
 
-	float x = 0;
+	kDebug(38000) <<"traceText(), using offset :" << m_offset;
+	float x = m_offset * pathLength;
+	
 	switch( m_alignment )
 	{
-		case Left: x = 0; break;
-		case Center: x = ( pathLength - l ) / 2; break;
-		case Right: x = pathLength - l; break;
+		case Qt::DockLeft: x += 0; break;
+		case Center: x -=  0.5 * l; break;
+		case Qt::DockRight: x -= l; break;
+		default: break;
 	}
 	float y = 0;
 	float dx = 0;
 	float sp = 0;
-	KoPoint point;
-	KoPoint normal;
-	KoPoint tangent;
+	QPointF point;
+	QPointF normal;
+	QPointF tangent;
 	VSubpathIterator pathIt( m_basePath );
 	VSegment* oldSeg = pathIt.current();
 	seg = ++pathIt;
-	KoPoint extPoint;
+	QPointF extPoint;
 	bool ext = false;
 	float fsx = 0;
 	float yoffset = ( m_position == Above ? 0 : ( m_position == On ? m_font.pointSize() / 3 : m_font.pointSize() / 1.5 ) );
-	kdDebug(38000) << "Position: " << m_position << " -> " << yoffset << endl;
-	for( unsigned int i = 0; i < m_text.length(); i++ )
+	kDebug(38000) <<"Position:" << m_position <<" ->" << yoffset;
+	for( int i = 0; i < m_text.length(); i++ )
 	{
 		VPath* composite = m_glyphs.at( i );
-
+		if( ! composite ) 
+			continue;
 		// Step 1: place (0, 0) to the rotation center of the glyph.
 		dx = *glyphXAdvance.at( i ) / 2;
 		x += dx;
-		VTransformCmd trafo( 0L, QWMatrix( 1, 0, 0, 1, -dx, y + yoffset ) );
+		VTransformCmd trafo( 0L, QMatrix( 1, 0, 0, 1, -dx, y + yoffset ) );
 		trafo.visit( *composite );
 
 		// Step 2: find the position where to draw.
@@ -593,11 +631,11 @@ VText::traceText()
 
 		// Step 3: transform glyph and append it. That's it, we've got
 		// text following a path. Really easy, isn't it ;) ?
-		trafo.setMatrix( QWMatrix( tangent.x(), tangent.y(), tangent.y(), -tangent.x(), point.x(), point.y() ) );
+		trafo.setMatrix( QMatrix( tangent.x(), tangent.y(), tangent.y(), -tangent.x(), point.x(), point.y() ) );
 		trafo.visit( *composite );
 		composite->setState( state() );
 
-		//kdDebug(38000) << "Glyph: " << (QString)character << " [String pos: " << x << ", " << y << " / Canvas pos: " << point.x() << ", " << point.y() << "]" << endl;
+		//kDebug(38000) <<"Glyph:" << (QString)character <<" [String pos:" << x <<"," << y <<" / Canvas pos:" << point.x() <<"," << point.y() <<"]";
 
 		x += dx;
 		y += *glyphYAdvance.at( i );
@@ -613,7 +651,7 @@ VText::buildRequest( QString family, int weight, int slant, double size, int &id
 {
 	// Strip those stupid [Xft or whatever]...
 	int pos;
-	if( ( pos = family.find( '[' ) ) )
+	if( ( pos = family.indexOf( '[' ) ) )
 		family = family.left( pos );
 
 	// Use FontConfig to locate & select fonts and use  FreeType2 to open them
@@ -625,47 +663,74 @@ VText::buildRequest( QString family, int weight, int slant, double size, int &id
 							  FC_SIZE, FcTypeDouble, size, NULL );
 
 	// Add font name
-	FcPatternAddString( pattern, FC_FAMILY, reinterpret_cast<const FcChar8 *>( family.latin1() ) );
+	FcPatternAddString( pattern, FC_FAMILY, reinterpret_cast<const FcChar8 *>( family.toLatin1().data() ) );
 
 	// Disable hinting
-	FcPatternAddBool( pattern, FC_HINTING, false );
+	FcPatternAddBool( pattern, FC_HINTING, FcFalse );
+	// Enforce scalability
+	FcPatternAddBool( pattern, FC_SCALABLE, FcTrue );
 
 	// Perform the default font pattern modification operations.
 	FcDefaultSubstitute( pattern );
 	FcConfigSubstitute( FcConfigGetCurrent(), pattern, FcMatchPattern );
 
-	// Match the pattern!
 	FcResult result;
-	FcPattern *match = FcFontMatch( 0, pattern, &result );
+
+	// we do not want to use bitmap fonts, so get a list of fonts sorted by closeness to pattern
+	// and use the best matching scalable font
+	FcFontSet *fset = FcFontSort( 0, pattern, FcFalse, 0L, &result );
 
 	// Destroy pattern
 	FcPatternDestroy( pattern );
 
-	// Get index & filename
-	FcChar8 *temp;
-
-	if(match)
+	if( fset )
 	{
-		FcPattern *pattern = FcPatternDuplicate( match );
-
-		// Get index & filename
-		if(	FcPatternGetString(pattern, FC_FILE, 0, &temp) != FcResultMatch ||
-		   	FcPatternGetInteger(pattern, FC_INDEX, 0, &id) != FcResultMatch )
+		FcBool scalable;
+		FcChar8 *temp;
+	
+		// iterate over font list and take best scaleable font
+		for( int i = 0; i < fset->nfont; ++i )
 		{
-			kdDebug(38000) << "VText::buildRequest(), could not load font file for requested font \"" << family.latin1() << "\"" << endl;
-			return QString::null;
+			pattern = fset->fonts[i];
+			if( FcResultMatch != FcPatternGetBool( pattern, FC_SCALABLE, 0, &scalable ) )
+				continue;
+			if( scalable == FcTrue )
+			{
+				// Get index & filename
+				if(	FcPatternGetString(pattern, FC_FILE, 0, &temp) != FcResultMatch ||
+					FcPatternGetInteger(pattern, FC_INDEX, 0, &id) != FcResultMatch )
+				{
+					kDebug(38000) <<"VText::buildRequest(), could not load font file for requested font \"" << family.toLatin1() <<"\"";
+					return QString();
+				}
+		
+				fileName = QFile::decodeName(reinterpret_cast<const char *>( temp ));
+				
+				// get family name of matched font
+				QString newFamily;
+
+				if( FcResultMatch == FcPatternGetString( pattern, FC_FAMILY, 0, &temp ) )
+					m_font.setFamily( reinterpret_cast<const char *>( temp ) );
+
+				break;
+			}
 		}
-
-		fileName = QFile::decodeName(reinterpret_cast<const char *>( temp ));
-
-		// Kill pattern
-		FcPatternDestroy( pattern );
+		
+		FcFontSetDestroy( fset );
 	}
 
-	// Kill pattern
-	FcPatternDestroy( match );
-
+	
 	return fileName;
 }
 
+void VText::setOffset( double offset )
+{
+	if( offset < 0.0 )
+		m_offset = 0.0;
+	else if( offset > 1.0 )
+		m_offset = 1.0;
+	else
+		m_offset = offset;
+}
+
 #endif // HAVE_KARBONTEXT
