@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 0214111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef __VTEXT_IFACE_H__
@@ -32,7 +32,7 @@ public:
 	VTextIface( VText *text );
 
 k_dcop:
-	void setText( QString text );
+	void setText( const QString &text );
 	QString text();
 
 	void setFontSize( int pointSize );
