@@ -13,15 +13,14 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 
 #include "vcomposite.h"
 #include "vdocument.h"
 #include "vgroup.h"
-#include "vlayer.h"
 #include "vpath.h"
 #include "vselection.h"
 #include "vvisitor.h"
@@ -40,12 +39,10 @@ VVisitor::visit( VObject& object )
 void
 VVisitor::visitVDocument( VDocument& document )
 {
-	VLayerListIterator itr( document.layers() );
-
-	for( ; itr.current(); ++itr )
-	{
-		itr.current()->accept( *this );
-	}
+    /*
+	foreach( KoShape* layer, document.layers() )
+		((KoShapeLayer*)layer)->accept( *this );
+    */
 }
 
 void
@@ -60,14 +57,12 @@ VVisitor::visitVGroup( VGroup& group )
 }
 
 void
-VVisitor::visitVLayer( VLayer& layer )
+VVisitor::visitVLayer( KoShapeLayer& layer )
 {
-	VObjectListIterator itr( layer.objects() );
-
-	for( ; itr.current(); ++itr )
-	{
-		itr.current()->accept( *this );
-	}
+	/* TODO: do we still want that ?
+	foreach( KoShape *shape, layer.iterator() )
+		shape->accept( *this );
+	*/
 }
 
 void
