@@ -14,8 +14,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include <klocale.h>
@@ -25,9 +25,13 @@
 #include "vcolortab.h"
 
 VColorDlg::VColorDlg( const VColor &c, QWidget* parent, const char* name )
-	: KDialogBase ( parent, name, true, i18n( "Uniform Color" ),
-		KDialogBase::Ok | KDialogBase::Cancel )
+	: KDialog ( parent )
 {
+	setCaption( i18n( "Uniform Color" ) );
+	setButtons( KDialog::Ok | KDialog::Cancel );
+	setObjectName(name);
+	setModal(true);
+
 	m_colortab = new VColorTab( VColor( c ), this, name );
 
 	setMainWidget( m_colortab );
