@@ -1,5 +1,17 @@
 /* This file is part of the KDE project
-   Copyright (C) 2001, 2002, 2003 The Karbon Developers
+   Copyright (C) 2001-2002 Lennart Kudling <kudling@kde.org>
+   Copyright (C) 2001-2005 Rob Buis <buis@kde.org>
+   Copyright (C) 2002,2004-2005 Laurent Montel <montel@kde.org>
+   Copyright (C) 2002 Benoit Vautrin <benoit.vautrin@free.fr>
+   Copyright (C) 2004-2005,2007 David Faure <faure@kde.org>
+   Copyright (C) 2004,2006 Peter Simonsson <psn@linux.se>
+   Copyright (C) 2004-2005 Fredrik Edemar <f_edemar@linux.se>
+   Copyright (C) 2005-2007 Jan Hambrecht <jaham@gmx.net>
+   Copyright (C) 2005-2007 Thomas Zander <zander@kde.org>
+   Copyright (C) 2006 Inge Wallin <inge@lysator.liu.se>
+   Copyright (C) 2006 Tim Beaulen <tbscope@gmail.com>
+   Copyright (C) 2006 Casper Boemann <cbr@boemann.dk>
+   Copyright (C) 2006 Thorsten Zachmann <t.zachmann@zagge.de>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -13,26 +25,21 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef __KARBON_PART_H__
 #define __KARBON_PART_H__
 
+#include <KoShapeControllerBase.h>
 
-#include <qptrlist.h>
-
-#include "karbon_part_base.h"
-#include <koUnit.h>
+#include <KoDocument.h>
+#include <KoUnit.h>
 #include "vdocument.h"
-#include "koffice_export.h"
+#include "karbon_export.h"
 
-class DCOPObject;
-class KoRect;
 class QRect;
-class VCommand;
-class VCommandHistory;
 
 /**
  * Keeps track of visual per document properties.
@@ -41,48 +48,28 @@ class VCommandHistory;
  * Finally a dcop interface is set up here.
  */
 
-class KARBONCOMMON_EXPORT KarbonPart : public KarbonPartBase
+class KARBONCOMMON_EXPORT KarbonPart : public KoDocument, public KoShapeControllerBase
 {
 	Q_OBJECT
 public:
-	KarbonPart( QWidget* parentWidget = 0L, const char* widgetName = 0L,
+	explicit KarbonPart( QWidget* parentWidget = 0L, const char* widgetName = 0L,
 				QObject* parent = 0L, const char* name = 0L, bool singleViewMode = false );
 	virtual ~KarbonPart();
 
-	virtual void paintContent( QPainter& painter, const QRect& rect,
-							   bool transparent = false, double zoomX = 1.0, double zoomY = 1.0 );
-
-	/// standard koDocument inherited methods
-	virtual bool initDoc(InitDocFlags flags, QWidget* parentWidget=0);
+	virtual void paintContent( QPainter& painter, const QRect& rect);
 
 	/// file-> open calls this method
-	virtual bool loadXML( QIODevice*, const QDomDocument& document );
-	virtual bool loadOasis( const QDomDocument &doc, KoOasisStyles &styles, const QDomDocument &settings, KoStore *store );
+	virtual bool loadXML( QIODevice*, const KoXmlDocument& document );
+    virtual bool loadOasis( const KoXmlDocument & doc, KoOasisStyles& oasisStyles,
+                            const KoXmlDocument & settings, KoStore* store );
 
 	/// file-> save and file-> save as call this method
 	virtual QDomDocument saveXML();
 	virtual bool saveOasis( KoStore *store, KoXmlWriter *manifestWriter );
 
-	virtual DCOPObject* dcopObject();
-
-	/// insert a new vobject
-	void insertObject( VObject* object );
-
-	/// insert a command into the undo/redo-history:
-	void addCommand( VCommand* cmd, bool repaint = false );
-
 	// access static document:
 	VDocument& document() { return m_doc; }
 
-	// Clear history.
-	void clearHistory();
-
-	/// access the command history:
-	VCommandHistory* commandHistory()
-	{
-		return m_commandHistory;
-	}
-
 	bool showStatusBar() const
 	{
 		return m_bShowStatusBar;
@@ -93,42 +80,34 @@ public:
 	/// at this time only the status bar is handled
 	void reorganizeGUI();
 
-	void setUndoRedoLimit( int undos );
-
 	void initConfig();
 	unsigned int maxRecentFiles() const { return m_maxRecentFiles; }
 
-	QString unitName() const { return KoUnit::unitName( m_doc.unit() ); }
-	KoUnit::Unit unit() const { return m_doc.unit(); }
-	void setUnit( KoUnit::Unit _unit );
-	void initUnit();
-
-	void setPageLayout( KoPageLayout& layout, KoUnit::Unit _unit );
+	void setPageLayout( KoPageLayout& layout, KoUnit _unit );
 
 	bool mergeNativeFormat( const QString & file );
 
+	// implemented from KoShapeController
+	virtual void addShape( KoShape* shape );
+	virtual void removeShape( KoShape* shape );
+
 public slots:
 	/// repaint all views attached to this koDocument
 	void repaintAllViews( bool repaint = true );
-	void repaintAllViews( const KoRect& );
 	void slotDocumentRestored();
-	void slotCommandExecuted( VCommand * );
 
 protected:
-	virtual KoView* createViewInstance( QWidget* parent, const char* name );
+	virtual KoView* createViewInstance( QWidget* parent );
 	virtual void removeView( KoView *view );
-    void saveOasisSettings( KoXmlWriter &/*settingsWriter*/ );
-    void loadOasisSettings( const QDomDocument&settingsDoc );
-
+	void loadOasisSettings( const KoXmlDocument&settingsDoc );
 
+    void updateDocumentSize();
 private:
 	VDocument m_doc;					/// store non-visual doc info
-	VCommandHistory* m_commandHistory;	/// maintain a command history for undo/redo
 
 	bool m_bShowStatusBar;				/// enable/disable status bar in attached view(s)
 	bool m_merge;
 	unsigned int m_maxRecentFiles;				/// max. number of files shown in open recent menu item
-	DCOPObject *dcop;
 };
 
 #endif
