@@ -1,10 +1,19 @@
 /* This file is part of the KDE project
-   Copyright (C) 2001, 2002, 2003 The Karbon Developers
 
    Original work :
    kis_resourceserver.h - part of KImageShop
 
    Copyright (c) 1999 Matthias Elter <elter@kde.org>
+   Copyright (C) 2002-2004 Rob Buis <buis@kde.org>
+   Copyright (C) 2002 Benot Vautrin <benoit.vautrin@free.fr>
+   Copyright (C) 2002 Lennart Kudling <kudling@kde.org>
+   Copyright (C) 2005-2006 Laurent Montel <montel@kde.org>
+   Copyright (C) 2005 Thomas Zander <zander@kde.org>
+   Copyright (C) 2006 Tim Beaulen <tbscope@gmail.com>
+   Copyright (C) 2006 Casper Boemann <cbr@boemann.dk>
+   Copyright (C) 2006 Dirk Mueller <mueller@kde.org>
+   Copyright (C) 2007 David Faure <faure@kde.org>
+   Copyright (C) 2007 Jan Hambrecht <jaham@gmx.net>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -26,13 +35,15 @@
 #define __KARBONRESOURCESERVER_H__
 
 
-#include <qptrlist.h>
-#include <qdict.h>
-#include <qstring.h>
+#include <q3ptrlist.h>
+#include <q3dict.h>
+#include <QString>
+//Added by qt3to4:
+#include <QPixmap>
 
 //#include "vgradient.h"
 #include "vpattern.h"
-#include <koffice_export.h>
+#include <karbon_export.h>
 
 class VGradient;
 class VGradientListItem;
@@ -52,7 +63,7 @@ public:
 		return m_patterns.count();
 	}
 
-	QPtrList<KoIconItem> patterns()
+	Q3PtrList<QTableWidgetItem> patterns()
 	{
 		return m_patterns;
 	}
@@ -65,12 +76,12 @@ public:
 		return m_gradients->count();
 	}
 
-	QPtrList<VGradientListItem>* gradients()
+	Q3PtrList<VGradientListItem>* gradients()
 	{
 		return m_gradients;
 	}
 
-	VGradientListItem* addGradient( VGradient* gradient );
+	VGradientListItem* addGradient( QGradient* gradient );
 	void removeGradient( VGradientListItem* gradient );
 
 	int clipartCount()
@@ -78,7 +89,7 @@ public:
 		return m_cliparts->count();
 	}
 
-	QPtrList<VClipartIconItem>* cliparts()
+	Q3PtrList<VClipartIconItem>* cliparts()
 	{
 		return m_cliparts;
 	}
@@ -98,16 +109,16 @@ protected:
 	void saveClipart( VObject* object, double width, double height, const QString& filename );
 
 private:
-	QPtrList<KoIconItem> m_patterns;
-	QPtrList<VGradientListItem>* m_gradients;
-	QPtrList<VClipartIconItem>* m_cliparts;
-	QDict<QPixmap> m_pixmaps;
+	Q3PtrList<QTableWidgetItem> m_patterns;
+	Q3PtrList<VGradientListItem>* m_gradients;
+	Q3PtrList<VClipartIconItem>* m_cliparts;
+	Q3Dict<QPixmap> m_pixmaps;
 };
 
-class VClipartIconItem : public KoIconItem
+class VClipartIconItem : public QTableWidgetItem
 {
 public:
-	VClipartIconItem( const VObject* clipart, double width, double height, QString filename );
+	VClipartIconItem( const VObject* clipart, double width, double height, const QString & filename );
 	VClipartIconItem( const VClipartIconItem& item );
 	~VClipartIconItem();
 
@@ -146,7 +157,7 @@ public:
 		return m_height;
 	}
 
-	VClipartIconItem* clone();
+	VClipartIconItem* clone() const;
 
 private:
 	QPixmap m_pixmap;
