@@ -22,7 +22,7 @@
 #define __VPAINTERDACTORY_H__
 
 // painter factory
-#include <koffice_export.h>
+#include <karbon_export.h>
 class VPainter;
 class QPaintDevice;
 
