@@ -13,15 +13,15 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef __VPOLYLINE_H__
 #define __VPOLYLINE_H__
 
 #include "vcomposite.h"
-#include <qstring.h>
+#include <QString>
 
 class VPolyline : public VPath
 {
@@ -33,7 +33,11 @@ public:
 	virtual QString name() const;
 
 	virtual void save( QDomElement& element ) const;
-	virtual void load( const QDomElement& element );
+	virtual void saveOasis( KoStore *store, KoXmlWriter *docWriter, KoGenStyles &mainStyles, int &index ) const;
+	virtual void load( const KoXmlElement& element );
+	virtual bool loadOasis( const KoXmlElement &element, KoOasisLoadingContext &context );
+
+	virtual VPath* clone() const;
 
 protected:
 	void init();
