@@ -13,25 +13,32 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include <math.h>
-
-#include <qcheckbox.h>
-#include <qcombobox.h>
+#include <config-karbon.h>
+#include <QCheckBox>
+#include <QComboBox>
 #include <qcursor.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qlineedit.h>
+#include <QFontComboBox>
+#include <QLabel>
+#include <QLayout>
+#include <QLineEdit>
 #include <qpainter.h>
 #include <qpixmap.h>
-#include <qpushbutton.h>
+#include <QPushButton>
 #include <qtabwidget.h>
+#include <QPointF>
+#include <QHBoxLayout>
+#include <QGridLayout>
+#include <QMouseEvent>
+#include <QVBoxLayout>
+#include <QPaintEvent>
+#include <kicon.h>
 
 #include <kdebug.h>
-#include <kfontcombo.h>
 #include <kfontdialog.h>
 #include <kiconloader.h>
 #include <knuminput.h>
@@ -45,32 +52,36 @@
 #include <core/vfill.h>
 #include <core/vgroup.h>
 #include <core/vstroke.h>
+#include <core/vcursor.h>
 #include <render/vpainterfactory.h>
-#include <render/vkopainter.h>
+#include <render/vqpainter.h>
 #include "vtexttool.h"
 
+#include <kactioncollection.h>
+
 
 static void
-traceShape( VKoPainter* p, int x, int y, int w, int h )
+traceShape( VQPainter* p, int x, int y, int w, int h )
 {
 	p->newPath();
-	p->moveTo( KoPoint( x + w , y + h ) );
-	p->lineTo( KoPoint( x + w / 3, y + h ) );
-	p->lineTo( KoPoint( x + w / 3, y + h / 3 ) );
-	p->lineTo( KoPoint( x + w , y + h / 3 ) );
-	p->lineTo( KoPoint( x + w , y + h ) );
+	p->moveTo( QPointF( x + w , y + h ) );
+	p->lineTo( QPointF( x + w / 3, y + h ) );
+	p->lineTo( QPointF( x + w / 3, y + h / 3 ) );
+	p->lineTo( QPointF( x + w , y + h / 3 ) );
+	p->lineTo( QPointF( x + w , y + h ) );
 
-	p->moveTo( KoPoint( x , y ) );
-	p->lineTo( KoPoint( x + ( w / 3 ) * 2, y ) );
-	p->lineTo( KoPoint( x + ( w / 3 ) * 2, y + ( h / 3 ) * 2 ) );
-	p->lineTo( KoPoint( x , y + ( h / 3 ) * 2 ) );
-	p->lineTo( KoPoint( x , y ) );
+	p->moveTo( QPointF( x , y ) );
+	p->lineTo( QPointF( x + ( w / 3 ) * 2, y ) );
+	p->lineTo( QPointF( x + ( w / 3 ) * 2, y + ( h / 3 ) * 2 ) );
+	p->lineTo( QPointF( x , y + ( h / 3 ) * 2 ) );
+	p->lineTo( QPointF( x , y ) );
 }
 
 ShadowPreview::ShadowPreview( ShadowWidget* parent )
 		: QWidget( parent ), m_parent( parent )
 {
-	setBackgroundMode( Qt::NoBackground );
+	QPalette p = palette();
+	p.setBrush(QPalette::Window, QBrush(Qt::NoBrush));
 	setMinimumSize( 60, 60 );
 
 	connect( this, SIGNAL( changed( int, int, bool ) ), m_parent, SLOT( setShadowValues( int, int, bool ) ) );
@@ -111,20 +122,20 @@ ShadowPreview::paintEvent( QPaintEvent* )
 	int a = 360 - m_parent->shadowAngle();
 
 	QPixmap pm( w, h );
-	VKoPainter p( &pm, w, h );
+	VQPainter p( &pm, w, h );
 	VColor color( VColor::rgb );
 
 	VFill fill;
 	KIconLoader il;
-	fill.pattern() = VPattern( il.iconPath( "karbon.png", KIcon::Small ) );
+	fill.pattern() = VPattern( il.iconPath( "karbon.png", K3Icon::Small ) );
 	fill.setType( VFill::patt );
 
 	p.newPath();
-	p.moveTo( KoPoint( 0, 0 ) );
-	p.lineTo( KoPoint( 0, h ) );
-	p.lineTo( KoPoint( w, h ) );
-	p.lineTo( KoPoint( w, 0 ) );
-	p.lineTo( KoPoint( 0, 0 ) );
+	p.moveTo( QPointF( 0, 0 ) );
+	p.lineTo( QPointF( 0, h ) );
+	p.lineTo( QPointF( w, h ) );
+	p.lineTo( QPointF( w, 0 ) );
+	p.lineTo( QPointF( 0, 0 ) );
 	p.setBrush( fill );
 	p.fillPath();
 
@@ -166,20 +177,22 @@ ShadowPreview::paintEvent( QPaintEvent* )
 
 	if( !m_parent->useShadow() )
 	{
+/* TODO moveto and lineto need porting
 		p.newPath();
-		p.moveTo( KoPoint( 0, 0 ) );
-		p.lineTo( KoPoint( 0, h ) );
-		p.lineTo( KoPoint( w, h ) );
-		p.lineTo( KoPoint( w, 0 ) );
-		p.lineTo( KoPoint( 0, 0 ) );
+		p.moveTo( QPointF( 0, 0 ) );
+		p.lineTo( QPointF( 0, h ) );
+		p.lineTo( QPointF( w, h ) );
+		p.lineTo( QPointF( w, 0 ) );
+		p.lineTo( QPointF( 0, 0 ) );
 		VColor c( colorGroup().background() );
 		c.setOpacity( .8 );
 		p.setBrush( VFill( c ) );
-		p.fillPath();
+		p.fillPath();*/
 	}
 
 	p.end();
 
+/* TODO moveto and lineto need porting
 	QPainter painter( this );
 	painter.drawPixmap( 2, 2, pm );
 	painter.setPen( colorGroup().light() );
@@ -195,25 +208,25 @@ ShadowPreview::paintEvent( QPaintEvent* )
 	painter.moveTo( width() - 2, 2 );
 	painter.lineTo( width() - 2, height() - 2 );
 	painter.lineTo( 2, height() - 2 );
-	painter.setPen( Qt::black );
+	painter.setPen( QColor( "black" ) );
 	painter.drawLine( width() / 2 - 2, height() / 2, width() / 2 + 2, height() / 2 );
-	painter.drawLine( width() / 2, height() / 2 - 2, width() / 2, height() / 2 + 2 );
+	painter.drawLine( width() / 2, height() / 2 - 2, width() / 2, height() / 2 + 2 );*/
 }
 
 ShadowWidget::ShadowWidget( QWidget* parent, const char* name, int angle, int distance, bool translucent )
-		: QGroupBox( parent, name )
+		: Q3GroupBox( parent, name )
 {
 	setTitle( i18n( "Shadow" ) );
 	setSizePolicy( QSizePolicy( QSizePolicy::Minimum, QSizePolicy::Minimum ) );
 
 	QGridLayout* layout = new QGridLayout( this );
-	layout->addRowSpacing( 0, 12 );
+	layout->addItem(new QSpacerItem(0, 12), 0, 0);
 	layout->setMargin( 3 );
 	layout->setSpacing( 2 );
-	layout->setColStretch( 0, 1 );
-	layout->setColStretch( 1, 0 );
-	layout->setColStretch( 2, 2 );
-	layout->addMultiCellWidget( m_preview = new ShadowPreview( this ), 1, 3, 0, 0 );
+	layout->setColumnStretch( 0, 1 );
+	layout->setColumnStretch( 1, 0 );
+	layout->setColumnStretch( 2, 2 );
+	layout->addWidget( m_preview = new ShadowPreview( this ), 1, 0, 3, 1 );
 	layout->addWidget( new QLabel( i18n( "Angle:" ), this ), 1, 1 );
 	layout->addWidget( m_angle = new KIntNumInput( this ), 1, 2 );
 	layout->addWidget( new QLabel( i18n( "Distance:" ), this ), 2, 1 );
@@ -314,15 +327,20 @@ ShadowWidget::updatePreview()
 }
 
 VTextOptionsWidget::VTextOptionsWidget( VTextTool* tool, QWidget *parent )
-	: KDialogBase( parent, "", true, i18n( "Text" ), Ok | Cancel ), m_tool( tool )
+	: KDialog( parent )
+	, m_tool( tool )
 {
+	setModal( true );
+	setCaption( i18n( "Text" ) );
+	setButtons( Ok | Cancel );
+
 	//setSizePolicy( QSizePolicy( QSizePolicy::Minimum, QSizePolicy::Minimum ) );
 	//setFrameStyle( Box | Sunken );
 	QWidget *base = new QWidget( this );
 	QVBoxLayout* mainLayout = new QVBoxLayout( base );
 	mainLayout->setMargin( 3 );
 
-	mainLayout->add( m_tabWidget = new QTabWidget( base ) );
+	mainLayout->addWidget( m_tabWidget = new QTabWidget( base ) );
 
 	m_tabWidget->setFont( QFont( KGlobalSettings::generalFont().family() , 8 ) );
 
@@ -335,53 +353,68 @@ VTextOptionsWidget::VTextOptionsWidget( VTextTool* tool, QWidget *parent )
 
 	textLayout->setMargin( 3 );
 	textLayout->setSpacing( 2 );
-	textLayout->addMultiCellWidget( m_fontCombo = new KFontCombo( list, textWidget ), 0, 0, 0, 2 );
+	textLayout->addWidget( m_fontCombo = new QFontComboBox( textWidget ), 0, 0, 1, 3 );
+	m_fontCombo->insertItems( 0, list );
 	textLayout->addWidget( m_fontSize = new KIntNumInput( textWidget ), 1, 0 );
 	textLayout->addWidget( m_boldCheck = new QCheckBox( i18n( "Bold" ), textWidget ), 1, 1 );
 	textLayout->addWidget( m_italicCheck = new QCheckBox( i18n( "Italic" ), textWidget ), 1, 2 );
-	textLayout->addMultiCellWidget( m_textEditor = new QLineEdit( textWidget ), 2, 2, 0, 2 );
+	textLayout->addWidget( m_textEditor = new QLineEdit( textWidget ), 2, 0, 1, 3 );
 
 	m_tabWidget->addTab( textWidget, i18n( "Text" ) );
 
+	QWidget* posWidget = new QWidget( m_tabWidget );
+	
+	QGridLayout* posLayout = new QGridLayout( posWidget );
+	textLayout->setMargin( 3 );
+	posLayout->setSpacing( 2 );
+	posLayout->addWidget( new QLabel( i18n( "Alignment:" ), posWidget ), 0, 0 );
+	posLayout->addWidget( m_textAlignment = new QComboBox( posWidget ), 0, 1 );
+	posLayout->addWidget( new QLabel( i18n( "Position:" ), posWidget ), 1, 0 );
+	posLayout->addWidget( m_textPosition = new QComboBox( posWidget ), 1, 1 );
+	posLayout->addWidget( new QLabel( i18n( "Offset:" ), posWidget ), 2, 0 );
+	posLayout->addWidget( m_textOffset = new KDoubleNumInput( posWidget ), 2, 1 );
+	posLayout->setColumnStretch( 0, 0 );
+	posLayout->setColumnStretch( 1, 1 );
+	
+	m_tabWidget->addTab( posWidget, i18n( "Position" ) );
+
 	QWidget* fxWidget = new QWidget( m_tabWidget );
 
 	QVBoxLayout* fxLayout = new QVBoxLayout( fxWidget );
 
 	fxLayout->setMargin( 3 );
 	fxLayout->setSpacing( 2 );
-	fxLayout->add( m_shadow = new ShadowWidget( fxWidget, 0L, 315, 4, true ) );
+	fxLayout->addWidget( m_shadow = new ShadowWidget( fxWidget, 0L, 315, 4, true ) );
 
-	QGridLayout* fxLayout2 = new QGridLayout( fxLayout );
+	QHBoxLayout* fxLayout2 = new QHBoxLayout();
 
 	fxLayout2->setSpacing( 2 );
-	fxLayout2->addWidget( new QLabel( i18n( "Alignment:" ), fxWidget ), 1, 0 );
-	fxLayout2->addWidget( m_textAlignment = new QComboBox( fxWidget ), 1, 1 );
-	fxLayout2->addWidget( new QLabel( i18n( "Position:" ), fxWidget ), 1, 2 );
-	fxLayout2->addWidget( m_textPosition = new QComboBox( fxWidget ), 1, 3 );
-	fxLayout2->addMultiCellWidget( m_editBasePath = new QPushButton( i18n( "Edit Base Path" ), fxWidget ), 2, 2, 0, 1 );
-	fxLayout2->addMultiCellWidget( m_convertToShapes = new QPushButton( i18n( "Convert to Shapes" ), fxWidget ), 2, 2, 2, 3 );
-	fxLayout2->setColStretch( 1, 1 );
-	fxLayout2->setColStretch( 3, 1 );
+	fxLayout2->addWidget( m_editBasePath = new QPushButton( i18n( "Edit Base Path" ), fxWidget ) );
+	fxLayout2->addWidget( m_convertToShapes = new QPushButton( i18n( "Convert to Shapes" ), fxWidget ) );
+	fxLayout->addLayout( fxLayout2 );
 
 	m_tabWidget->addTab( fxWidget, i18n( "Effects" ) );
 
-	m_fontCombo->setCurrentText( KGlobalSettings::generalFont().family() );
+	m_fontCombo->setItemText( m_fontCombo->currentIndex(), KGlobalSettings::generalFont().family() );
 
 	m_fontSize->setValue( 12 );
 	m_fontSize->setSuffix( " pt" );
 
 	m_textEditor->setMinimumHeight( 100 );
+	m_textEditor->setText( i18n( "New text") );
+	m_textEditor->selectAll();
 
 	m_convertToShapes->setEnabled( true );
 
-	// TODO: Find a way to display correctly the following icons...
-	m_textAlignment->insertItem( "Left" );
-	m_textAlignment->insertItem( "Center" );
-	m_textAlignment->insertItem( "Right" );
+	m_textAlignment->insertItem( 0, i18nc( "Horizontal alignment", "Left") );
+	m_textAlignment->insertItem( 1, i18nc( "Horizontal alignment", "Center") );
+	m_textAlignment->insertItem( 2, i18nc( "Horizontal alignment", "Right") );
 
-	m_textPosition->insertItem( SmallIcon( "14_text_above" ) );
-	m_textPosition->insertItem( SmallIcon( "14_text_on" ) );
-	m_textPosition->insertItem( SmallIcon( "14_text_under" ) );
+	m_textPosition->insertItem( 0, i18nc( "Vertical alignment", "Above") );
+	m_textPosition->insertItem( 1, i18nc( "Vertical alignment", "On") );
+	m_textPosition->insertItem( 2, i18nc( "Vertical alignment", "Under") );
+
+	m_textOffset->setRange( 0.0, 100.0, 1.0, true );
 
 	connect( m_fontCombo, SIGNAL( activated( int ) ), this, SLOT( valueChanged( int ) ) );
 	connect( m_boldCheck, SIGNAL( stateChanged( int ) ), this, SLOT( valueChanged( int ) ) );
@@ -389,6 +422,7 @@ VTextOptionsWidget::VTextOptionsWidget( VTextTool* tool, QWidget *parent )
 	connect( m_fontSize, SIGNAL( valueChanged( int ) ), this, SLOT( valueChanged( int ) ) );
 	connect( m_textPosition, SIGNAL( activated( int ) ), this, SLOT( valueChanged( int ) ) );
 	connect( m_textAlignment, SIGNAL( activated( int ) ), this, SLOT( valueChanged( int ) ) );
+	connect( m_textOffset, SIGNAL( valueChanged( double ) ), this, SLOT( valueChanged( double ) ) );
 	connect( m_textEditor, SIGNAL( returnPressed() ), this, SLOT( accept() ) );
 	connect( m_textEditor, SIGNAL( textChanged( const QString& ) ), this, SLOT( textChanged( const QString& ) ) );
 	connect( m_editBasePath, SIGNAL( clicked() ), this, SLOT( editBasePath() ) );
@@ -406,12 +440,21 @@ VTextOptionsWidget::~VTextOptionsWidget()
 void
 VTextOptionsWidget::valueChanged( int )
 {
+	/* TODO: port to QFontComboBox which doesn't seem to have similar functions
 	m_fontCombo->setBold( m_boldCheck->isChecked() );
 	m_fontCombo->setItalic( m_italicCheck->isChecked() );
+	*/
 
 	m_textEditor->setFont( QFont( m_fontCombo->currentText(), m_fontSize->value(), ( m_boldCheck->isChecked() ? 75 : 50 ), m_italicCheck->isChecked() ) );
 
-	if( isVisible() ) 
+	if( m_tool && isVisible() ) 
+		m_tool->textChanged();
+}
+
+void
+VTextOptionsWidget::valueChanged( double )
+{
+	if( m_tool && isVisible() ) 
 		m_tool->textChanged();
 }
 
@@ -433,26 +476,28 @@ VTextOptionsWidget::cancel()
 void
 VTextOptionsWidget::textChanged( const QString& )
 {
-	if( isVisible() )
+	if( m_tool && isVisible() )
 		m_tool->textChanged();
 }
 
 void
 VTextOptionsWidget::editBasePath()
 {
-	m_tool->editBasePath();
+	if( m_tool )
+		m_tool->editBasePath();
 }
 
 void
 VTextOptionsWidget::convertToShapes()
 {
-	m_tool->convertToShapes();
+	if( m_tool )
+		m_tool->convertToShapes();
 }
 
 void
 VTextOptionsWidget::setFont( const QFont& font )
 {
-	m_fontCombo->setCurrentText( font.family() );
+	m_fontCombo->setItemText( m_fontCombo->currentIndex(), font.family() );
 
 	m_boldCheck->setChecked( font.bold() );
 
@@ -460,8 +505,10 @@ VTextOptionsWidget::setFont( const QFont& font )
 
 	m_fontSize->setValue( font.pointSize() );
 
+	/* TODO: Port to QFontComboBox which doesn't seem to have similar functions
 	m_fontCombo->setBold( m_boldCheck->isChecked() );
 	m_fontCombo->setItalic( m_italicCheck->isChecked() );
+	*/
 
 	m_textEditor->setFont( QFont( m_fontCombo->currentText(), m_fontSize->value(), ( m_boldCheck->isChecked() ? 75 : 50 ), m_italicCheck->isChecked() ) );
 }
@@ -485,23 +532,37 @@ QString VTextOptionsWidget::text()
 void
 VTextOptionsWidget::setPosition( VText::Position position )
 {
-	m_textPosition->setCurrentItem( position );
+	m_textPosition->setCurrentIndex( position );
 }
 
 VText::Position VTextOptionsWidget::position()
 {
-	return ( VText::Position ) m_textPosition->currentItem();
+	return ( VText::Position ) m_textPosition->currentIndex();
 }
 
 void
 VTextOptionsWidget::setAlignment( VText::Alignment alignment )
 {
-	m_textAlignment->setCurrentItem( alignment );
+	m_textAlignment->setCurrentIndex( alignment );
 }
 
 VText::Alignment VTextOptionsWidget::alignment()
 {
-	return ( VText::Alignment ) m_textAlignment->currentItem();
+	return ( VText::Alignment ) m_textAlignment->currentIndex();
+}
+
+void 
+VTextOptionsWidget::setOffset( double offset )
+{
+	if( offset < 0.0 ) offset = 0.0;
+	if( offset > 100.0 ) offset = 100.0;
+
+	m_textOffset->setValue( offset );
+}
+double 
+VTextOptionsWidget::offset()
+{
+	return m_textOffset->value();
 }
 
 void
@@ -545,35 +606,30 @@ VTextOptionsWidget::initialize( VObject &text )
 		m_tool->visit( text );
 }
 
-void 
-VTextOptionsWidget::moveEvent ( QMoveEvent * )
-{
-	if( m_tool && isVisible() )
-		m_tool->textChanged();
-}
-
-VTextTool::VTextTool( KarbonPart *part, const char* name )
-		: VTool( part, name )
+VTextTool::VTextTool( KarbonView *view )
+		: VTool( view, "tool_text" )
 {
 	m_optionsWidget = new VTextOptionsWidget( this, 0L );
 	m_text = 0L;
 	m_editedText = 0L;
 	registerTool( this );
+	m_cursor = new QCursor( VCursor::createCursor( VCursor::CrossHair ) );
 }
 
 VTextTool::~VTextTool()
 {
 	delete m_optionsWidget;
 	delete m_editedText;
+	delete m_cursor;
 }
 
 QString VTextTool::contextHelp()
 {
-	QString s = "<qt><b>Text tool</b><br>";
-	s += "<i>Type</i> your text and <i>click and drag</i> to place it.<br>";
-	s += "If the selection made before the tool activation was a text object, it is edited.<br>";
-	s += "If the selection was a path, the text is drawn along it.<br>";
-	s += "Press <i>Return</i> to validate your text.</qt>";
+	QString s = i18n( "<qt><b>Text Tool</b><br>" );
+	s += i18n("<i>Click</i> on document to place horizontal text.<br>" );
+	s += i18n("<i>Click and drag</i> in document to place directional text.<br>" );
+	s += i18n("<i>Click</i> on a selected path object to place text along its outline.<br>" );
+	s += i18n("<i>Click</i> on a selected text object to change it.<br></qt>" );
 
 	return s;
 }
@@ -581,8 +637,9 @@ QString VTextTool::contextHelp()
 void
 VTextTool::activate()
 {
+	VTool::activate();
 	view()->statusMessage()->setText( i18n( "Text Tool" ) );
-	view()->setCursor( QCursor( Qt::crossCursor ) );
+	view()->setCursor( *m_cursor );
 
 	m_creating = true;
 	m_text = 0L;
@@ -595,6 +652,13 @@ VTextTool::deactivate()
 {
 }
 
+void
+VTextTool::draw( VPainter* painter )
+{
+	if( m_editedText )
+		m_editedText->draw( painter, &m_editedText->boundingBox() );
+}
+
 void
 VTextTool::drawPathCreation()
 {
@@ -602,29 +666,24 @@ VTextTool::drawPathCreation()
 
 	painter->setZoomFactor( view()->zoom() );
 
-	painter->setRasterOp( Qt::NotROP );
+	// TODO rasterops need porting
+	// painter->setRasterOp( Qt::NotROP );
 	painter->newPath();
 	painter->setPen( Qt::DotLine );
 	painter->setBrush( Qt::NoBrush );
 
+/* TODO moveto and lineto need porting
 	painter->moveTo( first() );
-	painter->lineTo( m_last );
+	painter->lineTo( m_last );*/
+
 	painter->strokePath();
 }
 
 void
 VTextTool::drawEditedText()
 {
-	if( !m_editedText )
-		return;
-
-	kdDebug(38000) << "Drawing: " << m_editedText->text() << endl;
-
-	VPainter* painter = view()->painterFactory()->editpainter();
-
-	painter->setZoomFactor( view()->zoom() );
-
-	m_editedText->draw( painter, &m_editedText->boundingBox() );
+	//if( m_editedText ) 
+	//	view()->repaintAll( m_editedText->boundingBox() );
 }
 
 void
@@ -638,13 +697,32 @@ VTextTool::mouseButtonPress()
 void
 VTextTool::mouseButtonRelease()
 {
-	// use a default horizontal path when just clicking
-	VSubpath path( 0L );
-	path.moveTo( first() );
-	path.lineTo( KoPoint( first().x()+10, first().y() ) );
+	if( ! view() ) 
+		return;
 
-	if( createText( path ) )
-		m_optionsWidget->show();
+	VSelection* selection = view()->part()->document().selection();
+	VObject* selObj = selection->objects().getFirst();
+
+	// initialize dialog with single selected object
+	if( selection->objects().count() == 1 && selObj->boundingBox().contains( last() ) )
+		m_optionsWidget->initialize( *selObj );
+	else 
+	{
+		// use a default horizontal path when just clicking
+		VSubpath path( 0L );
+		path.moveTo( first() );
+		path.lineTo( QPointF( first().x()+10, first().y() ) );
+	
+		if( ! createText( path ) )
+			return;
+	}
+
+	if( dynamic_cast<VText*>( selObj ) && selObj->boundingBox().contains( last() ) )
+		m_optionsWidget->setCaption( i18n( "Change Text") );
+	else 
+		m_optionsWidget->setCaption( i18n( "Insert Text") );
+
+	m_optionsWidget->show();
 }
 
 void
@@ -654,8 +732,8 @@ VTextTool::mouseDrag()
 
 	if( m_stepwise && shiftPressed() )
 	{
-		KoPoint act = last();
-		KoPoint dst = act - first();
+		QPointF act = last();
+		QPointF dst = act - first();
  
 		double angle = atan2( dst.y(), dst.x() );
 		if( angle < 0 )
@@ -703,7 +781,10 @@ VTextTool::mouseDragRelease()
 	path.lineTo( m_last );
 
 	if( createText( path ) )
+	{
+		m_optionsWidget->setCaption( i18n( "Insert Text") );
 		m_optionsWidget->show();
+	}
 }
 
 bool
@@ -733,7 +814,6 @@ VTextTool::createText( VSubpath &path )
 void
 VTextTool::textChanged()
 {
-
 	if( !m_editedText )
 		return;
 
@@ -741,16 +821,16 @@ VTextTool::textChanged()
 	{
 		// hide the original text if we are changing it
 		m_text->setState( VObject::hidden );
-		view()->repaintAll( m_text->boundingBox() );
+		//view()->repaintAll( m_text->boundingBox() );
 	}
 	else
-		view()->repaintAll( m_editedText->boundingBox() );
+		//view()->repaintAll( m_editedText->boundingBox() );
 
 	m_editedText->setText( m_optionsWidget->text() );
 	m_editedText->setFont( m_optionsWidget->font() );
 	m_editedText->setPosition( m_optionsWidget->position() );
 	m_editedText->setAlignment( m_optionsWidget->alignment() );
-
+	m_editedText->setOffset( 0.01 * m_optionsWidget->offset()  );
 #ifdef HAVE_KARBONTEXT
 	m_editedText->traceText();
 #endif
@@ -776,6 +856,7 @@ VTextTool::accept()
 				  m_editedText->basePath(),
 				  m_editedText->position(),
 				  m_editedText->alignment(),
+				  m_editedText->offset(),
 				  m_editedText->text(),
 				  m_optionsWidget->useShadow(),
 				  m_optionsWidget->shadowAngle(),
@@ -792,6 +873,9 @@ VTextTool::accept()
 				  &view()->part()->document(),
 				  i18n( "Insert Text" ),
 				  newText );
+
+		delete m_editedText;
+		m_editedText = 0L;
 	}
 
 	view()->part()->addCommand( cmd, true );
@@ -806,7 +890,7 @@ VTextTool::cancel()
 	{
 		// show original text if we canceled changing it
 		m_text->setState( VObject::selected );
-		view()->repaintAll( m_text->boundingBox() );
+		//view()->repaintAll( m_text->boundingBox() );
 	}
 	else
 		drawPathCreation();
@@ -875,10 +959,12 @@ VTextTool::visitVText( VText& text )
 	m_optionsWidget->setText( text.text() );
 	m_optionsWidget->setPosition( text.position() );
 	m_optionsWidget->setAlignment( text.alignment() );
+	m_optionsWidget->setOffset( text.offset() * 100.0 );
 	m_optionsWidget->setUseShadow( text.useShadow() );
 	m_optionsWidget->setShadow( text.shadowAngle(), text.shadowDistance(), text.translucentShadow() );
-
 	m_creating = false;
+	m_text->setState( VObject::hidden );
+	m_editedText->setState( VObject::edit );
 }
 
 VTextTool::VTextCmd::VTextCmd( VDocument* doc, const QString& name, VText* text )
@@ -886,11 +972,11 @@ VTextTool::VTextCmd::VTextCmd( VDocument* doc, const QString& name, VText* text
 {
 	m_textModifications = 0L;
 
-	m_executed = false;
+	m_redod = false;
 }
 
 VTextTool::VTextCmd::VTextCmd( VDocument* doc, const QString& name, VText* text,
-							   const QFont &newFont, const VSubpath& newBasePath, VText::Position newPosition, VText::Alignment newAlignment, const QString& newText,
+							   const QFont &newFont, const VSubpath& newBasePath, VText::Position newPosition, VText::Alignment newAlignment, double newOffset, const QString& newText,
 							   bool newUseShadow, int newShadowAngle, int newShadowDistance, bool newTranslucentShadow )
 		: VCommand( doc, name, "14_text" ), m_text( text )
 {
@@ -903,6 +989,8 @@ VTextTool::VTextCmd::VTextCmd( VDocument* doc, const QString& name, VText* text,
 	m_textModifications->oldPosition = text->position();
 	m_textModifications->newAlignment = newAlignment;
 	m_textModifications->oldAlignment = text->alignment();
+	m_textModifications->newOffset = newOffset;
+	m_textModifications->oldOffset = text->offset();
 	m_textModifications->newText = newText;
 	m_textModifications->oldText = text->text();
 	m_textModifications->newUseShadow = newUseShadow;
@@ -914,7 +1002,7 @@ VTextTool::VTextCmd::VTextCmd( VDocument* doc, const QString& name, VText* text,
 	m_textModifications->newTranslucentShadow = newTranslucentShadow;
 	m_textModifications->oldTranslucentShadow = text->translucentShadow();
 
-	m_executed = false;
+	m_redod = false;
 }
 
 VTextTool::VTextCmd::~VTextCmd()
@@ -923,7 +1011,7 @@ VTextTool::VTextCmd::~VTextCmd()
 }
 
 void
-VTextTool::VTextCmd::execute()
+VTextTool::VTextCmd::redo()
 {
 	if( !m_text )
 		return;
@@ -935,9 +1023,11 @@ VTextTool::VTextCmd::execute()
 		else
 		{
 			m_text->setState( VObject::normal );
+			/* TODO: porting to flake
 			document()->append( m_text );
 			document()->selection()->clear();
 			document()->selection()->append( m_text );
+			*/
 		}
 	}
 	else
@@ -946,6 +1036,7 @@ VTextTool::VTextCmd::execute()
 		m_text->setBasePath( m_textModifications->newBasePath );
 		m_text->setPosition( m_textModifications->newPosition );
 		m_text->setAlignment( m_textModifications->newAlignment );
+		m_text->setOffset( m_textModifications->newOffset );
 		m_text->setText( m_textModifications->newText );
 		m_text->setUseShadow( m_textModifications->newUseShadow );
 		m_text->setShadow( m_textModifications->newShadowAngle, m_textModifications->newShadowDistance, m_textModifications->newTranslucentShadow );
@@ -957,13 +1048,13 @@ VTextTool::VTextCmd::execute()
 		m_text->setState( VObject::normal );
 	}
 
-	m_executed = true;
+	m_redod = true;
 
 	setSuccess( true );
 }
 
 void
-VTextTool::VTextCmd::unexecute()
+VTextTool::VTextCmd::undo()
 {
 	if( !m_text )
 		return;
@@ -979,6 +1070,7 @@ VTextTool::VTextCmd::unexecute()
 		m_text->setBasePath( m_textModifications->oldBasePath );
 		m_text->setPosition( m_textModifications->oldPosition );
 		m_text->setAlignment( m_textModifications->oldAlignment );
+		m_text->setOffset( m_textModifications->oldOffset );
 		m_text->setText( m_textModifications->oldText );
 		m_text->setUseShadow( m_textModifications->oldUseShadow );
 		m_text->setShadow( m_textModifications->oldShadowAngle, m_textModifications->oldShadowDistance, m_textModifications->oldTranslucentShadow );
@@ -990,13 +1082,13 @@ VTextTool::VTextCmd::unexecute()
 		m_text->setState( VObject::normal );
 	}
 
-	m_executed = false;
+	m_redod = false;
 
 	setSuccess( false );
 }
 
 VTextTool::VTextToCompositeCmd::VTextToCompositeCmd( VDocument* doc, const QString& name, VText* text )
-		: VCommand( doc, name, "14_text" ), m_text( text ), m_group( 0L ), m_executed( false )
+		: VCommand( doc, name, "14_text" ), m_text( text ), m_group( 0L ), m_redod( false )
 {
 }
 
@@ -1005,15 +1097,18 @@ VTextTool::VTextToCompositeCmd::~VTextToCompositeCmd()
 }
 
 void
-VTextTool::VTextToCompositeCmd::execute()
+VTextTool::VTextToCompositeCmd::redo()
 {
 	if( !m_text )
 		return;
 
 	if( !m_group )
 	{
+                return;
+		/* TODO: porting to flake
 		m_group = m_text->toVGroup();
 		document()->append( m_group );
+		*/
 	}
 
 	m_text->setState( VObject::deleted );
@@ -1021,13 +1116,13 @@ VTextTool::VTextToCompositeCmd::execute()
 	document()->selection()->clear();
 	document()->selection()->append( m_group );
 
-	m_executed = true;
+	m_redod = true;
 
 	setSuccess( true );
 }
 
 void
-VTextTool::VTextToCompositeCmd::unexecute()
+VTextTool::VTextToCompositeCmd::undo()
 {
 	if( !m_text )
 		return;
@@ -1038,7 +1133,7 @@ VTextTool::VTextToCompositeCmd::unexecute()
 
 	m_group->setState( VObject::deleted );
 
-	m_executed = false;
+	m_redod = false;
 
 	setSuccess( false );
 }
@@ -1048,12 +1143,17 @@ VTextTool::showDialog() const
 {
 	VSelection* selection = view()->part()->document().selection();
 
-	// initialize dialog single selected object
+	// initialize dialog with single selected object
 	if( selection->objects().count() == 1 )
 		m_optionsWidget->initialize( *selection->objects().getFirst());
 	else 
 		return false;
 
+	if( dynamic_cast<VText*>( selection->objects().getFirst() ) )
+		m_optionsWidget->setCaption(i18n( "Change Text") );
+	else 
+		m_optionsWidget->setCaption(i18n( "Insert Text") );
+
 	m_optionsWidget->show();
 	return true;
 }
@@ -1072,5 +1172,22 @@ VTextTool::mouseDragShiftReleased()
 	mouseDrag();
 }
 
+void
+VTextTool::setup( KActionCollection *collection )
+{
+	m_action = static_cast<KAction *>(collection -> action( objectName() ) );
+
+	if( m_action == 0 )
+	{
+		m_action = new KAction( KIcon( "14_text" ), i18n( "Text Tool" ), collection );
+        collection->addAction(objectName(), m_action );
+		m_action->setShortcut( KShortcut( Qt::SHIFT+Qt::Key_T ), KAction::DefaultShortcut );
+		m_action->setToolTip( i18n( "Text Tool" ) );
+		connect( m_action, SIGNAL( triggered() ), this, SLOT( activate() ) );
+		// TODO needs porting: m_action->setExclusiveGroup( "misc" );
+		//m_ownAction = true;
+	}
+}
+
 #include "vtexttool.moc"
 
