@@ -32,7 +32,7 @@ VSelectionDescription::visitVSelection( VSelection& selection )
 	if( selection.objects().count() == 1 )
 		VVisitor::visitVSelection( selection );
 	else
-		m_desc = i18n( "One object", "%n objects", selection.objects().count() );
+		m_desc = i18np( "One object", "%n objects", selection.objects().count() );
 }
 
 void
@@ -44,7 +44,7 @@ VSelectionDescription::visitVPath( VPath& composite )
 void
 VSelectionDescription::visitVGroup( VGroup &group )
 {
-	m_desc = i18n( "One group, containing one object", "One group, containing %n objects", group.objects().count() );
+	m_desc = i18np( "One group, containing one object", "One group, containing %n objects", group.objects().count() );
 	m_shortdesc = !group.name().isEmpty() ? group.name() : i18n( "group" );
 }
 
