@@ -23,8 +23,11 @@
 /* needed for KDE_EXPORT and KDE_IMPORT macros */
 #include <kdemacros.h>
 
+/* We use _WIN32/_WIN64 instead of Q_OS_WIN so that this header can be used from C files too */
+#if defined _WIN32 || defined _WIN64
+
 #ifndef KCHART_EXPORT
-# if defined(MAKE_KCHART_LIB)
+# if defined(MAKE_KCHARTCOMMON_LIB)
    /* We are building this library */ 
 #  define KCHART_EXPORT KDE_EXPORT
 # else
@@ -33,24 +36,10 @@
 # endif
 #endif
 
-#ifndef KCHARTCOMMON_EXPORT
-# if defined(MAKE_KCHARTCOMMON_LIB)
-   /* We are building this library */ 
-#  define KCHARTCOMMON_EXPORT KDE_EXPORT
-# else
-   /* We are using this library */ 
-#  define KCHARTCOMMON_EXPORT KDE_IMPORT
-# endif
-#endif
+#else /* UNIX */
+
+#define KCHART_EXPORT KDE_EXPORT
 
-#ifndef CHARTSHAPELIB_EXPORT
-# if defined(MAKE_CHARTSHAPELIB_LIB)
-   /* We are building this library */ 
-#  define CHARTSHAPELIB_EXPORT KDE_EXPORT
-# else
-   /* We are using this library */ 
-#  define CHARTSHAPELIB_EXPORT KDE_IMPORT
-# endif
 #endif
 
 #endif
