@@ -1,40 +1,40 @@
 /****************************************************************************
- ** Copyright (C) 2007 Klarälvdalens Datakonsult AB.  All rights reserved.
+ ** Copyright (C) 2006 Klarälvdalens Datakonsult AB.  All rights reserved.
  **
  ** This file is part of the KD Chart library.
  **
- ** This file may be used under the terms of the GNU General Public
- ** License versions 2.0 or 3.0 as published by the Free Software
- ** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
- ** included in the packaging of this file.  Alternatively you may (at
- ** your option) use any later version of the GNU General Public
- ** License if such license has been publicly approved by
- ** Klarälvdalens Datakonsult AB (or its successors, if any).
- ** 
- ** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
- ** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
- ** A PARTICULAR PURPOSE. Klarälvdalens Datakonsult AB reserves all rights
- ** not expressly granted herein.
- ** 
+ ** This file may be distributed and/or modified under the terms of the
+ ** GNU General Public License version 2 as published by the Free Software
+ ** Foundation and appearing in the file LICENSE.GPL included in the
+ ** packaging of this file.
+ **
+ ** Licensees holding valid commercial KD Chart licenses may use this file in
+ ** accordance with the KD Chart Commercial License Agreement provided with
+ ** the Software.
+ **
  ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
  ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  **
+ ** See http://www.kdab.net/kdchart for
+ **   information about KDChart Commercial License Agreements.
+ **
+ ** Contact info@kdab.net if any conditions of this
+ ** licensing are not clear to you.
+ **
  **********************************************************************/
 
 #include <QDebug>
 #include <QPainter>
 #include <QStack>
 
-#include "KDChartPieDiagram.h"
-#include "KDChartPieDiagram_p.h"
-
 #include "KDChartAttributesModel.h"
 #include "KDChartPaintContext.h"
+#include "KDChartPieDiagram.h"
+#include "KDChartPieDiagram_p.h"
 #include "KDChartPieAttributes.h"
 #include "KDChartThreeDPieAttributes.h"
 #include "KDChartPainterSaver_p.h"
 #include "KDChartDataValueAttributes.h"
-#include "KDChartNullPaintDevice.h"
 
 #include <KDABLibFakes>
 
@@ -63,9 +63,6 @@ void PieDiagram::init()
 {
 }
 
-/**
-  * Creates an exact copy of this diagram.
-  */
 PieDiagram * PieDiagram::clone() const
 {
     return new PieDiagram( new Private( *d ) );
@@ -160,7 +157,6 @@ void PieDiagram::paint( PaintContext* ctx )
         startAngle += spanAngle;
         startAngleValueSpace += nextValue;
     }
-    d->clearListOfAlreadyDrawnDataValueTexts();
     DataValueTextInfoListIterator it( list );
     while ( it.hasNext() ) {
         const DataValueTextInfo& info = it.next();
@@ -169,36 +165,14 @@ void PieDiagram::paint( PaintContext* ctx )
 }
 */
 
-void PieDiagram::paint(PaintContext* ctx)
-{
-    // Painting is a two stage process
-    // In the first stage we figure out how much space is needed
-    // for text labels.
-    // In the second stage, we make use of that information and
-    // perform the actual painting.
-    QPainter* actualPainter = ctx->painter();
-    QRectF textBoundingRect;
 
-    // Use a null paint device and perform the first painting.
-    KDChart::NullPaintDevice nullPd(ctx->rectangle().size().toSize());
-    QPainter nullPainter(&nullPd);
-    ctx->setPainter(&nullPainter);
-    paintInternal(ctx, textBoundingRect);
-
-    // Now perform the real painting
-    ctx->setPainter(actualPainter);
-    paintInternal(ctx, textBoundingRect);
-}
-
-void PieDiagram::paintInternal(PaintContext* ctx, QRectF& textBoundingRect)
+void PieDiagram::paint( PaintContext* ctx )
 {
     // note: Not having any data model assigned is no bug
     //       but we can not draw a diagram then either.
     if ( !checkInvariants(true) )
         return;
 
-    d->reverseMapper.clear();
-
     const PieAttributes attrs( pieAttributes() );
     const ThreeDPieAttributes threeDAttrs( threeDPieAttributes( model()->index( 0, 0, rootIndex() ) ) );
 
@@ -232,35 +206,6 @@ void PieDiagram::paintInternal(PaintContext* ctx, QRectF& textBoundingRect)
     }
     d->size /= ( 1.0 + 2.0 * maxExplode );
 
-    if(!textBoundingRect.isEmpty())
-    {
-        // Find out the maximum distance from every corner of the rectangle with
-        // the center.
-        double maxDistance = 0, dist = 0;
-
-        QPointF center = ctx->rectangle().center();
-
-        dist = qAbs(textBoundingRect.right() - center.x());
-        if(dist > maxDistance)
-            maxDistance = dist;
-
-        dist = qAbs(textBoundingRect.left() - center.x());
-        if(dist > maxDistance)
-            maxDistance = dist;
-
-        dist = qAbs(textBoundingRect.top() - center.y());
-        if(dist > maxDistance)
-            maxDistance = dist;
-
-        dist = qAbs(textBoundingRect.bottom() - center.y());
-        if(dist > maxDistance)
-            maxDistance = dist;
-
-        double size = d->size;
-        double diff = (2*maxDistance - d->size);
-        if(diff > 0)
-            d->size *= 1.0-(diff/size);
-    }
 
     qreal sizeFor3DEffect = 0.0;
     if ( ! threeDAttrs.isEnabled() ) {
@@ -340,9 +285,7 @@ void PieDiagram::paintInternal(PaintContext* ctx, QRectF& textBoundingRect)
     int currentLeftPie = backmostpie;
     int currentRightPie = backmostpie;
 
-    d->clearListOfAlreadyDrawnDataValueTexts();
-
-    drawOnePie( ctx->painter(), &list, 0, backmostpie, granularity(), sizeFor3DEffect );
+    drawOnePie( ctx->painter(), 0, backmostpie, granularity(), sizeFor3DEffect );
 
     if( backmostpie == frontmostpie )
     {
@@ -354,25 +297,26 @@ void PieDiagram::paintInternal(PaintContext* ctx, QRectF& textBoundingRect)
     while( currentLeftPie != frontmostpie )
     {
         if( currentLeftPie != backmostpie )
-            drawOnePie( ctx->painter(), &list, 0, currentLeftPie, granularity(), sizeFor3DEffect );
+            drawOnePie( ctx->painter(), 0, currentLeftPie, granularity(), sizeFor3DEffect );
         currentLeftPie = findLeftPie( currentLeftPie, colCount );
     }
     while( currentRightPie != frontmostpie )
     {
         if( currentRightPie != backmostpie )
-            drawOnePie( ctx->painter(), &list, 0, currentRightPie, granularity(), sizeFor3DEffect );
+            drawOnePie( ctx->painter(), 0, currentRightPie, granularity(), sizeFor3DEffect );
         currentRightPie = findRightPie( currentRightPie, colCount );
     }
 
     // if the backmost pie is not the frontmost pie, we draw the frontmost at last
     if( backmostpie != frontmostpie || ! threeDPieAttributes().isEnabled() )
     {
-        drawOnePie( ctx->painter(), &list, 0, frontmostpie, granularity(), sizeFor3DEffect );
-    // otherwise, this gets a bit more complicated...
-/*    } else if( threeDPieAttributes().isEnabled() ) {
-        //drawPieSurface( ctx->painter(), 0, frontmostpie, granularity() );
+        drawOnePie( ctx->painter(), 0, frontmostpie, granularity(), sizeFor3DEffect );
+    // else, this gets a bit mor complicated...
+    } else if( threeDPieAttributes().isEnabled() ) {
+        drawPieSurface( ctx->painter(), 0, frontmostpie, granularity() );
         const QModelIndex index = model()->index( 0, frontmostpie, rootIndex() );
         QPen pen = this->pen( index );
+        ctx->painter()->setRenderHint ( QPainter::Antialiasing );
         ctx->painter()->setBrush( brush( index ) );
         if ( threeDAttrs.isEnabled() )
             pen.setColor( QColor( 0, 0, 0 ) );
@@ -386,10 +330,8 @@ void PieDiagram::paintInternal(PaintContext* ctx, QRectF& textBoundingRect)
         startAngle = qMax( startAngle, 180.0 );
 
         drawArcEffectSegment( ctx->painter(), piePosition( 0, frontmostpie),
-                sizeFor3DEffect, startAngle, endAngle, granularity() );*/
+                sizeFor3DEffect, startAngle, endAngle, granularity() );
     }
-
-    d->paintDataValueTextsAndMarkers(  this,  ctx,  list,  false, false, &textBoundingRect );
 }
 
 #if defined ( Q_WS_WIN)
@@ -398,7 +340,6 @@ void PieDiagram::paintInternal(PaintContext* ctx, QRectF& textBoundingRect)
 
 QRectF PieDiagram::piePosition( uint dataset, uint pie ) const
 {
-    Q_UNUSED( dataset );
     qreal angleLen = d->angleLens[ pie ];
     qreal startAngle = d->startAngles[ pie ];
     QModelIndex index( model()->index( 0, pie, rootIndex() ) );
@@ -415,6 +356,8 @@ QRectF PieDiagram::piePosition( uint dataset, uint pie ) const
         qreal explodeX = attrs.explodeFactor() * d->size * cosAngle;
         qreal explodeY = attrs.explodeFactor() * d->size * sinAngle;
         drawPosition.translate( explodeX, explodeY );
+    }else{
+        drawPosition = d->position;
     }
     return drawPosition;
  }
@@ -428,20 +371,28 @@ QRectF PieDiagram::piePosition( uint dataset, uint pie ) const
   \param threeDPieHeight the height of the three dimnensional effect
   */
 void PieDiagram::drawOnePie( QPainter* painter,
-        DataValueTextInfoList* list,
         uint dataset, uint pie,
         qreal granularity,
         qreal threeDPieHeight )
 {
-    Q_UNUSED( threeDPieHeight );
     // Is there anything to draw at all?
-    const qreal angleLen = d->angleLens[ pie ];
+    qreal angleLen = d->angleLens[ pie ];
     if ( angleLen ) {
-        const QModelIndex index( model()->index( 0, pie, rootIndex() ) );
+  //      qreal startAngle = d->startAngles[ pie ];
+/*
+        KDChartDataRegion* datReg = 0;
+        QRegion* region = 0;
+        bool mustDeleteRegion = false;
+        if ( regions ){
+            region = new QRegion();
+            mustDeleteRegion = true;
+        }
+*/
+        QModelIndex index( model()->index( 0, pie, rootIndex() ) );
         const PieAttributes attrs( pieAttributes( index ) );
         const ThreeDPieAttributes threeDAttrs( threeDPieAttributes( index ) );
 
-        const QRectF drawPosition = piePosition( dataset, pie );
+        QRectF drawPosition = piePosition( dataset, pie );
 
         draw3DEffect( painter,
             drawPosition, dataset, pie,
@@ -449,7 +400,7 @@ void PieDiagram::drawOnePie( QPainter* painter,
             threeDAttrs,
             attrs.explode() );
 
-        drawPieSurface( painter, list, dataset, pie, granularity );
+        drawPieSurface( painter, dataset, pie, granularity );
     }
 }
 
@@ -461,7 +412,6 @@ void PieDiagram::drawOnePie( QPainter* painter,
   \param pie the pie to draw
   */
 void PieDiagram::drawPieSurface( QPainter* painter,
-        DataValueTextInfoList* list,
         uint dataset, uint pie,
         qreal granularity )
 {
@@ -469,23 +419,78 @@ void PieDiagram::drawPieSurface( QPainter* painter,
     qreal angleLen = d->angleLens[ pie ];
     if ( angleLen ) {
         qreal startAngle = d->startAngles[ pie ];
-
+/*
+        KDChartDataRegion* datReg = 0;
+        QRegion* region = 0;
+        bool mustDeleteRegion = false;
+        if ( regions ){
+            region = new QRegion();
+            mustDeleteRegion = true;
+        }
+*/
         QModelIndex index( model()->index( 0, pie, rootIndex() ) );
         const PieAttributes attrs( pieAttributes( index ) );
         const ThreeDPieAttributes threeDAttrs( threeDPieAttributes( index ) );
 
         QRectF drawPosition = piePosition( dataset, pie );
+//        QRectF drawPosition( d->position );
+
+/*        if ( attrs.explode() ) {
+            qreal explodeAngle = ( startAngle + angleLen / 2.0 );
+            qreal explodeAngleRad = DEGTORAD( explodeAngle );
+            qreal cosAngle = cos( explodeAngleRad );
+            qreal sinAngle = -sin( explodeAngleRad );
+            qreal explodeX = attrs.explodeFactor() * d->size * cosAngle;
+            qreal explodeY = attrs.explodeFactor() * d->size * sinAngle;
+            drawPosition.translate( explodeX, explodeY );
+        }else{
+            drawPosition = d->position;
+        }*/
 
         QPen pen = this->pen( index );
+        PainterSaver painterSaver( painter );
         painter->setRenderHint ( QPainter::Antialiasing );
         painter->setBrush( brush( index ) );
-//        if ( threeDAttrs.isEnabled() )
-//            pen.setColor( QColor( 0, 0, 0 ) );
-//        painter->setPen( pen );
+        if ( threeDAttrs.isEnabled() )
+            pen.setColor( QColor( 0, 0, 0 ) );
+        painter->setPen( pen );
 
         if ( angleLen == 360 ) {
             // full circle, avoid nasty line in the middle
             painter->drawEllipse( drawPosition );
+/*
+            if ( regions ) {
+                QPointArray hitregion;
+                hitregion.makeEllipse( drawPosition.x(), drawPosition.y(),
+                                       drawPosition.width(),
+                                       drawPosition.height() );
+                datReg = new KDChartDataRegion( region->unite( QRegion( hitregion ) ),
+                                                dataset,
+                                                pie,
+                                                chart );
+                datReg->points[ KDChartEnums::PosCenter ]
+                    = drawPosition.center();
+                datReg->points[ KDChartEnums::PosCenterRight ]
+                    = pointOnCircle( drawPosition,    0 );
+                datReg->points[ KDChartEnums::PosTopRight ]
+                    = pointOnCircle( drawPosition,  45 );
+                datReg->points[ KDChartEnums::PosTopCenter ]
+                    = pointOnCircle( drawPosition, 90 );
+                datReg->points[ KDChartEnums::PosTopLeft ]
+                    = pointOnCircle( drawPosition, 135 );
+                datReg->points[ KDChartEnums::PosCenterLeft ]
+                    = pointOnCircle( drawPosition, 180 );
+                datReg->points[ KDChartEnums::PosBottomLeft ]
+                    = pointOnCircle( drawPosition, 225 );
+                datReg->points[ KDChartEnums::PosBottomCenter ]
+                    = pointOnCircle( drawPosition, 270 );
+                datReg->points[ KDChartEnums::PosBottomRight ]
+                    = pointOnCircle( drawPosition, 315 );
+                datReg->startAngle = 180;
+                datReg->angleLen   = 360;
+                regions->append( datReg );
+            }
+*/
         } else {
             // draw the top of this piece
             // Start with getting the points for the arc.
@@ -507,57 +512,86 @@ void PieDiagram::drawPieSurface( QPainter* painter,
             if( ! perfectMatch ){
                 poly[ iPoint ] = pointOnCircle( drawPosition, startAngle + angleLen );
 
+//qDebug() << "adding" << poly[ iPoint ];
                 // add the center point of the piece
                 poly.append( drawPosition.center() );
+//qDebug() << "center:" << poly[ ++iPoint ];
             }else{
                 poly[ iPoint ] = drawPosition.center();
+//qDebug() << "center:" << poly[ iPoint ];
             }
+//qDebug() << "a";
             //find the value and paint it
             //fix value position
             const qreal sum = valueTotals();
-            d->reverseMapper.addPolygon( index.row(), index.column(), poly );
             painter->drawPolygon( poly );
 
-            // the new code is setting the needed position points according to the slice:
-            // all is calculated as if the slice were 'standing' on it's tip and the border
-            // were on top, so North is the middle of the curved outside line and South is the tip
-            //
-            const QPointF south = drawPosition.center();
-            const QPointF southEast = south;
-            const QPointF southWest = south;
-            const QPointF north = pointOnCircle( drawPosition, startAngle + angleLen/2.0 );
-            const QPointF northEast = pointOnCircle( drawPosition, startAngle );
-            const QPointF northWest = pointOnCircle( drawPosition, startAngle + angleLen );
-            const QPointF center    = (south + north) / 2.0;
-            const QPointF east      = (south + northEast) / 2.0;
-            const QPointF west      = (south + northWest) / 2.0;
-            PositionPoints points( center, northWest, north, northEast, east, southEast, south, southWest, west);
-            qreal topAngle = startAngle - 90;
-            if( topAngle < 0.0 )
-                topAngle += 360;
-            points.setDegrees(KDChartEnums::PositionEast,      topAngle);
-            points.setDegrees(KDChartEnums::PositionNorthEast, topAngle);
-            points.setDegrees(KDChartEnums::PositionWest,      topAngle + angleLen);
-            points.setDegrees(KDChartEnums::PositionNorthWest, topAngle + angleLen);
-            points.setDegrees(KDChartEnums::PositionCenter,    topAngle + angleLen/2.0);
-            points.setDegrees(KDChartEnums::PositionNorth,     topAngle + angleLen/2.0);
-            d->appendDataValueTextInfoToList(
-                    this, *list, index, 0,
-                    points, Position::Center, Position::Center,
-                    angleLen*sum / 360 );
+            QLineF centerLine(  drawPosition.center(),
+                            QPointF( (poly[ last - 2].x() + poly.first().x())/2,
+                                     ( poly.first().y() + poly[last-2].y() )/2 ) );
+            QPointF valuePos( ( centerLine.x1() + centerLine.x2() )/2,
+                                  ( centerLine.y1() + centerLine.y2() )/2 ) ;
 
-            // The following, old code (since kdc 2.0.0) was not correct:
-            // Settings made for the position had been totally ignored,
-            // AND the center was NOT the center - except for pieces of 45 degrees size
-            //
-            // QLineF centerLine(  drawPosition.center(),
-            //                 QPointF( (poly[ last - 2].x() + poly.first().x())/2,
-            //                          ( poly.first().y() + poly[last-2].y() )/2 ) );
-            // QPointF valuePos( ( centerLine.x1() + centerLine.x2() )/2,
-            //                       ( centerLine.y1() + centerLine.y2() )/2 ) ;
-            //
-            // paintDataValueText( painter, index, valuePos, angleLen*sum / 360  );
+            paintDataValueText( painter, index, valuePos, angleLen*sum / 360  );
+
+//if( bHelp ){
+                            //painter->drawPolyline( collect );
+//bHelp=false;
+//}
+
+
+/*
+            if ( regions ) {
+                QPointArray hitregion;
+                hitregion.makeArc( drawPosition.x(), drawPosition.y(),
+                        drawPosition.width(),
+                        drawPosition.height(),
+                        ( int ) startAngle, ( int ) angleLen );
+                hitregion.resize( hitregion.size() + 1 );
+                hitregion.setPoint( hitregion.size() - 1,
+                        drawPosition.center() );
+                datReg = new KDChartDataRegion( region->unite( QRegion( hitregion ) ),
+                                                dataset,
+                                                pie,
+                                                chart );
+
+                datReg->points[ KDChartEnums::PosTopLeft ]
+                    = pointOnCircle( drawPosition, startAngle + angleLen );
+                datReg->points[ KDChartEnums::PosTopCenter ]
+                    = pointOnCircle( drawPosition, startAngle + angleLen / 2 );
+                datReg->points[ KDChartEnums::PosTopRight ]
+                    = pointOnCircle( drawPosition, startAngle );
+
+                datReg->points[   KDChartEnums::PosBottomLeft   ] = drawPosition.center();
+                datReg->points[   KDChartEnums::PosBottomCenter ]
+                    = datReg->points[ KDChartEnums::PosBottomLeft   ];
+                datReg->points[   KDChartEnums::PosBottomRight  ]
+                    = datReg->points[ KDChartEnums::PosBottomLeft   ];
+
+                datReg->points[ KDChartEnums::PosCenterLeft ]
+                    = QPoint( (   datReg->points[ KDChartEnums::PosTopLeft      ].x()
+                                + datReg->points[ KDChartEnums::PosBottomLeft   ].x() ) / 2,
+                            (   datReg->points[ KDChartEnums::PosTopLeft      ].y()
+                                + datReg->points[ KDChartEnums::PosBottomLeft   ].y() ) / 2 );
+                datReg->points[ KDChartEnums::PosCenter ]
+                    = QPoint( (   datReg->points[ KDChartEnums::PosTopCenter    ].x()
+                                + datReg->points[ KDChartEnums::PosBottomCenter ].x() ) / 2,
+                            (   datReg->points[ KDChartEnums::PosTopCenter    ].y()
+                                + datReg->points[ KDChartEnums::PosBottomCenter ].y() ) / 2 );
+                datReg->points[ KDChartEnums::PosCenterRight ]
+                    = QPoint( (   datReg->points[ KDChartEnums::PosTopRight     ].x()
+                                + datReg->points[ KDChartEnums::PosBottomRight  ].x() ) / 2,
+                            (   datReg->points[ KDChartEnums::PosTopRight     ].y()
+                                + datReg->points[ KDChartEnums::PosBottomRight  ].y() ) / 2 );
+
+                datReg->startAngle = startAngle;
+                datReg->angleLen   = angleLen;
+                regions->append( datReg );
+            }
+*/
         }
+//        if( mustDeleteRegion )
+//            delete region;
     }
 }
 
@@ -578,8 +612,6 @@ void PieDiagram::draw3DEffect( QPainter* painter,
         const ThreeDPieAttributes& threeDAttrs,
         bool /*explode*/ )
 {
-    Q_UNUSED( dataset );
-
     if( ! threeDAttrs.isEnabled() )
         return;
 
@@ -815,7 +847,6 @@ void PieDiagram::drawStraightEffectSegment( QPainter* painter,
     poly[1] = circlePoint;
     poly[2] = QPointF( circlePoint.x(), circlePoint.y() + threeDHeight );
     poly[3] = QPointF( center.x(), center.y() + threeDHeight );
-    // TODO: add polygon to ReverseMapper
     painter->drawPolygon( poly );
 //    if ( region )
 //        *region += QRegion( points );
@@ -861,7 +892,7 @@ void PieDiagram::drawArcEffectSegment( QPainter* painter,
     if( endA > 540 )
         drawArcEffectSegment( painter, rect, threeDHeight, 180, endA - 360, granularity );
     if( endA > 360 )
-        endA = qMin( endA, qreal( 360.0 ) );
+        endA = qMin( endA, 360.0 );
 
     int numHalfPoints = static_cast<int>( trunc( ( endA - startA ) / granularity ) ) + 1;
 
@@ -893,7 +924,6 @@ void PieDiagram::drawArcEffectSegment( QPainter* painter,
         poly[ numHalfPoints * 2 - i - 1 ] = pointOnFirstArc;
     }
 
-    // TODO: Add polygon to ReverseMapper
     painter->drawPolygon( poly );
 //    if ( region )
 //        *region += QRegion( collect );
