@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
    Copyright (C) 2003 Lucijan Busch <lucijan@kde.org>
-   Copyright (C) 2003-2005 Jaroslaw Staniek <js@iidea.pl>
+   Copyright (C) 2003-2007 Jaroslaw Staniek <js@iidea.pl>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -25,14 +25,13 @@
 #include <qmap.h>
 
 #include <kexiutils/tristate.h>
+#include <kexiutils/InternalPropertyMap.h>
 #include "kexi.h"
-#include "keximainwindow.h"
 
 class KActionCollection;
-class KexiDialogBase;
-class KexiDialogTempData;
-class KexiViewBase;
-class KexiMainWindowImpl;
+class KexiWindow;
+class KexiWindowData;
+class KexiView;
 class KAction;
 class KShortcut;
 class KTabWidget;
@@ -42,8 +41,7 @@ namespace KexiPart
 	class Info;
 	class Item;
 	class GUIClient;
-	class PartPrivate;
-	class StaticInfo;
+		class StaticInfo;
 
 /*! Official (registered) type IDs for objects like table, query, form... */
 enum ObjectTypes {
@@ -59,17 +57,34 @@ enum ObjectTypes {
 	UserObjectType = 100 //!< external types
 };
 
-/**
- * The main class for kexi frontend parts like tables, queries, forms and reports
+//! @short The main class for kexi frontend parts (plugins) like tables, queries, forms and reports
+/*! 
+  Plugins create windows (KexiWindow) for a given type of object.
+
+  Notes for plugins implementors:  This class supports InternalPropertyMap interface,
+  so supported internal properties affecting its behaviour are:
+  - newObjectsAreDirty: True if newly created, unsaved objects are dirty. False by default.
+  - instanceName: base i18n'd name of objects created by a plugin, e.g. "table", 
+    see instanceName().
+  - instanceCaption: i18n'd instance name usable for displaying in gui as object's caption,
+    e.g. "Table", see instanceCaption()
+  - instanceToolTip: i18n'd tool tip for "Create" action for a given part, e.g. "Create new table"
+  - instanceWhatsThis: i18n'd "What's This" text for "Create" action for a given part, 
+    e.g. "Creates new table."
+  - textViewModeCaption: custum action text replacing standard "Text View" text. 
+    Used in for query's "SQL View".
+  In general: a whole set of i18n'd action names, initialised on KexiPart::Part subclass ctor.
+  The names are useful because the same action can have other name for each part
+  E.g. "New table" vs "New query" can have different forms for some languages.
+  So this is a flexible way for customizing translatable strings.
  */
-class KEXICORE_EXPORT Part : public QObject
+class KEXICORE_EXPORT Part : public QObject, protected KexiUtils::InternalPropertyMap
 {
 	Q_OBJECT
 
 	public:
-		/*! Constructor. */
-		Part(QObject *parent, const char *name, const QStringList &);
-		/*! Destructor. */
+		Part(int partID, QObject *parent, const QStringList &);
+		
 		virtual ~Part();
 
 //! @todo make it protected, outside world should use KexiProject
@@ -80,11 +95,11 @@ class KEXICORE_EXPORT Part : public QObject
 		NULL if there is no sender. The KFormDesigner uses this to pass
 		the actual widget (e.g. the button that was pressed).
 		\return true if execution was successfully else false.
-		*/
+                */
 		virtual bool execute(KexiPart::Item* item, QObject* sender = 0) {
-			Q_UNUSED(item);
-			Q_UNUSED(sender);
-			return false;
+		    Q_UNUSED(item);
+		    Q_UNUSED(sender);
+		    return false;
 		}
 
 		/*! \return supported modes for dialogs created by this part, i.e. a combination
@@ -93,23 +108,24 @@ class KEXICORE_EXPORT Part : public QObject
 		 that equals Kexi::DataViewMode | Kexi::DesignViewMode, 
 		 or Kexi::DesignViewMode in case of Kexi::PartStaticPart object.
 		 This information is used to set supported view modes for every 
-		 KexiDialogBase-derived object created by this KexiPart. */
-		inline int supportedViewModes() const { return m_supportedViewModes; }
-
+		 KexiView-derived object created by this KexiPart. */
+		Kexi::ViewModes supportedViewModes() const;
+		
 		/*! \return supported modes for dialogs created by this part in "user mode", i.e. a combination
 		 of Kexi::ViewMode enum elements.
 		 Set this member in your KexiPart subclass' ctor, if you need to override the default value
 		 that equals Kexi::DataViewMode. or 0 in case of Kexi::PartStaticPart object.
 		 This information is used to set supported view modes for every 
-		 KexiDialogBase-derived object created by this KexiPart. */
-		inline int supportedUserViewModes() const { return m_supportedUserViewModes; }
+		 KexiView-derived object created by this KexiPart. */
+		Kexi::ViewModes supportedUserViewModes() const;
 
 //! @todo make it protected, outside world should use KexiProject
 		/*! "Opens" an instance that the part provides, pointed by \a item in a mode \a viewMode. 
 		 \a viewMode is one of Kexi::ViewMode enum. 
-		 \a staticObjectArgs can be passed for static Kexi Parts. */
-		KexiDialogBase* openInstance(KexiMainWindow *win, KexiPart::Item &item, 
-			int viewMode = Kexi::DataViewMode, QMap<QString,QString>* staticObjectArgs = 0);
+		 \a staticObjectArgs can be passed for static Kexi Parts.
+		 The new widget will be a child of \a parent. */
+		KexiWindow* openInstance(QWidget* parent, KexiPart::Item &item, 
+			Kexi::ViewMode viewMode = Kexi::DataViewMode, QMap<QString,QString>* staticObjectArgs = 0);
 
 //! @todo make it protected, outside world should use KexiProject
 		/*! Removes any stored data pointed by \a item (example: table is dropped for table part). 
@@ -126,7 +142,7 @@ class KEXICORE_EXPORT Part : public QObject
 		 
 		 Default implementation just removes object from kexi__* system structures 
 		 at the database backend using KexiDB::Connection::removeObject(). */
-		virtual bool remove(KexiMainWindow *win, KexiPart::Item & item);
+		virtual bool remove(KexiPart::Item & item);
 
 		/*! Renames stored data pointed by \a item to \a newName 
 		 (example: table name is altered in the database). 
@@ -139,40 +155,39 @@ class KEXICORE_EXPORT Part : public QObject
 		 You shouldn't use by hand transactions here.
 
 		 Default implementation does nothing and returns true. */
-		virtual tristate rename(KexiMainWindow *win, KexiPart::Item &item, const QString& newName);
+		virtual tristate rename(KexiPart::Item &item, const QString& newName);
 
-		/*! Creates and returns a new temporary data for a dialog \a dialog. 
+		/*! Creates and returns a new temporary data for a window  \a window. 
 		 This method is called on openInstance() once per dialog.
-		 Reimplement this to return KexiDialogTempData subclass instance.
-		 Default implemention just returns empty KexiDialogTempData object. */
-		virtual KexiDialogTempData* createTempData(KexiDialogBase* dialog);
+		 Reimplement this to return KexiWindowData subclass instance.
+		 Default implemention just returns empty KexiWindowData object. */
+		virtual KexiWindowData* createWindowData(KexiWindow *window);
 
 		/*! Creates a new view for mode \a viewMode, \a item and \a parent. The view will be 
 		 used inside \a dialog. */
-		virtual KexiViewBase* createView(QWidget *parent, KexiDialogBase* dialog, 
-			KexiPart::Item &item, int viewMode = Kexi::DataViewMode, QMap<QString,QString>* staticObjectArgs = 0) = 0;
+		virtual KexiView* createView(QWidget *parent, KexiWindow *window, 
+			KexiPart::Item &item, Kexi::ViewMode viewMode = Kexi::DataViewMode, QMap<QString,QString>* staticObjectArgs = 0) = 0;
 
 		/*! i18n'd instance name usable for displaying in gui as object's name.
 		 The name is valid identifier - contains latin1 lowercase characters only.
 		 @todo move this to Info class when the name could be moved as localized property 
 		 to service's .desktop file. */
-		QCString instanceName() const;
+		QString instanceName() const;
 
 		/*! i18n'd instance name usable for displaying in gui as object's caption.
 		 @todo move this to Info class when the name could be moved as localized property 
 		 to service's .desktop file. */
 		QString instanceCaption() const;
 
-		inline Info *info() const { return m_info; }
+		Info *info() const;
 
 		/*! \return part's GUI Client, so you can 
 		 create part-wide actions using this client. */
-		inline GUIClient *guiClient() const { return m_guiClient; }
+		GUIClient *guiClient() const;
 
 		/*! \return part's GUI Client, so you can 
 		 create instance-wide actions using this client. */
-		inline GUIClient *instanceGuiClient(int mode = 0) const
-			{ return m_instanceGuiClients[mode]; }
+		GUIClient *instanceGuiClient(Kexi::ViewMode mode = Kexi::AllViewModes) const;
 
 #if 0
 		/**
@@ -183,9 +198,9 @@ class KEXICORE_EXPORT Part : public QObject
 #endif
 
 		/*! \return action collection for mode \a viewMode. */
-		KActionCollection* actionCollectionForMode(int viewMode) const;
+		KActionCollection* actionCollectionForMode(Kexi::ViewMode viewMode) const;
 
-		const Kexi::ObjectStatus& lastOperationStatus() const { return m_status; }
+		const Kexi::ObjectStatus& lastOperationStatus() const;
 
 		/*! \return i18n'd message translated from \a englishMessage.
 		 This method is useful for messages like: 
@@ -199,10 +214,36 @@ class KEXICORE_EXPORT Part : public QObject
 		 In special cases, \a englishMessage can start with ":", 
 		 to indicate that empty string will be generated if 
 		 a part does not offer a message for such \a englishMessage.
-		 This is used e.g. in KexiMainWindowImpl::closeDialog().
-		 */
-		virtual QString i18nMessage(const QCString& englishMessage, 
-			KexiDialogBase* dlg) const;
+		 This is used e.g. in KexiMainWindow::closeWindow().
+		 
+		 Note: As number of %n parameters is unspecified,
+		 you should add appropriate number of parameters using .subs(). 
+		 to result of results of i18nMessage().
+		 In your your implementation, you should use ki18n(I18N_NOOP())
+		 or ki18nc(I18N_NOOP2()) instead of i18n() or i18nc().
+		 Example:
+		 @code
+		  QString tableName = "Employees";
+		 	QString translated 
+		 	 = part->i18nMessage("Design of object \"%1\" has been modified.")
+		 	  .subs(tableName).toString();
+		 @endcode */
+		virtual KLocalizedString i18nMessage(const QString& englishMessage, 
+			KexiWindow *window) const;
+
+		/*! @internal 
+		 Creates GUIClients for this part, attached to the main window.
+		 This method is called by KexiMainWindow. */
+		void createGUIClients();
+
+		/*! @internal
+		 This method can be reimplemented to setup additional tabs 
+		 in the property editor panel. Default implementation does nothing. 
+		 This method is called whenever current window (KexiWindow) is switched and
+		 type (mime type) of its contents differs from previous one. 
+		 For example, if a user switched from Table Designer to Form Designer,
+		 additional tab containing Form Designer's object tree should be shown. */
+		virtual void setupCustomPropertyPanelTabs(KTabWidget *tab);
 
 	signals: 
 		void newObjectRequest( KexiPart::Info *info );
@@ -214,12 +255,6 @@ class KEXICORE_EXPORT Part : public QObject
 		//! Used by StaticPart
 		Part(QObject* parent, StaticInfo *info);
 
-//		virtual KexiDialogBase* createInstance(KexiMainWindow *win, const KexiPart::Item &item, int viewMode = Kexi::DataViewMode) = 0;
-
-		//! Creates GUICLients for this part, attached to \a win
-		//! This method is called from KexiMainWindow
-		void createGUIClients(KexiMainWindow *win);
-
 #if 0
 		/*! For reimplementation. Create here all part actions (KAction or similar). 
 		 "Part action" is an action that is bound to given part, not for dialogs 
@@ -246,22 +281,22 @@ class KEXICORE_EXPORT Part : public QObject
 		virtual void initPartActions();
 		virtual void initInstanceActions();
 
-		virtual KexiDB::SchemaData* loadSchemaData(KexiDialogBase *dlg, 
-			const KexiDB::SchemaData& sdata, int viewMode);
+		virtual KexiDB::SchemaData* loadSchemaData(KexiWindow *window, 
+			const KexiDB::SchemaData& sdata, Kexi::ViewMode viewMode);
 
-		bool loadDataBlock( KexiDialogBase *dlg, QString &dataString, const QString& dataID = QString::null);
+		bool loadDataBlock( KexiWindow *window, QString &dataString, const QString& dataID = QString());
 
 		/*! Creates shared action for action collection declared 
 		 for 'instance actions' of this part.
 		 See KexiSharedActionHost::createSharedAction() for details.
 		 Pass desired KAction subclass with \a subclassName (e.g. "KToggleAction") to have
 		 that subclass allocated instead just KAction (what is the default). */
-		KAction* createSharedAction(int mode, const QString &text, 
+		KAction* createSharedAction(Kexi::ViewMode mode, const QString &text, 
 			const QString &pix_name, const KShortcut &cut, const char *name, 
 			const char *subclassName = 0);
 
 		/*! Convenience version of above method - creates shared toggle action. */
-		KAction* createSharedToggleAction(int mode, const QString &text,
+		KAction* createSharedToggleAction(Kexi::ViewMode mode, const QString &text,
 			const QString &pix_name, const KShortcut &cut, const char *name);
 
 		/*! Creates shared action for action collection declared 
@@ -280,51 +315,24 @@ class KEXICORE_EXPORT Part : public QObject
 
 		void setActionAvailable(const char *action_name, bool avail);
 
-		inline void setInfo(Info *info) { m_info = info; }
-
-		/*! This method can be reimplemented to setup additional tabs 
-		 in the property editor panel. Default implementation does nothing. 
-		 This method is called whenever current dialog (KexiDialogBase) is switched and
-		 type (mime type) of its contents differs from previous one. 
-		 For example, if a user switched from Table Designer to Form Designer,
-		 additional tab containing Form Designer's object tree should be shown. */
-		virtual void setupCustomPropertyPanelTabs(KTabWidget *tab, KexiMainWindow* mainWin);
-
-		//! Set of i18n'd action names for, initialised on KexiPart::Part subclass ctor
-		//! The names are useful because the same action can have other name for each part
-		//! E.g. "New table" vs "New query" can have different forms for some languages...
-		QMap<QString,QString> m_names;
-
-		/*! Supported modes for dialogs created by this part.
-		 @see supportedViewModes() */
-		int m_supportedViewModes;
-
-		/*! Supported modes for dialogs created by this part in "user mode".
+		void setInfo(Info *info);
+		
+		int registeredPartID() const;
+		
+		/*! Sets supported modes for windows created by this part in "user mode".
 		 The default is Kexi::DataViewMode. It is altered in classes like KexiSimplePrintingPart.
 		 @see supportedUserViewModes() */
-		int m_supportedUserViewModes;
+		void setSupportedUserViewModes(Kexi::ViewModes modes);
 
-		Info *m_info;
-		GUIClient *m_guiClient;
-		QIntDict<GUIClient> m_instanceGuiClients;
-		KexiMainWindow* m_mainWin;
-		Kexi::ObjectStatus m_status;
+		/*! Sets supported view modes for this part. */
+		void setSupportedViewModes(Kexi::ViewModes modes);
 
-		/*! If you're implementing a new part, set this to value >0 in your ctor 
-		 if you have well known (ie registered ID) for your part.
-		 So far, table, query, form, report and script part have defined their IDs 
-		 (see KexiPart::ObjectTypes). */
-		int m_registeredPartID;
-
-		/*! True if newwly created, unsaved objects are dirty. False by default.
-		 You can change it in your subclass' constructor.	*/
-		bool m_newObjectsAreDirty : 1;
-
-		PartPrivate *d;
+	private:
+		class Private;
+		Private * const d;
 
 	friend class Manager;
-	friend class ::KexiMainWindow;
-	friend class ::KexiMainWindowImpl;
+	friend class ::KexiWindow;
 	friend class GUIClient;
 };
 
