@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
    Copyright (C) 2003 Lucijan Busch <lucijan@kde.org>
-   Copyright (C) 2003-2006 Jaroslaw Staniek <js@iidea.pl>
+   Copyright (C) 2003-2007 Jaroslaw Staniek <js@iidea.pl>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -39,13 +39,14 @@
 #include <kexiutils/utils.h>
 
 #include "kexiproject.h"
+#include "kexiprojectdata.h"
 #include "kexipartmanager.h"
 #include "kexipartitem.h"
 #include "kexipartinfo.h"
 #include "kexipart.h"
-#include "kexidialogbase.h"
+#include "KexiWindow.h"
+#include "KexiWindowData.h"
 #include "kexi.h"
-#include "keximainwindow.h"
 #include "kexiblobbuffer.h"
 #include "kexiguimsghandler.h"
 
@@ -56,37 +57,38 @@ class KexiProject::Private
 	public:
 		Private()
 		 : data(0)
-		 , itemDictsCache(199)
-		 , unstoredItems(199)
 		 , tempPartItemID_Counter(-1)
 		 , sqlParser(0)
 		 , versionMajor(0)
 		 , versionMinor(0)
+		 , privateIDCounter(0)
 		{
-			itemDictsCache.setAutoDelete(true);
-			unstoredItems.setAutoDelete(true);
 		}
 		~Private() {
 			delete data;
 			data=0;
 			delete sqlParser;
+			foreach (KexiPart::ItemDict* dict, itemDictsCache) {
+				qDeleteAll(*dict);
+				dict->clear();
+			}
+			qDeleteAll(unstoredItems);
+			unstoredItems.clear();
 		}
 
-		QGuardedPtr<KexiDB::Connection> connection;
-		QGuardedPtr<KexiProjectData> data;
-		
+		QPointer<KexiDB::Connection> connection;
+		QPointer<KexiProjectData> data;
 		QString error_title;
 
 		//! a cache for item() method, indexed by project part's ids
-		QIntDict<KexiPart::ItemDict> itemDictsCache;
-
-		QPtrDict<KexiPart::Item> unstoredItems;
+		QHash<int, KexiPart::ItemDict*> itemDictsCache;
+		QSet<KexiPart::Item*> unstoredItems;
 		int tempPartItemID_Counter; //!< helper for getting unique 
 		                              //!< temporary identifiers for unstored items
 		KexiDB::Parser* sqlParser;
-
 		int versionMajor;
 		int versionMinor;
+		int privateIDCounter; //!< counter: ID for private "document" like Relations window
 };
 
 //---------------------------
@@ -96,7 +98,7 @@ class KexiProject::Private
 class KexiProject::ErrorTitle
 {
 	public:
-	ErrorTitle(KexiProject* p, const QString& msg = QString::null)
+	ErrorTitle(KexiProject* p, const QString& msg = QString())
 		: prj(p)
 		, prev_err_title(p->m_error_title)
 	{ 
@@ -115,8 +117,6 @@ KexiProject::KexiProject(KexiProjectData *pdata, KexiDB::MessageHandler* handler
  , d(new Private())
 {
 	d->data = pdata;
-//! @todo partmanager is outside project, so can be initialised just once:
-	Kexi::partManager().lookup();
 }
 
 KexiProject::KexiProject(KexiProjectData *pdata, KexiDB::MessageHandler* handler, 
@@ -128,11 +128,9 @@ KexiProject::KexiProject(KexiProjectData *pdata, KexiDB::MessageHandler* handler
 	if (d->data->connectionData() == d->connection->data())
 		d->connection = conn;
 	else
-		kdWarning() << "KexiProject::KexiProject(): passed connection's data ("
+		kWarning() << "KexiProject::KexiProject(): passed connection's data ("
 			<< conn->data()->serverInfoString() << ") is not compatible with project's conn. data ("
 			<< d->data->connectionData()->serverInfoString() << ")" << endl;
-//! @todo partmanager is outside project, so can be initialised just once:
-	Kexi::partManager().lookup();
 }
 
 KexiProject::~KexiProject()
@@ -176,14 +174,18 @@ KexiProject::open()
 tristate
 KexiProject::openInternal(bool *incompatibleWithKexi)
 {
+	if (!Kexi::partManager().lookup()) {
+		setError( &Kexi::partManager() );
+		return cancelled;
+	}
 	if (incompatibleWithKexi)
 		*incompatibleWithKexi = false;
-	kdDebug() << "KexiProject::open(): " << d->data->databaseName() <<" "<< d->data->connectionData()->driverName  << endl;
+	kDebug() << "KexiProject::open(): " << d->data->databaseName() <<" "<< d->data->connectionData()->driverName  << endl;
 	KexiDB::MessageTitle et(this, 
-		i18n("Could not open project \"%1\".").arg(d->data->databaseName()));
+		i18n("Could not open project \"%1\".", d->data->databaseName()));
 	
 	if (!createConnection()) {
-		kdDebug() << "KexiProject::open(): !createConnection()" << endl;
+		kDebug() << "KexiProject::open(): !createConnection()" << endl;
 		return false;
 	}
 	bool cancel = false;
@@ -193,13 +195,13 @@ KexiProject::openInternal(bool *incompatibleWithKexi)
 		if (cancel) {
 			return cancelled;
 		}
-		kdDebug() << "KexiProject::open(): !d->connection->useDatabase() " 
+		kDebug() << "KexiProject::open(): !d->connection->useDatabase() " 
 			<< d->data->databaseName() <<" "<< d->data->connectionData()->driverName  << endl;
 
 		if (d->connection->errorNum() == ERR_NO_DB_PROPERTY) {
 //<temp> 
 //! @todo this is temporary workaround as we have no import driver for SQLite
-			if (/*supported?*/ !d->data->connectionData()->driverName.lower().startsWith("sqlite")) {
+			if (/*supported?*/ !d->data->connectionData()->driverName.toLower().startsWith("sqlite")) {
 //</temp> 
 				if (incompatibleWithKexi)
 					*incompatibleWithKexi = true;
@@ -225,8 +227,8 @@ tristate
 KexiProject::create(bool forceOverwrite)
 {
 	KexiDB::MessageTitle et(this, 
-		i18n("Could not create project \"%1\".").arg(d->data->databaseName()));
-		
+		i18n("Could not create project \"%1\".", d->data->databaseName()));
+
 	if (!createConnection())
 		return false;
 	if (!checkWritable())
@@ -239,23 +241,22 @@ KexiProject::create(bool forceOverwrite)
 			closeConnection();
 			return false;
 		}
-		kdDebug() << "--- DB '" << d->data->databaseName() << "' dropped ---"<< endl;
+		kDebug() << "--- DB '" << d->data->databaseName() << "' dropped ---"<< endl;
 	}
 	if (!d->connection->createDatabase( d->data->databaseName() )) {
 		setError(d->connection);
 		closeConnection();
 		return false;
 	}
-	kdDebug() << "--- DB '" << d->data->databaseName() << "' created ---"<< endl;
+	kDebug() << "--- DB '" << d->data->databaseName() << "' created ---"<< endl;
 	// and now: open
-	if (!d->connection->useDatabase(d->data->databaseName()))
-	{
-		kdDebug() << "--- DB '" << d->data->databaseName() << "' USE ERROR ---"<< endl;
+	if (!d->connection->useDatabase(d->data->databaseName())) {
+		kDebug() << "--- DB '" << d->data->databaseName() << "' USE ERROR ---"<< endl;
 		setError(d->connection);
 		closeConnection();
 		return false;
 	}
-	kdDebug() << "--- DB '" << d->data->databaseName() << "' used ---"<< endl;
+	kDebug() << "--- DB '" << d->data->databaseName() << "' used ---"<< endl;
 
 	//<add some data>
 	KexiDB::Transaction trans = d->connection->beginTransaction();
@@ -293,6 +294,10 @@ KexiProject::create(bool forceOverwrite)
 		return false;
 	//</add some data>
 
+	if (!Kexi::partManager().lookup()) {
+		setError( &Kexi::partManager() );
+		return cancelled;
+	}
 	return initProject();
 }
 
@@ -408,7 +413,7 @@ bool KexiProject::createInternalStructures(bool insideTransaction)
 	}
 
 	//Store default part infos.
-	//Infos for other parts (forms, reports...) are created on demand in KexiDialogBase::storeNewData()
+	//Infos for other parts (forms, reports...) are created on demand in KexiWindow::storeNewData()
 	KexiDB::InternalTableSchema *t_parts = new KexiDB::InternalTableSchema("kexi__parts"); //newKexiDBSystemTableSchema("kexi__parts");
 	t_parts->addField( 
 		new KexiDB::Field("p_id", KexiDB::Field::Integer, KexiDB::Field::PrimaryKey | KexiDB::Field::AutoInc, KexiDB::Field::Unsigned) 
@@ -472,7 +477,7 @@ KexiProject::createConnection()
 	d->connection = driver->createConnection(*d->data->connectionData(), connectionOptions);
 	if (!d->connection)
 	{
-		kdDebug() << "KexiProject::open(): uuups failed " << driver->errorMsg()  << endl;
+		kDebug() << "KexiProject::open(): uuups failed " << driver->errorMsg()  << endl;
 		setError(driver);
 		return false;
 	}
@@ -480,7 +485,7 @@ KexiProject::createConnection()
 	if (!d->connection->connect())
 	{
 		setError(d->connection);
-		kdDebug() << "KexiProject::createConnection(): error connecting: " << (d->connection ? d->connection->errorMsg() : QString::null) << endl;
+		kDebug() << "KexiProject::createConnection(): error connecting: " << (d->connection ? d->connection->errorMsg() : QString()) << endl;
 		closeConnection();
 		return false;
 	}
@@ -512,7 +517,7 @@ bool
 KexiProject::initProject()
 {
 //	emit dbAvailable();
-	kdDebug() << "KexiProject::open(): checking project parts..." << endl;
+	kDebug() << "KexiProject::open(): checking project parts..." << endl;
 	
 	if (!Kexi::partManager().checkProject(d->connection)) {
 		setError(Kexi::partManager().error() ? (KexiDB::Object*)&Kexi::partManager() : (KexiDB::Connection*)d->connection);
@@ -549,27 +554,25 @@ KexiProject::isConnected()
 KexiPart::ItemDict*
 KexiProject::items(KexiPart::Info *i)
 {
-	kdDebug() << "KexiProject::items()" << endl;
+	kDebug() << "KexiProject::items()" << endl;
 	if(!i || !isConnected())
 		return 0;
 
 	//trying in cache...
-	KexiPart::ItemDict *dict = d->itemDictsCache[ i->projectPartID() ];
+	KexiPart::ItemDict *dict = d->itemDictsCache.value( i->projectPartID() );
 	if (dict)
 		return dict;
 	//retrieve:
 	KexiDB::Cursor *cursor = d->connection->executeQuery(
 		"SELECT o_id, o_name, o_caption  FROM kexi__objects WHERE o_type = " 
 		+ QString::number(i->projectPartID()));//, KexiDB::Cursor::Buffered);
-//	kdDebug() << "KexiProject::items(): cursor handle is:" << cursor << endl;
+//	kDebug() << "KexiProject::items(): cursor handle is:" << cursor << endl;
 	if(!cursor)
 		return 0;
 
-	dict = new KexiPart::ItemDict(1009);
-	dict->setAutoDelete(true);
+	dict = new KexiPart::ItemDict();
 
-	for(cursor->moveFirst(); !cursor->eof(); cursor->moveNext())
-	{
+	for(cursor->moveFirst(); !cursor->eof(); cursor->moveNext()) {
 		KexiPart::Item *it = new KexiPart::Item();
 		bool ok;
 		int ident = cursor->value(0).toInt(&ok);
@@ -584,17 +587,17 @@ KexiProject::items(KexiPart::Info *i)
 			it->setCaption(cursor->value(2).toString());
 		}
 		dict->insert(it->identifier(), it);
-//		kdDebug() << "KexiProject::items(): ITEM ADDED == "<<objName <<" id="<<ident<<endl;
+//		kDebug() << "KexiProject::items(): ITEM ADDED == "<<objName <<" id="<<ident<<endl;
 	}
 
 	d->connection->deleteCursor(cursor);
-//	kdDebug() << "KexiProject::items(): end with count " << dict->count() << endl;
+//	kDebug() << "KexiProject::items(): end with count " << dict->count() << endl;
 	d->itemDictsCache.insert( i->projectPartID(), dict );
 	return dict;
 }
 
 KexiPart::ItemDict*
-KexiProject::itemsForMimeType(const QCString &mimeType)
+KexiProject::itemsForMimeType(const QString &mimeType)
 {
 	KexiPart::Info *info = Kexi::partManager().infoForMimeType(mimeType);
 	return items(info);
@@ -607,12 +610,12 @@ KexiProject::getSortedItems(KexiPart::ItemList& list, KexiPart::Info *i)
 	KexiPart::ItemDict* dict = items(i);
 	if (!dict)
 		return;
-	for (KexiPart::ItemDictIterator it(*dict); it.current(); ++it)
-		list.append(it.current());
+	for (KexiPart::ItemDict::const_iterator it(dict->constBegin()); it!=dict->constEnd(); ++it)
+		list.append(it.value());
 }
 
 void
-KexiProject::getSortedItemsForMimeType(KexiPart::ItemList& list, const QCString &mimeType)
+KexiProject::getSortedItemsForMimeType(KexiPart::ItemList& list, const QString &mimeType)
 {
 	KexiPart::Info *info = Kexi::partManager().infoForMimeType(mimeType);
 	getSortedItems(list, info);
@@ -625,23 +628,26 @@ KexiProject::addStoredItem(KexiPart::Info *info, KexiPart::Item *item)
 		return;
 	KexiPart::ItemDict *dict = items(info);
 	item->setNeverSaved( false );
-	d->unstoredItems.take(item); //no longer unstored
+	d->unstoredItems.remove(item); //no longer unstored
 	dict->insert( item->identifier(), item );
 	//let's update e.g. navigator
 	emit newItemStored(*item);
 }
 
 KexiPart::Item*
-KexiProject::itemForMimeType(const QCString &mimeType, const QString &name)
+KexiProject::itemForMimeType(const QString &mimeType, const QString &name)
 {
 	KexiPart::ItemDict *dict = itemsForMimeType(mimeType);
-	if (!dict)
+	if (!dict) {
+		kexiwarn << "KexiProject::itemForMimeType() no mimetype="<<mimeType<<endl;
 		return 0;
-	const QString l_name = name.lower();
-	for (KexiPart::ItemDictIterator it( *dict ); it.current(); ++it) {
-		if (it.current()->name().lower()==l_name)
-			return it.current();
 	}
+	const QString l_name = name.toLower();
+	for (KexiPart::ItemDict::const_iterator it(dict->constBegin()); it!=dict->constEnd(); ++it) {
+		if (it.value()->name().toLower()==l_name)
+			return it.value();
+	}
+	kexiwarn << "KexiProject::itemForMimeType() no name="<<name<<endl;
 	return 0;
 }
 
@@ -651,10 +657,10 @@ KexiProject::item(KexiPart::Info *i, const QString &name)
 	KexiPart::ItemDict *dict = items(i);
 	if (!dict)
 		return 0;
-	const QString l_name = name.lower();
-	for (KexiPart::ItemDictIterator it( *dict ); it.current(); ++it) {
-		if (it.current()->name().lower()==l_name)
-			return it.current();
+	const QString l_name = name.toLower();
+	for (KexiPart::ItemDict::const_iterator it( dict->constBegin() ); it!=dict->constEnd(); ++it) {
+		if (it.value()->name().toLower()==l_name)
+			return it.value();
 	}
 	return 0;
 }
@@ -662,9 +668,8 @@ KexiProject::item(KexiPart::Info *i, const QString &name)
 KexiPart::Item*
 KexiProject::item(int identifier)
 {
-	KexiPart::ItemDict *dict;
-	for (QIntDictIterator<KexiPart::ItemDict> it(d->itemDictsCache); (dict = it.current()); ++it) {
-		KexiPart::Item *item = dict->find(identifier);
+	foreach (KexiPart::ItemDict *dict, d->itemDictsCache) {
+		KexiPart::Item *item = dict->value(identifier);
 		if (item)
 			return item;
 	}
@@ -674,7 +679,7 @@ KexiProject::item(int identifier)
 /*void KexiProject::clearMsg()
 {
 	clearError();
-//	d->error_title=QString::null;
+//	d->error_title.clear();
 }
 
 void KexiProject::setError(int code, const QString &msg )
@@ -717,13 +722,15 @@ KexiPart::Part *KexiProject::findPartFor(KexiPart::Item& item)
 	clearError();
 	KexiDB::MessageTitle et(this);
 	KexiPart::Part *part = Kexi::partManager().partForMimeType(item.mimeType());
-	if (!part)
+	if (!part) {
+		kexiwarn<<"KexiProject::findPartFor() !part: " << item.mimeType() <<endl;
 		setError(&Kexi::partManager());
+	}
 	return part;
 }
 
-KexiDialogBase* KexiProject::openObject(KexiMainWindow *wnd, KexiPart::Item& item, 
-	int viewMode, QMap<QString,QString>* staticObjectArgs)
+KexiWindow* KexiProject::openObject(QWidget* parent, KexiPart::Item& item, 
+	Kexi::ViewMode viewMode, QMap<QString,QString>* staticObjectArgs)
 {
 	clearError();
 	if (viewMode!=Kexi::DataViewMode && data()->userMode())
@@ -733,22 +740,22 @@ KexiDialogBase* KexiProject::openObject(KexiMainWindow *wnd, KexiPart::Item& ite
 	KexiPart::Part *part = findPartFor(item);
 	if (!part)
 		return 0;
-	KexiDialogBase *dlg  = part->openInstance(wnd, item, viewMode, staticObjectArgs);
-	if (!dlg) {
+	KexiWindow *window  = part->openInstance(parent, item, viewMode, staticObjectArgs);
+	if (!window) {
 		if (part->lastOperationStatus().error())
-			setError(i18n("Opening object \"%1\" failed.").arg(item.name())+"<br>"
+			setError(i18n("Opening object \"%1\" failed.", item.name())+"<br>"
 				+part->lastOperationStatus().message, 
 				part->lastOperationStatus().description);
 		return 0;
 	}
-	return dlg;
+	return window;
 }
 
-KexiDialogBase* KexiProject::openObject(KexiMainWindow *wnd, const QCString &mimeType, 
-	const QString& name, int viewMode)
+KexiWindow* KexiProject::openObject(QWidget* parent, const QString &mimeType, 
+	const QString& name, Kexi::ViewMode viewMode)
 {
 	KexiPart::Item *it = itemForMimeType(mimeType, name);
-	return it ? openObject(wnd, *it, viewMode) : 0;
+	return it ? openObject(parent, *it, viewMode) : 0;
 }
 
 bool KexiProject::checkWritable()
@@ -759,7 +766,7 @@ bool KexiProject::checkWritable()
 	return false;
 }
 
-bool KexiProject::removeObject(KexiMainWindow *wnd, KexiPart::Item& item)
+bool KexiProject::removeObject(KexiPart::Item& item)
 {
 	clearError();
 	if (data()->userMode())
@@ -771,7 +778,7 @@ bool KexiProject::removeObject(KexiMainWindow *wnd, KexiPart::Item& item)
 	KexiPart::Part *part = findPartFor(item);
 	if (!part)
 		return false;
-	if (!item.neverSaved() && !part->remove(wnd, item)) {
+	if (!item.neverSaved() && !part->remove(item)) {
 		//js TODO check for errors
 		return false;
 	}
@@ -794,21 +801,21 @@ bool KexiProject::removeObject(KexiMainWindow *wnd, KexiPart::Item& item)
 
 	//now: remove this item from cache
 	if (part->info()) {
-		KexiPart::ItemDict *dict = d->itemDictsCache[ part->info()->projectPartID() ];
+		KexiPart::ItemDict *dict = d->itemDictsCache.value( part->info()->projectPartID() );
 		if (!(dict && dict->remove( item.identifier() )))
 			d->unstoredItems.remove(&item);//remove temp.
 	}
 	return true;
 }
 
-bool KexiProject::renameObject( KexiMainWindow *wnd, KexiPart::Item& item, const QString& _newName )
+bool KexiProject::renameObject( KexiPart::Item& item, const QString& _newName )
 {
 	clearError();
 	if (data()->userMode())
 		return 0;
 	
 	KexiUtils::WaitCursor wait;
-	QString newName = _newName.stripWhiteSpace();
+	QString newName = _newName.trimmed();
 	{
 		KexiDB::MessageTitle et(this);
 		if (newName.isEmpty()) {
@@ -816,14 +823,14 @@ bool KexiProject::renameObject( KexiMainWindow *wnd, KexiPart::Item& item, const
 			return false;
 		}
 		if (this->itemForMimeType(item.mimeType(), newName)!=0) {
-			setError( i18n("Could not use this name. Object with name \"%1\" already exists.")
-				.arg(newName) );
+			setError( i18n("Could not use this name. Object with name \"%1\" already exists.",
+				newName) );
 			return false;
 		}
 	}
 
 	KexiDB::MessageTitle et(this, 
-		i18n("Could not rename object \"%1\".").arg(item.name()) );
+		i18n("Could not rename object \"%1\".", item.name()) );
 	if (!checkWritable())
 		return false;
 	KexiPart::Part *part = findPartFor(item);
@@ -834,7 +841,7 @@ bool KexiProject::renameObject( KexiMainWindow *wnd, KexiPart::Item& item, const
 		setError(d->connection);
 		return false;
 	}
-	if (!part->rename(wnd, item, newName)) {
+	if (!part->rename(item, newName)) {
 		setError(part->lastOperationStatus().message, part->lastOperationStatus().description);
 		return false;
 	}
@@ -848,7 +855,7 @@ bool KexiProject::renameObject( KexiMainWindow *wnd, KexiPart::Item& item, const
 		setError(d->connection);
 		return false;
 	}
-	QCString oldName( item.name().latin1() );
+	QString oldName( item.name() );
 	item.setName( newName );
 	emit itemRenamed(item, oldName);
 	return true;
@@ -868,6 +875,18 @@ KexiPart::Item* KexiProject::createPartItem(KexiPart::Info *info, const QString&
 	}
 
 	KexiPart::ItemDict *dict = items(info);
+	QSet<QString> storedItemNames;
+	for (KexiPart::ItemDict::const_iterator storedIt( dict->constBegin() ); 
+		storedIt!=dict->constEnd(); ++storedIt)
+	{
+		storedItemNames.insert( storedIt.value()->name().toLower() );
+	}
+	QSet<QString> unstoredItemNames;
+	for (QSet<KexiPart::Item*>::ConstIterator itUnstored( d->unstoredItems.constBegin() );
+		itUnstored != d->unstoredItems.constEnd(); ++itUnstored)
+	{
+		unstoredItemNames.insert( (*itUnstored)->name().toLower() );
+	}
 
 	//find new, unique default name for this item
 	int n;
@@ -879,28 +898,18 @@ KexiPart::Item* KexiProject::createPartItem(KexiPart::Info *info, const QString&
 	}
 	else {
 		n = 0; //means: try not to add 'n'
-		base_name = KexiUtils::string2Identifier(suggestedCaption).lower();
+		base_name = KexiUtils::string2Identifier(suggestedCaption).toLower();
 	}
-	base_name = KexiUtils::string2Identifier(base_name).lower();
-	KexiPart::ItemDictIterator it(*dict);
-	QPtrDictIterator<KexiPart::Item> itUnstored(d->unstoredItems);
+	base_name = KexiUtils::string2Identifier(base_name).toLower();
 	do {
 		new_name = base_name;
 		if (n>=1)
 			new_name += QString::number(n);
-		for (it.toFirst(); it.current(); ++it) {
-			if (it.current()->name().lower()==new_name)
-				break;
-		}
-		if ( it.current() ) {
+		if (storedItemNames.contains( new_name )) {
 			n++;
 			continue; //stored exists!
 		}
-		for (itUnstored.toFirst(); itUnstored.current(); ++itUnstored) {
-			if (itUnstored.current()->name().lower()==new_name)
-				break;
-		}
-		if ( !itUnstored.current() )
+		if (!unstoredItemNames.contains( new_name ))
 			break; //unstored doesn't exist
 		n++;
 	} while (n<1000/*sanity*/);
@@ -918,7 +927,7 @@ KexiPart::Item* KexiProject::createPartItem(KexiPart::Info *info, const QString&
 	item->setName(new_name);
 	item->setCaption(new_caption);
 	item->setNeverSaved(true);
-	d->unstoredItems.insert(item, item);
+	d->unstoredItems.insert(item);
 	return item;
 }
 
@@ -944,7 +953,7 @@ KexiDB::Parser* KexiProject::sqlParser()
 	return d->sqlParser;
 }
 
-static const QString warningNoUndo = i18n("Warning: entire project's data will be removed.");
+const char* warningNoUndo = I18N_NOOP("Warning: entire project's data will be removed.");
 
 /*static*/
 KexiProject*
@@ -959,9 +968,9 @@ KexiProject::createBlankProject(bool &cancelled, KexiProjectData* data,
 //! @todo move to KexiMessageHandler
 		if (KMessageBox::Yes != KMessageBox::warningYesNo(0, "<qt>"+i18n(
 			"The project %1 already exists.\n"
-			"Do you want to replace it with a new, blank one?")
-				.arg(prj->data()->infoString())+"\n"+warningNoUndo+"</qt>",
-			QString::null, KGuiItem(i18n("Replace")), KStdGuiItem::cancel() ))
+			"Do you want to replace it with a new, blank one?",
+				prj->data()->infoString())+"\n"+i18n(warningNoUndo)+"</qt>",
+			QString(), KGuiItem(i18n("Replace")), KStandardGuiItem::cancel() ))
 //todo add serverInfoString() for server-based prj
 		{
 			delete prj;
@@ -974,7 +983,7 @@ KexiProject::createBlankProject(bool &cancelled, KexiProjectData* data,
 		delete prj;
 		return 0;
 	}
-	kdDebug() << "KexiProject::createBlankProject(): new project created --- " << endl;
+	kDebug() << "KexiProject::createBlankProject(): new project created --- " << endl;
 //todo?	Kexi::recentProjects().addProjectData( data );
 
 	return prj;
@@ -985,7 +994,8 @@ tristate KexiProject::dropProject(KexiProjectData* data,
 	KexiDB::MessageHandler* handler, bool dontAsk)
 {
 	if (!dontAsk && KMessageBox::Yes != KMessageBox::warningYesNo(0, 
-		i18n("Do you want to drop the project \"%1\"?").arg(data->objectName())+"\n"+warningNoUndo ))
+		i18n("Do you want to drop the project \"%1\"?", 
+			static_cast< KexiDB::SchemaData* >(data)->objectName())+"\n"+i18n(warningNoUndo) ))
 		return cancelled;
 
 	KexiProject prj( new KexiProjectData(*data), handler );
@@ -1001,23 +1011,9 @@ tristate KexiProject::dropProject(KexiProjectData* data,
 	return prj.dbConnection()->dropDatabase();
 }
 
-/*void KexiProject::reloadPartItem( KexiDialogBase* dialog )
+int KexiProject::generatePrivateID()
 {
-	if (!dialog)
-		return;
-
-	KexiPart::Item* item = dialog->partItem();
-
-	if (dialog || !d->connection->setQuerySchemaObsolete( queryName ))
-		return;
-	KexiPart::Info *partInfo = Kexi::partManager().infoForMimeType("kexi/query");
-	if (!partInfo)
-		return; //err?
-		item(partInfo, queryName);
-	if (!item)
-		return; //err?
-	emit itemSetO
-
-}*/
+	return --d->privateIDCounter;
+}
 
 #include "kexiproject.moc"
