@@ -23,21 +23,25 @@
 
 #include <qobject.h>
 #include <qdom.h>
-#include <qptrlist.h>
+#include <q3ptrlist.h>
 #include <qtimer.h>
-#include <qguardedptr.h>
+#include <qpointer.h>
 #include <qstringlist.h>
+#include <Q3CString>
+#include <QActionGroup>
+
+#include "form.h"
+#include <kexi_export.h>
 
 class QWidget;
 class QWorkspace;
-class KPopupMenu;
+class KMenu;
 class KActionCollection;
 class KAction;
 class KToggleAction;
-class KDialogBase;
+class KPageDialog;
 class KTextEdit;
 class KXMLGUIClient;
-class KMainWindow;
 
 namespace KoProperty {
 	class Editor;
@@ -49,13 +53,12 @@ namespace KoProperty {
 namespace KFormDesigner {
 
 class WidgetPropertySet;
-class Form;
 class Container;
 class WidgetLibrary;
 class ObjectTreeView;
 class Connection;
 class FormManager;
-typedef QPtrList<KAction> ActionList;
+typedef Q3PtrList<KAction> ActionList;
 
 //! @internal
 //static FormManager* FormManager_static = 0;
@@ -80,9 +83,9 @@ class KFORMEDITOR_EXPORT FormManager : public QObject
 
 		virtual ~FormManager();
 
-		//! Creates widget library for supportedFactoryGroups 
+		//! Creates widget library for supportedFactoryGroups
 		//! and initializes FormManager singleton. \a m should be always the same for every call.
-		static WidgetLibrary* createWidgetLibrary(FormManager* m, 
+		static WidgetLibrary* createWidgetLibrary(FormManager* m,
 			const QStringList& supportedFactoryGroups);
 
 		//! Access to FormManager singleton
@@ -94,12 +97,14 @@ class KFORMEDITOR_EXPORT FormManager : public QObject
 		enum Options { HideEventsInPopupMenu = 1, SkipFileActions = 2,
 			HideSignalSlotConnections = 4 }; //todo
 
-		/*! Creates all the KAction related to widget insertion, and plug them
-		  into the KActionCollection \a parent.
+		/*! Creates all the KActions related to widget insertion, and plug them
+		  into the \a collection. \a client XML GUI client is used to call
+			lib->addCustomWidgetActions(client).
 		  These actions are automatically connected to \ref insertWidget() slot.
 		  \return a QPtrList of the created actions.
 		 */
-		ActionList createActions(WidgetLibrary *lib, KActionCollection *parent);
+		ActionList createActions(WidgetLibrary *lib, KActionCollection* collection,
+			KXMLGUIClient *client);
 
 		/*! Enables or disables actions \a name.
 		 KFD uses KPart's, action collection here.
@@ -107,7 +112,7 @@ class KFORMEDITOR_EXPORT FormManager : public QObject
 		virtual void enableAction( const char* name, bool enable ) = 0;
 
 		/*! \return action for \a name. @see enableAction() */
-		virtual KAction* action(const char* name) = 0;
+		virtual QAction* action(const char* name) = 0;
 
 		bool isPasteEnabled();
 
@@ -123,7 +128,7 @@ class KFORMEDITOR_EXPORT FormManager : public QObject
 
 		/*! \return The name of the class being inserted, corresponding
 		 to the menu item or the toolbar button clicked. */
-		QCString selectedClass() const { return m_selectedClass; }
+		Q3CString selectedClass() const { return m_selectedClass; }
 
 		/*! Sets the point where the pasted widget should be moved to. */
 		void setInsertPoint(const QPoint &p);
@@ -146,7 +151,7 @@ class KFORMEDITOR_EXPORT FormManager : public QObject
 		void createSlotMenu(QWidget *w);
 
 		//! Emits the signal \ref createFormSlot(). Used by WidgetPropertySet.
-		void  emitCreateSlot(const QString &widget, const QString &value)
+		void emitCreateSlot(const QString &widget, const QString &value)
 			{ emit createFormSlot(m_active, widget, value); }
 
 		/*! \return The Form actually active and focused.
@@ -163,17 +168,20 @@ class KFORMEDITOR_EXPORT FormManager : public QObject
 		bool isTopLevel(QWidget *w);
 
 		//! \return A pointer to the KoProperty::Editor we use.
-		KoProperty::Editor* propertyEditor() const { return m_editor; }
+		//unused KoProperty::Editor* propertyEditor() const { return m_editor; }
 
-		/*! Shows a propertybuffer \a buff in a Property Editor.
+		/*! Shows a property set \a set in a Property Editor.
 		 If \a buff is 0, Property Editor will be cleared.
-		 If \a forceReload is true, the buffer needs to be reloaded even
-		 if it's the same as previous one. */
-		virtual void showPropertySet(WidgetPropertySet *list, bool forceReload = false);
+		 If \a forceReload is true, the set will be reloaded even
+		 if it's the same as previous one.
+		 If \a propertyToSelect is not empty, an item for this name will be selected
+		 (usable when previously there was no set visible). */
+		virtual void showPropertySet(WidgetPropertySet *set, bool forceReload = false,
+			const QByteArray& propertyToSelect = QByteArray());
 
 		void blockPropertyEditorUpdating(void *blockingObject);
 
-		void unblockPropertyEditorUpdating(void *blockingObject, WidgetPropertySet *propSet);
+		void unblockPropertyEditorUpdating(void *blockingObject, WidgetPropertySet *set);
 
 		/*! Sets the external property editor pane used by FormDesigner (it may be docked).*/
 		void setEditor(KoProperty::Editor *editor);
@@ -211,7 +219,7 @@ class KFORMEDITOR_EXPORT FormManager : public QObject
 		void emitNoFormSelected();
 
 		/*! @internal
-		 \return true is redo action is being executed. 
+		 \return true is redo action is being executed.
 		 Used in WidgetPropertySet::slotPropertyChanged() */
 		bool isRedoing() const { return m_isRedoing; }
 
@@ -298,7 +306,7 @@ class KFORMEDITOR_EXPORT FormManager : public QObject
 		  or a "Widget" menu item. Prepares all Forms for
 		  creation of a new widget (ie changes cursor ...).
 		 */
-		void insertWidget(const QCString &classname);
+		void insertWidget(const Q3CString &classname);
 
 		/*! Stops the current widget insertion (ie unset the cursor ...). */
 		void stopInsert();
@@ -329,10 +337,11 @@ class KFORMEDITOR_EXPORT FormManager : public QObject
 		void changeFont();
 
 	signals:
-		/*! This signal is emited as the property buffer switched.
-		 If \a forceReload is true, the buffer needs to be reloaded even
+		/*! This signal is emitted as the property set switched.
+		 If \a forceReload is true, the set needs to be reloaded even
 		 if it's the same as previous one. */
-		void propertySetSwitched(KoProperty::Set *list, bool forceReload = false);
+		void propertySetSwitched(KoProperty::Set *set, bool forceReload = false,
+			const QByteArray& propertyToSelect = QByteArray());
 
 		/*! This signal is emitted when any change is made to the Form \a form,
 		 so it will need to be saved. */
@@ -353,11 +362,11 @@ class KFORMEDITOR_EXPORT FormManager : public QObject
 
 		/*! Signal emitted when undo action activation changes.
 		 \a text is the full text of the action (including command name). */
-		void undoEnabled(bool enabled, const QString &text = QString::null);
+		void undoEnabled(bool enabled, const QString &text = QString());
 
 		/*! Signal emitted when redo action activation changes.
 		 \a text is the full text of the action (including command name). */
-		void redoEnabled(bool enabled, const QString &text = QString::null);
+		void redoEnabled(bool enabled, const QString &text = QString());
 
 		/*! Signal emitted when the user choose a signal in 'Events' menu
 		 in context menu, or in 'Events' in property editor.
@@ -385,13 +394,13 @@ class KFORMEDITOR_EXPORT FormManager : public QObject
 	protected slots:
 		void deleteWidgetLaterTimeout();
 
-		/*! Slot called when a buddy is choosed in the buddy list. Sets the label buddy. */
-		void buddyChoosed(int id);
+		/*! Slot called when a buddy is chosen in the buddy list. Sets the label buddy. */
+		void buddyChosen(QAction* action);
 
 		/*! Slot called when the user chooses an item in signal (or slot) menu.
 		 The \ref createdConnection() is updated, and the connection created
 		 (for the signal menu). */
-		void menuSignalChoosed(int id);
+		void menuSignalChosen(QAction* action);
 
 		/*! Slot called when the user changes current style using combbox in toolbar or menu. */
 		void slotStyle();
@@ -404,6 +413,9 @@ class KFORMEDITOR_EXPORT FormManager : public QObject
 		/*! Inits the Form, adds it to m_forms, and conects slots. */
 		void initForm(Form *form);
 
+		/*! \return action group containing "insert widget" actions for each widget. */
+		QActionGroup* widgetActionGroup() const { return m_widgetActionGroup; }
+
 #if 0
 		/*! Default implementation just calls FormIO::loadFormFromDom().
 		 Change this if you need to handle, eg. custom UI XML tags, as in Kexi's Form Designer. */
@@ -426,6 +438,10 @@ class KFORMEDITOR_EXPORT FormManager : public QObject
 		void emitUndoEnabled(bool enabled, const QString &text);
 		void emitRedoEnabled(bool enabled, const QString &text);
 
+		/*! True if emitSelectionSignals() updates property set so showPropertySet() will
+		 not be needed in windowChanged(). False by default. Set to true in KexiFormManager. */
+		bool m_emitSelectionSignalsUpdatesPropertySet : 1;
+
 	private:
 		static FormManager* _self;
 
@@ -435,38 +451,40 @@ class KFORMEDITOR_EXPORT FormManager : public QObject
 
 		WidgetPropertySet *m_propSet;
 //		WidgetLibrary *m_lib;
-		QGuardedPtr<KoProperty::Editor>  m_editor;
-		QGuardedPtr<ObjectTreeView>  m_treeview;
+		QPointer<KoProperty::Editor>  m_editor;
+		QPointer<ObjectTreeView>  m_treeview;
 		// Forms
-		QPtrList<Form> m_forms;
-		QPtrList<Form> m_preview;
-		QGuardedPtr<Form> m_active;
+		Q3PtrList<Form> m_forms;
+		Q3PtrList<Form> m_preview;
+		QPointer<Form> m_active;
 
 		// Copy/Paste
 		QDomDocument m_domDoc;
-		KPopupMenu *m_popup;
+		KMenu *m_popup;
 		QPoint m_insertPoint;
-		QGuardedPtr<QWidget> m_menuWidget;
+		QPointer<QWidget> m_menuWidget;
 
 		// Insertion
 		bool m_inserting;
-		QCString m_selectedClass;
+		Q3CString m_selectedClass;
 
 		// Connection stuff
 		bool m_drawingSlot;
 		Connection *m_connection;
-		KPopupMenu *m_sigSlotMenu;
+		KMenu *m_sigSlotMenu;
 
 		// Actions
 		KActionCollection *m_collection;
+		QActionGroup* m_widgetActionGroup;
 		KToggleAction *m_pointer, *m_dragConnection, *m_snapToGrid;
+		QPointer<QAction> m_menuNoBuddy;
 
 		//! Used to delayed widgets deletion
 		QTimer m_deleteWidgetLater_timer;
-		QPtrList<QWidget> m_deleteWidgetLater_list;
+		Q3PtrList<QWidget> m_deleteWidgetLater_list;
 
-#ifdef KEXI_SHOW_DEBUG_ACTIONS
-		KDialogBase *m_uiCodeDialog;
+#ifdef KEXI_DEBUG_GUI
+		KPageDialog *m_uiCodeDialog;
 		KTextEdit *m_currentUICodeDialogEditor;
 		KTextEdit *m_originalUICodeDialogEditor;
 #endif
@@ -475,11 +493,13 @@ class KFORMEDITOR_EXPORT FormManager : public QObject
 		int m_contextMenuKey; //!< Id of context menu key (cached)
 
 		void *m_objectBlockingPropertyEditorUpdating;
+		QStyle *m_style;
 		bool m_isRedoing : 1;
 
 		friend class PropertyCommand;
 		friend class GeometryPropertyCommand;
 		friend class CutWidgetCommand;
+		friend class LibActionWidget;
 		friend class Form;
 };
 
