@@ -28,20 +28,14 @@
 //#define KEXI_STANDALONE 1
 
 #include <kexi_export.h>
-#include <config.h>
+#include <config-kexi.h>
 
-#define kexidbg  kdDebug(44010)   //! General debug area for Kexi
-#define kexicoredbg  kdDebug(44020)   //! Debug area for Kexi Core
-#define kexipluginsdbg kdDebug(44021) //! Debug area for Kexi Plugins
-#define kexiwarn  kdWarning(44010)
-#define kexicorewarn kdWarning(44020)
-#define kexipluginswarn kdWarning(44021)
-
-/* useful macros */
-
-/*! a shortcut for iterating over lists or maps, eg. QMap, QValueList */
-#define foreach(_class, _variable, _list) \
-	for (_class _variable = (_list).constBegin(); _variable!=(_list).constEnd(); ++_variable)
+#define kexidbg  kDebug(44010)   //! General debug area for Kexi
+#define kexicoredbg  kDebug(44020)   //! Debug area for Kexi Core
+#define kexipluginsdbg kDebug(44021) //! Debug area for Kexi Plugins
+#define kexiwarn  kWarning(44010)
+#define kexicorewarn kWarning(44020)
+#define kexipluginswarn kWarning(44021)
 
 /*! nonconst version of foreach iterator */
 #define foreach_nonconst(_class, _variable, _list) \
@@ -67,4 +61,26 @@
 # define FUTURE_I18N_NOOP(x) (x)
 #endif
 
+#ifdef _MSC_VER
+/* WARNING preprocessor directive
+ Reserved: preprocessor needs two indirections to replace __LINE__ with actual
+ string
+*/
+#define _MSG0(msg)     #msg
+/* Preprocessor needs two indirections to replace __LINE__ or __FILE__
+ with actual string. */
+#define _MSG1(msg)    _MSG0(msg)
+
+/*! Creates message prolog with the name of the source file and the line
+   number where a preprocessor message has been inserted.
+
+  Example:
+     #pragma KMESSAGE(Your message)
+  Output:
+     C:\MyCode.cpp(111) : Your message
+*/
+# define _MSGLINENO __FILE__ "(" _MSG1(__LINE__) ") : warning: "
+# define WARNING(msg) message(_MSGLINENO #msg)
+#endif /*_MSC_VER*/
+
 #endif /* _KEXI_GLOBAL_ */
