@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (c) 2003-2005 Kexi Team
+   Copyright (c) 2003-2007 Kexi Team
     
    Version information based on kofficeversion.h,
    Copyright (c) 2003 KOffice Team
@@ -23,6 +23,8 @@
 #ifndef _KEXI_VERSION_
 #define _KEXI_VERSION_
 
+#include "kexi_export.h"
+
 #ifdef CUSTOM_VERSION /* user-friendly version info */
 # include "custom_global.h"
 #else /* default */
@@ -30,12 +32,12 @@
 #endif
 
 #ifndef KEXI_VERSION_STRING
-# define KEXI_VERSION_STRING "1.1.2"
+# define KEXI_VERSION_STRING "2.0 alpha-3"
 #endif
 
 #define KEXI_VERSION_MAJOR 1
-#define KEXI_VERSION_MINOR 1
-#define KEXI_VERSION_RELEASE 2
+#define KEXI_VERSION_MINOR 9
+#define KEXI_VERSION_RELEASE 93
 
 #define KEXI_MAKE_VERSION( a,b,c ) (((a) << 16) | ((b) << 8) | (c))
 
