@@ -22,13 +22,15 @@
 
 #include <qobject.h>
 #include <qstringlist.h>
-#include <qintdict.h>
-#include <qdict.h>
-#include <qptrdict.h>
-#include <qvaluevector.h>
-#include <qvaluelist.h>
+#include <q3intdict.h>
+#include <q3dict.h>
+#include <q3ptrdict.h>
+#include <q3valuevector.h>
+#include <q3valuelist.h>
 #include <qvariant.h>
-#include <qguardedptr.h>
+#include <qpointer.h>
+//Added by qt3to4:
+#include <Q3PtrList>
 
 #include <kexidb/object.h>
 #include <kexidb/connectiondata.h>
@@ -44,7 +46,7 @@
 namespace KexiDB {
 
 //! structure for storing single record with type information
-typedef QValueVector<QVariant> RowData; 
+typedef Q3ValueVector<QVariant> RowData; 
 
 class Cursor;
 class ConnectionPrivate;
@@ -160,7 +162,7 @@ class KEXI_DB_EXPORT Connection : public QObject, public KexiDB::Object
 		 if dbName is not specified, currently used database name is used
 		 (it is closed before dropping).
 		*/
-		bool dropDatabase( const QString &dbName = QString::null );
+		bool dropDatabase( const QString &dbName = QString() );
 
 		 /*! \return names of all the \a objecttype (see \a ObjectTypes in global.h)
 		 schemas stored in currently used database. KexiDB::AnyObjectType can be passed 
@@ -206,16 +208,16 @@ class KEXI_DB_EXPORT Connection : public QObject, public KexiDB::Object
 		 If \a also_system_tables is true, 
 		 Internal KexiDB system tables (kexi__*) are not available here 
 		 because these have no identifiers assigned (more formally: id=-1). */
-		QValueList<int> tableIds();
+		Q3ValueList<int> tableIds();
 
 		/*! \return ids of all database query schemas stored in currently 
 		 used database. These ids can be later used as argument for querySchema().
 		 This is a shortcut for objectIds(TableObjectType). */
-		QValueList<int> queryIds();
+		Q3ValueList<int> queryIds();
 
 		/*! \return names of all schemas of object with \a objType type 
 		 that are stored in currently used database. */
-		QValueList<int> objectIds(int objType);
+		Q3ValueList<int> objectIds(int objType);
 
 		/*! \brief Creates new transaction handle and starts a new transaction.
 		 \return KexiDB::Transaction object if transaction has been started 
@@ -242,7 +244,7 @@ class KEXI_DB_EXPORT Connection : public QObject, public KexiDB::Object
 		 On successful commit, \a trans object will be destroyed.
 		 If this was default transaction, there is no default transaction for now.
 		*/
-		bool commitTransaction( Transaction trans = Transaction::null,
+		bool commitTransaction( Transaction trans = Transaction(),
 			bool ignore_inactive = false );
 		
 		/*! Rollbacks transaction \a trans.
@@ -256,7 +258,7 @@ class KEXI_DB_EXPORT Connection : public QObject, public KexiDB::Object
 		 On successful rollback, \a trans object will be destroyed.
 		 If this was default transaction, there is no default transaction for now.
 		*/
-		bool rollbackTransaction( Transaction trans = Transaction::null,
+		bool rollbackTransaction( Transaction trans = Transaction(),
 			bool ignore_inactive = false );
 		
 		/*! \return handle for default transaction for this connection
@@ -283,7 +285,7 @@ class KEXI_DB_EXPORT Connection : public QObject, public KexiDB::Object
 		 Use Transaction::active() to check that. Inactive transaction 
 		 handle is useless and can be safely dropped.
 		*/
-		const QValueList<Transaction>& transactions();
+		const Q3ValueList<Transaction>& transactions();
 
 		/*! \return true if "auto commit" option is on. 
 
@@ -336,7 +338,7 @@ class KEXI_DB_EXPORT Connection : public QObject, public KexiDB::Object
 		*/
 		virtual Cursor* prepareQuery( const QString& statement, uint cursor_options = 0) = 0;
 
-		/*! \overload prepareQuery( const QString& statement = QString::null, uint cursor_options = 0)
+		/*! \overload prepareQuery( const QString& statement = QString(), uint cursor_options = 0)
 		 Prepares query described by \a query schema. \a params are values of parameters that
 		 will be inserted into places marked with [] before execution of the query.
 
@@ -345,16 +347,16 @@ class KEXI_DB_EXPORT Connection : public QObject, public KexiDB::Object
 		 (passing \a query and \a cursor_options to it's constructor).
 		 Kexi SQL and driver-specific escaping is performed on table names.
 		*/
-		Cursor* prepareQuery( QuerySchema& query, const QValueList<QVariant>& params, 
+		Cursor* prepareQuery( QuerySchema& query, const Q3ValueList<QVariant>& params, 
 			uint cursor_options = 0 );
 
-		/*! \overload prepareQuery( QuerySchema& query, const QValueList<QVariant>& params, 
+		/*! \overload prepareQuery( QuerySchema& query, const Q3ValueList<QVariant>& params, 
 			uint cursor_options = 0 )
 		 Prepares query described by \a query schema without parameters.
 		*/
 		virtual Cursor* prepareQuery( QuerySchema& query, uint cursor_options = 0 ) = 0;
 
-		/*! \overload prepareQuery( const QString& statement = QString::null, uint cursor_options = 0)
+		/*! \overload prepareQuery( const QString& statement = QString(), uint cursor_options = 0)
 		 Statement is build from data provided by \a table schema, 
 		 it is like "select * from table_name".*/
 		Cursor* prepareQuery( TableSchema& table, uint cursor_options = 0);
@@ -375,10 +377,10 @@ class KEXI_DB_EXPORT Connection : public QObject, public KexiDB::Object
 
 		 Statement is build from data provided by \a query schema. 
 		 Kexi SQL and driver-specific escaping is performed on table names. */
-		Cursor* executeQuery( QuerySchema& query, const QValueList<QVariant>& params, 
+		Cursor* executeQuery( QuerySchema& query, const Q3ValueList<QVariant>& params, 
 			uint cursor_options = 0 );
 
-		/*! \overload executeQuery( QuerySchema& query, const QValueList<QVariant>& params, 
+		/*! \overload executeQuery( QuerySchema& query, const Q3ValueList<QVariant>& params, 
 			uint cursor_options = 0 ) */
 		Cursor* executeQuery( QuerySchema& query, uint cursor_options = 0 );
 
@@ -481,7 +483,7 @@ class KEXI_DB_EXPORT Connection : public QObject, public KexiDB::Object
 		/*! \return true if there is at least one record in \a table. */
 		bool isEmpty( TableSchema& table, bool &success );
 
-//! @todo perhaps use Q_ULLONG here?
+//! @todo perhaps use quint64 here?
 		/*! \return number of records in \a sql query.
 		 Does not fetch any records. -1 is returned on query execution errors (>0 otherwise).
 		 Note: real executed query is: "SELECT COUNT() FROM (\a sql) LIMIT 1" 
@@ -510,9 +512,9 @@ class KEXI_DB_EXPORT Connection : public QObject, public KexiDB::Object
 		#undef H_INS_REC
 		#undef A
 		
-		bool insertRecord(TableSchema &tableSchema, QValueList<QVariant>& values);
+		bool insertRecord(TableSchema &tableSchema, Q3ValueList<QVariant>& values);
 		
-		bool insertRecord(FieldList& fields, QValueList<QVariant>& values);
+		bool insertRecord(FieldList& fields, Q3ValueList<QVariant>& values);
 
 		/*! Creates table defined by \a tableSchema.
 		 Schema information is also added into kexi system tables, for later reuse.
@@ -647,19 +649,19 @@ class KEXI_DB_EXPORT Connection : public QObject, public KexiDB::Object
 		 Simply, method internally fetches last inserted record and returns selected 
 		 field's value. Requirements: field must be of integer type, there must be a
 		 record inserted in current database session (whatever this means).
-		 On error (Q_ULLONG)-1 is returned.
+		 On error (quint64)-1 is returned.
 		 Last inserted record is identified by magical row identifier, usually called 
 		 ROWID (PostgreSQL has it as well as SQLite; 
 		 see DriverBehaviour::ROW_ID_FIELD_RETURNS_LAST_AUTOINCREMENTED_VALUE). 
 		 ROWID's value will be assigned back to \a ROWID if this pointer is not null.
 		*/
-		Q_ULLONG lastInsertedAutoIncValue(const QString& aiFieldName, const QString& tableName, 
-			Q_ULLONG* ROWID = 0);
+		quint64 lastInsertedAutoIncValue(const QString& aiFieldName, const QString& tableName, 
+			quint64* ROWID = 0);
 		
-		/*! \overload int lastInsertedAutoIncValue(const QString&, const QString&, Q_ULLONG*)
+		/*! \overload int lastInsertedAutoIncValue(const QString&, const QString&, quint64*)
 		*/
-		Q_ULLONG lastInsertedAutoIncValue(const QString& aiFieldName, 
-			const TableSchema& table, Q_ULLONG* ROWID = 0);
+		quint64 lastInsertedAutoIncValue(const QString& aiFieldName, 
+			const TableSchema& table, quint64* ROWID = 0);
 
 		/*! Executes query \a statement, but without returning resulting 
 		 rows (used mostly for functional queries). 
@@ -678,23 +680,28 @@ class KEXI_DB_EXPORT Connection : public QObject, public KexiDB::Object
 
 				//! True if ROWID should be also retrieved. False by default.
 				bool alsoRetrieveROWID : 1;
+
+				/*! True if relations (LEFT OUTER JOIN) for visible lookup columns should be added. 
+				 True by default. This is set to false when user-visible statement is generated 
+				 e.g. for the Query Designer. */
+				bool addVisibleLookupColumns : 1;
 		};
 
 		/*! \return "SELECT ..." statement's string needed for executing query 
 		 defined by \a querySchema and \a params. */
 		QString selectStatement( QuerySchema& querySchema, 
-			const QValueList<QVariant>& params, 
+			const Q3ValueList<QVariant>& params, 
 			const SelectStatementOptions& options = SelectStatementOptions() ) const;
 
 		/*! \overload QString selectStatement( QuerySchema& querySchema, 
-			QValueList<QVariant> params = QValueList<QVariant>(), 
+			Q3ValueList<QVariant> params = Q3ValueList<QVariant>(), 
 			const SelectStatementOptions& options = SelectStatementOptions() ) const;
 		 \return "SELECT ..." statement's string needed for executing query 
 		 defined by \a querySchema. */
 		inline QString selectStatement( QuerySchema& querySchema, 
 			const SelectStatementOptions& options = SelectStatementOptions() ) const
 		{
-			return selectStatement(querySchema, QValueList<QVariant>(), options);
+			return selectStatement(querySchema, Q3ValueList<QVariant>(), options);
 		}
 
 		/*! Stores object's schema data (id, name, caption, help text)
@@ -730,14 +737,15 @@ class KEXI_DB_EXPORT Connection : public QObject, public KexiDB::Object
 		 If there is already such record in the table, it's simply overwritten.
 		 \return true on success
 		 \sa loadDataBlock(). */
-		bool storeDataBlock( int objectID, const QString &dataString, const QString& dataID = QString::null );
+		bool storeDataBlock( int objectID, const QString &dataString, 
+			const QString& dataID = QString() );
 
 		/*! Removes (potentially large) string data (e.g. xml form's representation), 
 		 referenced by objectID, and pointed by optional \a dataID.
 		 \return true on success. Does not fail if the block does not exist.
 		 Note that if \a dataID is not specified, all data blocks for this dialog will be removed.
 		 \sa loadDataBlock() storeDataBlock(). */
-		bool removeDataBlock( int objectID, const QString& dataID = QString::null);
+		bool removeDataBlock( int objectID, const QString& dataID = QString());
 
 		class KEXI_DB_EXPORT TableSchemaChangeListenerInterface
 		{
@@ -763,7 +771,7 @@ class KEXI_DB_EXPORT Connection : public QObject, public KexiDB::Object
 
 		void unregisterForTablesSchemaChanges(TableSchemaChangeListenerInterface& listener);
 
-		QPtrList<Connection::TableSchemaChangeListenerInterface>*
+		Q3PtrList<Connection::TableSchemaChangeListenerInterface>*
 			tableSchemaChangeListeners(TableSchema& tableSchema) const;
 
 		tristate closeAllTableSchemaChangeListeners(TableSchema& tableSchema);
@@ -901,11 +909,11 @@ class KEXI_DB_EXPORT Connection : public QObject, public KexiDB::Object
 		virtual bool drv_databaseExists( const QString &dbName, bool ignoreErrors = true );
 
 		/*! For reimplemenation: creates new database using connection */
-		virtual bool drv_createDatabase( const QString &dbName = QString::null ) = 0;
+		virtual bool drv_createDatabase( const QString &dbName = QString() ) = 0;
 
 		/*! For reimplemenation: opens existing database using connection 
 		 \return true on success, false on failure and cancelled if user has cancelled this action. */
-		virtual bool drv_useDatabase( const QString &dbName = QString::null, bool *cancelled = 0, 
+		virtual bool drv_useDatabase( const QString &dbName = QString(), bool *cancelled = 0, 
 			MessageHandler* msgHandler = 0 ) = 0;
 
 		/*! For reimplemenation: closes previously opened database 
@@ -930,7 +938,7 @@ class KEXI_DB_EXPORT Connection : public QObject, public KexiDB::Object
 		/*! For reimplemenation: drops database from the server
 			using connection. After drop, database shouldn't be accessible 
 			anymore. */
-		virtual bool drv_dropDatabase( const QString &dbName = QString::null ) = 0;
+		virtual bool drv_dropDatabase( const QString &dbName = QString() ) = 0;
 
 		/*! \return "CREATE TABLE ..." statement string needed for \a tableSchema
 		 creation in the database. 
@@ -970,7 +978,7 @@ class KEXI_DB_EXPORT Connection : public QObject, public KexiDB::Object
 		 just inserted row.
 		 Note for driver developers: contact js (at) iidea.pl 
 		 if your engine do not offers this information. */
-		virtual Q_ULLONG drv_lastInsertRowID() = 0;
+		virtual quint64 drv_lastInsertRowID() = 0;
 
 		/*! Note for driver developers: begins new transaction
 		 and returns handle to it. Default implementation just
@@ -1165,19 +1173,23 @@ class KEXI_DB_EXPORT Connection : public QObject, public KexiDB::Object
 		 Changes value of field property.
 		 \return true on success, false on failure, cancelled if the action has been cancelled.
 
-		 Note for driver developers: implement this if the driver has to support the altering. */
+		 Note for driver developers: implement this if the driver has to supprot the altering. */
 		virtual tristate drv_changeFieldProperty(TableSchema &table, Field& field, 
 			const QString& propertyName, const QVariant& value) {
 			Q_UNUSED(table); Q_UNUSED(field); Q_UNUSED(propertyName); Q_UNUSED(value);
 			return cancelled; }
 
-		//! cursors created for this connection
-		QPtrDict<KexiDB::Cursor> m_cursors;
+		//! Used by Cursor class
+		void addCursor(KexiDB::Cursor& cursor);
+
+		//! Used by Cursor class
+		void takeCursor(KexiDB::Cursor& cursor);
 
 	private:
 		ConnectionPrivate* d; //!< @internal d-pointer class.
 		Driver* const m_driver; //!< The driver this \a Connection instance uses.
 		bool m_destructor_started : 1; //!< helper: true if destructor is started.
+		bool m_insideCloseDatabase : 1; //!< helper: true while closeDatabase() is executed
 
 	friend class KexiDB::Driver;
 	friend class KexiDB::Cursor;
