@@ -22,8 +22,8 @@
 
 #include <qstring.h>
 #include <qvariant.h>
-#include <qptrvector.h>
-#include <qvaluevector.h>
+#include <q3ptrvector.h>
+#include <q3valuevector.h>
 
 #include <kexidb/connection.h>
 #include <kexidb/object.h>
@@ -92,7 +92,7 @@ class KEXI_DB_EXPORT Cursor: public QObject, public Object
 //		 Omit \a statement if cursor is already initialized with statement 
 //		 at creation time. If \a statement is not empty, existing statement
 //		 (if any) is overwritten. */
-//		bool open( const QString& statement = QString::null );
+//		bool open( const QString& statement = QString() );
 
 		/*! Closes previously opened cursor. 
 			If the cursor is closed, nothing happens. */
@@ -103,10 +103,10 @@ class KEXI_DB_EXPORT Cursor: public QObject, public Object
 		inline QuerySchema *query() const { return m_query; }
 
 		//! \return query parameters assigned to this cursor
-		QValueList<QVariant> queryParameters() const;
+		Q3ValueList<QVariant> queryParameters() const;
 
 		//! Sets query parameters \a params for this cursor.
-		void setQueryParameters(const QValueList<QVariant>& params);
+		void setQueryParameters(const Q3ValueList<QVariant>& params);
 
 		/*! \return raw query statement used to define this cursor
 		 or null string if raw statement instead (but QuerySchema is defined instead). */
@@ -157,7 +157,7 @@ class KEXI_DB_EXPORT Cursor: public QObject, public Object
 		 Value -1 means that cursor does not point to any valid record
 		 (this happens eg. after open(), close(), 
 		 and after moving after last record or before first one. */
-		Q_LLONG at() const;
+		qint64 at() const;
 
 		/*! \return number of fields available for this cursor. 
 		 This never includes ROWID column or other internal coluns (e.g. lookup). */
@@ -199,9 +199,9 @@ class KEXI_DB_EXPORT Cursor: public QObject, public Object
 		void setOrderByColumnList(const QStringList& columnNames);
 
 		/*! Convenience method, similar to setOrderByColumnList(const QStringList&). */
-		void setOrderByColumnList(const QString& column1, const QString& column2 = QString::null, 
-			const QString& column3 = QString::null, const QString& column4 = QString::null, 
-			const QString& column5 = QString::null);
+		void setOrderByColumnList(const QString& column1, const QString& column2 = QString(), 
+			const QString& column3 = QString(), const QString& column4 = QString(), 
+			const QString& column5 = QString());
 
 		/*! \return a list of fields contained in ORDER BY section of the query. 
 		 @see setOrderBy(const QStringList&) */
@@ -236,14 +236,14 @@ class KEXI_DB_EXPORT Cursor: public QObject, public Object
 		 to refer a documentation. SQLite is one of such engines. 
 		 Note for driver developers: Leave the default implementation (null 
 		 string is returned ) if your engine has no such capability. */
-		virtual QString serverResultName() { return QString::null; }
+		virtual QString serverResultName() { return QString(); }
 
 		/*! \return (not i18n'd) description text (message) of last operation's error/result.
 		 In most cases engines do return such a messages, any user can then use this
 		 to refer a documentation.
 		 Note for driver developers: Leave the default implementation (null 
 		 string is returned ) if your engine has no such capability. */
-		virtual QString serverErrorMsg() { return QString::null; }
+		virtual QString serverErrorMsg() { return QString(); }
 	
 		/*! \return Debug information. */
 		QString debugString() const;
@@ -252,8 +252,8 @@ class KEXI_DB_EXPORT Cursor: public QObject, public Object
 		void debug() const;
 
 	protected:
-		//! posible results of row fetching, used for m_result
-		typedef enum FetchResult { FetchError=0, FetchOK=1, FetchEnd=2 };
+		//! possible results of row fetching, used for m_result
+		enum FetchResult { FetchError=0, FetchOK=1, FetchEnd=2 };
 
 		/*! Cursor will operate on \a conn, raw \a statement will be used to execute query. */
 		Cursor(Connection* conn, const QString& statement, uint options = NoOptions );
@@ -299,7 +299,7 @@ class KEXI_DB_EXPORT Cursor: public QObject, public Object
 		virtual void drv_bufferMovePointerPrev() = 0;
 		/*! Moves pointer (that points to the buffer) to a new place: \a at.
 		*/
-		virtual void drv_bufferMovePointerTo(Q_LLONG at) = 0;
+		virtual void drv_bufferMovePointerTo(qint64 at) = 0;
 
 		/*DISABLED: ! This is called only once in open(), after successful drv_open().
 			Reimplement this if you need (or not) to do get the first record after drv_open(),
@@ -318,7 +318,7 @@ class KEXI_DB_EXPORT Cursor: public QObject, public Object
 		 the same that is returend by serverResult(). */
 		virtual void drv_clearServerResult() = 0;
 
-		QGuardedPtr<Connection> m_conn;
+		QPointer<Connection> m_conn;
 		QuerySchema *m_query;
 //		CursorData *m_data;
 		QString m_rawStatement;
@@ -329,7 +329,7 @@ class KEXI_DB_EXPORT Cursor: public QObject, public Object
 //		bool m_atLast;
 		bool m_validRecord : 1; //!< true if valid record is currently retrieved @ current position
 		bool m_containsROWIDInfo : 1;
-		Q_LLONG m_at;
+		qint64 m_at;
 		uint m_fieldCount; //!< cached field count information
 		uint m_logicalFieldCount;  //!< logical field count, i.e. without intrernal values like ROWID or lookup
 		uint m_options; //!< cursor options that describes its behaviour
@@ -346,7 +346,7 @@ class KEXI_DB_EXPORT Cursor: public QObject, public Object
 		//! Used by setOrderByColumnList()
 		QueryColumnInfo::Vector* m_orderByColumnList;
 
-		QValueList<QVariant>* m_queryParameters;
+		Q3ValueList<QVariant>* m_queryParameters;
 
 	private:
 		bool m_readAhead : 1;
