@@ -22,9 +22,12 @@
 #include "mysqlconnection.h"
 #include "mysqlconnection_p.h"
 #include <kexidb/error.h>
+#include <kexidb/utils.h>
 #include <klocale.h>
 #include <kdebug.h>
 #include <limits.h>
+//Added by qt3to4:
+#include <Q3CString>
 
 #define BOOL bool
 
@@ -56,7 +59,7 @@ bool MySqlCursor::drv_open() {
 //	KexiDBDrvDbg << "MySqlCursor::drv_open:" << m_sql << endl;
 	// This can't be right?  mysql_real_query takes a length in order that
 	// queries can have binary data - but strlen does not allow binary data.
-	if(mysql_real_query(d->mysql, m_sql.utf8(), strlen(m_sql.utf8())) == 0) {
+	if(mysql_real_query(d->mysql, m_sql.toUtf8(), strlen(m_sql.toUtf8())) == 0) {
 		if(mysql_errno(d->mysql) == 0) {
 			d->mysqlres= mysql_store_result(d->mysql);
 			m_fieldCount=mysql_num_fields(d->mysqlres);
@@ -114,24 +117,27 @@ QVariant MySqlCursor::value(uint pos) {
 	
 //! @todo js: use MYSQL_FIELD::type here!
 
+	return KexiDB::cstringToVariant(d->mysqlrow[pos], f, d->lengths[pos]);
+/* moved to cstringToVariant()
 	//from most to least frequently used types:
 	if (!f || f->isTextType())
-		return QVariant( QString::fromUtf8((const char*)d->mysqlrow[pos]) );
+		return QVariant( QString::fromUtf8((const char*)d->mysqlrow[pos], d->lengths[pos]) );
 	else if (f->isIntegerType())
 //! @todo support BigInteger
-		return QVariant( QCString((const char*)d->mysqlrow[pos]).toInt() );
+		return QVariant( Q3CString((const char*)d->mysqlrow[pos], d->lengths[pos]).toInt() );
 	else if (f->isFPNumericType())
-		return QVariant( QCString((const char*)d->mysqlrow[pos]).toDouble() );
+		return QVariant( Q3CString((const char*)d->mysqlrow[pos], d->lengths[pos]).toDouble() );
 
 	//default
-	return QVariant(QString::fromUtf8((const char*)d->mysqlrow[pos]));
+	return QVariant(QString::fromUtf8((const char*)d->mysqlrow[pos], d->lengths[pos]));*/
 }
 
 
 /* As with sqlite, the DB library returns all values (including numbers) as
    strings. So just put that string in a QVariant and let KexiDB deal with it.
  */
-void MySqlCursor::storeCurrentRow(RowData &data) const {
+void MySqlCursor::storeCurrentRow(RowData &data) const
+{
 //	KexiDBDrvDbg << "MySqlCursor::storeCurrentRow: Position is " << (long)m_at<< endl;
 	if (d->numRows<=0)
 		return;
@@ -141,22 +147,22 @@ void MySqlCursor::storeCurrentRow(RowData &data) const {
 
 	data.resize(m_fieldCount);
 	const uint fieldsExpandedCount = m_fieldsExpanded ? m_fieldsExpanded->count() : UINT_MAX;
-	const uint realCount = QMIN(fieldsExpandedCount, m_fieldCount);
+	const uint realCount = qMin(fieldsExpandedCount, m_fieldCount);
 	for( uint i=0; i<realCount; i++) {
 		Field *f = m_fieldsExpanded ? m_fieldsExpanded->at(i)->field : 0;
 		if (m_fieldsExpanded && !f)
 			continue;
+		data[i] = KexiDB::cstringToVariant(d->mysqlrow[i], f, d->lengths[i]);
+/* moved to cstringToVariant()
 		if (f && f->type()==Field::BLOB) {
-			QByteArray ba;
-			ba.duplicate(d->mysqlrow[i], d->mysqlres->lengths[i]);
-			data[i] = ba;
+			data[i] = QByteArray(d->mysqlrow[i], d->mysqlres->lengths[i]);
 			KexiDBDbg << data[i].toByteArray().size() << endl;
 		}
 //! @todo more types!
 //! @todo look at what type mysql declares!
 		else {
-			data[i] = QVariant(QString::fromUtf8((const char*)d->mysqlrow[i]));
-		}
+			data[i] = QVariant(QString::fromUtf8((const char*)d->mysqlrow[i], d->lengths[i]));
+		}*/
 	}
 }
 
@@ -177,7 +183,7 @@ void MySqlCursor::drv_bufferMovePointerPrev() {
 }
 
 
-void MySqlCursor::drv_bufferMovePointerTo(Q_LLONG to) {
+void MySqlCursor::drv_bufferMovePointerTo(qint64 to) {
 	//MYSQL_ROW_OFFSET ro=mysql_row_tell(d->mysqlres);
 	mysql_data_seek(d->mysqlres, to);
 	d->mysqlrow=mysql_fetch_row(d->mysqlres);
@@ -196,7 +202,7 @@ int MySqlCursor::serverResult()
 
 QString MySqlCursor::serverResultName()
 {
-	return QString::null;
+	return QString();
 }
 
 void MySqlCursor::drv_clearServerResult()
