@@ -30,9 +30,13 @@
 #include <klocale.h>
 
 #include <qdatetime.h>
+//Added by qt3to4:
+#include <Q3CString>
 
 #include <assert.h>
 
+#include "kexi_global.h"
+
 using namespace KexiDB;
 
 Field::FieldTypeNames Field::m_typeNames;
@@ -68,7 +72,7 @@ Field::Field(const QString& name, Type ctype,
  QVariant defaultValue, const QString& caption, const QString& description,
  uint width)
 	: m_parent(0)
-	,m_name(name.lower())
+	,m_name(name.toLower())
 	,m_length(length)
 	,m_precision(precision)
 	,m_visibleDecimalPlaces(-1)
@@ -110,6 +114,11 @@ Field::~Field()
 	delete m_customProperties;
 }
 
+Field* Field::copy() const
+{
+	return new Field(*this);
+}
+
 void Field::init()
 {
 	m_parent = 0;
@@ -119,7 +128,7 @@ void Field::init()
 	m_precision = 0;
 	m_visibleDecimalPlaces = -1;
 	m_options = NoOptions;
-	m_defaultValue = QVariant(QString::null);
+	m_defaultValue = QVariant(QString());
 	m_order = -1;
 	m_width = 0;
 	m_expr = 0;
@@ -171,6 +180,11 @@ QString Field::typeName(uint type)
 	return (type <= LastType) ? m_typeNames.at(type) : QString::number(type);
 }
 
+QStringList Field::typeNames()
+{
+	return m_typeNames.names;
+}
+
 QString Field::typeString(uint type)
 {
 	m_typeNames.init();
@@ -183,28 +197,34 @@ QString Field::typeGroupName(uint typeGroup)
 	return (typeGroup <= LastTypeGroup) ? m_typeGroupNames.at(typeGroup) : typeGroupString(typeGroup);
 }
 
+QStringList Field::typeGroupNames()
+{
+	return m_typeGroupNames.names;
+}
+
 QString Field::typeGroupString(uint typeGroup)
 {
 	m_typeGroupNames.init();
-	return (typeGroup <= LastTypeGroup) ? m_typeGroupNames.at((int)LastTypeGroup+1 + typeGroup) : QString("TypeGroup%1").arg(typeGroup);
+	return (typeGroup <= LastTypeGroup)
+		? m_typeGroupNames.at((int)LastTypeGroup+1 + typeGroup) : QString("TypeGroup%1").arg(typeGroup);
 }
 
 Field::Type Field::typeForString(const QString& typeString)
 {
 	m_typeNames.init();
-	QMap<QString,Type>::ConstIterator it = m_typeNames.str2num.find(typeString.lower());
+	QMap<QString,Type>::ConstIterator it = m_typeNames.str2num.find(typeString.toLower());
 	if (it==m_typeNames.str2num.end())
 		return InvalidType;
-	return it.data();
+	return it.value();
 }
 
 Field::TypeGroup Field::typeGroupForString(const QString& typeGroupString)
 {
 	m_typeGroupNames.init();
-	QMap<QString,TypeGroup>::ConstIterator it = m_typeGroupNames.str2num.find(typeGroupString.lower());
+	QMap<QString,TypeGroup>::ConstIterator it = m_typeGroupNames.str2num.find(typeGroupString.toLower());
 	if (it==m_typeGroupNames.str2num.end())
 		return InvalidGroup;
-	return it.data();
+	return it.value();
 }
 
 bool Field::isIntegerType( uint type )
@@ -263,11 +283,6 @@ bool Field::isTextType( uint type )
 	return false;
 }
 
-bool Field::isQueryAsterisk() const
-{
-	return dynamic_cast<QueryAsterisk const *>(this);
-}
-
 bool Field::hasEmptyProperty(uint type)
 {
 	return Field::isTextType(type) || type==BLOB;
@@ -323,7 +338,7 @@ Field::setQuery(QuerySchema *querySchema)
 void
 Field::setName(const QString& n)
 {
-	m_name = n.lower();
+	m_name = n.toLower();
 }
 
 void
@@ -399,7 +414,7 @@ Field::setDefaultValue(const QVariant& def)
 }
 
 bool
-Field::setDefaultValue(const QCString& def)
+Field::setDefaultValue(const QByteArray& def)
 {
 	if (def.isNull()) {
 		m_defaultValue = QVariant();
@@ -429,20 +444,20 @@ Field::setDefaultValue(const QCString& def)
 			if (!ok || (!(m_options & Unsigned) && (-v > (int)0x07FFFFFFF || v > (int)(0x080000000-1))))
 				m_defaultValue = QVariant();
 			else
-				m_defaultValue = QVariant((Q_LLONG)v);
+				m_defaultValue = QVariant((qint64)v);
 			break;
 		}case BigInteger: {//8 bytes
 //! @todo BigInteger support
 /*
-			Q_LLONG long v = def.toLongLong(&ok);
+			qint64 long v = def.toLongLong(&ok);
 //TODO: 2-part decoding
 			if (!ok || (!(m_options & Unsigned) && (-v > 0x080000000 || v > (0x080000000-1))))
 				m_defaultValue = QVariant();
 			else
 				if (m_options & Unsigned)
-					m_defaultValue=QVariant((Q_ULLONG) v);
+					m_defaultValue=QVariant((quint64) v);
 				else
-					m_defaultValue = QVariant((Q_LLONG)v);*/
+					m_defaultValue = QVariant((qint64)v);*/
 			break;
 		}case Boolean: {
 			unsigned short v = def.toUShort(&ok);
@@ -614,12 +629,15 @@ QString Field::debugString() const
 	if (m_customProperties && !m_customProperties->isEmpty()) {
 		dbg += QString(" CUSTOM PROPERTIES (%1): ").arg(m_customProperties->count());
 		bool first = true;
-		foreach (CustomPropertiesMap::ConstIterator, it, *m_customProperties) {
+		for (CustomPropertiesMap::ConstIterator it(m_customProperties->constBegin());
+			it!=m_customProperties->constEnd(); ++it)
+		{
 			if (first)
 				first = false;
 			else
 				dbg += ", ";
-			dbg += QString("%1 = %2 (%3)").arg(it.key()).arg(it.data().toString()).arg(it.data().typeName());
+			dbg += QString("%1 = %2 (%3)").arg(QString(it.key())).arg(it.value().toString())
+				.arg(it.value().typeName());
 		}
 	}
 	return dbg;
@@ -641,7 +659,7 @@ void Field::setExpression(KexiDB::BaseExpr *expr)
 	m_expr = expr;
 }
 
-QVariant Field::customProperty(const QCString& propertyName,
+QVariant Field::customProperty(const QByteArray& propertyName,
 	const QVariant& defaultValue) const
 {
 	if (!m_customProperties)
@@ -649,10 +667,10 @@ QVariant Field::customProperty(const QCString& propertyName,
 	CustomPropertiesMap::ConstIterator it(m_customProperties->find(propertyName));
 	if (it==m_customProperties->constEnd())
 		return defaultValue;
-	return it.data();
+	return it.value();
 }
 
-void Field::setCustomProperty(const QCString& propertyName, const QVariant& value)
+void Field::setCustomProperty(const QByteArray& propertyName, const QVariant& value)
 {
 	if (propertyName.isEmpty())
 		return;
@@ -664,13 +682,15 @@ void Field::setCustomProperty(const QCString& propertyName, const QVariant& valu
 //-------------------------------------------------------
 #define ADDTYPE(type, i18, str) this->at(Field::type) = i18; \
 	this->at(Field::type+Field::LastType+1) = str; \
-	str2num.insert(QString::fromLatin1(str).lower(), type)
+	str2num.insert(QString::fromLatin1(str).toLower(), type); \
+	names.append(i18)
 #define ADDGROUP(type, i18, str) this->at(Field::type) = i18; \
 	this->at(Field::type+Field::LastTypeGroup+1) = str; \
-	str2num.insert(QString::fromLatin1(str).lower(), type)
+	str2num.insert(QString::fromLatin1(str).toLower(), type); \
+	names.append(i18)
 
 Field::FieldTypeNames::FieldTypeNames()
- : QValueVector<QString>()
+ : Q3ValueVector<QString>()
  , m_initialized(false)
 {
 }
@@ -701,7 +721,7 @@ void Field::FieldTypeNames::init()
 //-------------------------------------------------------
 
 Field::FieldTypeGroupNames::FieldTypeGroupNames()
- : QValueVector<QString>()
+ : Q3ValueVector<QString>()
  , m_initialized(false)
 {
 }
