@@ -25,8 +25,12 @@
 #include <qvariant.h>
 #include <qstring.h>
 #include <qpair.h>
-#include <qvaluevector.h>
-#include <qptrvector.h>
+#include <q3valuevector.h>
+#include <q3ptrvector.h>
+//Added by qt3to4:
+#include <Q3CString>
+#include <Q3PtrList>
+#include <QStringList>
 #include "kexidb/kexidb_export.h"
 namespace KexiDB {
 
@@ -72,16 +76,17 @@ class BaseExpr;
 class KEXI_DB_EXPORT Field
 {
 	public:
-		typedef QPtrList<Field> List; //!< list of fields 
-		typedef QPtrVector<Field> Vector; //!< vector of fields 
-		typedef QPtrListIterator<Field> ListIterator; //!< iterator for list of fields 
+		typedef Q3PtrList<Field> List; //!< list of fields 
+		typedef Q3PtrVector<Field> Vector; //!< vector of fields 
+		typedef Q3PtrListIterator<Field> ListIterator; //!< iterator for list of fields 
 		typedef QPair<Field*,Field*> Pair; //!< fields pair
-		typedef QPtrList<Pair> PairList; //!< list of fields pair
+		typedef Q3PtrList<Pair> PairList; //!< list of fields pair
 
 		/*! Unified (most common used) types of fields. */
 		enum Type
 		{
 			InvalidType = 0, /*!< Unsupported/Unimplemented type */
+			FirstType = 1, /*! First type */
 			Byte = 1,        /*!< 1 byte, signed or unsigned */
 			ShortInteger = 2,/*!< 2 bytes, signed or unsigned */
 			Integer = 3,     /*!< 4 bytes, signed or unsigned */
@@ -159,8 +164,8 @@ class KEXI_DB_EXPORT Field
 			uint options = NoOptions,
 			uint length=0, uint precision=0,
 			QVariant defaultValue=QVariant(),
-			const QString& caption = QString::null,
-			const QString& description = QString::null,
+			const QString& caption = QString(),
+			const QString& description = QString(),
 			uint width = 0);
 
 		/*! Copy constructor. */
@@ -175,6 +180,9 @@ class KEXI_DB_EXPORT Field
 		 not greater than Field::LastType) */
 		static QString typeName(uint type);
 
+		/*! \return list of all available i18n'd type names. */
+		static QStringList typeNames();
+
 		/*! \return type string for \a type, e.g. "Integer" for Integer type 
 		 (not-i18n'd, \a type has to be an element from Field::Type, 
 		 not greater than Field::LastType) */
@@ -193,6 +201,9 @@ class KEXI_DB_EXPORT Field
 		 (\a typeGroup has to be an element from Field::TypeGroup) */
 		static QString typeGroupName(uint typeGroup);
 
+		/*! \return list of all available i18n'd type group names. */
+		static QStringList typeGroupNames();
+
 		/*! \return type group string for \a typeGroup, e.g. "IntegerGroup" for IntegerGroup type 
 		 (not-i18n'd, \a type has to be an element from Field::Type, 
 		 not greater than Field::LastType) */
@@ -434,11 +445,11 @@ class KEXI_DB_EXPORT Field
 		 @see defaultValue() */
 		void setDefaultValue(const QVariant& def);
 
-		/*! Sets default value decoded from QCString. 
+		/*! Sets default value decoded from QByteArray. 
 			Decoding errors are detected (value is strictly checked against field type) 
 			- if one is encountered, default value is cleared (defaultValue()==QVariant()). 
 			\return true if given value was valid for field type. */
-		bool setDefaultValue(const QCString& def);
+		bool setDefaultValue(const QByteArray& def);
 
 		/*! Sets auto increment flag. Only available to set true, 
 		 if isAutoIncrementAllowed() is true. */
@@ -507,7 +518,7 @@ class KEXI_DB_EXPORT Field
 		 Every QueryAsterisk object returns true here,
 		 and every Field object returns false.
 		*/
-		bool isQueryAsterisk() const;
+		virtual bool isQueryAsterisk() const { return false; }
 		
 		/*! \return string for debugging purposes. */
 		virtual QString debugString() const;
@@ -538,22 +549,22 @@ class KEXI_DB_EXPORT Field
 
 //<TMP>
 		/*! \return the hints for enum fields. */
-		QValueVector<QString> enumHints() const { return m_hints; }
-		QString enumHint(uint num) { return (num < m_hints.size()) ? m_hints.at(num) : QString::null; }
+		Q3ValueVector<QString> enumHints() const { return m_hints; }
+		QString enumHint(uint num) { return (num < (uint)m_hints.size()) ? m_hints.at(num) : QString(); }
 		/*! sets the hint for enum fields */
-		void setEnumHints(const QValueVector<QString> &l) { m_hints = l; }
+		void setEnumHints(const Q3ValueVector<QString> &l) { m_hints = l; }
 //</TMP>
 
 		/*! \return custom property \a propertyName.
 		 If there is no such a property, \a defaultValue is returned. */
-		QVariant customProperty(const QCString& propertyName,
+		QVariant customProperty(const QByteArray& propertyName,
 			const QVariant& defaultValue = QVariant()) const;
 
 		//! Sets value \a value for custom property \a propertyName
-		void setCustomProperty(const QCString& propertyName, const QVariant& value);
+		void setCustomProperty(const QByteArray& propertyName, const QVariant& value);
 
 		//! A data type used for handling custom properties of a field
-		typedef QMap<QCString,QVariant> CustomPropertiesMap;
+		typedef QMap<QByteArray,QVariant> CustomPropertiesMap;
 
 		//! \return all custom properties
 		inline const CustomPropertiesMap customProperties() const {
@@ -570,6 +581,9 @@ class KEXI_DB_EXPORT Field
 		/*! @internal Used by constructors. */
 		void init();
 
+		//! \return a deep copy of this object. Used in @ref FieldList(const FieldList& fl).
+		virtual Field* copy() const;
+
 		FieldList *m_parent; //!< In most cases this points to a TableSchema 
 		                     //!< object that field is assigned.
 		QString m_name;
@@ -584,27 +598,29 @@ class KEXI_DB_EXPORT Field
 		QString m_caption;
 		QString m_desc;
 		uint m_width;
-		QValueVector<QString> m_hints;
+		Q3ValueVector<QString> m_hints;
 
 		KexiDB::BaseExpr *m_expr;
 		CustomPropertiesMap* m_customProperties;
 
 		//! @internal Used in m_typeNames member to handle i18n'd type names
-		class KEXI_DB_EXPORT FieldTypeNames : public QValueVector<QString> {
+		class KEXI_DB_EXPORT FieldTypeNames : public Q3ValueVector<QString> {
 			public:
 				FieldTypeNames();
 				void init();
 			QMap<QString,Type> str2num;
+			QStringList names;
 			protected:
 				bool m_initialized : 1;
 		};
 
 		//! @internal Used in m_typeGroupNames member to handle i18n'd type group names
-		class KEXI_DB_EXPORT FieldTypeGroupNames : public QValueVector<QString> {
+		class KEXI_DB_EXPORT FieldTypeGroupNames : public Q3ValueVector<QString> {
 			public: 
 				FieldTypeGroupNames();
 				void init();
 			QMap<QString,TypeGroup> str2num;
+			QStringList names;
 			protected:
 				bool m_initialized : 1;
 		};
