@@ -24,15 +24,19 @@
 #include <klocale.h>
 
 #include <qregexp.h>
+//Added by qt3to4:
+#include <Q3ValueList>
+#include <Q3CString>
+#include <Q3PtrList>
 
 #include <assert.h>
 
 using namespace KexiDB;
 
-Parser *parser;
-Field *field;
+Parser *parser = 0;
+Field *field = 0;
 //bool requiresTable;
-QPtrList<Field> fieldList;
+Q3PtrList<Field> fieldList;
 int current = 0;
 QString ctoken = "";
 
@@ -85,9 +89,9 @@ void yyerror(const char *str)
 	parser->setOperation(Parser::OP_Error);
 
 	const bool otherError = (qstrnicmp(str, "other error", 11)==0);
-	
-	if (parser->error().type().isEmpty() 
-		&& (str==0 || strlen(str)==0 
+
+	if (parser->error().type().isEmpty()
+		&& (str==0 || strlen(str)==0
 		|| qstrnicmp(str, "syntax error", 12)==0 || qstrnicmp(str, "parse error", 11)==0)
 		|| otherError)
 	{
@@ -121,31 +125,33 @@ void yyerror(const char *str)
 //						KexiDBDbg << "**" << captured.at(2) << endl;
 					}
 				}
-					
-					
-					
+
+
+
 //			 IDENTIFIER, expecting '")) {
 				e = errtypestr.mid(47);
 				KexiDBDbg << e <<endl;
 //				,' or ')'
 //		lexerErr i18n("identifier was expected");
-				
-			} else 
+
+			} else
 #endif
 			if (errtypestr.startsWith("parse error, expecting `IDENTIFIER'"))
 				lexerErr = i18n("identifier was expected");
 		}
-		
+
 		if (!otherError) {
 			if (!lexerErr.isEmpty())
 				lexerErr.prepend(": ");
 
-			if (parser->isReservedKeyword(ctoken.latin1()))
-				parser->setError( ParserError(i18n("Syntax Error"), 
-					i18n("\"%1\" is a reserved keyword").arg(ctoken)+lexerErr, ctoken, current) );
+			if ( parser->isReservedKeyword( ctoken.toLatin1() ) )
+				parser->setError( ParserError(i18n("Syntax Error"),
+					i18n("\"%1\" is a reserved keyword", ctoken ) + lexerErr,
+					ctoken, current) );
 			else
-				parser->setError( ParserError(i18n("Syntax Error"), 
-					i18n("Syntax Error near \"%1\"").arg(ctoken)+lexerErr, ctoken, current) );
+				parser->setError( ParserError(i18n("Syntax Error"),
+					i18n("Syntax Error near \"%1\"", ctoken ) + lexerErr,
+					ctoken, current) );
 		}
 	}
 }
@@ -153,7 +159,7 @@ void yyerror(const char *str)
 void setError(const QString& errName, const QString& errDesc)
 {
 	parser->setError( ParserError(errName, errDesc, ctoken, current) );
-	yyerror(errName.latin1());
+	yyerror( errName.toLatin1() );
 }
 
 void setError(const QString& errDesc)
@@ -196,7 +202,7 @@ bool parseData(Parser *p, const char *data)
 /*			TableSchema *ts;
 			for(QDictIterator<TableSchema> it(tableDict); TableSchema *s = tableList.first(); s; s = tableList.next())
 			{
-				KexiDBDbg << "  " << s->name() << endl;
+				KexiDBDbg << "	" << s->name() << endl;
 			}*/
 /*removed
 			Field::ListIterator it = parser->select()->fieldsIterator();
@@ -223,7 +229,7 @@ bool parseData(Parser *p, const char *data)
 	return ok;
 }
 
-	
+
 /* Adds \a column to \a querySchema. \a column can be in a form of
  table.field, tableAlias.field or field
 */
@@ -245,7 +251,7 @@ bool addColumn( ParseInfo& parseInfo, BaseExpr* columnExpr )
 			parseInfo.querySchema->addAsterisk( new QueryAsterisk(parseInfo.querySchema) );
 		}
 		else if (v_e->tableForQueryAsterisk) {//one-table asterisk
-			parseInfo.querySchema->addAsterisk( 
+			parseInfo.querySchema->addAsterisk(
 				new QueryAsterisk(parseInfo.querySchema, v_e->tableForQueryAsterisk) );
 		}
 		else if (v_e->field) {//"table.field" or "field" (bound to a table or not)
@@ -285,7 +291,7 @@ bool addColumn( ParseInfo& parseInfo, BaseExpr* columnExpr )
 						firstField = f;
 					} else if (f->table()!=firstField->table()) {
 						//ambiguous field name
-						setError(i18n("Ambiguous field name"), 
+						setError(i18n("Ambiguous field name"),
 							i18n("Both table \"%1\" and \"%2\" have defined \"%3\" field. "
 								"Use \"<tableName>.%4\" notation to specify table name.")
 								.arg(firstField->table()->name()).arg(f->table()->name())
@@ -295,7 +301,7 @@ bool addColumn( ParseInfo& parseInfo, BaseExpr* columnExpr )
 				}
 			}
 			if (!firstField) {
-					setError(i18n("Field not found"), 
+					setError(i18n("Field not found"),
 						i18n("Table containing \"%1\" field not found").arg(fieldName));
 					return false;
 			}
@@ -304,32 +310,34 @@ bool addColumn( ParseInfo& parseInfo, BaseExpr* columnExpr )
 		}
 	}
 	else {//table.fieldname or tableAlias.fieldname
-		tableName = tableName.lower();
+		tableName = tableName.toLower();
 		TableSchema *ts = parseInfo.querySchema->table( tableName );
 		if (ts) {//table.fieldname
 			//check if "table" is covered by an alias
-			const QValueList<int> tPositions = parseInfo.querySchema->tablePositions(tableName);
-			QValueList<int>::ConstIterator it = tPositions.constBegin();
-			QCString tableAlias;
+			const Q3ValueList<int> tPositions = parseInfo.querySchema->tablePositions(tableName);
+			Q3ValueList<int>::ConstIterator it = tPositions.constBegin();
+			Q3CString tableAlias;
 			bool covered = true;
 			for (; it!=tPositions.constEnd() && covered; ++it) {
-				tableAlias = parseInfo.querySchema->tableAlias(*it);
-				if (tableAlias.isEmpty() || tableAlias.lower()==tableName.latin1())
+				tableAlias = parseInfo.querySchema->tableAlias(*it).toLower();
+				if (tableAlias.isEmpty() || tableAlias == tableName.toLatin1())
 					covered = false; //uncovered
 				KexiDBDbg << " --" << "covered by " << tableAlias << " alias" << endl;
 			}
 			if (covered) {
-				setError(i18n("Could not access the table directly using its name"), 
+				setError(i18n("Could not access the table directly using its name"),
 					i18n("Table \"%1\" is covered by aliases. Instead of \"%2\", "
-					"you can write \"%3\"").arg(tableName)
-					.arg(tableName+"."+fieldName).arg(tableAlias+"."+fieldName.latin1()));
+					"you can write \"%3\"")
+					.arg( tableName )
+					.arg( tableName + "." + fieldName)
+					.arg( tableAlias + "." + fieldName.toLatin1() ));
 				return false;
 			}
 		}
-		
+
 		int tablePosition = -1;
 		if (!ts) {//try to find tableAlias
-			tablePosition = parseInfo.querySchema->tablePositionForAlias( tableName.latin1() );
+			tablePosition = parseInfo.querySchema->tablePositionForAlias( tableName.toLatin1() );
 			if (tablePosition>=0) {
 				ts = parseInfo.querySchema->tables()->at(tablePosition);
 				if (ts) {
@@ -340,7 +348,7 @@ bool addColumn( ParseInfo& parseInfo, BaseExpr* columnExpr )
 
 
 		if (ts) {
-			QValueList<int> *positionsList = repeatedTablesAndAliases[ tableName ];
+			Q3ValueList<int> *positionsList = repeatedTablesAndAliases[ tableName ];
 			if (!positionsList) {
 				IMPL_ERROR(tableName + "." + fieldName + ", !positionsList ");
 				return false;
@@ -361,7 +369,7 @@ bool addColumn( ParseInfo& parseInfo, BaseExpr* columnExpr )
 					// check if table or alias is used twice and both have the same column
 					// (so the column is ambiguous)
 					int numberOfTheSameFields = 0;
-					for (QValueList<int>::iterator it = positionsList->begin();
+					for (Q3ValueList<int>::iterator it = positionsList->begin();
 						it!=positionsList->end();++it)
 					{
 						TableSchema *otherTS = parseInfo.querySchema->tables()->at(*it);
@@ -404,12 +412,12 @@ QuerySchema* buildSelectQuery(
 	SelectOptionsInternal* options )
 {
 	ParseInfo parseInfo(querySchema);
-	
+
 	//-------tables list
 //	assert( tablesList ); //&& tablesList->exprClass() == KexiDBExpr_TableList );
 
 	uint columnNum = 0;
-/*TODO: use this later if there are columns that use database fields, 
+/*TODO: use this later if there are columns that use database fields,
         e.g. "SELECT 1 from table1 t, table2 t") is ok however. */
 	//used to collect information about first repeated table name or alias:
 //	QDict<char> tableNamesAndTableAliases(997, false);
@@ -418,7 +426,7 @@ QuerySchema* buildSelectQuery(
 		for (int i=0; i<tablesList->args(); i++, columnNum++) {
 			BaseExpr *e = tablesList->arg(i);
 			VariableExpr* t_e = 0;
-			QCString aliasString;
+			QString aliasString;
 			if (e->exprClass() == KexiDBExpr_SpecialBinary) {
 				BinaryExpr* t_with_alias = e->toBinary();
 				assert(t_with_alias);
@@ -426,22 +434,22 @@ QuerySchema* buildSelectQuery(
 				assert(t_with_alias->right()->exprClass() == KexiDBExpr_Variable
 					&& (t_with_alias->token()==AS || t_with_alias->token()==0));
 				t_e = t_with_alias->left()->toVariable();
-				aliasString = t_with_alias->right()->toVariable()->name.latin1();
+				aliasString = t_with_alias->right()->toVariable()->name.toLatin1();
 			}
 			else {
 				t_e = e->toVariable();
 			}
 			assert(t_e);
-			QCString tname = t_e->name.latin1();
+			QString tname = t_e->name.toLatin1();
 			TableSchema *s = parser->db()->tableSchema(tname);
 			if(!s) {
-				setError(//i18n("Field List Error"), 
-					i18n("Table \"%1\" does not exist").arg(tname));
+				setError(//i18n("Field List Error"),
+					i18n("Table \"%1\" does not exist", tname));
 	//			yyerror("fieldlisterror");
 				CLEANUP;
 				return 0;
 			}
-			QCString tableOrAliasName;
+			QString tableOrAliasName;
 			if (!aliasString.isEmpty()) {
 				tableOrAliasName = aliasString;
 //				KexiDBDbg << "- add alias for table: " << aliasString << endl;
@@ -450,14 +458,14 @@ QuerySchema* buildSelectQuery(
 			}
 			// 1. collect information about first repeated table name or alias
 			//    (potential ambiguity)
-			QValueList<int> *list = parseInfo.repeatedTablesAndAliases[tableOrAliasName];
+			Q3ValueList<int> *list = parseInfo.repeatedTablesAndAliases[tableOrAliasName];
 			if (list) {
 				//another table/alias with the same name
 				list->append( i );
 //				KexiDBDbg << "- another table/alias with name: " << tableOrAliasName << endl;
 			}
 			else {
-				list = new QValueList<int>();
+				list = new Q3ValueList<int>();
 				list->append( i );
 				parseInfo.repeatedTablesAndAliases.insert( tableOrAliasName, list );
 //				KexiDBDbg << "- first table/alias with name: " << tableOrAliasName << endl;
@@ -481,7 +489,7 @@ QuerySchema* buildSelectQuery(
 				}
 			}*/
 //			KexiDBDbg << "addTable: " << tname << endl;
-			querySchema->addTable( s, aliasString );
+			querySchema->addTable( s, aliasString.toLatin1() );
 		}
 	}
 
@@ -510,15 +518,15 @@ QuerySchema* buildSelectQuery(
 	//			isFieldWithAlias = true;
 				aliasVariable = e->toBinary()->right()->toVariable();
 				if (!aliasVariable) {
-					setError(i18n("Invalid alias definition for column \"%1\"")
-						.arg(columnExpr->toString())); //ok?
+					setError(i18n("Invalid alias definition for column \"%1\"",
+						columnExpr->toString())); //ok?
 					CLEANUP;
 					return 0;
 				}
 			}
-	
+
 			const int c = columnExpr->exprClass();
-			const bool isExpressionField = 
+			const bool isExpressionField =
 					c == KexiDBExpr_Const
 				|| c == KexiDBExpr_Unary
 				|| c == KexiDBExpr_Arithm
@@ -527,7 +535,7 @@ QuerySchema* buildSelectQuery(
 				|| c == KexiDBExpr_Const
 				|| c == KexiDBExpr_Function
 				|| c == KexiDBExpr_Aggregation;
-	
+
 			if (c == KexiDBExpr_Variable) {
 				//just a variable, do nothing, addColumn() will handle this
 			}
@@ -542,20 +550,20 @@ QuerySchema* buildSelectQuery(
 				e->toBinary()->m_larg = 0;
 			}
 			else {
-				setError(i18n("Invalid \"%1\" column definition").arg(e->toString())); //ok?
+				setError(i18n("Invalid \"%1\" column definition", e->toString())); //ok?
 				CLEANUP;
 				return 0;
 			}
-	
+
 			if (!addColumn( parseInfo, columnExpr )) {
 				CLEANUP;
 				return 0;
 			}
-			
+
 			if (aliasVariable) {
-//				KexiDBDbg << "ALIAS \"" << aliasVariable->name << "\" set for column " 
+//				KexiDBDbg << "ALIAS \"" << aliasVariable->name << "\" set for column "
 //					<< columnNum << endl;
-				querySchema->setColumnAlias(columnNum, aliasVariable->name.latin1());
+				querySchema->setColumnAlias(columnNum, aliasVariable->name.toLatin1());
 			}
 	/*		if (e->exprClass() == KexiDBExpr_SpecialBinary && dynamic_cast<BinaryExpr*>(e)
 				&& (e->type()==AS || e->type()==0))
@@ -567,11 +575,11 @@ QuerySchema* buildSelectQuery(
 					setError(i18n("Invalid column alias definition")); //ok?
 					return 0;
 				}
-				kdDebug() << "ALIAS \"" << aliasVariable->name << "\" set for column " 
+				kDebug() << "ALIAS \"" << aliasVariable->name << "\" set for column "
 					<< columnNum << endl;
-				querySchema->setColumnAlias(columnNum, aliasVariable->name.latin1());
+				querySchema->setColumnAlias(columnNum, aliasVariable->name.toLatin1());
 			}*/
-	
+
 			if (moveNext) {
 				colViews->list.next();
 //				++it;
@@ -609,8 +617,8 @@ QuerySchema* buildSelectQuery(
 						if (!orderByColumnList.appendColumn( *querySchema,
 							(*it).ascending, (*it).columnNumber-1 ))
 						{
-							setError(i18n("Could not define sorting - no column at position %1")
-								.arg((*it).columnNumber));
+							setError(i18n("Could not define sorting - no column at position %1",
+								(*it).columnNumber));
 							CLEANUP;
 							return 0;
 						}
@@ -619,7 +627,7 @@ QuerySchema* buildSelectQuery(
 						Field * f = querySchema->findTableField((*it).aliasOrName);
 						if (!f) {
 							setError(i18n("Could not define sorting - "
-								"column name or alias \"%1\" does not exist").arg((*it).aliasOrName));
+								"column name or alias \"%1\" does not exist", (*it).aliasOrName));
 							CLEANUP;
 							return 0;
 						}
@@ -630,9 +638,9 @@ QuerySchema* buildSelectQuery(
 		}
 	}
 
-//	KexiDBDbg << "Select ColViews=" << (colViews ? colViews->debugString() : QString::null)
-//		<< " Tables=" << (tablesList ? tablesList->debugString() : QString::null) << endl;
-	
+//	KexiDBDbg << "Select ColViews=" << (colViews ? colViews->debugString() : QString())
+//		<< " Tables=" << (tablesList ? tablesList->debugString() : QString()s) << endl;
+
 	CLEANUP;
 	return querySchema;
 }
