@@ -22,6 +22,8 @@
 #include <kexidb/connection.h>
 #include <kexidb/connection_p.h>
 #include <kdebug.h>
+//Added by qt3to4:
+#include <Q3CString>
 
 using namespace KexiDB;
 
@@ -42,9 +44,9 @@ PreparedStatement::~PreparedStatement()
 	delete m_whereFields;
 }
 
-QCString PreparedStatement::generateStatementString()
+Q3CString PreparedStatement::generateStatementString()
 {
-	QCString s(1024);
+	Q3CString s(1024);
 	if (m_type == SelectStatement) {
 //! @todo only tables and trivial queries supported for select...
 		s = "SELECT ";
@@ -55,7 +57,7 @@ QCString PreparedStatement::generateStatementString()
 				first = false;
 			else
 				s.append(", ");
-			s.append(it.current()->name().latin1());
+			s.append(it.current()->name().toLatin1());
 		}
 		first = true;
 		s.append(" WHERE ");
@@ -75,18 +77,18 @@ QCString PreparedStatement::generateStatementString()
 				continue;
 			}
 			m_whereFields->append(f);
-			s.append((*it).latin1());
+			s.append((*it).toLatin1());
 			s.append("=?");
 		}
 	}
 	else if (m_type == InsertStatement /*&& dynamic_cast<TableSchema*>(m_fields)*/) {
-//! @todo only tables supported for insert; what about views?
+  //! @todo only tables supported for insert; what about views?
 		
 		TableSchema *table = m_fields->fieldCount()>0 ? m_fields->field(0)->table() : 0;
 		if (!table)
 			return ""; //err
 
-		QCString namesList;
+		Q3CString namesList;
 		bool first = true;
 		const bool allTableFieldsUsed = dynamic_cast<TableSchema*>(m_fields); //we are using a selection of fields only
 		Field::ListIterator it = m_fields->fieldsIterator();
@@ -94,17 +96,17 @@ QCString PreparedStatement::generateStatementString()
 			if (first) {
 				s.append( "?" );
 				if (!allTableFieldsUsed)
-					namesList = it.current()->name().latin1();
+					namesList = it.current()->name().toLatin1();
 				first = false;
 			} else {
 				s.append( ",?" );
 				if (!allTableFieldsUsed)
-					namesList.append(QCString(", ")+it.current()->name().latin1());
+					namesList.append(Q3CString(", ")+it.current()->name().toLatin1());
 			}
 		}
 		s.append(")");
-		s.prepend(QCString("INSERT INTO ") + table->name().latin1()
-			+ (allTableFieldsUsed ? QCString() : (" (" + namesList + ")"))
+		s.prepend(Q3CString("INSERT INTO ") + table->name().toLatin1()
+			+ (allTableFieldsUsed ? "" : (" (" + namesList + ")"))
 			+ " VALUES (");
 	}
 	return s;
