@@ -27,18 +27,20 @@
 
 #include <assert.h>
 
-#include <qvaluelist.h>
-#include <qasciidict.h>
-#include <qptrdict.h>
-#include <qintdict.h>
+#include <q3valuelist.h>
+#include <q3asciidict.h>
+#include <q3ptrdict.h>
+#include <q3intdict.h>
 #include <qbitarray.h>
+//Added by qt3to4:
+#include <Q3CString>
 
 #include <kdebug.h>
 #include <klocale.h>
 
 using namespace KexiDB;
 
-QueryColumnInfo::QueryColumnInfo(Field *f, const QCString& _alias, bool _visible, 
+QueryColumnInfo::QueryColumnInfo(Field *f, const Q3CString& _alias, bool _visible, 
 	QueryColumnInfo *foreignColumn)
  : field(f), alias(_alias), visible(_visible), m_indexForVisibleLookupValue(-1)
  , m_foreignColumn(foreignColumn)
@@ -52,7 +54,7 @@ QueryColumnInfo::~QueryColumnInfo()
 QString QueryColumnInfo::debugString() const
 {
 	return field->name() + 
-		( alias.isEmpty() ? QString::null 
+		( alias.isEmpty() ? QString() 
 			: (QString::fromLatin1(" AS ") + QString(alias)) );
 }
 
@@ -116,7 +118,7 @@ class QuerySchemaPrivate
 				if (copy->columnsOrderExpanded)
 					columnsOrderExpanded = new QMap<QueryColumnInfo*,int>(*copy->columnsOrderExpanded);
 				if (copy->pkeyFieldsOrder)
-					pkeyFieldsOrder = new QValueVector<int>(*copy->pkeyFieldsOrder);
+					pkeyFieldsOrder = new Q3ValueVector<int>(*copy->pkeyFieldsOrder);
 				if (copy->whereExpr)
 					whereExpr = copy->whereExpr->copy();
 				if (copy->fakeRowIDCol)
@@ -156,7 +158,7 @@ class QuerySchemaPrivate
 			delete pkeyFieldsOrder;
 			pkeyFieldsOrder=0;
 			visibility.fill(false);
-			tablesBoundToColumns = QValueVector<int>(64,-1);
+			tablesBoundToColumns = Q3ValueVector<int>(64,-1);
 			tablePositionsForAliases.clear();
 			columnPositionsForAliases.clear();
 		}
@@ -177,7 +179,7 @@ class QuerySchemaPrivate
 				columnsOrderExpanded = 0;
 				delete autoincFields;
 				autoincFields = 0;
-				autoIncrementSQLFieldsList = QString::null;
+				autoIncrementSQLFieldsList.clear();
 				columnInfosByNameExpanded.clear();
 				columnInfosByName.clear();
 				delete ownedVisibleColumns;
@@ -185,16 +187,16 @@ class QuerySchemaPrivate
 			}
 		}
 
-		void setColumnAliasInternal(uint position, const QCString& alias)
+		void setColumnAliasInternal(uint position, const Q3CString& alias)
 		{
-			columnAliases.replace(position, new QCString(alias));
+			columnAliases.replace(position, new Q3CString(alias));
 			columnPositionsForAliases.replace(alias, new int(position));
-			maxIndexWithAlias = QMAX( maxIndexWithAlias, (int)position );
+			maxIndexWithAlias = qMax( maxIndexWithAlias, (int)position );
 		}
 
-		void setColumnAlias(uint position, const QCString& alias)
+		void setColumnAlias(uint position, const Q3CString& alias)
 		{
-			QCString *oldAlias = columnAliases.take(position);
+			Q3CString *oldAlias = columnAliases.take(position);
 			if (oldAlias) {
 				tablePositionsForAliases.remove(*oldAlias);
 				delete oldAlias;
@@ -213,7 +215,7 @@ class QuerySchemaPrivate
 			return !columnAliases.isEmpty();
 		}
 
-		QCString* columnAlias(uint position)
+		Q3CString* columnAlias(uint position)
 		{
 			tryRegenerateExprAliases();
 			return columnAliases[position];
@@ -241,14 +243,14 @@ class QuerySchemaPrivate
 			Field *f;
 			uint p=0;
 			uint colNum=0; //used to generate a name
-			QCString columnAlias;
+			Q3CString columnAlias;
 			for (Field::ListIterator it(query->fieldsIterator()); (f = it.current()); ++it, p++) {
 				if (f->isExpression() && !columnAliases[p]) {
 					//missing
 					for (;;) { //find 1st unused
 						colNum++;
-						columnAlias = (i18n("short for 'expression' word (only latin letters, please)", "expr") 
-							+ QString::number(colNum)).latin1();
+						columnAlias = (i18nc("short for 'expression' word (only latin letters, please)", "expr").toLatin1() 
+							+ QString::number(colNum)).toLatin1();
 						if (!tablePositionsForAliases[columnAlias])
 							break;
 					}
@@ -259,11 +261,11 @@ class QuerySchemaPrivate
 		}
 
 		/*! Used to mapping columns to its aliases for this query */
-		QIntDict<QCString> columnAliases;
+		Q3IntDict<Q3CString> columnAliases;
 
 	public:
 		/*! Used to mapping tables to its aliases for this query */
-		QIntDict<QCString> tableAliases;
+		Q3IntDict<Q3CString> tableAliases;
 		
 		/*! Helper used with aliases */
 		int maxIndexWithAlias;
@@ -300,7 +302,7 @@ class QuerySchemaPrivate
 		
 		/*! A cache for autoIncrementSQLFieldsList(). */
 		QString autoIncrementSQLFieldsList;
-		QGuardedPtr<Driver> lastUsedDriverForAutoIncrementSQLFieldsList;
+		QPointer<Driver> lastUsedDriverForAutoIncrementSQLFieldsList;
 
 		/*! A map for fast lookup of query columns' order (unexpanded version). */
 		QMap<QueryColumnInfo*,int> *columnsOrder;
@@ -316,7 +318,7 @@ class QuerySchemaPrivate
 //		QValueList<bool> detailedVisibility;
 
 		/*! order of PKEY fields (e.g. for updateRow() ) */
-		QValueVector<int> *pkeyFieldsOrder;
+		Q3ValueVector<int> *pkeyFieldsOrder;
 
 		/*! number of PKEY fields within the query */
 		uint pkeyFieldsCount;
@@ -342,20 +344,20 @@ class QuerySchemaPrivate
 		 - second coulmn is not specially bound (othertable.x isn't ambiguous)
 		 - third column is bound to table 1 "t2"
 		*/
-		QValueVector<int> tablesBoundToColumns;
+		Q3ValueVector<int> tablesBoundToColumns;
 		
 		/*! Collects table positions for aliases: used in tablePositionForAlias(). */
-		QAsciiDict<int> tablePositionsForAliases;
+		Q3AsciiDict<int> tablePositionsForAliases;
 
 		/*! Collects column positions for aliases: used in columnPositionForAlias(). */
-		QAsciiDict<int> columnPositionsForAliases;
+		Q3AsciiDict<int> columnPositionsForAliases;
 
 		/*! WHERE expression */
 		BaseExpr *whereExpr;
 
-		QDict<QueryColumnInfo> columnInfosByNameExpanded;
+		Q3Dict<QueryColumnInfo> columnInfosByNameExpanded;
 
-		QDict<QueryColumnInfo> columnInfosByName; //!< Same as columnInfosByNameExpanded but asterisks are skipped
+		Q3Dict<QueryColumnInfo> columnInfosByName; //!< Same as columnInfosByNameExpanded but asterisks are skipped
 
 		//! field schemas created for multiple joined columns like a||' '||b||' '||c
 		Field::List *ownedVisibleColumns;
@@ -431,7 +433,7 @@ QString OrderByColumn::toSQLString(bool includeTableName, Driver *drv, int ident
 	}
 	else {
 		if (includeTableName) {
-			tableName = m_column->field->table()->name();
+			tableName = m_field->table()->name();
 			if (drv)
 				tableName = drv->escapeIdentifier(tableName, identifierEscaping);
 			tableName += ".";
@@ -567,9 +569,9 @@ QuerySchema::QuerySchema(TableSchema& tableSchema)
 {
 	d->masterTable = &tableSchema;
 	init();
-/*	if (!d->masterTable) {
+	/*if (!d->masterTable) {
 		KexiDBWarn << "QuerySchema(TableSchema*): !d->masterTable" << endl;
-		m_name = QString::null;
+		m_name.clear();
 		return;
 	}*/
 	addTable(d->masterTable);
@@ -598,7 +600,7 @@ QuerySchema::QuerySchema(const QuerySchema& querySchema)
 		Field *f;
 		if (dynamic_cast<QueryAsterisk*>( f_it.current() )) {
 			f = f_it.current()->copy();
-			if (f_it.current()->m_parent == &querySchema)
+			if (static_cast<const KexiDB::FieldList *>(f_it.current()->m_parent) == &querySchema)
 				f->m_parent = this;
 		}
 		else
@@ -653,7 +655,7 @@ FieldList& QuerySchema::insertField(uint position, Field *field,
 			<<"' must contain table information!" <<endl;
 		return *this;
 	}
-	if (fieldCount()>=d->visibility.size()) {
+	if ((int)fieldCount()>=d->visibility.size()) {
 		d->visibility.resize(d->visibility.size()*2);
 		d->tablesBoundToColumns.resize(d->tablesBoundToColumns.size()*2);
 	}
@@ -710,7 +712,7 @@ FieldList& QuerySchema::insertField(uint position, Field *field,
 
 int QuerySchema::tableBoundToColumn(uint columnPosition) const
 {
-	if (columnPosition > d->tablesBoundToColumns.count()) {
+	if ((int)columnPosition > d->tablesBoundToColumns.count()) {
 		KexiDBWarn << "QuerySchema::tableBoundToColumn(): columnPosition (" << columnPosition
 			<< ") out of range" << endl;
 		return -1;
@@ -814,7 +816,7 @@ QString QuerySchema::debugString()
 	for (uint i = 0; i<fieldCount(); i++) {
 		int tablePos = tableBoundToColumn(i);
 		if (tablePos>=0) {
-			QCString tAlias = tableAlias(tablePos);
+			Q3CString tAlias = tableAlias(tablePos);
 			if (!tAlias.isEmpty()) {
 				dbg2 += (QString::fromLatin1(" field \"") + FieldList::field(i)->name() 
 					+ "\" uses alias \"" + QString(tAlias) + "\" of table \""
@@ -845,7 +847,7 @@ QString QuerySchema::debugString()
 	else {
 		Field::ListIterator it( m_fields );
 		for (int i=0; it.current(); ++it, i++) {
-			QCString *alias = d->columnAlias(i);
+			Q3CString *alias = d->columnAlias(i);
 			if (alias)
 				aliases += (QString("field #%1: ").arg(i) 
 					+ (it.current()->name().isEmpty() ? "<noname>" : it.current()->name())
@@ -860,7 +862,7 @@ QString QuerySchema::debugString()
 		aliases = "";
 		TableSchema::ListIterator t_it(d->tables);
 		for (int i=0; t_it.current(); ++t_it, i++) {
-			QCString *alias = d->tableAliases[i];
+			Q3CString *alias = d->tableAliases[i];
 			if (alias)
 				aliases += (QString("table #%1: ").arg(i) 
 					+ (t_it.current()->name().isEmpty() ? "<noname>" : t_it.current()->name())
@@ -868,7 +870,7 @@ QString QuerySchema::debugString()
 		}
 	}
 	dbg += QString("-TABLE ALIASES:\n" + aliases);
-	QString where = d->whereExpr ? d->whereExpr->debugString() : QString::null;
+	QString where = d->whereExpr ? d->whereExpr->debugString() : QString();
 	if (!where.isEmpty())
 		dbg += (QString("\n-WHERE EXPRESSION:\n") + where);
 	if (!orderByColumnList().isEmpty())
@@ -888,7 +890,7 @@ TableSchema* QuerySchema::masterTable() const
 	int num = 0;
 	QString tableNameLower;
 	for (TableSchema::ListIterator it(d->tables); it.current(); ++it, num++) {
-		if (!tableNameLower.isEmpty() && it.current()->name().lower()!=tableNameLower) {
+		if (!tableNameLower.isEmpty() && it.current()->name().toLower()!=tableNameLower) {
 			//two or more different tables
 			return 0;
 		}
@@ -908,7 +910,7 @@ TableSchema::List* QuerySchema::tables() const
 	return &d->tables;
 }
 
-void QuerySchema::addTable(TableSchema *table, const QCString& alias)
+void QuerySchema::addTable(TableSchema *table, const Q3CString& alias)
 {
 	KexiDBDbg << "QuerySchema::addTable() " << (void *)table 
 		<< " alias=" << alias << endl;
@@ -919,11 +921,11 @@ void QuerySchema::addTable(TableSchema *table, const QCString& alias)
 	//-it has alias
 	//-it has no alias but there is no such table on the list
 	if (alias.isEmpty() && d->tables.findRef(table)!=-1) {
-		const QString& tableNameLower = table->name().lower();
-		const QString& aliasLower = QString(alias.lower());
+		const QString& tableNameLower = table->name().toLower();
+		const QString& aliasLower = QString(alias.toLower());
 		int num = 0;
 		for (TableSchema::ListIterator it(d->tables); it.current(); ++it, num++) {
-			if (it.current()->name().lower()==tableNameLower) {
+			if (it.current()->name().toLower()==tableNameLower) {
 				const QString& tAlias = tableAlias(num);
 				if (tAlias == aliasLower) {
 					KexiDBWarn << "QuerySchema::addTable(): table with \"" 
@@ -954,7 +956,7 @@ TableSchema* QuerySchema::table(const QString& tableName) const
 {
 //TODO: maybe use tables_byname?
 	for (TableSchema::ListIterator it(d->tables); it.current(); ++it) {
-		if (it.current()->name().lower()==tableName.lower())
+		if (it.current()->name().toLower()==tableName.toLower())
 			return it.current();
 	}
 	return 0;
@@ -985,10 +987,10 @@ Field* QuerySchema::findTableField(const QString &tableOrTableAndFieldName) cons
 	return tableSchema->field(fieldName);
 }
 
-QCString QuerySchema::columnAlias(uint position) const
+Q3CString QuerySchema::columnAlias(uint position) const
 {
-	QCString *a = d->columnAlias(position);
-	return a ? *a : QCString();
+	Q3CString *a = d->columnAlias(position);
+	return a ? *a : Q3CString();
 }
 
 bool QuerySchema::hasColumnAlias(uint position) const
@@ -996,14 +998,14 @@ bool QuerySchema::hasColumnAlias(uint position) const
 	return d->columnAlias(position)!=0;
 }
 
-void QuerySchema::setColumnAlias(uint position, const QCString& alias)
+void QuerySchema::setColumnAlias(uint position, const Q3CString& alias)
 {
 	if (position >= m_fields.count()) {
 		KexiDBWarn << "QuerySchema::setColumnAlias(): position ("  << position 
 			<< ") out of range!" << endl;
 		return;
 	}
-	QCString fixedAlias = alias.stripWhiteSpace();
+	Q3CString fixedAlias = alias.trimmed();
 	Field *f = FieldList::field(position);
 	if (f->captionOrName().isEmpty() && fixedAlias.isEmpty()) {
 		KexiDBWarn << "QuerySchema::setColumnAlias(): position ("  << position 
@@ -1013,13 +1015,13 @@ void QuerySchema::setColumnAlias(uint position, const QCString& alias)
 	d->setColumnAlias(position, fixedAlias);
 }
 
-QCString QuerySchema::tableAlias(uint position) const
+Q3CString QuerySchema::tableAlias(uint position) const
 {
-	QCString *a = d->tableAliases[position];
-	return a ? *a : QCString();
+	Q3CString *a = d->tableAliases[position];
+	return a ? *a : Q3CString();
 }
 
-int QuerySchema::tablePositionForAlias(const QCString& name) const
+int QuerySchema::tablePositionForAlias(const Q3CString& name) const
 {
 	int *num = d->tablePositionsForAliases[name];
 	if (!num)
@@ -1031,19 +1033,19 @@ int QuerySchema::tablePosition(const QString& tableName) const
 {
 	int num = 0;
 	for (TableSchema::ListIterator it(d->tables); it.current(); ++it, num++) {
-		if (it.current()->name().lower()==tableName.lower())
+		if (it.current()->name().toLower()==tableName.toLower())
 			return num;
 	}
 	return -1;
 }
 
-QValueList<int> QuerySchema::tablePositions(const QString& tableName) const
+Q3ValueList<int> QuerySchema::tablePositions(const QString& tableName) const
 {
 	int num = 0;
-	QValueList<int> result;
-	const QString& tableNameLower = tableName.lower();
+	Q3ValueList<int> result;
+	const QString& tableNameLower = tableName.toLower();
 	for (TableSchema::ListIterator it(d->tables); it.current(); ++it, num++) {
-		if (it.current()->name().lower()==tableNameLower) {
+		if (it.current()->name().toLower()==tableNameLower) {
 			result += num;
 		}
 	}
@@ -1055,7 +1057,7 @@ bool QuerySchema::hasTableAlias(uint position) const
 	return d->tableAliases[position]!=0;
 }
 
-int QuerySchema::columnPositionForAlias(const QCString& name) const
+int QuerySchema::columnPositionForAlias(const Q3CString& name) const
 {
 	int *num = d->columnPositionsForAliases[name];
 	if (!num)
@@ -1063,16 +1065,16 @@ int QuerySchema::columnPositionForAlias(const QCString& name) const
 	return *num;
 }
 
-void QuerySchema::setTableAlias(uint position, const QCString& alias)
+void QuerySchema::setTableAlias(uint position, const Q3CString& alias)
 {
 	if (position >= d->tables.count()) {
 		KexiDBWarn << "QuerySchema::setTableAlias(): position ("  << position 
 			<< ") out of range!" << endl;
 		return;
 	}
-	QCString fixedAlias = alias.stripWhiteSpace();
+	Q3CString fixedAlias = alias.trimmed();
 	if (fixedAlias.isEmpty()) {
-		QCString *oldAlias = d->tableAliases.take(position);
+		Q3CString *oldAlias = d->tableAliases.take(position);
 		if (oldAlias) {
 			d->tablePositionsForAliases.remove(*oldAlias);
 			delete oldAlias;
@@ -1080,9 +1082,9 @@ void QuerySchema::setTableAlias(uint position, const QCString& alias)
 //			d->maxIndexWithTableAlias = -1;
 	}
 	else {
-		d->tableAliases.replace(position, new QCString(fixedAlias));
+		d->tableAliases.replace(position, new Q3CString(fixedAlias));
 		d->tablePositionsForAliases.replace(fixedAlias, new int(position));
-//		d->maxIndexWithTableAlias = QMAX( d->maxIndexWithTableAlias, (int)index );
+//		d->maxIndexWithTableAlias = qMax( d->maxIndexWithTableAlias, (int)index );
 	}
 }
 
@@ -1144,7 +1146,7 @@ QueryColumnInfo::Vector QuerySchema::fieldsExpanded(FieldsExpandedOptions option
 			if (options == WithInternalFieldsAndRowID) {
 				if (!d->fakeRowIDField) {
 					d->fakeRowIDField = new Field("rowID", Field::BigInteger);
-					d->fakeRowIDCol = new QueryColumnInfo(d->fakeRowIDField, QCString(), true);
+					d->fakeRowIDCol = new QueryColumnInfo(d->fakeRowIDField, Q3CString(), true);
 				}
 				tmpFieldsExpandedWithInternal->insert( 
 					fieldsExpandedVectorSize + internalFieldsCount, d->fakeRowIDCol );
@@ -1157,7 +1159,7 @@ QueryColumnInfo::Vector QuerySchema::fieldsExpanded(FieldsExpandedOptions option
 		return *d->fieldsExpanded;
 
 	//options == Unique:
-	QDict<char> columnsAlreadyFound;
+	Q3Dict<char> columnsAlreadyFound;
 	QueryColumnInfo::Vector result( d->fieldsExpanded->count() ); //initial size is set
 //	QMapConstIterator<QueryColumnInfo*, bool> columnsAlreadyFoundIt;
 	//compute unique list
@@ -1225,7 +1227,7 @@ void QuerySchema::computeFieldsExpanded()
 				Field::List *ast_fields = static_cast<QueryAsterisk*>(f)->table()->fields();
 				for (Field *ast_f = ast_fields->first(); ast_f; ast_f=ast_fields->next()) {
 //					d->detailedVisibility += isFieldVisible(fieldPosition);
-					QueryColumnInfo *ci = new QueryColumnInfo(ast_f, QCString()/*no field for asterisk!*/,
+					QueryColumnInfo *ci = new QueryColumnInfo(ast_f, Q3CString()/*no field for asterisk!*/,
 						isColumnVisible(fieldPosition));
 					list.append( ci );
 					KexiDBDbg << "QuerySchema::computeFieldsExpanded(): caching (unexpanded) columns order: "
@@ -1242,7 +1244,7 @@ void QuerySchema::computeFieldsExpanded()
 //! \todo (js): perhaps not all fields should be appended here
 //						d->detailedVisibility += isFieldVisible(fieldPosition);
 //						list.append(tab_f);
-						QueryColumnInfo *ci = new QueryColumnInfo(tab_f, QCString()/*no field for asterisk!*/,
+						QueryColumnInfo *ci = new QueryColumnInfo(tab_f, Q3CString()/*no field for asterisk!*/,
 							isColumnVisible(fieldPosition));
 						list.append( ci );
 						KexiDBDbg << "QuerySchema::computeFieldsExpanded(): caching (unexpanded) columns order: "
@@ -1303,7 +1305,7 @@ void QuerySchema::computeFieldsExpanded()
 					}
 
 					lookup_list.append( 
-						new QueryColumnInfo(visibleColumn, QCString(), true/*visible*/, ci/*foreign*/) );
+						new QueryColumnInfo(visibleColumn, Q3CString(), true/*visible*/, ci/*foreign*/) );
 /*
 					//add visibleField to the list of SELECTed fields if it is not yes present there
 					if (!findTableField( visibleField->table()->name()+"."+visibleField->name() )) {
@@ -1330,10 +1332,13 @@ void QuerySchema::computeFieldsExpanded()
 				Field *boundField = boundColumnInfo->field;
 				if (!boundField)
 					continue;
-				const QValueList<uint> visibleColumns( lookupFieldSchema->visibleColumns() );
+				const Q3ValueList<uint> visibleColumns( lookupFieldSchema->visibleColumns() );
 				bool ok = true;
 				// all indices in visibleColumns should be in [0..lookupQueryFieldsExpanded.size()-1]
-				foreach (QValueList<uint>::ConstIterator, visibleColumnsIt, visibleColumns) {
+				for (Q3ValueList<uint>::ConstIterator
+					visibleColumnsIt(visibleColumns.constBegin());
+					visibleColumnsIt!=visibleColumns.constEnd(); ++visibleColumnsIt)
+				{
 					if ((*visibleColumnsIt) >= lookupQueryFieldsExpanded.count()) {
 						ok = false;
 						break;
@@ -1363,7 +1368,7 @@ void QuerySchema::computeFieldsExpanded()
 				}
 
 				lookup_list.append( 
-					new QueryColumnInfo(visibleColumn, QCString(), true/*visible*/, ci/*foreign*/) );
+					new QueryColumnInfo(visibleColumn, Q3CString(), true/*visible*/, ci/*foreign*/) );
 /*
 				//add visibleField to the list of SELECTed fields if it is not yes present there
 				if (!findTableField( visibleField->table()->name()+"."+visibleField->name() )) {
@@ -1439,7 +1444,7 @@ void QuerySchema::computeFieldsExpanded()
 	}
 
 	//remove duplicates for lookup fields
-	QDict<uint> lookup_dict(101); //used to fight duplicates and to update QueryColumnInfo::indexForVisibleLookupValue()
+	Q3Dict<uint> lookup_dict(101); //used to fight duplicates and to update QueryColumnInfo::indexForVisibleLookupValue()
 	                         // (a mapping from table.name string to uint* lookupFieldIndex
 	lookup_dict.setAutoDelete(true);
 	i=0;
@@ -1531,15 +1536,16 @@ void QuerySchema::computeFieldsExpanded()
 			Field *boundField = boundColumnInfo->field;
 			if (!boundField)
 				continue;
-			const QValueList<uint> visibleColumns( lookupFieldSchema->visibleColumns() );
-			Field *visibleColumn = 0;
+			const Q3ValueList<uint> visibleColumns( lookupFieldSchema->visibleColumns() );
 			// for single visible column, just add it as-is
 			if (visibleColumns.count() == 1) {
-				visibleColumn = lookupQueryFieldsExpanded[ visibleColumns.first() ]->field;
-				const QString key( lookupColumnKey(ci->field, visibleColumn) );
-				uint *index = lookup_dict[ key ];
-				if (index)
-					ci->setIndexForVisibleLookupValue( d->fieldsExpanded->size() + *index );
+				if (lookupQueryFieldsExpanded.count() > visibleColumns.first()) { // sanity check
+					Field *visibleColumn = lookupQueryFieldsExpanded[ visibleColumns.first() ]->field;
+					const QString key( lookupColumnKey(ci->field, visibleColumn) );
+					uint *index = lookup_dict[ key ];
+					if (index)
+						ci->setIndexForVisibleLookupValue( d->fieldsExpanded->size() + *index );
+				}
 			}
 			else {
 				const QString key( QString::fromLatin1("[multiple_visible_fields_%1]_%2.%3")
@@ -1568,20 +1574,20 @@ QMap<QueryColumnInfo*,int> QuerySchema::columnsOrder(ColumnsOrderOptions options
 	return *d->columnsOrderExpanded;
 }
 
-QValueVector<int> QuerySchema::pkeyFieldsOrder()
+Q3ValueVector<int> QuerySchema::pkeyFieldsOrder()
 {
 	if (d->pkeyFieldsOrder)
 		return *d->pkeyFieldsOrder;
 
 	TableSchema *tbl = masterTable();
 	if (!tbl || !tbl->primaryKey())
-		return QValueVector<int>();
+		return Q3ValueVector<int>();
 
 	//get order of PKEY fields (e.g. for rows updating or inserting )
 	IndexSchema *pkey = tbl->primaryKey();
 	pkey->debug();
 	debug();
-	d->pkeyFieldsOrder = new QValueVector<int>( pkey->fieldCount(), -1 );
+	d->pkeyFieldsOrder = new Q3ValueVector<int>( pkey->fieldCount(), -1 );
 
 	const uint fCount = fieldsExpanded().count();
 	d->pkeyFieldsCount = 0;
@@ -1648,7 +1654,7 @@ QueryColumnInfo::List* QuerySchema::autoIncrementFields()
 QString QuerySchema::sqlColumnsList(QueryColumnInfo::List* infolist, Driver *driver)
 {
 	if (!infolist)
-		return QString::null;
+		return QString();
 	QString result;
 	result.reserve(256);
 	QueryColumnInfo::ListIterator it( *infolist );
@@ -1700,7 +1706,7 @@ void QuerySchema::addToWhereExpression(KexiDB::Field *field, const QVariant& val
 		KexiDBExpr_Relational, 
 		new ConstExpr( token, value ),
 		relation,
-		new VariableExpr((field->table() ? (field->table()->name()+".") : QString::null)+field->name())
+		new VariableExpr((field->table() ? (field->table()->name()+".") : QString())+field->name())
 	);
 	if (d->whereExpr) {
 		d->whereExpr = new BinaryExpr(
@@ -1837,7 +1843,7 @@ void QueryAsterisk::setTable(TableSchema *table)
 	m_table=table;
 }
 
-QString QueryAsterisk::debugString()
+QString QueryAsterisk::debugString() const
 {
 	QString dbg;
 	if (isAllTableAsterisk()) {
