@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 2003-2005 Jaroslaw Staniek <js@iidea.pl>
+   Copyright (C) 2003-2007 Jaroslaw Staniek <js@iidea.pl>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -20,60 +20,215 @@
 #ifndef KEXIDB_QUERY_H
 #define KEXIDB_QUERY_H
 
-#include <qvaluevector.h>
+#include <q3valuevector.h>
 #include <qstring.h>
 #include <qmap.h>
-#include <qptrlist.h>
+#include <q3ptrlist.h>
+//Added by qt3to4:
+#include <Q3ValueList>
+#include <Q3CString>
 
-#include <kexidb/fieldlist.h>
-#include <kexidb/schemadata.h>
-#include <kexidb/tableschema.h>
-#include <kexidb/relationship.h>
+#include "fieldlist.h"
+#include "schemadata.h"
+#include "tableschema.h"
+#include "relationship.h"
 
 namespace KexiDB {
 
 class Connection;
 class QueryAsterisk;
 class QuerySchemaPrivate;
+class QuerySchemaParameter;
+typedef Q3ValueList<QuerySchemaParameter> QuerySchemaParameterList;
 
-/*! Helper class that assigns additional information for the column in a query:
-	- alias
-	- visibility
+//! @short Helper class that assigns additional information for the column in a query
+/*! The following information is assigned:
+	 - alias
+	 - visibility
 	QueryColumnInfo::Vector is created and returned by QuerySchema::fieldsExpanded().
-	It's efficiently cached there.
+	It is efficiently cached within the QuerySchema object.
 */
 class KEXI_DB_EXPORT QueryColumnInfo
 {
 	public:
-		typedef QPtrVector<QueryColumnInfo> Vector;
-		typedef QPtrList<QueryColumnInfo> List;
-		typedef QPtrListIterator<QueryColumnInfo> ListIterator;
+		typedef Q3PtrVector<QueryColumnInfo> Vector;
+		typedef Q3PtrList<QueryColumnInfo> List;
+		typedef Q3PtrListIterator<QueryColumnInfo> ListIterator;
 
-		QueryColumnInfo(Field *f, QCString _alias, bool _visible)
-		 : field(f), alias(_alias), visible(_visible)
-		{
-		}
-		~QueryColumnInfo()
-		{
-		}
-		//! \return alias if it's not empty, field's name otherwise.
-		inline QCString aliasOrName() const { 
-			return alias.isEmpty() ? field->name().latin1() : (const char*)alias; 
+		QueryColumnInfo(Field *f, const Q3CString& _alias, bool _visible, QueryColumnInfo *foreignColumn = 0);
+		~QueryColumnInfo();
+
+		//! \return alias if it is not empty, field's name otherwise.
+		inline Q3CString aliasOrName() const {
+			if ( alias.isEmpty() ) {
+				return Q3CString( field->name().toLatin1() );
+			} else {
+				return Q3CString( (const char*)alias );
+			}
 		}
 
-		//! \return field's caption if it's not empty, field's alias otherwise.
+		//! \return field's caption if it is not empty, field's alias otherwise.
 		//! If alias is also empty - returns field's name.
 		inline QString captionOrAliasOrName() const {
 			return field->caption().isEmpty() ? QString(aliasOrName()) : field->caption(); }
 
 		Field *field;
-		QCString alias;
+		Q3CString alias;
+
+		/*! \return index of column with visible lookup value within the 'fields expanded' vector.
+		 -1 means no visible lookup value is available because there is no lookup for the column defined.
+		 Cached for efficiency as we use this information frequently.
+		 @see LookupFieldSchema::visibleVolumn() */
+		inline int indexForVisibleLookupValue() const { return m_indexForVisibleLookupValue; }
+
+		/*! Sets index of column with visible lookup value within the 'fields expanded' vector. */
+		inline void setIndexForVisibleLookupValue(int index) { m_indexForVisibleLookupValue = index; }
+
+		//! \return non-0 if this column is a visible column for other column
+		QueryColumnInfo *foreignColumn() const { return m_foreignColumn; }
+
+		/*! \return string for debugging purposes. */
+		QString debugString() const;
+
+		//! true if this column is visible to the user (and its data is fetched by the engine)
 		bool visible : 1;
+
+	private:
+		/*! Index of column with visible lookup value within the 'fields expanded' vector.
+		 @see indexForVisibleLookupValue() */
+		int m_indexForVisibleLookupValue;
+
+		//! Non-0 if this column is a visible column for \a m_foreignColumn
+		QueryColumnInfo *m_foreignColumn;
 };
 
-/*! KexiDB::QuerySchema provides information about database query
-	that can be executed using SQL database engine. 
-*/
+//! @short KexiDB::OrderByColumn provides information about a single query column used for sorting
+/*! The column can be expression or table field. */
+class KEXI_DB_EXPORT OrderByColumn
+{
+	public:
+		typedef Q3ValueListConstIterator<OrderByColumn> ListConstIterator;
+		OrderByColumn();
+		OrderByColumn(QueryColumnInfo& column, bool ascending = true, int pos = -1);
+		
+		//! Like above but used when the field \a field is not present on the list of columns.
+		//! (e.g. SELECT a FROM t ORDER BY b; where T is a table with fields (a,b)). 
+		OrderByColumn(Field& field, bool ascending = true);
+
+		~OrderByColumn();
+
+		//! A column to sort.
+		inline QueryColumnInfo* column() const { return m_column; }
+
+		/*! A helper for column() that allows you to know that sorting column 
+		 was defined by providing its position. -1 by default.
+		 Example query: SELECT a, b FROM T ORDER BY 2 */
+		inline int position() const { return m_pos; }
+
+		//! A field to sort, used only in case when the second constructor was used.
+		inline Field *field() const { return m_field; }
+
+		//! \return true if ascending sorting should be performed (the default).
+		inline bool ascending() const { return m_ascending; }
+
+		//! \return true if this column is thesame as \a col
+		bool operator== ( const OrderByColumn& col ) const 
+			{ return m_column==col.m_column && m_field==col.m_field 
+				&& m_ascending==col.m_ascending; }
+
+		/*! \return string for debugging purposes. */
+		QString debugString() const;
+
+		/*! \return a string like "name ASC" usable for building a SQL statement. 
+		 If \a includeTableNames is true (the default) field is output in a form 
+		 of "tablename.fieldname" (but only if fieldname is not a name of alias).
+		 \a drv and \a identifierEscaping are used for escaping the table and field identifiers. */
+		QString toSQLString(bool includeTableName = true, 
+			Driver *drv = 0, int identifierEscaping = Driver::EscapeDriver|Driver::EscapeAsNecessary) const;
+
+	protected:
+		//! Column to sort
+		QueryColumnInfo* m_column; //!< 0 if m_field is non-0.
+		int m_pos; //!< A helper for m_column that allows to know that sorting column 
+		           //!< was defined by providing its position. -1 by default.
+		           //!< e.g. SELECT a, b FROM T ORDER BY 2
+		Field* m_field; //!< Used only in case when the second contructor is used.
+
+		//! true if ascending sorting should be performed (the default).
+		bool m_ascending : 1;
+};
+
+//! A base for KexiDB::OrderByColumnList
+typedef Q3ValueList<OrderByColumn> OrderByColumnListBase;
+
+//! @short KexiDB::OrderByColumnList provides list of sorted columns for a query schema
+class KEXI_DB_EXPORT OrderByColumnList : protected OrderByColumnListBase
+{
+	public:
+		/*! Constructs empty list of ordered columns. */
+		OrderByColumnList();
+
+		~OrderByColumnList();
+
+		/*! Appends multiple fields for sorting. \a querySchema 
+		 is used to find appropriate field or alias name.
+		 \return false if there is at least one name for which a field or alias name does not exist
+		 (all the newly appended fields are removed in this case) */
+		bool appendFields(QuerySchema& querySchema,
+			const QString& field1, bool ascending1 = true, 
+			const QString& field2 = QString(), bool ascending2 = true, 
+			const QString& field3 = QString(), bool ascending3 = true, 
+			const QString& field4 = QString(), bool ascending4 = true, 
+			const QString& field5 = QString(), bool ascending5 = true);
+
+		/*! Appends column \a columnInfo. Ascending sorting is set is \a ascending is true. */
+		void appendColumn(QueryColumnInfo& columnInfo, bool ascending = true);
+		
+		/*! Appends a field \a field. Ascending sorting is set is \a ascending is true. 
+		 Read documentation of \ref OrderByColumn(const Field& field, bool ascending = true)
+		 for more info. */
+		void appendField(Field& field, bool ascending = true);
+
+		/*! Appends field with a name \a field. Ascending sorting is set is \a ascending is true. 
+		 \return true on successful appending, and false if there is no such field or alias 
+		 name in the \a querySchema. */
+		bool appendField(QuerySchema& querySchema, const QString& fieldName, 
+			bool ascending = true);
+
+		/*! Appends a column that is at position \a pos (counted from 0). 
+		 \return true on successful adding and false if there is no such position \a pos. */
+		bool appendColumn(QuerySchema& querySchema, bool ascending = true, int pos = -1);
+
+		/*! Appends \a column to the list. */
+		void appendColumn(const OrderByColumn& column);
+		
+		/*! \return true if the list is empty. */
+		bool isEmpty() const { return OrderByColumnListBase::isEmpty(); }
+		
+		/*! \return number of elements of the list. */
+		uint count() const { return OrderByColumnListBase::count(); }
+
+		/*! Removes all elements from the list. */
+		void clear() { OrderByColumnListBase::clear(); }
+
+		const_iterator constBegin () const { return OrderByColumnListBase::constBegin(); }
+		const_iterator constEnd () const { return OrderByColumnListBase::constEnd(); }
+
+		/*! \return string for debugging purposes. */
+		QString debugString() const;
+		
+		/*! \return a string like "name ASC, 2 DESC" usable for building a SQL statement.
+		 If \a includeTableNames is true (the default) fields are output in a form 
+		 of "tablename.fieldname". 
+		 \a drv and \a identifierEscaping are used for escaping the table and field identifiers. */
+		QString toSQLString(bool includeTableNames = true, 
+			Driver *drv = 0, int identifierEscaping = Driver::EscapeDriver|Driver::EscapeAsNecessary) const;
+};
+
+//! @short KexiDB::QuerySchema provides information about database query
+/*! The query that can be executed using KexiDB-compatible SQL database engine 
+ or used as an introspection tool. KexiDB parser builds QuerySchema objects
+ by parsing SQL statements. */
 class KEXI_DB_EXPORT QuerySchema : public FieldList, public SchemaData
 {
 	public:
@@ -82,16 +237,24 @@ class KEXI_DB_EXPORT QuerySchema : public FieldList, public SchemaData
 
 		/*! Creates query schema object that is equivalent to "SELECT * FROM table" 
 		 sql command. Schema of \a table is used to contruct this query -- 
-		 it is defined just by defining "all-tables query asterisk" (see QueryAsterisk)
-		 item. Properties such as the name and caption of the query are inherited 
+		 it is defined by just adding all the fields to the query in natural order.
+		 To avoid problems (e.g. with fields added outside of Kexi using ALTER TABLE) 
+		 we do not use "all-tables query asterisk" (see QueryAsterisk) item to achieve 
+		 this effect. 
+
+		 Properties such as the name and caption of the query are inherited 
 		 from table schema.
 
 		 We consider that query schema based on \a table is not (a least yet) stored 
 		 in a system table, so query connection is set to NULL
 		 (even if \a tableSchema's connection is not NULL).
 		 Id of the created query is set to 0. */
-		QuerySchema(TableSchema* tableSchema);
-		
+		QuerySchema(TableSchema& tableSchema);
+
+		/*! Copy constructor. Creates deep copy of \a querySchema. 
+		 QueryAsterisk objects are deeply copied while only pointers to Field objects are copied. */
+		QuerySchema(const QuerySchema& querySchema);
+
 		virtual ~QuerySchema();
 		
 		/*! Inserts \a field to the columns list at \a position.
@@ -111,23 +274,26 @@ class KEXI_DB_EXPORT QuerySchema : public FieldList, public SchemaData
 		virtual FieldList& insertField(uint position, Field *field);
 
 		/* Like above method, but you can also set column's visibility. 
-		 New column isn't bound explicity to any table.
+		 New column is not bound explicitly to any table.
 		*/
 		FieldList& insertField(uint position, Field *field, bool visible);
 
-		/* Like above method, but you can also explicity bound the new column
+		/* Like above method, but you can also explicitly bound the new column
 		 to specific position on tables list. 
+		 If \a visible is true (the default), the field will be visible. 
 		 If bindToTable==-1, no particular table should be bound.
 		 @see tableBoundToColumn(uint columnPosition) */
 		FieldList& insertField(uint position, Field *field, 
 			int bindToTable, bool visible = true);
 		
-		/*! Adds \a field to the columns list.
+		/*! Adds \a field to the columns list. 
+		 If \a visible is true (the default), the field will be visible. 
 		 \sa insertField() */
 		FieldList& addField(Field* field, bool visible = true);
 		
 		/*! Adds \a field to the columns list. Also binds to a table 
 		 at \a bindToTable position. Use bindToTable==-1 if no table should be bound.
+		 If \a visible is true (the default), the field will be visible. 
 		 \sa insertField()
 		 \sa tableBoundToColumn(uint columnPosition)
 		*/
@@ -137,6 +303,10 @@ class KEXI_DB_EXPORT QuerySchema : public FieldList, public SchemaData
 		/*! Removes field from the columns list. Use with care. */
 		virtual void removeField(Field *field);
 
+		/*! Adds a field built on top of \a expr expression. 
+		 This creates a new Field object and adds it to the query schema using addField(). */
+		FieldList& addExpression(BaseExpr* expr, bool visible = true);
+
 		/*! \return visibility flag for column at \a position. 
 		 By default column is visible. */
 		bool isColumnVisible(uint position) const;
@@ -189,7 +359,7 @@ class KEXI_DB_EXPORT QuerySchema : public FieldList, public SchemaData
 		 if \a alias is not empty, it will be assigned to this table
 		 using setTableAlias(position, alias)
 		*/
-		void addTable(TableSchema *table, const QCString& alias = QCString());
+		void addTable(TableSchema *table, const Q3CString& alias = Q3CString());
 
 		/*! Removes \a table schema from this query. 
 		 This does not destroy \a table object but only takes it out of the list. 
@@ -208,16 +378,20 @@ class KEXI_DB_EXPORT QuerySchema : public FieldList, public SchemaData
 		 The field does not need to be included on the list of query columns.
 		 Similarly, query aliases are not taken into account.
 
-		 \a tableDotFieldName string must contain table name and field name 
+		 \a tableOrTableAndFieldName string may contain table name and field name 
 		 with '.' character between them, e.g. "mytable.myfield". 
+		 This is recommended way to avoid ambiguity.
 		 0 is returned if the query has no such 
 		 table defined of the table has no such field defined.
+		 If you do not provide a table name, the first field found is returned.
 
 		 QuerySchema::table("mytable")->field("myfield") could be 
 		 alternative for findTableField("mytable.myfield") but it can crash
 		 if "mytable" is not defined in the query.
+		 
+		 @see KexiDB::splitToTableAndFieldParts()
 		*/
-		Field* findTableField(const QString &tableDotFieldName) const;
+		Field* findTableField(const QString &tableOrTableAndFieldName) const;
 
 		/*! \return alias of a column at \a position or null string 
 		 If there is no alias for this column
@@ -225,7 +399,7 @@ class KEXI_DB_EXPORT QuerySchema : public FieldList, public SchemaData
 		 If the column is an expression and has no alias defined, 
 		 a new unique alias will be generated automatically on this call.
 		*/
-		QCString columnAlias(uint position) const;
+		Q3CString columnAlias(uint position) const;
 		
 		/*! Provided for convenience. 
 		 \return true if a column at \a position has non empty alias defined 
@@ -236,7 +410,7 @@ class KEXI_DB_EXPORT QuerySchema : public FieldList, public SchemaData
 
 		/*! Sets \a alias for a column at \a position, within the query. 
 		 Passing empty string to \a alias clears alias for a given column. */
-		void setColumnAlias(uint position, const QCString& alias);
+		void setColumnAlias(uint position, const Q3CString& alias);
 
 		/*! \return a table position (within FROM section), 
 		 that is bound to column at \a columnPosition (within SELECT section).
@@ -264,7 +438,7 @@ class KEXI_DB_EXPORT QuerySchema : public FieldList, public SchemaData
 		/*! \return alias of a table at \a position (within FROM section) 
 		 or null string if there is no alias for this table
 		 or if there is no such table within the query defined. */
-		QCString tableAlias(uint position) const;
+		Q3CString tableAlias(uint position) const;
 		
 		/*! \return table position (within FROM section) that has attached 
 		 alias \a name.
@@ -277,7 +451,7 @@ class KEXI_DB_EXPORT QuerySchema : public FieldList, public SchemaData
 		 e.g. "SELECT 1 from table1 t, table2 t" is ok
 		 but "SELECT t.id from table1 t, table2 t" is not.
 		*/
-		int tablePositionForAlias(const QCString& name) const;
+		int tablePositionForAlias(const Q3CString& name) const;
 
 		/*! \return table position (within FROM section) for \a tableName.
 		 -1 is returend if there's no such table declared in the FROM section.
@@ -285,13 +459,13 @@ class KEXI_DB_EXPORT QuerySchema : public FieldList, public SchemaData
 		*/
 		int tablePosition(const QString& tableName) const;
 		
-		/*! \return a list of all \a tableName table occurences (within FROM section).
+		/*! \return a list of all \a tableName table occurrences (within FROM section).
 		 E.g. for "SELECT * FROM table t, table t2" [0, 1] list is returned.
 		 Empty list is returned there's no such table declared 
 		 in the FROM section at all.
 		 \sa tablePosition()
 		*/
-		QValueList<int> tablePositions(const QString& tableName) const;
+		Q3ValueList<int> tablePositions(const QString& tableName) const;
 
 		/*! Provided for convenience. 
 		 \return true if a table at \a position (within FROM section of the the query)
@@ -302,13 +476,13 @@ class KEXI_DB_EXPORT QuerySchema : public FieldList, public SchemaData
 
 		/*! \return column position that has defined alias \a name.
 		 If there is no such alias, -1 is returned. */
-		int columnPositionForAlias(const QCString& name) const;
+		int columnPositionForAlias(const Q3CString& name) const;
 
 		/*! Sets \a alias for a table at \a position (within FROM section 
 		 of the the query).
 		 Passing empty sting to \a alias clears alias for a given table
 		 (only for specified \a position). */
-		void setTableAlias(uint position, const QCString& alias);
+		void setTableAlias(uint position, const Q3CString& alias);
 
 		/*! \return a list of relationships defined for this query */
 		Relationship::List* relationships() const;
@@ -325,70 +499,147 @@ class KEXI_DB_EXPORT QuerySchema : public FieldList, public SchemaData
 		/*! \return list of QueryAsterisk objects defined for this query */
 		Field::List* asterisks() const;
 
-		/*! \return field for \a name or 0 if no field for this name 
+		/*! \return field for \a identifier or 0 if no field for this name 
 		 was found within the query. fieldsExpanded() method is used 
 		 to lookup expanded list of the query fields, so queries with asterisks 
 		 are processed well.
 		 If a field has alias defined, name is not taken into account, 
-		 but only it's alias. If a field has no alias:
+		 but only its alias. If a field has no alias:
 		 - field's name is checked
 		 - field's table and field's name are checked in a form of "tablename.fieldname",
-		   so you can provide \a name of this form to avoid ambiguity.
+		   so you can provide \a identifier in this form to avoid ambiguity.
 
-		 If there are more than one fields with the same name equal to \a name,
+		 If there are more than one fields with the same name equal to \a identifier,
 		 first-found is returned (checking is performed from first to last query field).
 		 Structures needed to compute result of this method are cached, 
 		 so only first usage costs o(n) - another usages cost o(1). 
 
 		 Example:
-		 Let query be defined by "SELECT T.B AS X, * FROM T" statement and T 
-		 is table containing fields A, B, C. 
+		 Let query be defined by "SELECT T.B AS X, T.* FROM T" statement and let T 
+		 be table containing fields A, B, C. 
 		 Expanded list of columns for the query is: T.B AS X, T.A, T.B, T.C.
-		 - Calling field("B") will return a pointer to third query column (not first, 
+		 - Calling field("B") will return a pointer to third query column (not the first, 
 		   because it is covered by "X" alias). Additionally, calling field("X") 
 		   will return the same pointer.
 		 - Calling field("T.A") will return the same pointer as field("A").
 		 */
-		virtual Field* field(const QString& name);
+		virtual Field* field(const QString& name, bool expanded = true);
 
-		/* Like QuerySchema::field(const QString& name) but returns not only Field
-		 object for \a name but entire QueryColumnInfo object. */
-		QueryColumnInfo* columnInfo(const QString& name);
+		/*! \return field id or NULL if there is no such a field. */
+		inline Field* field(uint id) { return FieldList::field(id); }
 
-		/*! QuerySchema::fields() returns vector of fields used for the query columns,
+		/*! Like QuerySchema::field(const QString& name) but returns not only Field
+		 object for \a identifier but entire QueryColumnInfo object. 
+		 \a identifier can be:
+		 - a fieldname
+		 - an aliasname
+		 - a tablename.fieldname
+		 - a tablename.aliasname 
+		 Note that if there are two occurrrences of the same name,
+		 only the first is accessible using this method. For instance,
+		 calling columnInfo("name") for "SELECT t1.name, t2.name FROM t1, t2" statement
+		 will only return the column related to t1.name and not t2.name, so you'll need to
+		 explicitly specify "t2.name" as the identifier to get the second column. */
+		QueryColumnInfo* columnInfo(const QString& identifier, bool expanded = true);
+
+		/*! Options used in fieldsExpanded(). */
+		enum FieldsExpandedOptions {
+			Default,                   //!< All fields are returned even if duplicated
+			Unique,                    //!< Unique list of fields is returned
+			WithInternalFields,        //!< Like Default but internal fields (for lookup) are appended
+			WithInternalFieldsAndRowID //!< Like WithInternalFields but RowID (big int type) field 
+			                           //!< is appended after internal fields
+		};
+
+		/*! \return fully expanded list of fields. 
+		 QuerySchema::fields() returns vector of fields used for the query columns,
 		 but in a case when there are asterisks defined for the query,
 		 it does not expand QueryAsterisk objects to field lists but return every
 		 asterisk as-is.
 		 This could be inconvenient when you need just a fully expanded list of fields,
 		 so this method does the work for you. 
 
-		 If \a unique is true, each field is returned in the vector only once 
+		 If \a options is Unique, each field is returned in the vector only once 
 		 (first found field is selected).
 		 Note however, that the same field can be returned more than once if it has attached 
 		 a different alias.
-		 For example, let t is TABLE( a, b ) and let query be defined 
-		 by "SELECT *, a AS alfa FROM t" statement. Either fieldsExpanded(true) and fieldsExpanded(false)
-		 will return [ a, b, a (alfa) ] list.
+		 For example, let t be TABLE( a, b ) and let query be defined 
+		 by "SELECT *, a AS alfa FROM t" statement. Both fieldsExpanded(Default) 
+		 and fieldsExpanded(Unique) will return [ a, b, a (alfa) ] list.
 		 On the other hand, for query defined by "SELECT *, a FROM t" statement,
-		 fieldsExpanded(true) will return [ a, b ] list 
-		 and fieldsExpanded(false) will return [ a, b, a ] list.
+		 fieldsExpanded(Default) will return [ a, b, a ] list while
+		 fieldsExpanded(Unique) will return [ a, b ] list.
+
+		 If \a options is WithInternalFields or WithInternalFieldsAndRowID, 
+		 additional internal fields are also appended to the vector.
+
+		 If \a options is WithInternalFieldsAndRowID, 
+		 one fake BigInteger column is appended to make space for ROWID column used 
+		 by KexiDB::Cursor implementations. For example, let persons be TABLE( surname, city_id ), 
+		 let city_number reference cities.is in TABLE cities( id, name ) and let query q be defined 
+		 by "SELECT * FROM t" statement. If we want to display persons' city names instead of city_id's.
+		 To do this, cities.name has to be retrieved as well, so the following statement should be used:
+		 "SELECT * FROM persons, cities.name LEFT OUTER JOIN cities ON persons.city_id=cities.id".
+		 Thus, calling fieldsExpanded(WithInternalFieldsAndRowID) will return 4 elements instead of 2:
+		 persons.surname, persons.city_id, cities.name, {ROWID}. The {ROWID} item is the placeholder 
+		 used for fetching ROWID by KexiDB cursors.
 
 		 By default, all fields are returned in the vector even 
-		 if there are multiple occurences of one or more.
+		 if there are multiple occurrences of one or more (options == Default). 
 
 		 Note: You should assign the resulted vector in your space - it will be shared 
 		 and implicity copied on any modification.
 		 This method's result is cached by QuerySchema object.
 @todo js: UPDATE CACHE!
 		*/
-		QueryColumnInfo::Vector fieldsExpanded(bool unique = false); //QValueList<bool> *detailedVisibility = 0);
+		QueryColumnInfo::Vector fieldsExpanded(FieldsExpandedOptions options = Default);
+
+		/*! \return list of fields internal fields used for lookup columns. */
+		QueryColumnInfo::Vector internalFields();
+
+		/*! \return info for expanded of internal field at index \a index. 
+		 The returned field can be either logical or internal (for lookup),
+		 the latter case is true if \a index &gt;= fieldsExpanded().count(). 
+		 Equivalent of QuerySchema::fieldsExpanded(WithInternalFields).at(index). */
+		QueryColumnInfo* expandedOrInternalField(uint index);
+
+		/*! Options used in columnsOrder(). */
+		enum ColumnsOrderOptions {
+			UnexpandedList,                 //!< A map for unexpanded list is created
+			UnexpandedListWithoutAsterisks, //!< A map for unexpanded list is created, with asterisks skipped
+			ExpandedList                    //!< A map for expanded list is created
+		};
 
 		/*! \return a map for fast lookup of query columns' order.
-		 This is exactly opposite information compared to vector returned 
-		 by fieldsExpanded(). This method's result is cached by QuerySchema object.
-@todo js: UPDATE CACHE!
+		 - If \a options is UnexpandedList, each QueryColumnInfo pointer is mapped to the index
+		   within (unexpanded) list of fields, i.e. "*" or "table.*" asterisks are considered 
+		   to be single items.
+		 - If \a options is UnexpandedListWithoutAsterisks, each QueryColumnInfo pointer 
+		   is mapped to the index within (unexpanded) list of columns that come from asterisks 
+		   like "*" or "table.*" are not included in the map at all.
+		 - If \a options is ExpandedList (the default) this method provides is exactly opposite 
+		   information compared to vector returned by fieldsExpanded(). 
+
+		 This method's result is cached by the QuerySchema object.
+		 Note: indices of internal fields (see internalFields()) are also returned 
+		 here - in this case the index is counted as a sum of size(e) + i (where "e" is 
+		 the list of expanded fields and i is the column index within internal fields list).
+		 This feature is used eg. at the end of Connection::updateRow() where need indices of
+		 fields (including internal) to update all the values in memory.
+
+		 Example use: let t be table (int id, name text, surname text) and q be query
+		 defined by a statement "select * from t". 
+
+		 - columnsOrder(ExpandedList) will return the following map: QueryColumnInfo(id)->0,
+		   QueryColumnInfo(name)->1, QueryColumnInfo(surname)->2.
+		 - columnsOrder(UnexpandedList) will return the following map: QueryColumnInfo(id)->0,
+		   QueryColumnInfo(name)->0, QueryColumnInfo(surname)->0 because the column 
+		   list is not expanded. This way you can use the returned index to get Field*
+		   pointer using field(uint) method of FieldList superclass.
+		 - columnsOrder(UnexpandedListWithoutAsterisks) will return the following map: 
+		   QueryColumnInfo(id)->0,
 		*/
-		QMap<QueryColumnInfo*,int> fieldsOrder();
+		QMap<QueryColumnInfo*,int> columnsOrder(ColumnsOrderOptions options = ExpandedList);
 
 		/*! \return table describing order of primary key (PKEY) fields within the query.
 		 Indexing is performed against vector returned by fieldsExpanded().
@@ -412,7 +663,7 @@ class KEXI_DB_EXPORT QuerySchema : public FieldList, public SchemaData
 		 @see example for pkeyFieldsCount().
 @todo js: UPDATE CACHE!
 		*/
-		QValueVector<int> pkeyFieldsOrder();
+		Q3ValueVector<int> pkeyFieldsOrder();
 
 		/*! \return number of master table's primary key fields included in this query.
 		 This method is useful to quickly check whether the vector returned by pkeyFieldsOrder()
@@ -477,36 +728,39 @@ class KEXI_DB_EXPORT QuerySchema : public FieldList, public SchemaData
 
 		/*! Sets a list of columns for ORDER BY section of the query. 
 		 Each name on the list must be a field or alias present within the query 
-		 and must not be covered by aliases. If one or more names cannot be found within 
-		 the query, the method will have no effect. Any previous ORDER BY settings will be removed. 
-		 */
-		void setOrderByColumnList(const QStringList& columnNames);
+		 and must not be covered by aliases. If one or more names cannot be found 
+		 within the query, the method will have no effect. 
+		 Any previous ORDER BY settings will be removed. 
 
-		/*! Convenience method, similar to setOrderByColumnList(const QStringList&). */
-		void setOrderByColumnList(const QString& column1, const QString& column2 = QString::null, 
-			const QString& column3 = QString::null, const QString& column4 = QString::null, 
-			const QString& column5 = QString::null);
+		 Note that this information is cleared whenever you call methods that 
+		 modify list of columns (QueryColumnInfo), i.e. insertFiled(), 
+		 addField(), removeField(), addExpression(), etc. 
+		 (because OrderByColumn items can point to a QueryColumnInfo that's removed by these 
+		 methods), so you should use setOrderByColumnList() method after the query 
+		 is completely built. */
+		void setOrderByColumnList(const OrderByColumnList& list);
 
-		/*! \return a list of columns contained in ORDER BY section of the query. 
-		 @see setOrderBy(const QStringList&) */
-		QueryColumnInfo::Vector orderByColumnList() const;
+		/*! \return a list of columns listed in ORDER BY section of the query. 
+		 Read notes for \ref setOrderByColumnList(). */
+		OrderByColumnList& orderByColumnList() const;
+
+		/*! \return query schema parameters. These are taked from the WHERE section 
+		 (a tree of expression items). */
+		QuerySchemaParameterList parameters();
 
 	protected:
 		void init();
 
 		void computeFieldsExpanded();
 
-	//		/*! Automatically retrieves query schema via connection. */
-//		QuerySchema(Connection *conn);
-
 		QuerySchemaPrivate *d;
 		
 	friend class Connection;
 	friend class QuerySchemaPrivate;
 };
 
-/*! This class encapsulates information about single asterisk in query definition.
- There are two types of query asterisks:
+//! @short KexiDB::QueryAsterisk class encapsulates information about single asterisk in query definition
+/*! There are two types of query asterisks:
  
  1. "Single-table" asterisk, that references all fields of given table used
  in the query.
@@ -528,8 +782,7 @@ class KEXI_DB_EXPORT QuerySchema : public FieldList, public SchemaData
  There can be many asterisks of 1st type defined for given single query.
  There can be one asterisk of 2nd type defined for given single query.
 */
-
-class KEXI_DB_EXPORT QueryAsterisk : protected Field
+class KEXI_DB_EXPORT QueryAsterisk : public Field
 {
 	public:
 		/*! Constructs query asterisk definition object.
@@ -557,6 +810,9 @@ class KEXI_DB_EXPORT QueryAsterisk : protected Field
 		 \a table may be NULL - then the asterisk becames "all-tables" type asterisk. */
 		virtual void setTable(TableSchema *table);
 
+		/*! Reimplemented. */
+		virtual bool isQueryAsterisk() const  { return true; }
+
 		/*! This is convenience method that returns true 
 		 if the asterisk has "all-tables" type (2nd type).*/
 		bool isSingleTableAsterisk() const { return m_table!=NULL; }
@@ -566,9 +822,12 @@ class KEXI_DB_EXPORT QueryAsterisk : protected Field
 		bool isAllTableAsterisk() const { return m_table==NULL; }
 		
 		/*! \return String for debugging purposes. */
-		virtual QString debugString();
+		virtual QString debugString() const;
 
 	protected:
+		//! \return a deep copy of this object. Used in FieldList(const FieldList& fl).
+		virtual Field* copy() const;
+
 		/*! Table schema for this asterisk */
 		TableSchema* m_table;
 
