@@ -26,6 +26,8 @@
 #include <assert.h>
 #include <kdebug.h>
 
+#include <q3ptrdict.h>
+
 namespace KexiDB {
 //! @internal
 class TableSchema::Private
@@ -46,13 +48,14 @@ public:
 		for (QMap<const Field*, LookupFieldSchema*>::ConstIterator it = lookupFields.constBegin(); 
 			it!=lookupFields.constEnd(); ++it)
 		{
-			delete it.data();
+			delete it.value();
 		}
 		lookupFields.clear();
 	}
 
 	Field *anyNonPKField;
 	QMap<const Field*, LookupFieldSchema*> lookupFields;
+	Q3PtrVector<LookupFieldSchema> lookupFieldsList;
 };
 }
 //-------------------------------------
@@ -66,7 +69,7 @@ TableSchema::TableSchema(const QString& name)
 	, m_query(0)
 	, m_isKexiDBSystem(false)
 {
-	m_name = name.lower();
+	m_name = name.toLower();
 	init();
 }
 
@@ -91,27 +94,16 @@ TableSchema::TableSchema()
 TableSchema::TableSchema(const TableSchema& ts, bool copyId)
 	: FieldList(static_cast<const FieldList&>(ts))
 	, SchemaData(static_cast<const SchemaData&>(ts))
-	, m_conn( ts.m_conn )
-	, m_query(0) //not cached
-	, m_isKexiDBSystem(false)
 {
-	d = new Private();
-	m_name = ts.m_name;
-	m_indices.setAutoDelete( true );
-	m_pkey = 0; //will be copied
-	if (!copyId)
-		m_id = -1;
+	init(ts, copyId);
+}
 
-	//deep copy all members
-	IndexSchema::ListIterator idx_it(ts.m_indices);
-	for (;idx_it.current();++idx_it) {
-		IndexSchema *idx = new IndexSchema(
-			*idx_it.current(), *this /*fields from _this_ table will be assigned to the index*/);
-		if (idx->isPrimaryKey()) {//assign pkey
-			m_pkey = idx;
-		}
-		m_indices.append(idx);
-	}
+TableSchema::TableSchema(const TableSchema& ts, int setId)
+	: FieldList(static_cast<const FieldList&>(ts))
+	, SchemaData(static_cast<const SchemaData&>(ts))
+{
+	init(ts, false);
+	m_id = setId;
 }
 
 // used by Connection
@@ -146,6 +138,30 @@ void TableSchema::init()
 	m_indices.append(m_pkey);
 }
 
+void TableSchema::init(const TableSchema& ts, bool copyId)
+{
+	m_conn = ts.m_conn;
+	m_query = 0; //not cached
+	m_isKexiDBSystem = false;
+	d = new Private();
+	m_name = ts.m_name;
+	m_indices.setAutoDelete( true );
+	m_pkey = 0; //will be copied
+	if (!copyId)
+		m_id = -1;
+
+	//deep copy all members
+	IndexSchema::ListIterator idx_it(ts.m_indices);
+	for (;idx_it.current();++idx_it) {
+		IndexSchema *idx = new IndexSchema(
+			*idx_it.current(), *this /*fields from _this_ table will be assigned to the index*/);
+		if (idx->isPrimaryKey()) {//assign pkey
+			m_pkey = idx;
+		}
+		m_indices.append(idx);
+	}
+}
+
 void TableSchema::setPrimaryKey(IndexSchema *pkey)
 {
 	if (m_pkey && m_pkey!=pkey) {
@@ -330,6 +346,11 @@ QString TableSchema::debugString(bool includeTableName)
 	return s;
 }
 
+Connection* TableSchema::connection() const
+{
+	return (Connection*)m_conn;
+}
+
 void TableSchema::setKexiDBSystem(bool set)
 {
 	if (set)
@@ -351,7 +372,7 @@ QuerySchema* TableSchema::query()
 {
 	if (m_query)
 		return m_query;
-	m_query = new QuerySchema( this ); //it's owned by me
+	m_query = new QuerySchema( *this ); //it's owned by me
 	return m_query;
 }
 
@@ -379,11 +400,12 @@ bool TableSchema::setLookupFieldSchema( const QString& fieldName, LookupFieldSch
 		return false;
 	}
 	if (lookupFieldSchema)
-		d->lookupFields.replace( f, lookupFieldSchema );
+		d->lookupFields.insert( f, lookupFieldSchema );
 	else {
 		delete d->lookupFields[f];
 		d->lookupFields.remove( f );
 	}
+	d->lookupFieldsList.clear(); //this will force to rebuid the internal cache
 	return true;
 }
 
@@ -400,6 +422,26 @@ LookupFieldSchema *TableSchema::lookupFieldSchema( const QString& fieldName )
 	return lookupFieldSchema( *f );
 }
 
+const Q3PtrVector<LookupFieldSchema>& TableSchema::lookupFieldsList()
+{
+	if (d->lookupFields.isEmpty())
+		return d->lookupFieldsList;
+	if (!d->lookupFields.isEmpty() && !d->lookupFieldsList.isEmpty())
+		return d->lookupFieldsList; //already updated
+	//update
+	d->lookupFieldsList.clear();
+	d->lookupFieldsList.resize( d->lookupFields.count() );
+	uint i = 0;
+	for (Field::ListIterator it(m_fields); it.current(); ++it) {
+		QMap<const Field*, LookupFieldSchema*>::ConstIterator itMap = d->lookupFields.find( it.current() );
+		if (itMap != d->lookupFields.constEnd()) {
+			d->lookupFieldsList.insert( i, itMap.value() );
+			i++;
+		}
+	}
+	return d->lookupFieldsList;
+}
+
 //--------------------------------------
 
 InternalTableSchema::InternalTableSchema(const QString& name)
@@ -407,6 +449,11 @@ InternalTableSchema::InternalTableSchema(const QString& name)
 {
 }
 
+InternalTableSchema::InternalTableSchema(const TableSchema& ts)
+ : TableSchema(ts, false)
+{
+}
+
 InternalTableSchema::~InternalTableSchema()
 {
 }
