@@ -21,10 +21,11 @@
 #ifndef KEXIDB_TABLE_H
 #define KEXIDB_TABLE_H
 
-#include <qvaluelist.h>
-#include <qptrlist.h>
+#include <q3valuelist.h>
+#include <q3ptrlist.h>
 #include <qstring.h>
-#include <qguardedptr.h>
+#include <qpointer.h>
+#include <q3ptrvector.h>
 
 #include <kexidb/fieldlist.h>
 #include <kexidb/schemadata.h>
@@ -42,8 +43,8 @@ class LookupFieldSchema;
 class KEXI_DB_EXPORT TableSchema : public FieldList, public SchemaData
 {
 	public:
-		typedef QPtrList<TableSchema> List; //!< Type of tables list
-		typedef QPtrListIterator<TableSchema> ListIterator; //!< Iterator for tables list
+		typedef Q3PtrList<TableSchema> List; //!< Type of tables list
+		typedef Q3PtrListIterator<TableSchema> ListIterator; //!< Iterator for tables list
 
 		TableSchema(const QString & name);
 		TableSchema(const SchemaData& sdata);
@@ -106,7 +107,7 @@ class KEXI_DB_EXPORT TableSchema : public FieldList, public SchemaData
 
 		/*! \return connection object if table was created/retrieved using a connection, 
 			otherwise 0. */
-		Connection* connection() const { return m_conn; }
+		Connection* connection() const;
 
 		/*! \return true if this is KexiDB storage system's table 
 		 (used internally by KexiDB). This helps in hiding such tables
@@ -164,15 +165,15 @@ class KEXI_DB_EXPORT TableSchema : public FieldList, public SchemaData
 
 		/*! \return list of lookup field schemas for this table. 
 		 The order is the same as the order of fields within the table. */
-		const QPtrVector<LookupFieldSchema>& lookupFieldsList();
+		const Q3PtrVector<LookupFieldSchema>& lookupFieldsList();
 
 	protected:
 		/*! Automatically retrieves table schema via connection. */
-		TableSchema(Connection *conn, const QString & name = QString::null);
+		TableSchema(Connection *conn, const QString & name = QString());
 
 		IndexSchema::List m_indices;
 
-		QGuardedPtr<Connection> m_conn;
+		QPointer<Connection> m_conn;
 		
 		IndexSchema *m_pkey;
 
