@@ -20,7 +20,7 @@
 #ifndef KEXIDB_TRANSACTION_H
 #define KEXIDB_TRANSACTION_H
 
-#include <qguardedptr.h>
+#include <qpointer.h>
 
 #include <kexidb/kexidb_export.h>
 
@@ -82,7 +82,7 @@ class KEXI_DB_EXPORT Transaction : public QObject
 		bool isNull() const;
 		
 		/*! shortcut that offers uinitialised (null) transaction */
-		static const Transaction null;
+		//static const Transaction null;
 
 		//helper for debugging
 		static int globalCount();
@@ -130,7 +130,7 @@ class KEXI_DB_EXPORT TransactionGuard
 		 setTransaction() can be used later to do so. */
 		TransactionGuard();
 
-		/*! Rollbacks not commited transaction. */
+		/*! Rollbacks not committed transaction. */
 		~TransactionGuard();
 
 		/*! Assigns transaction \a trans to this guard. 
