@@ -21,7 +21,7 @@
 #include "kexisimpleprintingpagesetupbase.h"
 #include "kexisimpleprintpreviewwindow.h"
 
-#include <core/keximainwindow.h>
+#include <core/KexiMainWindowIface.h>
 #include <kexiutils/utils.h>
 #include <kexi_version.h>
 
@@ -41,20 +41,24 @@
 #include <qlayout.h>
 #include <qpainter.h>
 #include <qcheckbox.h>
-#include <qwhatsthis.h>
+#include <q3whatsthis.h>
 #include <qtooltip.h>
+//Added by qt3to4:
+#include <Q3VBoxLayout>
+#include <Q3ValueList>
 
 #include <kexiutils/tristate.h>
 
 KexiSimplePrintingCommand::KexiSimplePrintingCommand(
 	KexiMainWindow* mainWin, int objectId, QObject* parent)
- : QObject(parent, "KexiSimplePrintCommand")
+ : QObject(parent)
  , m_previewEngine(0)
  , m_mainWin(mainWin)
  , m_objectId(objectId)
  , m_previewWindow(0)
  , m_printPreviewNeedsReloading(false)
 {
+	setObjectName("KexiSimplePrintCommand");
 	connect(this, SIGNAL(showPageSetupRequested(KexiPart::Item*)), 
 		m_mainWin, SLOT(showPageSetupForItem(KexiPart::Item*)));
 }
@@ -82,7 +86,7 @@ bool KexiSimplePrintingCommand::print(const QString& aTitleText)
 //! @todo item not found
 		return false;
 	}
-	QString titleText(aTitleText.stripWhiteSpace());
+	QString titleText(aTitleText.trimmed());
 	if (titleText.isEmpty())
 		titleText = tableOrQuery.captionOrName();
 
@@ -134,7 +138,7 @@ bool KexiSimplePrintingCommand::print(const QString& aTitleText)
 	engine.calculatePagesCount(painter);
 
 	uint loops, loopsPerPage;
-	QValueList<int> pagesToPrint;
+	Q3ValueList<int> pagesToPrint;
 	int fromPage = 0;
 #ifdef Q_WS_WIN
 	int toPage = 0;
@@ -162,7 +166,7 @@ bool KexiSimplePrintingCommand::print(const QString& aTitleText)
 #else
 	// on !win32 print QPrinter::numCopies() times (the OS does not perform buffering)
 	pagesToPrint = printer.pageList();
-	kdDebug() << pagesToPrint << endl;
+	kDebug() << pagesToPrint << endl;
 	if (pagesToPrint.isEmpty()) {
 		fromPage = 0;
 		for (int i = 0; i<(int)engine.pagesCount(); i++) {
@@ -185,14 +189,14 @@ bool KexiSimplePrintingCommand::print(const QString& aTitleText)
 #endif
 	// now, total number of printed pages is printer.numCopies()*printer.pageList().count()
 
-	kdDebug() << "printing..." << endl;
+	kDebug() << "printing..." << endl;
 	bool firstPage = true;
 	for (uint copy = 0;copy < loops; copy++) {
-		kdDebug() << "copy " << (copy+1) << " of " << loops << endl;
+		kDebug() << "copy " << (copy+1) << " of " << loops << endl;
 		uint pageNumber = fromPage;
-		QValueList<int>::ConstIterator pagesIt = pagesToPrint.constBegin();
-		for(;(int)pageNumber == fromPage || !engine.eof(); ++pageNumber) {
-			kdDebug() << "printing..." << endl;
+		Q3ValueList<int>::ConstIterator pagesIt = pagesToPrint.constBegin();
+		for(;(int)pageNumber == fromPage || !engine.atEnd(); ++pageNumber) {
+			kDebug() << "printing..." << endl;
 			if (pagesIt == pagesToPrint.constEnd()) //no more pages to print
 				break;
 			if ((int)pageNumber < *pagesIt) { //skip pages without printing (needed for computation)
@@ -208,13 +212,13 @@ bool KexiSimplePrintingCommand::print(const QString& aTitleText)
 					printer.newPage();
 				else
 					firstPage = false;
-				kdDebug() << "page #" << pageNumber << endl;
+				kDebug() << "page #" << pageNumber << endl;
 				engine.paintPage(pageNumber, painter);
 			}
 			++pagesIt;
 		}
 	}
-	kdDebug() << "end of printing." << endl;
+	kDebug() << "end of printing." << endl;
 
 	// stop painting, this will automatically send the print data to the printer
 	if (!painter.end())
@@ -237,7 +241,7 @@ bool KexiSimplePrintingCommand::showPrintPreview(const KexiSimplePrintingSetting
 		m_printPreviewNeedsReloading = true;
 
 	bool backToPage0 = true;
-	QString titleText(aTitleText.stripWhiteSpace());
+	QString titleText(aTitleText.trimmed());
 	KexiDB::Connection *conn = m_mainWin->project()->dbConnection();
 	KexiDB::TableOrQuerySchema tableOrQuery(conn, m_objectId);
 	if (!tableOrQuery.table() && !tableOrQuery.query()) {
@@ -246,8 +250,7 @@ bool KexiSimplePrintingCommand::showPrintPreview(const KexiSimplePrintingSetting
 	}
 	if (titleText.isEmpty())
 		titleText = tableOrQuery.captionOrName();
-	if (!m_previewWindow) {
-		backToPage0 = false;
+	if (!m_previewWindow || m_printPreviewNeedsReloading) {
 		QString errorMessage;
 		if (!m_previewEngine->init(
 			*conn, tableOrQuery, titleText, errorMessage)) {
@@ -255,6 +258,9 @@ bool KexiSimplePrintingCommand::showPrintPreview(const KexiSimplePrintingSetting
 				KMessageBox::sorry(m_mainWin, errorMessage, i18n("Print Preview")); 
 			return false;
 		}
+	}
+	if (!m_previewWindow) {
+		backToPage0 = false;
 		m_previewWindow = new KexiSimplePrintPreviewWindow(
 			*m_previewEngine, tableOrQuery.captionOrName(), 0, 
 			Qt::WStyle_Customize|Qt::WStyle_NormalBorder|Qt::WStyle_Title|
@@ -297,7 +303,7 @@ void KexiSimplePrintingCommand::slotShowPageSetupRequested()
 
 KexiSimplePrintingPageSetup::KexiSimplePrintingPageSetup( KexiMainWindow *mainWin, QWidget *parent, 
 	QMap<QString,QString>* args )
-	: KexiViewBase( mainWin, parent, "KexiSimplePrintingPageSetup" )
+	: KexiView( mainWin, parent, "KexiSimplePrintingPageSetup" )
 	, m_settings( KexiSimplePrintingSettings::load() )
 //	, m_command(0)
 {
@@ -322,10 +328,10 @@ KexiSimplePrintingPageSetup::KexiSimplePrintingPageSetup( KexiMainWindow *mainWi
 
 	// settings
 //! @todo default?
-	m_unit = KLocale::Metric == KGlobal::locale()->measureSystem() ? KoUnit::U_CM : KoUnit::U_INCH;
+	m_unit = KLocale::Metric == KGlobal::locale()->measureSystem() ? KoUnit::Centimeter : KoUnit::Inch;
 
 	// GUI
-	QVBoxLayout *lyr = new QVBoxLayout(this);
+	Q3VBoxLayout *lyr = new Q3VBoxLayout(this);
 	m_contents = new KexiSimplePrintingPageSetupBase(this, "KexiSimplePrintingPageSetupBase");
 	lyr->addWidget(m_contents);
 
@@ -333,17 +339,17 @@ KexiSimplePrintingPageSetup::KexiSimplePrintingPageSetup( KexiMainWindow *mainWi
 //	setFocusPolicy(WheelFocus);
 	m_contents->setFocusProxy(m_contents->headerTitleLineEdit);
 
-	m_contents->printButton->setIconSet( KStdGuiItem::print().iconSet(KIcon::Small) );
-	m_contents->printButton->setText( KStdGuiItem::print().text() );
+	m_contents->printButton->setIconSet( KStandardGuiItem::print().iconSet(K3Icon::Small) );
+	m_contents->printButton->setText( KStandardGuiItem::print().text() );
 	connect(m_contents->printButton, SIGNAL(clicked()), this, SLOT(print()));
 
-	m_contents->printPreviewButton->setIconSet( SmallIconSet("filequickprint") );
+	m_contents->printPreviewButton->setIconSet( KIcon("document-print-preview") );
 	m_contents->printPreviewButton->setText( i18n("Print Previe&w...") );
 	connect(m_contents->printPreviewButton, SIGNAL(clicked()), this, SLOT(printPreview()));
 
 	m_contents->iconLabel->setFixedWidth(32+6);
 	m_contents->iconLabel->setPixmap( DesktopIcon("document", 32) );
-	QWhatsThis::add(m_contents->headerTitleFontButton, i18n("Changes font for title text."));
+	Q3WhatsThis::add(m_contents->headerTitleFontButton, i18n("Changes font for title text."));
 	connect(m_contents->headerTitleFontButton, SIGNAL(clicked()), 
 		this, SLOT(slotChangeTitleFont()));
 
@@ -352,7 +358,7 @@ KexiSimplePrintingPageSetup::KexiSimplePrintingPageSetup( KexiMainWindow *mainWi
 		m_contents->headerTitleLineEdit->setText( m_item->captionOrName() );
 		if (m_item->mimeType()=="kexi/query") {
 			m_contents->openDataLink->setText( i18n("Open This Query") );
-			m_origCaptionLabelText = i18n("<h2>Page setup for printing \"%1\" query data</h2>");
+			m_origCaptionLabelText = I18N_NOOP("<h2>Page setup for printing \"%1\" query data</h2>");
 		}
 		m_contents->captionLabel->setText( m_origCaptionLabelText.arg(m_item->name()) );
 	}
@@ -360,23 +366,23 @@ KexiSimplePrintingPageSetup::KexiSimplePrintingPageSetup( KexiMainWindow *mainWi
 		this, SLOT(slotTitleTextChanged(const QString&)));
 	m_contents->headerTitleLineEdit->setFont( m_settings.pageTitleFont );
 
-	QWhatsThis::add(m_contents->openDataLink, 
+	Q3WhatsThis::add(m_contents->openDataLink, 
 		i18n("Shows data for table or query associated with this page setup."));
-	QToolTip::add(m_contents->openDataLink, 
+	m_contents->openDataLink->setToolTip( 
 		i18n("Shows data for table or query associated with this page setup."));
-	connect(m_contents->openDataLink, SIGNAL(leftClickedURL()), this, SLOT(slotOpenData())); 
+	connect(m_contents->openDataLink, SIGNAL(leftClickedUrl()), this, SLOT(slotOpenData())); 
 
-	QWhatsThis::add(m_contents->saveSetupLink, i18n("Saves settings for this setup as default."));
-	connect(m_contents->saveSetupLink, SIGNAL(leftClickedURL()), this, SLOT(slotSaveSetup()));
+	Q3WhatsThis::add(m_contents->saveSetupLink, i18n("Saves settings for this setup as default."));
+	connect(m_contents->saveSetupLink, SIGNAL(leftClickedUrl()), this, SLOT(slotSaveSetup()));
 #if !KDE_IS_VERSION(3,5,1) && !defined(Q_WS_WIN)
 	//a fix for problems with focusable KUrlLabel on KDElibs<=3.5.0
 	m_contents->openDataLink->setFocusPolicy(NoFocus);
 	m_contents->saveSetupLink->setFocusPolicy(NoFocus);
 #endif
 
-	QWhatsThis::add(m_contents->addDateTimeCheckbox, i18n("Adds date and time to the header."));
-	QWhatsThis::add(m_contents->addPageNumbersCheckbox, i18n("Adds page numbers to the footer."));
-	QWhatsThis::add(m_contents->addTableBordersCheckbox, i18n("Adds table borders."));
+	Q3WhatsThis::add(m_contents->addDateTimeCheckbox, i18n("Adds date and time to the header."));
+	Q3WhatsThis::add(m_contents->addPageNumbersCheckbox, i18n("Adds page numbers to the footer."));
+	Q3WhatsThis::add(m_contents->addTableBordersCheckbox, i18n("Adds table borders."));
 	
 #ifdef KEXI_NO_UNFINISHED 
 	m_contents->addDateTimeCheckbox->hide();
@@ -384,7 +390,7 @@ KexiSimplePrintingPageSetup::KexiSimplePrintingPageSetup( KexiMainWindow *mainWi
 #endif
 
 	updatePageLayoutAndUnitInfo();
-	QWhatsThis::add(m_contents->changePageSizeAndMarginsButton, 
+	Q3WhatsThis::add(m_contents->changePageSizeAndMarginsButton, 
 		i18n("Changes page size and margins."));
 	connect(m_contents->changePageSizeAndMarginsButton, SIGNAL(clicked()), 
 		this, SLOT(slotChangePageSizeAndMargins()));
@@ -483,7 +489,7 @@ void KexiSimplePrintingPageSetup::printPreview()
 void KexiSimplePrintingPageSetup::slotOpenData()
 {
 	bool openingCancelled;
-	m_mainWin->openObject(m_item, Kexi::DataViewMode, openingCancelled);
+	KexiMainWindowIface::global()->openObject(m_item, Kexi::DataViewMode, openingCancelled);
 }
 
 void KexiSimplePrintingPageSetup::slotTitleTextChanged(const QString&)
@@ -509,8 +515,15 @@ void KexiSimplePrintingPageSetup::slotChangePageSizeAndMargins()
 {
 	KoHeadFoot headfoot; //dummy
 
+#ifdef __GNUC__
+#warning TODO reenable when KoPageLayoutDia is ported
+#else
+#pragma WARNING( TODO reenable when KoPageLayoutDia is ported )
+#endif
+#if 0//TODO
 	if (int(QDialog::Accepted) != KoPageLayoutDia::pageLayout( 
 		m_settings.pageLayout, headfoot, FORMAT_AND_BORDERS | DISABLE_UNIT, m_unit, this ))
+#endif
 		return;
 
 	//update
