@@ -19,13 +19,13 @@
 
 #include "KexiNewProjectWizard.h"
 
+#include "ui_KexiNewPrjTypeSelector.h"
+#include "ui_KexiOpenExistingFile.h"
+#include "ui_KexiServerDBNamePage.h"
 #include "KexiConnSelector.h"
-#include "KexiConnSelectorBase.h"
-#include "KexiNewPrjTypeSelector.h"
-#include "KexiOpenExistingFile.h"
 #include "KexiDBTitlePage.h"
-#include "KexiServerDBNamePage.h"
 #include "KexiProjectSelector.h"
+#include "KexiStartupFileWidget.h"
 #include "kexi.h"
 
 #include <kexiutils/identifier.h>
@@ -38,43 +38,65 @@
 #include <klocale.h>
 #include <kdebug.h>
 #include <kconfig.h>
-#include <klistview.h>
+#include <k3listview.h>
 #include <kurlcombobox.h>
 #include <kmessagebox.h>
 #include <klineedit.h>
+#include <kurlcombobox.h>
 
-#include <qobjectlist.h>
+#include <qobject.h>
 #include <qlabel.h>
 #include <qpushbutton.h>
 #include <qlayout.h>
 #include <qcheckbox.h>
-#include <qheader.h>
+#include <q3header.h>
+//Added by qt3to4:
+#include <Q3VBoxLayout>
+
+KexiNewPrjTypeSelector::KexiNewPrjTypeSelector(QWidget* parent)
+	: QWidget(parent)
+{
+	setupUi(this);
+}
+
+KexiOpenExistingFile::KexiOpenExistingFile(QWidget* parent)
+	: QWidget(parent)
+{
+	setupUi(this);
+}
+
+KexiServerDBNamePage::KexiServerDBNamePage(QWidget* parent)
+	: QWidget(parent)
+{
+	setupUi(this);
+}
+
 
 //! @internal
-class KexiNewProjectWizardPrivate
+class KexiNewProjectWizard::Private
 {
 	public:
-	KexiNewProjectWizardPrivate()
+	Private()
 	{
 		le_dbname_txtchanged_disable = false;
 		le_dbname_autofill = true;
 //		conndata_to_show = 0;
 //		project_set_to_show = 0;
 	}
-	~KexiNewProjectWizardPrivate()
+	~Private()
 	{
 //		delete conndata_to_show;
 //		delete project_set_to_show;
 		delete msgHandler;
 	}
-//	KListView *lv_types;
-	KListViewItem *lvi_file, *lvi_server;
+//	K3ListView *lv_types;
+	K3ListViewItem *lvi_file, *lvi_server;
 	QString chk_file_txt, chk_server_txt; //!< helper
 
 	QString server_db_name_dblist_lbl_txt; //!< helper
 
 	//for displaying db list of the selected conn.
-	QGuardedPtr<KexiDB::ConnectionData> conndata_to_show;
+	QPointer<KexiDB::ConnectionData> conndata_to_show;
 	KexiProjectSet *project_set_to_show;
 
 	KexiGUIMessageHandler* msgHandler;
@@ -84,37 +106,38 @@ class KexiNewProjectWizardPrivate
 };
 
 KexiNewProjectWizard::KexiNewProjectWizard(KexiDBConnectionSet& conn_set,
-	QWidget *parent, const char *name, bool modal, WFlags f)
-: KWizard(parent, name, modal, f)
-, d(new KexiNewProjectWizardPrivate() )
+	QWidget *parent)
+: K3Wizard(parent)
+, d(new Private() )
 {
 	d->msgHandler = new KexiGUIMessageHandler(this);
-	setIcon( DesktopIcon("filenew") );
-	setCaption( i18n("Creating New Project") );
+	setWindowIcon( KIcon("document-new") );
+	setWindowTitle( i18n("Creating New Project") );
 	finishButton()->setText(i18n("Create"));
 
 	//page: type selector
-	m_prjtype_sel = new KexiNewPrjTypeSelector(this, "KexiNewPrjTypeSelector");
-//	lv_types = new KListView(m_prjtype_sel, "types listview");
+	m_prjtype_sel = new KexiNewPrjTypeSelector(this);
+	m_prjtype_sel->setObjectName("KexiNewPrjTypeSelector");
+//	lv_types = new K3ListView(m_prjtype_sel, "types listview");
 //	m_prjtype_sel->lv_types->setSizePolicy(QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Minimum, 0, 2));
-#if KDE_IS_VERSION(3,3,9)
 	m_prjtype_sel->lv_types->setShadeSortColumn(false);
-#endif
 	m_prjtype_sel->lv_types->header()->hide();
 	m_prjtype_sel->lv_types->setSorting(-1);
 	m_prjtype_sel->lv_types->setAlternateBackground(QColor()); //disable altering
-	m_prjtype_sel->lv_types->setItemMargin( KDialogBase::marginHint() );
+	m_prjtype_sel->lv_types->setItemMargin( KDialog::marginHint() );
 	QString none;
-	d->lvi_file = new KListViewItem( m_prjtype_sel->lv_types, i18n("New Project Stored in File") );
+	d->lvi_file = new K3ListViewItem(
+		m_prjtype_sel->lv_types, i18n("New Project Stored in File") );
 	d->lvi_file->setPixmap(0, 
-		KGlobal::iconLoader()->loadIcon( KMimeType::mimeType( 
-			KexiDB::Driver::defaultFileBasedDriverMimeType() )->icon(none,0), KIcon::Desktop 
+		KIconLoader::global()->loadMimeTypeIcon( KMimeType::mimeType( 
+			KexiDB::Driver::defaultFileBasedDriverMimeType() )->iconName(),
+			K3Icon::Desktop 
 		)
 	);
 	d->lvi_file->setMultiLinesEnabled( true );
-	d->lvi_server = new KListViewItem( m_prjtype_sel->lv_types, d->lvi_file, 
+	d->lvi_server = new K3ListViewItem( m_prjtype_sel->lv_types, d->lvi_file, 
 		i18n("New Project Stored on Database Server") );
-	d->lvi_server->setPixmap(0, DesktopIcon("network") );
+	d->lvi_server->setPixmap(0, DesktopIcon("network-wired") );
 	d->lvi_server->setMultiLinesEnabled( true );
 //	m_prjtype_sel->lv_types->resize(d->m_prjtype_sel->lv_types->width(), d->lvi_file->height()*3);
 	m_prjtype_sel->lv_types->setFocus();
@@ -123,31 +146,38 @@ KexiNewProjectWizard::KexiNewProjectWizard(KexiDBConnectionSet& conn_set,
 //	d->chk_server_txt = i18n("Always &use database server for creating new projects.")
 //		+"\n"+txt_dns;
 
-	connect(m_prjtype_sel->lv_types,SIGNAL(executed(QListViewItem*)),this,SLOT(slotLvTypesExecuted(QListViewItem*)));
-	connect(m_prjtype_sel->lv_types,SIGNAL(returnPressed(QListViewItem*)),this,SLOT(slotLvTypesExecuted(QListViewItem*)));
-	connect(m_prjtype_sel->lv_types,SIGNAL(selectionChanged( QListViewItem*)),this,SLOT(slotLvTypesSelected(QListViewItem*)));
+	connect(m_prjtype_sel->lv_types, SIGNAL(executed(Q3ListViewItem*)),
+		this, SLOT(slotLvTypesExecuted(Q3ListViewItem*)));
+	connect(m_prjtype_sel->lv_types, SIGNAL(returnPressed(Q3ListViewItem*)),
+		this, SLOT(slotLvTypesExecuted(Q3ListViewItem*)));
+	connect(m_prjtype_sel->lv_types, SIGNAL(selectionChanged(Q3ListViewItem*)),
+		this,SLOT(slotLvTypesSelected(Q3ListViewItem*)));
 
 //	static_cast<QVBoxLayout*>(m_prjtype_sel->layout())->insertWidget(1,d->m_prjtype_sel->lv_types);
 //	static_cast<QVBoxLayout*>(m_prjtype_sel->layout())->insertStretch(3,1);
 //	updateGeometry();
 
 	addPage(m_prjtype_sel, i18n("Select Storage Method"));
-//	d->m_prjtype_sel->lv_types->setMinimumHeight(QMAX(d->lvi_file->height(),d->lvi_server->height())+25);
+//	d->m_prjtype_sel->lv_types->setMinimumHeight(qMax(d->lvi_file->height(),d->lvi_server->height())+25);
 
 	//page: db title
-	m_db_title = new KexiDBTitlePage(QString::null, this, "KexiDBTitlePage");
+	m_db_title = new KexiDBTitlePage(QString(), this);
+	m_db_title->setObjectName("KexiDBTitlePage");
 	addPage(m_db_title, i18n("Select Project's Caption"));
 
 	//page: connection selector
 	m_conn_sel_widget = new QWidget(this);
-	QVBoxLayout* conn_sel_lyr = new QVBoxLayout(m_conn_sel_widget);
-	QLabel *conn_sel_label = new QLabel(i18n("Enter a new Kexi project's file name:"), m_conn_sel_widget);
-	conn_sel_label->setAlignment(Qt::AlignAuto|Qt::AlignTop|Qt::WordBreak);
+	Q3VBoxLayout* conn_sel_lyr = new Q3VBoxLayout(m_conn_sel_widget);
+	QLabel *conn_sel_label = new QLabel(i18n("Enter a new Kexi project's file name:"),
+		m_conn_sel_widget);
+	conn_sel_label->setAlignment(Qt::AlignLeft|Qt::AlignTop);
+	conn_sel_label->setWordWrap(true);
 	conn_sel_lyr->addWidget( conn_sel_label );
-	conn_sel_lyr->addSpacing(KDialogBase::spacingHint());
+	conn_sel_lyr->addSpacing(KDialog::spacingHint());
 
-	m_conn_sel = new KexiConnSelectorWidget(conn_set, ":OpenExistingOrCreateNewProject", 
-		m_conn_sel_widget, "KexiConnSelectorWidget");
+	m_conn_sel = new KexiConnSelectorWidget(conn_set,
+		"kfiledialog:///OpenExistingOrCreateNewProject", 
+		KAbstractFileWidget::Saving, m_conn_sel_widget);
 	conn_sel_lyr->addWidget( m_conn_sel );
 
 	//"Select database server connection"
@@ -164,12 +194,12 @@ KexiNewProjectWizard::KexiNewProjectWizard(KexiDBConnectionSet& conn_set,
 
 	m_conn_sel->showSimpleConn();
 	//anyway, db files will be _saved_
-	m_conn_sel->m_fileDlg->setMode( KexiStartupFileDialog::SavingFileBasedDB );
-//	m_conn_sel->m_fileDlg->setMode( KFile::LocalOnly | KFile::File );
-//	m_conn_sel->m_fileDlg->setOperationMode( KFileDialog::Saving );
-////js	connect(m_conn_sel->m_fileDlg,SIGNAL(rejected()),this,SLOT(reject()));
-//	connect(m_conn_sel->m_fileDlg,SIGNAL(fileHighlighted(const QString&)),this,SLOT(slotFileHighlighted(const QString&)));
-	connect(m_conn_sel->m_fileDlg,SIGNAL(accepted()),this,SLOT(accept()));
+	m_conn_sel->fileWidget->setMode( KexiStartupFileWidget::SavingFileBasedDB );
+#ifdef __GNUC__
+#warning TODO KFileWidget	connect(m_conn_sel->m_fileDlg,SIGNAL(accepted()),this,SLOT(accept()));
+#else
+#pragma WARNING( TODO KFileWidget	connect(m_conn_sel->m_fileDlg,SIGNAL(accepted()),this,SLOT(accept())); )
+#endif
 	m_conn_sel->showAdvancedConn();
 	connect(m_conn_sel,SIGNAL(connectionItemExecuted(ConnectionDataLVItem*)),
 		this,SLOT(next()));
@@ -177,8 +207,10 @@ KexiNewProjectWizard::KexiNewProjectWizard(KexiDBConnectionSet& conn_set,
 	addPage(m_conn_sel_widget, i18n("Select Project's Location"));
 
 	//page: server db name
-	m_server_db_name = new KexiServerDBNamePage(this, "KexiServerDBNamePage");
-	d->server_db_name_dblist_lbl_txt = i18n("Existing project databases on <b>%1</b> database server:");
+	m_server_db_name = new KexiServerDBNamePage(this);
+	m_server_db_name->setObjectName("KexiServerDBNamePage");
+	d->server_db_name_dblist_lbl_txt
+		= I18N_NOOP("Existing project databases on <b>%1</b> database server:");
 	connect(m_server_db_name->le_caption, SIGNAL(textChanged(const QString&)),
 		this,SLOT(slotServerDBCaptionTxtChanged(const QString&)));
 	connect(m_server_db_name->le_dbname, SIGNAL(textChanged(const QString&)),
@@ -188,11 +220,11 @@ KexiNewProjectWizard::KexiNewProjectWizard(KexiDBConnectionSet& conn_set,
 	connect(m_server_db_name->le_dbname, SIGNAL(returnPressed()),
 		this,SLOT(accept()));
 	m_server_db_name->le_caption->setText(i18n("New database"));
-	m_server_db_name->le_dbname->setValidator(new KexiUtils::IdentifierValidator(this, "id_val"));
+	m_server_db_name->le_dbname->setValidator(new KexiUtils::IdentifierValidator(this));
 	m_project_selector = new KexiProjectSelectorWidget(
-		m_server_db_name->frm_dblist, "KexiProjectSelectorWidget", 0, false, false );
+		m_server_db_name->frm_dblist, 0, false, false );
 	GLUE_WIDGET(m_project_selector, m_server_db_name->frm_dblist);
-	m_project_selector->setFocusPolicy(NoFocus);
+	m_project_selector->setFocusPolicy(Qt::NoFocus);
 	m_project_selector->setSelectable(false);
 
 	addPage(m_server_db_name, i18n("Select Project's Caption & Database Name"));
@@ -203,29 +235,7 @@ KexiNewProjectWizard::KexiNewProjectWizard(KexiDBConnectionSet& conn_set,
 
 	//finish:
 	updateGeometry();
-//	d->m_prjtype_sel->lv_types->setMaximumWidth(width()/2);
 	m_prjtype_sel->lv_types->setSelected(d->lvi_file, true);
-
-#ifdef KEXI_SERVER_SUPPORT
-//	//get settings
-//	KGlobal::config()->setGroup("Startup");
-//	//"" means goto 1st page
-//	QString default_storage = KGlobal::config()->readEntry("DefaultStorageForNewProjects","");
-#else
-//	QString default_storage = "file";
-	setBackEnabled(m_db_title, false);
-	showPage(m_db_title);
-#endif
-/*	if (default_storage.lower()=="server") {
-		m_prjtype_sel->lv_types->setSelected(d->lvi_server, true);
-//		m_prjtype_sel->chk_always->setChecked(true);
-		m_conn_sel->showAdvancedConn();
-		showPage(m_conn_sel);
-	}
-	else { //"file"
-//		m_prjtype_sel->chk_always->setChecked(true);
-		showPage(m_db_title);
-	}*/
 }
 
 KexiNewProjectWizard::~KexiNewProjectWizard()
@@ -236,15 +246,15 @@ KexiNewProjectWizard::~KexiNewProjectWizard()
 void KexiNewProjectWizard::show()
 {
 	KDialog::centerOnScreen(this);
-	KWizard::show();
+	K3Wizard::show();
 }
 
-void KexiNewProjectWizard::slotLvTypesExecuted(QListViewItem *)
+void KexiNewProjectWizard::slotLvTypesExecuted(Q3ListViewItem *)
 {
 	next();
 }
 
-void KexiNewProjectWizard::slotLvTypesSelected(QListViewItem *item)
+void KexiNewProjectWizard::slotLvTypesSelected(Q3ListViewItem *item)
 {
 /*	if (item==d->lvi_file) {
 		m_prjtype_sel->chk_always->setText(d->chk_file_txt);
@@ -262,7 +272,7 @@ void KexiNewProjectWizard::showPage(QWidget *page)
 		m_prjtype_sel->lv_types->setFocus();
 		m_prjtype_sel->lv_types->setCurrentItem(m_prjtype_sel->lv_types->currentItem());
 	} else if (page==m_db_title) {//p 2
-		if (m_db_title->le_caption->text().stripWhiteSpace().isEmpty())
+		if (m_db_title->le_caption->text().trimmed().isEmpty())
 			m_db_title->le_caption->setText(i18n("New database"));
 		m_db_title->le_caption->selectAll();
 		m_db_title->le_caption->setFocus();
@@ -272,7 +282,7 @@ void KexiNewProjectWizard::showPage(QWidget *page)
 			QString fn = KexiUtils::string2FileName( m_db_title->le_caption->text() );
 			if (!fn.endsWith(".kexi"))
 				fn += ".kexi";
-			m_conn_sel->m_fileDlg->setLocationText(fn);
+			m_conn_sel->fileWidget->setLocationText( fn );
 			setFinishEnabled(m_conn_sel_widget,true);
 			m_conn_sel->setFocus();
 		}
@@ -299,14 +309,14 @@ void KexiNewProjectWizard::showPage(QWidget *page)
 			m_project_selector->setProjectSet( d->project_set_to_show );
 		}
 	}
-	KWizard::showPage(page);
+	K3Wizard::showPage(page);
 }
 
 void KexiNewProjectWizard::next()
 {
 	//let's check if move to next page is allowed:
 	if (currentPage()==m_db_title) { //pg 2
-		if (m_db_title->le_caption->text().stripWhiteSpace().isEmpty()) {
+		if (m_db_title->le_caption->text().trimmed().isEmpty()) {
 			KMessageBox::information(this, i18n("Enter project caption."));
 			m_db_title->le_caption->setText("");
 			m_db_title->le_caption->setFocus();
@@ -322,36 +332,36 @@ void KexiNewProjectWizard::next()
 				KMessageBox::information(this, i18n("Select server connection for a new project."));
 				return;
 			}
-			m_project_selector->label->setText(
-				d->server_db_name_dblist_lbl_txt.arg(m_conn_sel->selectedConnectionData()->serverInfoString(false)) );
+			m_project_selector->label()->setText(
+				d->server_db_name_dblist_lbl_txt
+					.arg(m_conn_sel->selectedConnectionData()->serverInfoString(false)) );
 			m_server_db_name->le_caption->setFocus();
 
 		}
 	}
-	KWizard::next();
+	K3Wizard::next();
 }
 
 void KexiNewProjectWizard::accept()
 {
 	if (m_prjtype_sel->lv_types->currentItem()==d->lvi_file) {//FILE:
 		//check if new db file name is ok
-		kdDebug() << "********** sender() " << sender()->className() << endl;
+		kDebug() << "********** sender() " << sender()->metaObject()->className() << endl;
 		if (sender()==finishButton()) { /*(only if signal does not come from filedialog)*/
-			kdDebug() << "********** sender()==finishButton() ********" << endl;
-//			if (!m_conn_sel->m_fileDlg->checkURL()) {
-			if (!m_conn_sel->m_fileDlg->checkFileName()) {
+			kDebug() << "********** sender()==finishButton() ********" << endl;
+			if (!m_conn_sel->fileWidget->checkSelectedFile()) {
 				return;
 			}
 		}
 	} else {//SERVER:
 		//check if we have enough of data
-		if (m_server_db_name->le_caption->text().stripWhiteSpace().isEmpty()) {
+		if (m_server_db_name->le_caption->text().trimmed().isEmpty()) {
 			KMessageBox::information(this, i18n("Enter project caption."));
 			m_server_db_name->le_caption->setText("");
 			m_server_db_name->le_caption->setFocus();
 			return;
 		}
-		QString dbname = m_server_db_name->le_dbname->text().stripWhiteSpace();
+		QString dbname = m_server_db_name->le_dbname->text().trimmed();
 		if (dbname.isEmpty()) {
 			KMessageBox::information(this, i18n("Enter project's database name."));
 			m_server_db_name->le_dbname->setText("");
@@ -361,11 +371,12 @@ void KexiNewProjectWizard::accept()
 		//check for duplicated dbname
 		if (m_conn_sel->confirmOverwrites() && m_project_selector->projectSet() && m_project_selector->projectSet()
 			->findProject( m_server_db_name->le_dbname->text() )) {
-			if (KMessageBox::Continue!=KMessageBox::warningContinueCancel( this, "<qt>"
-				+i18n("<b>A project with database name \"%1\" already exists</b>"
-				"<p>Do you want to delete it and create a new one?")
-				.arg( m_server_db_name->le_dbname->text() ), QString::null, KStdGuiItem::del(), 
-				QString::null, KMessageBox::Notify|KMessageBox::Dangerous ))
+			if (KMessageBox::Continue!=KMessageBox::warningContinueCancel( this,
+				"<qt>"+i18n("<b>A project with database name \"%1\" already exists</b>"
+				"<p>Do you want to delete it and create a new one?",
+					m_server_db_name->le_dbname->text() ), QString(), 
+				KStandardGuiItem::del(), KStandardGuiItem::cancel(),
+				QString(), KMessageBox::Notify|KMessageBox::Dangerous ))
 			{
 				m_server_db_name->le_dbname->setFocus();
 				return;
@@ -373,7 +384,7 @@ void KexiNewProjectWizard::accept()
 		}
 	}
 
-	KWizard::accept();
+	K3Wizard::accept();
 }
 
 void KexiNewProjectWizard::done(int r)
@@ -388,7 +399,7 @@ void KexiNewProjectWizard::done(int r)
 		KGlobal::config()->writeEntry("DefaultStorageForNewProjects","Server");*/
 
 	KGlobal::config()->sync();
-	KWizard::done(r);
+	K3Wizard::done(r);
 }
 
 QString KexiNewProjectWizard::projectDBName() const
@@ -439,6 +450,4 @@ void KexiNewProjectWizard::setConfirmOverwrites(bool set)
 	m_conn_sel->setConfirmOverwrites(set);
 }
 
-
 #include "KexiNewProjectWizard.moc"
-
