@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 2003-2006 Jaroslaw Staniek <js@iidea.pl>
+   Copyright (C) 2003-2007 Jaroslaw Staniek <js@iidea.pl>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -18,11 +18,11 @@
 */
 
 #include "KexiStartup.h"
-#ifdef Q_WS_WIN
-# include "KexiStartup_p_win.h"
-#else
-# include "KexiStartup_p.h"
-#endif
+//#ifdef Q_WS_WIN
+//# include "KexiStartup_p_win.h"
+//#else
+#include "KexiStartup_p.h"
+//#endif
 
 #include "kexiproject.h"
 #include "kexiprojectdata.h"
@@ -33,7 +33,6 @@
 #include <kexidb/drivermanager.h>
 #include "KexiStartupDialog.h"
 #include "KexiConnSelector.h"
-#include "KexiProjectSelectorBase.h"
 #include "KexiProjectSelector.h"
 #include "KexiNewProjectWizard.h"
 #include <kexidbconnectionwidget.h>
@@ -45,45 +44,36 @@
 #include <kmessagebox.h>
 #include <kcmdlineargs.h>
 #include <kdeversion.h>
-#include <kprogress.h>
 #include <ktextedit.h>
-#include <kstaticdeleter.h>
+#include <kuser.h>
+#include <KProgressDialog>
 
 #include <unistd.h>
 
-#if KDE_IS_VERSION(3,1,9)
-# include <kuser.h>
-#endif
-
-#include <qcstring.h>
 #include <qapplication.h>
 #include <qlayout.h>
 
 namespace Kexi {
-	static KStaticDeleter<KexiStartupHandler> Kexi_startupHandlerDeleter;
-	KexiStartupHandler* _startupHandler = 0;
+	K_GLOBAL_STATIC(KexiStartupHandler, _startupHandler)
 
-	KexiStartupHandler& startupHandler()
-	{
-		if (!_startupHandler)
-			Kexi_startupHandlerDeleter.setObject( _startupHandler, new KexiStartupHandler() );
-		return *_startupHandler; 
+	KexiStartupHandler& startupHandler() {
+		return *_startupHandler;
 	}
 }
 
 //---------------------------------
 
 //! @internal
-class KexiStartupHandlerPrivate
+class KexiStartupHandler::Private
 {
 	public:
-		KexiStartupHandlerPrivate()
+		Private()
 		 : passwordDialog(0)//, showConnectionDetailsExecuted(false)
 			, shortcutFile(0), connShortcutFile(0), connDialog(0), startupDialog(0)
 		{
 		}
 
-		~KexiStartupHandlerPrivate()
+		~Private()
 		{
 			delete passwordDialog;
 			delete connDialog;
@@ -114,7 +104,8 @@ static bool stripQuotes(const QString &item, QString &name)
 void updateProgressBar(KProgressDialog *pd, char *buffer, int buflen)
 {
 	char *p = buffer;
-	QCString line(80);
+	QByteArray line;
+	line.reserve(80);
 	for (int i=0; i<buflen; i++, p++) {
 		if ((i==0 || buffer[i-1]=='\n') && buffer[i]=='%') {
 			bool ok;
@@ -123,13 +114,13 @@ void updateProgressBar(KProgressDialog *pd, char *buffer, int buflen)
 			++i;
 			line="";
 			for (;i<buflen && *p>='0' && *p<='9'; j++, i++, p++)
-				line+=QChar(*p);
+				line += *p;
 			--i; --p;
-			int percent = line.toInt(&ok);
-			if (ok && percent>=0 && percent<=100 && pd->progressBar()->progress()<percent) {
-//				kdDebug() << percent << endl;
-				pd->progressBar()->setProgress(percent);
-				qApp->processEvents(100);
+			const int percent = line.toInt(&ok);
+			if (ok && percent>=0 && percent<=100 && pd->progressBar()->value() < percent) {
+//				kDebug() << percent << endl;
+				pd->progressBar()->setValue(percent);
+				qApp->processEvents(QEventLoop::AllEvents, 100);
 			}
 		}
 	}
@@ -138,8 +129,8 @@ void updateProgressBar(KProgressDialog *pd, char *buffer, int buflen)
 //---------------------------------
 
 KexiDBPasswordDialog::KexiDBPasswordDialog(QWidget *parent, KexiDB::ConnectionData& cdata, bool showDetailsButton)
- : KPasswordDialog( KPasswordDialog::Password, false/*keep*/, 
-	showDetailsButton ? (int)KDialogBase::User1 : 0, parent )
+ : KPasswordDialog( parent, KPasswordDialog::NoFlags, 
+ 		showDetailsButton ? KDialog::User1 : KDialog::None )
  , m_cdata(&cdata)
  , m_showConnectionDetailsRequested(false)
 {
@@ -150,26 +141,27 @@ KexiDBPasswordDialog::KexiDBPasswordDialog(QWidget *parent, KexiDB::ConnectionDa
 			: "<p>"+i18n("Please enter the password for user.").arg("<b>"+cdata.userName+"</b>");*/
 
 	QString srv = cdata.serverInfoString(false);
-	if (srv.isEmpty() || srv.lower()=="localhost")
+	if (srv.isEmpty() || srv.toLower()=="localhost")
 		srv = i18n("local database server");
 
-	msg += ("</p><p>"+i18n("Database server: %1").arg(QString("<nobr>")+srv+"</nobr>")+"</p>");
+	msg += ("</p><p>"+i18n("Database server: %1", QString("<nobr>")+srv+"</nobr>")+"</p>");
 		
 	QString usr;
 	if (cdata.userName.isEmpty())
-		usr = i18n("unspecified user", "(unspecified)");
+		usr = i18nc("unspecified user", "(unspecified)");
 	else
 		usr = cdata.userName;
 	
-	msg += ("<p>"+i18n("Username: %1").arg(usr)+"</p>");
+	msg += ("<p>"+i18n("Username: %1", usr)+"</p>");
 
 	setPrompt( msg );
 	if (showDetailsButton) {
 		connect( this, SIGNAL(user1Clicked()), 
 			this, SLOT(slotShowConnectionDetails()) );
-		setButtonText(KDialogBase::User1, i18n("&Details")+ " >>");
+		setButtonText(KDialog::User1, i18n("&Details")+ " >>");
 	}
-	setButtonOK(KGuiItem(i18n("&Open"), "fileopen"));
+	setButtonText(KDialog::Ok, i18n("&Open"));
+	setButtonIcon(KDialog::Ok, KIcon("document-open"));
 }
 
 KexiDBPasswordDialog::~KexiDBPasswordDialog()
@@ -179,7 +171,7 @@ KexiDBPasswordDialog::~KexiDBPasswordDialog()
 void KexiDBPasswordDialog::done(int r)
 {
 	if (r == QDialog::Accepted) {
-		m_cdata->password = QString::fromLatin1(password());
+		m_cdata->password = password();
 	}
 //	if (d->showConnectionDetailsExecuted || ret == QDialog::Accepted) {
 /*			} else {
@@ -198,9 +190,9 @@ void KexiDBPasswordDialog::slotShowConnectionDetails()
 
 //---------------------------------
 KexiStartupHandler::KexiStartupHandler()
- : QObject(0,"KexiStartupHandler")
+ : QObject(0)
  , KexiStartupData()
- , d( new KexiStartupHandlerPrivate() )
+ , d( new Private() )
 {
 }
 
@@ -209,13 +201,12 @@ KexiStartupHandler::~KexiStartupHandler()
 	delete d;
 }
 
-bool KexiStartupHandler::getAutoopenObjects(KCmdLineArgs *args, const QCString &action_name)
+bool KexiStartupHandler::getAutoopenObjects(KCmdLineArgs *args, const QByteArray &action_name)
 {
-	QCStringList list = args->getOptionList(action_name);
-	QCStringList::ConstIterator it;
+	QStringList list = args->getOptionList(action_name);
 	bool atLeastOneFound = false;
-	for ( it = list.constBegin(); it!=list.constEnd(); ++it) {
-		QString type_name, obj_name, item=*it;
+	foreach ( QString option, list ) {
+		QString type_name, obj_name, item = option;
 		int idx;
 		bool name_required = true;
 		if (action_name=="new") {
@@ -234,9 +225,9 @@ bool KexiStartupHandler::getAutoopenObjects(KCmdLineArgs *args, const QCString &
 			if (stripQuotes(item, obj_name)) {
 				type_name = defaultType;
 			}
-			else if ((idx = item.find(':'))!=-1) {
+			else if ((idx = item.indexOf(':'))!=-1) {
 				//option with type name specified:
-				type_name = item.left(idx).lower();
+				type_name = item.left(idx).toLower();
 				obj_name = item.mid(idx+1);
 				//optional: remove ""
 				if (obj_name.left(1)=="\"" && obj_name.right(1)=="\"")
@@ -285,8 +276,8 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 //!       For we're displaying generic error msg.
 			KMessageBox::sorry( 0, "<qt>"
 				+i18n("Could not read connection information from connection shortcut "
-				"file <nobr>\"%1\"</nobr>.<br><br>Check whether the file has valid contents.")
-				.arg(QDir::convertSeparators(connectionShortcut.fileName())));
+				"file <nobr>\"%1\"</nobr>.<br><br>Check whether the file has valid contents.",
+				QDir::convertSeparators(connectionShortcut.fileName())));
 			return false;
 		}
 	}
@@ -294,24 +285,22 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 	if (!args->getOption("dbdriver").isEmpty())
 		cdata.driverName = args->getOption("dbdriver");
 
-	QString fileType( args->getOption("type").lower() );
+	QString fileType( args->getOption("type").toLower() );
 	if (args->count()>0 && (!fileType.isEmpty() && fileType!="project" && fileType!="shortcut" && fileType!="connection")) {
 		KMessageBox::sorry( 0, 
-			i18n("You have specified invalid argument (\"%1\") for \"type\" command-line option.")
-			.arg(fileType));
+			i18n("You have specified invalid argument (\"%1\") for \"type\" command-line option.",
+				fileType));
 		return false;
 	}
 
 //	if (cdata.driverName.isEmpty())
 //		cdata.driverName = KexiDB::Driver::defaultFileBasedDriverName();
-#ifdef KEXI_SERVER_SUPPORT
 	if (!args->getOption("host").isEmpty())
 		cdata.hostName = args->getOption("host");
 	if (!args->getOption("local-socket").isEmpty())
 		cdata.localSocketFileName = args->getOption("local-socket");
 	if (!args->getOption("user").isEmpty())
 		cdata.userName = args->getOption("user");
-#endif
 //	cdata.password = args->getOption("password");
 	bool fileDriverSelected;
 	if (cdata.driverName.isEmpty())
@@ -320,7 +309,7 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 		KexiDB::DriverManager dm;
 		KexiDB::Driver::Info dinfo = dm.driverInfo(cdata.driverName);
 		if (dinfo.name.isEmpty()) {
-			//driver name provided explicity, but not found
+			//driver name provided explicitly, but not found
 			KMessageBox::sorry(0, dm.errorMsg());
 			return false;
 		}
@@ -346,7 +335,6 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 	}
 	*/
 	
-#ifdef KEXI_SERVER_SUPPORT
 	const QString portStr = args->getOption("port");
 	if (!portStr.isEmpty()) {
 		bool ok;
@@ -355,19 +343,14 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 			cdata.port = p;
 		else {
 			KMessageBox::sorry( 0, 
-				i18n("You have specified invalid port number \"%1\"."));
+				i18n("You have specified invalid port number \"%1\".", portStr));
 			return false;
 		}
 	}
-#endif
 
-#ifdef KEXI_SHOW_UNIMPLEMENTED
-	m_forcedFinalMode = args->isSet("final-mode");
+	m_forcedUserMode = args->isSet("user-mode");
 	m_forcedDesignMode = args->isSet("design-mode");
-#else
-	m_forcedFinalMode = false;
-	m_forcedDesignMode = false;
-#endif
+	m_isProjectNavigatorVisible = args->isSet("show-navigator");
 	bool createDB = args->isSet("createdb");
 	const bool alsoOpenDB = args->isSet("create-opendb");
 	if (alsoOpenDB)
@@ -414,14 +397,14 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 		}
 	}
 
-/*	kdDebug() << "ARGC==" << args->count() << endl;
+/*	kDebug() << "ARGC==" << args->count() << endl;
 	for (int i=0;i<args->count();i++) {
-		kdDebug() << "ARG" <<i<< "= " << args->arg(i) <<endl;
+		kDebug() << "ARG" <<i<< "= " << args->arg(i) <<endl;
 	}*/
 
-	if (m_forcedFinalMode && m_forcedDesignMode) {
+	if (m_forcedUserMode && m_forcedDesignMode) {
 		KMessageBox::sorry( 0, i18n(
-		"You have used both \"final-mode\" and \"design-mode\" startup options.")+couldnotMsg);
+		"You have used both \"user-mode\" and \"design-mode\" startup options.")+couldnotMsg);
 		return false;
 	}
 
@@ -430,22 +413,22 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 		QString prjName;
 		QString fileName;
 		if (fileDriverSelected) {
-			fileName = QFile::decodeName(args->arg(0));
+			fileName = args->arg(0);
 		}
 		else {
-			prjName = QString::fromLocal8Bit(args->arg(0));
+			prjName = args->arg(0);
 		}
 		
 		if (fileDriverSelected) {
 			QFileInfo finfo(fileName);
 			prjName = finfo.fileName(); //filename only, to avoid messy names like when Kexi is started with "../../db" arg
-			cdata.setFileName( finfo.absFilePath() );
+			cdata.setFileName( finfo.absoluteFilePath() );
 			projectFileExists = finfo.exists();
 
 			if (dropDB && !projectFileExists) {
 				KMessageBox::sorry(0, 
-					i18n("Could not remove project.\nThe file \"%1\" does not exist.")
-					.arg(QDir::convertSeparators(cdata.dbFileName())));
+					i18n("Could not remove project.\nThe file \"%1\" does not exist.",
+						QDir::convertSeparators(cdata.dbFileName())));
 				return 0;
 			}
 		}
@@ -486,15 +469,15 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 					d->shortcutFile = new KexiDBShortcutFile(cdata.fileName());
 					m_projectData = new KexiProjectData();
 					if (!d->shortcutFile->loadProjectData(*m_projectData, &d->shortcutFileGroupKey)) {
-						KMessageBox::sorry(0, i18n("Could not open shortcut file\n\"%1\".")
-							.arg(QDir::convertSeparators(cdata.fileName())));
+						KMessageBox::sorry(0, i18n("Could not open shortcut file\n\"%1\".",
+							QDir::convertSeparators(cdata.fileName())));
 						delete m_projectData;
 						m_projectData = 0;
 						delete d->shortcutFile;
 						d->shortcutFile = 0;
 						return false;
 					}
-					d->connDialog = new KexiDBConnectionDialog(
+					d->connDialog = new KexiDBConnectionDialog(0,
 						*m_projectData, d->shortcutFile->fileName());
 					connect(d->connDialog, SIGNAL(saveChanges()), 
 						this, SLOT(slotSaveShortcutFileChanges()));
@@ -519,8 +502,8 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 					//get information for a connection file
 					d->connShortcutFile = new KexiDBConnShortcutFile(cdata.fileName());
 					if (!d->connShortcutFile->loadConnectionData(cdata, &d->shortcutFileGroupKey)) {
-						KMessageBox::sorry(0, i18n("Could not open connection data file\n\"%1\".")
-							.arg(QDir::convertSeparators(cdata.fileName())));
+						KMessageBox::sorry(0, i18n("Could not open connection data file\n\"%1\".",
+							QDir::convertSeparators(cdata.fileName())));
 						delete d->connShortcutFile;
 						d->connShortcutFile = 0;
 						return false;
@@ -531,7 +514,7 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 						if (showConnectionDialog) {
 							//show connection dialog, so user can change parameters
 							if (!d->connDialog) {
-								d->connDialog = new KexiDBConnectionDialog(
+								d->connDialog = new KexiDBConnectionDialog(0,
 									cdata, d->connShortcutFile->fileName());
 								connect(d->connDialog, SIGNAL(saveChanges()), 
 									this, SLOT(slotSaveShortcutFileChanges()));
@@ -575,7 +558,7 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 
 	//let's show connection details, user asked for that in the "password dialog"
 	if (d->passwordDialog && d->passwordDialog->showConnectionDetailsRequested()) {
-		d->connDialog = new KexiDBConnectionDialog(*m_projectData);
+		d->connDialog = new KexiDBConnectionDialog(0, *m_projectData);
 //		connect(d->connDialog->tabWidget->mainWidget, SIGNAL(saveChanges()), 
 //			this, SLOT(slotSaveShortcutFileChanges()));
 		int res = d->connDialog->exec();
@@ -622,8 +605,8 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 			return cancelled;
 		if (!alsoOpenDB) {
 			if (ok) {
-				KMessageBox::information( 0, i18n("Project \"%1\" created successfully.")
-					.arg( QDir::convertSeparators(projectData()->databaseName()) ));
+				KMessageBox::information( 0, i18n("Project \"%1\" created successfully.",
+					QDir::convertSeparators(projectData()->databaseName()) ));
 			}
 			return ok;
 		}
@@ -632,8 +615,8 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 		KexiGUIMessageHandler gui;
 		tristate res = KexiProject::dropProject(projectData(), &gui, false/*ask*/);
 		if (res==true)
-			KMessageBox::information( 0, i18n("Project \"%1\" dropped successfully.")
-				.arg( QDir::convertSeparators(projectData()->databaseName()) ));
+			KMessageBox::information( 0, i18n("Project \"%1\" dropped successfully.",
+				QDir::convertSeparators(projectData()->databaseName()) ));
 		return res!=false;
 	}
 
@@ -641,7 +624,7 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 
 /*	if (m_forcedFinalMode || (m_projectData && projectData->finalMode())) {
 		//TODO: maybe also auto allow to open objects...
-		KexiMainWindowImpl::initFinal(m_projectData);
+		KexiMainWindow::initFinal(m_projectData);
 		return;
 	}*/
 
@@ -655,33 +638,42 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 			//create d->startupDialog for reuse because it can be used again after conn err.
 			d->startupDialog = new KexiStartupDialog(
 				KexiStartupDialog::Everything, KexiStartupDialog::CheckBoxDoNotShowAgain,
-				Kexi::connset(), Kexi::recentProjects(), 0, "KexiStartupDialog");
+				Kexi::connset(), Kexi::recentProjects(), 0);
 		}
 		if (d->startupDialog->exec()!=QDialog::Accepted)
 			return true;
 
-		int r = d->startupDialog->result();
-		if (r==KexiStartupDialog::TemplateResult) {
-//			kdDebug() << "Template key == " << d->startupDialog->selectedTemplateKey() << endl;
-			QString selectedTemplateKey( d->startupDialog->selectedTemplateKey() );
-			if (selectedTemplateKey=="blank") {
-				m_action = CreateBlankProject;
-				return true;
-			}
-			else if (selectedTemplateKey=="import") {
-				m_action = ImportProject;
-				return true;
-			}
-			
-//! @todo - templates: m_action = UseTemplate;
+		const int r = d->startupDialog->result();
+		if (r == KexiStartupDialog::CreateBlankResult) {
+			m_action = CreateBlankProject;
 			return true;
 		}
-		else if (r==KexiStartupDialog::OpenExistingResult) {
-//			kdDebug() << "Existing project --------" << endl;
-			QString selFile = d->startupDialog->selectedExistingFile();
+		else if (r == KexiStartupDialog::ImportResult) {
+			m_action = ImportProject;
+			return true;
+		}
+		else if (r == KexiStartupDialog::CreateFromTemplateResult) {
+			const QString selFile( d->startupDialog->selectedFileName() );
+			cdata.setFileName( selFile );
+			QString detectedDriverName;
+			const tristate res = detectActionForFile( m_importActionData, detectedDriverName, 
+				cdata.driverName, selFile );
+			if (true != res)
+				return res;
+			if (m_importActionData || detectedDriverName.isEmpty())
+				return false;
+			cdata.driverName = detectedDriverName;
+			m_projectData = new KexiProjectData(cdata, selFile);
+			m_projectData->autoopenObjects = d->startupDialog->autoopenObjects();
+			m_action = CreateFromTemplate;
+			return true;
+		}
+		else if (r == KexiStartupDialog::OpenExistingResult) {
+//			kDebug() << "Existing project --------" << endl;
+			const QString selFile( d->startupDialog->selectedFileName() );
 			if (!selFile.isEmpty()) {
 				//file-based project
-//				kdDebug() << "Project File: " << selFile << endl;
+//				kDebug() << "Project File: " << selFile << endl;
 				cdata.setFileName( selFile );
 				QString detectedDriverName;
 				const tristate res = detectActionForFile( m_importActionData, detectedDriverName, 
@@ -699,7 +691,7 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 				m_projectData = new KexiProjectData(cdata, selFile);
 			}
 			else if (d->startupDialog->selectedExistingConnection()) {
-//				kdDebug() << "Existing connection: " <<
+//				kDebug() << "Existing connection: " <<
 //					d->startupDialog->selectedExistingConnection()->serverInfoString() << endl;
 				KexiDB::ConnectionData *cdata = d->startupDialog->selectedExistingConnection();
 				//ok, now we will try to show projects for this connection to the user
@@ -715,10 +707,10 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 			}
 		}
 		else if (r==KexiStartupDialog::OpenRecentResult) {
-//			kdDebug() << "Recent project --------" << endl;
+//			kDebug() << "Recent project --------" << endl;
 			const KexiProjectData *data = d->startupDialog->selectedProjectData();
 			if (data) {
-//				kdDebug() << "Selected project: database=" << data->databaseName()
+//				kDebug() << "Selected project: database=" << data->databaseName()
 //					<< " connection=" << data->constConnectionData()->serverInfoString() << endl;
 			}
 //! @todo
@@ -745,13 +737,13 @@ tristate KexiStartupHandler::detectActionForFile(
 {
 	detectedImportAction = KexiStartupData::Import(); //clear
 	QString suggestedDriverName(_suggestedDriverName); //safe
-	detectedDriverName = QString::null;
+	detectedDriverName.clear();
 	QFileInfo finfo(dbFileName);
 	if (dbFileName.isEmpty() || !finfo.isReadable()) {
 		if (!(options & SkipMessages))
 			KMessageBox::sorry(parent, i18n("<p>Could not open project.</p>")
-				+i18n("<p>The file <nobr>\"%1\"</nobr> does not exist or is not readable.</p>")
-				.arg(QDir::convertSeparators(dbFileName))
+				+i18n("<p>The file <nobr>\"%1\"</nobr> does not exist or is not readable.</p>",
+					QDir::convertSeparators(dbFileName))
 				+i18n("Check the file's permissions and whether it is already opened "
 				"and locked by another application."));
 		return false;
@@ -766,24 +758,24 @@ tristate KexiStartupHandler::detectActionForFile(
 	if ((options & ThisIsAProjectFile) || !thisIsShortcut) {
 		//try this detection if "project file" mode is forced or no type is forced:
 		ptr = KMimeType::findByFileContent(dbFileName);
-		mimename = ptr.data()->name();
-		kdDebug() << "KexiStartupHandler::detectActionForFile(): found mime is: " 
+		mimename = ptr.data() ? ptr.data()->name() : QString();
+		kDebug() << "KexiStartupHandler::detectActionForFile(): found mime is: " 
 			<< mimename << endl;
 		if (mimename.isEmpty() || mimename=="application/octet-stream" || mimename=="text/plain") {
 			//try by URL:
-			ptr = KMimeType::findByURL(dbFileName);
+			ptr = KMimeType::findByUrl( KUrl::fromPath(dbFileName) );
 			mimename = ptr.data()->name();
 		}
 	}
 	if (mimename.isEmpty() || mimename=="application/octet-stream") {
 		// perhaps the file is locked
 		QFile f(dbFileName);
-		if (!f.open(IO_ReadOnly)) {
+		if (!f.open(QIODevice::ReadOnly)) {
 			// BTW: similar error msg is provided in SQLiteConnection::drv_useDatabase()
 			if (!(options & SkipMessages))
 				KMessageBox::sorry(parent, i18n("<p>Could not open project.</p>")
-					+i18n("<p>The file <nobr>\"%1\"</nobr> is not readable.</p>")
-					.arg(QDir::convertSeparators(dbFileName))
+					+i18n("<p>The file <nobr>\"%1\"</nobr> is not readable.</p>",
+						QDir::convertSeparators(dbFileName))
 					+i18n("Check the file's permissions and whether it is already opened "
 						"and locked by another application."));
 			return false;
@@ -802,12 +794,12 @@ tristate KexiStartupHandler::detectActionForFile(
 	//! @todo rather check this using migration drivers' 
 	//! X-KexiSupportedMimeTypes [strlist] property
 	if (ptr.data()) {
-		if (mimename=="application/x-msaccess") {
+		if (mimename=="application/vnd.ms-access") {
 			if ((options & SkipMessages) || KMessageBox::Yes != KMessageBox::questionYesNo(
 				parent, i18n("\"%1\" is an external file of type:\n\"%2\".\n"
-				"Do you want to import the file as a Kexi project?")
-				.arg(QDir::convertSeparators(dbFileName)).arg(ptr.data()->comment()),
-				i18n("Open External File"), KGuiItem(i18n("Import...")), KStdGuiItem::cancel() ) )
+				"Do you want to import the file as a Kexi project?",
+					QDir::convertSeparators(dbFileName), ptr.data()->comment()),
+				i18n("Open External File"), KGuiItem(i18n("Import...")), KStandardGuiItem::cancel() ) )
 			{
 				return cancelled;
 			}
@@ -822,18 +814,18 @@ tristate KexiStartupHandler::detectActionForFile(
 	}
 
 	// "application/x-kexiproject-sqlite", etc.:
-	QString tmpDriverName = Kexi::driverManager().lookupByMime(mimename).latin1();
+	QString tmpDriverName = Kexi::driverManager().lookupByMime(mimename).toLatin1();
 //@todo What about trying to reuse KOFFICE FILTER CHAINS here?
-	bool useDetectedDriver = suggestedDriverName.isEmpty() || suggestedDriverName.lower()==detectedDriverName.lower();
+	bool useDetectedDriver = suggestedDriverName.isEmpty() || suggestedDriverName.toLower()==detectedDriverName.toLower();
 	if (!useDetectedDriver) {
 		int res = KMessageBox::Yes;
 		if (!(options & SkipMessages))
 			res = KMessageBox::warningYesNoCancel(parent, i18n(
 			 "The project file \"%1\" is recognized as compatible with \"%2\" database driver, "
 			 "while you have asked for \"%3\" database driver to be used.\n"
-			 "Do you want to use \"%4\" database driver?")
-			 .arg(QDir::convertSeparators(dbFileName))
-			 .arg(tmpDriverName).arg(suggestedDriverName).arg(tmpDriverName));
+			 "Do you want to use \"%4\" database driver?",
+			 QDir::convertSeparators(dbFileName),
+			 tmpDriverName, suggestedDriverName, tmpDriverName));
 		if (KMessageBox::Yes == res)
 			useDetectedDriver = true;
 		else if (KMessageBox::Cancel == res)
@@ -845,26 +837,34 @@ tristate KexiStartupHandler::detectActionForFile(
 	else {//use suggested driver
 		detectedDriverName = suggestedDriverName;
 	}
-//	kdDebug() << "KexiStartupHandler::detectActionForFile(): driver name: " << detectedDriverName << endl;
+//	kDebug() << "KexiStartupHandler::detectActionForFile(): driver name: " << detectedDriverName << endl;
 //hardcoded for convenience:
 	const QString newFileFormat = "SQLite3";
 	if (!(options & DontConvert || options & SkipMessages) 
-		&& detectedDriverName.lower()=="sqlite2" && detectedDriverName.lower()!=suggestedDriverName.lower()
+		&& detectedDriverName.toLower()=="sqlite2" && detectedDriverName.toLower()!=suggestedDriverName.toLower()
 		&& KMessageBox::Yes == KMessageBox::questionYesNo(parent, i18n(
 			"Previous version of database file format (\"%1\") is detected in the \"%2\" "
-			"project file.\nDo you want to convert the project to a new \"%3\" format (recommended)?")
-			.arg(detectedDriverName).arg(QDir::convertSeparators(dbFileName)).arg(newFileFormat)) )
+			"project file.\nDo you want to convert the project to a new \"%3\" format (recommended)?",
+				detectedDriverName, QDir::convertSeparators(dbFileName), newFileFormat)) )
 	{
-//		SQLite2ToSQLite3Migration *migr = new 
-		SQLite2ToSQLite3Migration migr( finfo.absFilePath() );
+#ifdef __GNUC__
+#warning reenable when SQLite2ToSQLite3Migration is ported
+#else
+#pragma WARNING( reenable when SQLite2ToSQLite3Migration is ported )
+#endif
+#if 0 //TODO
+		SQLite2ToSQLite3Migration migr( finfo.absoluteFilePath() );
 		tristate res = migr.run();
-//		kdDebug() << "--- migr.run() END ---" <<endl;
+//		kDebug() << "--- migr.run() END ---" <<endl;
+#else
+		tristate res = false;
+#endif
 		if (!res) {
 			//TODO msg
 			KMessageBox::sorry(parent, i18n(
 				"Failed to convert project file \"%1\" to a new \"%2\" format.\n"
-				"The file format remains unchanged.")
-				.arg(QDir::convertSeparators(dbFileName)).arg(newFileFormat) );
+				"The file format remains unchanged.",
+				QDir::convertSeparators(dbFileName), newFileFormat) );
 			//continue...
 		}
 		if (res==true)
@@ -879,11 +879,11 @@ tristate KexiStartupHandler::detectActionForFile(
 		}
 		if (!(options & SkipMessages))
 			KMessageBox::detailedSorry(parent, 
-				i18n( "The file \"%1\" is not recognized as being supported by Kexi.")
-					.arg(QDir::convertSeparators(dbFileName)),
+				i18n( "The file \"%1\" is not recognized as being supported by Kexi.",
+					QDir::convertSeparators(dbFileName)),
 				QString::fromLatin1("<p>")
-				+i18n("Database driver for this file type not found.\nDetected MIME type: %1")
-					.arg(mimename)
+				+i18n("Database driver for this file type not found.\nDetected MIME type: %1",
+					mimename)
 				+(ptr.data()->comment().isEmpty() 
 					? QString::fromLatin1(".") : QString::fromLatin1(" (%1).").arg(ptr.data()->comment()))
 				+QString::fromLatin1("</p>")
@@ -913,17 +913,17 @@ KexiStartupHandler::selectProject(KexiDB::ConnectionData *cdata, bool& cancelled
 	}
 	KexiProjectData* projectData = 0;
 	//dialog for selecting a project
-	KexiProjectSelectorDialog prjdlg( parent, "prjdlg", cdata, true, false );
+	KexiProjectSelectorDialog prjdlg( parent, *cdata, true, false );
 	if (!prjdlg.projectSet() || prjdlg.projectSet()->error()) {
 		KexiGUIMessageHandler msgh;
 		if (prjdlg.projectSet())
 			msgh.showErrorMessage(prjdlg.projectSet(), 
-				i18n("Could not load list of available projects for <b>%1</b> database server.")
-				.arg(cdata->serverInfoString(true)));
+				i18n("Could not load list of available projects for <b>%1</b> database server.",
+					cdata->serverInfoString(true)));
 		else
 			msgh.showErrorMessage(
-				i18n("Could not load list of available projects for <b>%1</b> database server.")
-				.arg(cdata->serverInfoString(true)));
+				i18n("Could not load list of available projects for <b>%1</b> database server.",
+					cdata->serverInfoString(true)));
 //		setStatus(i18n("Could not load list of available projects for database server \"%1\"")
 //		.arg(cdata->serverInfoString(true)), prjdlg.projectSet()->errorMsg());
 		return 0;
@@ -953,8 +953,8 @@ void KexiStartupHandler::slotSaveShortcutFileChanges()
 			&d->shortcutFileGroupKey );
 
 	if (!ok) {
-		KMessageBox::sorry(0, i18n("Failed saving connection data to\n\"%1\" file.")
-			.arg(QDir::convertSeparators(d->shortcutFile->fileName())));
+		KMessageBox::sorry(0, i18n("Failed saving connection data to\n\"%1\" file.",
+			QDir::convertSeparators(d->shortcutFile->fileName())));
 	}
 }
 
