@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 /*!
@@ -23,15 +23,19 @@
 */
 
 #include "KexiStartupFileDialog.h"
+#include <kexiutils/utils.h>
 
 #include <kiconloader.h>
 #include <kdebug.h>
+#include <krecentdirs.h>
 
-#include <qobjectlist.h>
+#include <qobject.h>
 #include <qlineedit.h>
 
 #include <win/win32_utils.h>
+#include <kconfiggroup.h>
 
+//! @internal
 class KexiStartupFileDialogBasePrivate
 {
 	public:
@@ -45,10 +49,11 @@ class KexiStartupFileDialogBasePrivate
 KexiStartupFileDialogBase::KexiStartupFileDialogBase(
 	const QString & dirName, const QString & filter, 
 	QWidget * parent, const char * name, bool modal )
- : QFileDialog( dirName, filter, parent, name, modal )
+ : Q3FileDialog( realStartDir(dirName), filter, parent, name, modal )
  , d(new KexiStartupFileDialogBasePrivate())
 {
-	QString _dirName = dirName;
+//	QString _dirName = dirName;
+	QString _dirName = dirPath();
 	//make default 'My Documents' folder
 //TODO: store changes in the app's config file?
 	if (_dirName.isEmpty())
@@ -80,22 +85,22 @@ void KexiStartupFileDialogBase::init(const QString& startDir, const QString& fil
 //TODO    d->keepLocation = false;
 //TODO    d->operationMode = Opening;
     setMode(KFile::File | KFile::ExistingOnly); //(js) default: open action
-    setIcon( KGlobal::iconLoader()->loadIcon("fileopen", KIcon::Desktop) );
+    setIcon( KGlobal::iconLoader()->loadIcon("document-open", K3Icon::Desktop) );
 		setDir(QDir(startDir));
 //TODO    d->hasDefaultFilter = false;
 //TODO    d->hasView = false;
 //(js)    d->mainWidget = new QWidget( this, "KFileDialog::mainWidget");
 //(js)    setMainWidget( d->mainWidget );
-//(js)    d->okButton = new KPushButton( KStdGuiItem::ok(), d->mainWidget );
+//(js)    d->okButton = new KPushButton( KStandardGuiItem::ok(), d->mainWidget );
 //(js)    d->okButton->setDefault( true );
-//(js)    d->cancelButton = new KPushButton(KStdGuiItem::cancel(), d->mainWidget);
+//(js)    d->cancelButton = new KPushButton(KStandardGuiItem::cancel(), d->mainWidget);
 //(js)    connect( d->okButton, SIGNAL( clicked() ), SLOT( slotOk() ));
 //(js)    connect( d->cancelButton, SIGNAL( clicked() ), SLOT( slotCancel() ));
 //(js)    d->customWidget = widget;
 //(js)    d->autoSelectExtCheckBox = 0; // delayed loading
 //TODO    d->autoSelectExtChecked = false;
 //(js)    d->urlBar = 0; // delayed loading
-//TODO    KConfig *config = KGlobal::config();
+//TODO    KSharedConfig::Ptr config = KGlobal::config();
 //TODO    KConfigGroupSaver cs( config, ConfigGroup );
 //TODO    d->initializeSpeedbar = config->readBoolEntry( "Set speedbar defaults",
 //TODO                                                   true );
@@ -107,38 +112,38 @@ void KexiStartupFileDialogBase::init(const QString& startDir, const QString& fil
 //(js)    toolbar->setFlat(true);
 //TODO    qInstallMsgHandler( oldHandler );
 
-//(js)    d->pathCombo = new KURLComboBox( KURLComboBox::Directories, true,
+//(js)    d->pathCombo = new KUrlComboBox( KUrlComboBox::Directories, true,
 //(js)                                     toolbar, "path combo" );
-//(js)    QToolTip::add( d->pathCombo, i18n("Often used directories") );
+//(js)    d->pathCombo->setToolTip( i18n("Often used directories") );
 //(js)    QWhatsThis::add( d->pathCombo, "<qt>" + i18n("Commonly used locations are listed here. "
 //(js)                                                 "This includes standard locations, such as your home directory, as well as "
 //(js)                                                 "locations that have been visited recently.") + autocompletionWhatsThisText);
 /*
-    KURL u;
-    u.setPath( QDir::rootDirPath() );
+    KUrl u;
+    u.setPath( QDir::rootPath() );
     QString text = i18n("Root Directory: %1").arg( u.path() );
     d->pathCombo->addDefaultURL( u,
-                                 KMimeType::pixmapForURL( u, 0, KIcon::Small ),
+                                 KMimeType::pixmapForURL( u, 0, K3Icon::Small ),
                                  text );
 
-    u.setPath( QDir::homeDirPath() );
+    u.setPath( QDir::homePath() );
     text = i18n("Home Directory: %1").arg( u.path( +1 ) );
-    d->pathCombo->addDefaultURL( u, KMimeType::pixmapForURL( u, 0, KIcon::Small ),
+    d->pathCombo->addDefaultURL( u, KMimeType::pixmapForURL( u, 0, K3Icon::Small ),
                                  text );
 
-    KURL docPath;
+    KUrl docPath;
     docPath.setPath( KGlobalSettings::documentPath() );
     if ( u.path(+1) != docPath.path(+1) ) {
         text = i18n("Documents: %1").arg( docPath.path( +1 ) );
         d->pathCombo->addDefaultURL( u,
-                                     KMimeType::pixmapForURL( u, 0, KIcon::Small ),
+                                     KMimeType::pixmapForURL( u, 0, K3Icon::Small ),
                                      text );
     }
 
     u.setPath( KGlobalSettings::desktopPath() );
     text = i18n("Desktop: %1").arg( u.path( +1 ) );
     d->pathCombo->addDefaultURL( u,
-                                 KMimeType::pixmapForURL( u, 0, KIcon::Small ),
+                                 KMimeType::pixmapForURL( u, 0, K3Icon::Small ),
                                  text );
 
     u.setPath( "/tmp" );
@@ -163,8 +168,8 @@ void KexiStartupFileDialogBase::init(const QString& startDir, const QString& fil
 
     ops = new KDirOperator(d->url, d->mainWidget, "KFileDialog::ops");
     ops->setOnlyDoubleClickSelectsFiles( true );
-    connect(ops, SIGNAL(urlEntered(const KURL&)),
-            SLOT(urlEntered(const KURL&)));
+    connect(ops, SIGNAL(urlEntered(const KUrl&)),
+            SLOT(urlEntered(const KUrl&)));
     connect(ops, SIGNAL(fileHighlighted(const KFileItem *)),
             SLOT(fileHighlighted(const KFileItem *)));
     connect(ops, SIGNAL(fileSelected(const KFileItem *)),
@@ -188,7 +193,7 @@ void KexiStartupFileDialogBase::init(const QString& startDir, const QString& fil
     coll->action( "forward" )->setWhatsThis(i18n("Click this button to move forward one step in the browsing history."));
     coll->action( "reload" )->plug( toolbar );
     coll->action( "reload" )->setWhatsThis(i18n("Click this button to reload the contents of the current location."));
-    coll->action( "mkdir" )->setShortcut(Key_F10);
+    coll->action( "mkdir" )->setShortcut(QKeySequence(Qt::Key_F10));
     coll->action( "mkdir" )->plug( toolbar );
     coll->action( "mkdir" )->setWhatsThis(i18n("Click this button to create a new directory."));
 
@@ -208,7 +213,7 @@ void KexiStartupFileDialogBase::init(const QString& startDir, const QString& fil
              SLOT( enterURL( const QString& )));
 
     KToggleAction *showSidebarAction =
-        new KToggleAction(i18n("Show Quick Access Navigation Panel"), Key_F9, coll,"toggleSpeedbar");
+        new KToggleAction(i18n("Show Quick Access Navigation Panel"), Qt::Key_F9, coll,"toggleSpeedbar");
     connect( showSidebarAction, SIGNAL( toggled( bool ) ),
              SLOT( toggleSpeedbar( bool )) );
 
@@ -223,17 +228,17 @@ void KexiStartupFileDialogBase::init(const QString& startDir, const QString& fil
                             "<li>separating directories from files</li></ul></qt>"));
     menu->insert( coll->action( "sorting menu" ));
     menu->insert( coll->action( "separator" ));
-    coll->action( "short view" )->setShortcut(Key_F6);
+    coll->action( "short view" )->setShortcut(QKeySequence(Qt::Key_F6));
     menu->insert( coll->action( "short view" ));
-    coll->action( "detailed view" )->setShortcut(Key_F7);
+    coll->action( "detailed view" )->setShortcut(QKeySequence(Qt::Key_F7));
     menu->insert( coll->action( "detailed view" ));
     menu->insert( coll->action( "separator" ));
-    coll->action( "show hidden" )->setShortcut(Key_F8);
+    coll->action( "show hidden" )->setShortcut(QKeySequence(Qt::Key_F8));
     menu->insert( coll->action( "show hidden" ));
     menu->insert( showSidebarAction );
-    coll->action( "preview" )->setShortcut(Key_F11);
+    coll->action( "preview" )->setShortcut(QKeySequence(Qt::Key_F11));
     menu->insert( coll->action( "preview" ));
-    coll->action( "separate dirs" )->setShortcut(Key_F12);
+    coll->action( "separate dirs" )->setShortcut(QKeySequence(Qt::Key_F12));
     menu->insert( coll->action( "separate dirs" ));
 
     menu->setDelayed( false );
@@ -260,8 +265,8 @@ void KexiStartupFileDialogBase::init(const QString& startDir, const QString& fil
 
     d->pathCombo->setCompletionObject( ops->dirCompletionObject(), false );
 
-    connect( d->pathCombo, SIGNAL( urlActivated( const KURL&  )),
-             this,  SLOT( enterURL( const KURL& ) ));
+    connect( d->pathCombo, SIGNAL( urlActivated( const KUrl&  )),
+             this,  SLOT( enterURL( const KUrl& ) ));
     connect( d->pathCombo, SIGNAL( returnPressed( const QString&  )),
              this,  SLOT( enterURL( const QString& ) ));
     connect( d->pathCombo, SIGNAL(textChanged( const QString& )),
@@ -275,7 +280,7 @@ void KexiStartupFileDialogBase::init(const QString& startDir, const QString& fil
 
     // the Location label/edit
     d->locationLabel = new QLabel(i18n("&Location:"), d->mainWidget);
-    locationEdit = new KURLComboBox(KURLComboBox::Files, true,
+    locationEdit = new KUrlComboBox(KUrlComboBox::Files, true,
                                     d->mainWidget, "LocationEdit");
     updateLocationWhatsThis ();
     d->locationLabel->setBuddy(locationEdit);
@@ -285,7 +290,7 @@ void KexiStartupFileDialogBase::init(const QString& startDir, const QString& fil
     (void) locationEdit->completionBox();
 
     locationEdit->setFocus();
-//     locationEdit->setCompletionObject( new KURLCompletion() );
+//     locationEdit->setCompletionObject( new KUrlCompletion() );
 //     locationEdit->setAutoDeleteCompletionObject( true );
     locationEdit->setCompletionObject( ops->completionObject(), false );
 
@@ -338,7 +343,7 @@ void KexiStartupFileDialogBase::init(const QString& startDir, const QString& fil
 void KexiStartupFileDialogBase::clearFilter()
 {
 	d->kde_filters = "";//(js)
-	QFileDialog::setFilter(""); //(js);
+	Q3FileDialog::setFilter(""); //(js);
 //todo    d->mimetypes.clear();
 //todo    d->hasDefaultFilter = false;
 
@@ -354,13 +359,13 @@ void KexiStartupFileDialogBase::setMode( KFile::Mode m )
 {
     //(js) translate mode for QFileDialog
     d->mode = m;
-    QFileDialog::Mode qm = (QFileDialog::Mode)0;
-    if (m & KFile::File) qm = Mode(qm | QFileDialog::AnyFile);
-    else if (m & KFile::Directory) qm = Mode(qm | QFileDialog::DirectoryOnly);
-    if (m & KFile::Files) qm = Mode(qm | QFileDialog::ExistingFiles);
-    if (m & KFile::ExistingOnly) qm = Mode(qm | QFileDialog::ExistingFile);
+    Q3FileDialog::Mode qm = (Q3FileDialog::Mode)0;
+    if (m & KFile::File) qm = Mode(qm | Q3FileDialog::AnyFile);
+    else if (m & KFile::Directory) qm = Mode(qm | Q3FileDialog::DirectoryOnly);
+    if (m & KFile::Files) qm = Mode(qm | Q3FileDialog::ExistingFiles);
+    if (m & KFile::ExistingOnly) qm = Mode(qm | Q3FileDialog::ExistingFile);
     
-    QFileDialog::setMode( qm );
+    Q3FileDialog::setMode( qm );
 /*(js)    ops->setMode(m);
     if ( ops->dirOnlyMode() ) {
 //(js)        filterWidget->setDefaultFilter( i18n("*|All Directories") );
@@ -383,10 +388,10 @@ void KexiStartupFileDialogBase::setOperationMode( KFileDialog::OperationMode mod
   //  d->keepLocation = (mode == Saving);
     if (mode == KFileDialog::Saving) {
       setMode( KFile::File );
-      setIcon( KGlobal::iconLoader()->loadIcon("filesave", KIcon::Desktop) );
+      setIcon( KGlobal::iconLoader()->loadIcon("document-save", K3Icon::Desktop) );
     }
 //(js)    filterWidget->setEditable( !d->hasDefaultFilter || mode != Saving );
-//(js)    d->okButton->setGuiItem( (mode == Saving) ? KStdGuiItem::save() : KStdGuiItem::ok() );
+//(js)    d->okButton->setGuiItem( (mode == Saving) ? KStandardGuiItem::save() : KStandardGuiItem::ok() );
 //TODO    updateLocationWhatsThis ();
     updateAutoSelectExtension ();
 }
@@ -411,61 +416,15 @@ void KexiStartupFileDialogBase::setFilter(const QString& filter)
 	d->kde_filters = filter;
     int pos = d->kde_filters.find('/');
 
-    // Check for an un-escaped '/', if found
+	// Check for an un-escaped '/', if found
     // interpret as a MIME filter.
 
     if (pos > 0 && filter[pos - 1] != '\\') {
-        QStringList filters = QStringList::split( " ", d->kde_filters );
+        QStringList filters = d->kde_filters.split(" ");
         setMimeFilter( filters );
         return;
     }
-
-    // Strip the escape characters from
-    // escaped '/' characters.
-
-    QString copy (d->kde_filters);
-    for (pos = 0; (pos = copy.find("\\/", pos)) != -1; ++pos)
-        copy.remove(pos, 1);
-
-	//<js>
-	//we need to convert KDE filter format to Qt format
-	//Qt format: "some text (*.first *.second)" or "All (*)"
-	//KDE format: "*.first *.second" or "*"
-	QStringList filters = QStringList::split("\n",d->kde_filters);
-	QString current;
-	QString converted; //finally - converted filter
-	for (QStringList::ConstIterator it = filters.constBegin(); it!=filters.constEnd();++it) {
-		current = *it;
-		QString new_f;//filter part
-		QString new_name;//filter name part
-		int p = (*it).find('|');
-		if (p!=-1) {
-			new_f = current.left(p);
-			new_name = current.mid(p+1);
-		}else {
-			new_f = current;
-			new_name = current; //nothing better
-		}
-		//remove (.....) from name
-		p=new_name.find('(');
-		int p2 = new_name.findRev(')');
-		QString new_name1, new_name2;
-		if (p!=-1)
-			new_name1 = new_name.left(p);
-		if (p2!=-1)
-			new_name2 = new_name.mid(p2+1);
-		if (!new_name1.isEmpty() || !new_name2.isEmpty())
-			new_name = new_name1.stripWhiteSpace() + " " + new_name2.stripWhiteSpace();
-		new_name.replace('(',"");
-		new_name.replace(')',"");
-		new_name = new_name.stripWhiteSpace();
-
-		if (!converted.isEmpty())
-			converted += ";;";
-
-		converted += (new_name + " (" + new_f + ")");
-	}
-	QFileDialog::setFilters(converted);
+	Q3FileDialog::setFilters( convertKFileDialogFilterToQFileDialogFilter(filter) );
 	//</js>
 //(js)    ops->clearFilter();
 //(js)    filterWidget->setFilter(copy);
@@ -493,3 +452,26 @@ void KexiStartupFileDialogBase::setMimeFilter( const QStringList& mimeTypes,
 //TODO    updateAutoSelectExtension ();
 }
 
+QString KexiStartupFileDialogBase::realStartDir(const QString& startDir)
+{
+	if (!startDir.startsWith(":"))
+		return startDir;
+	QString recentDir; //dummy
+	QString path( KFileDialog::getStartURL(startDir, recentDir).path() );
+	if (path.isEmpty())
+		return QString();
+	QFileInfo fi(path);
+	return fi.isDir() ? fi.absoluteFilePath() : fi.dir(true).absolutePath();
+}
+
+void KexiStartupFileDialogBase::saveLastVisitedPath(const QString& path)
+{
+	if (!m_lastVisitedPathsVariable.isEmpty()) {
+		//save last visited dir path
+//		QString dir = QDir(path).absolutePath();
+		QFileInfo fi(path);
+		QString dir( fi.isDir() ? fi.absoluteFilePath() : fi.dir(true).absolutePath() );
+		if (!dir.isEmpty())
+			KRecentDirs::add(m_lastVisitedPathsVariable, dir);
+	}
+}
