@@ -1,5 +1,6 @@
 /* This file is part of the KDE project
    Copyright (C) 2004 Martin Ellis <m.a.ellis@ncl.ac.uk>
+   Copyright (C) 2006 Jaroslaw Staniek <js@iidea.pl>
  
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -23,7 +24,7 @@
 #include <qregexp.h>
 #include <qfile.h>
 #include <qvariant.h>
-#include <qvaluelist.h>
+#include <q3valuelist.h>
 #include <kdebug.h>
 
 #include <mysql_version.h>
@@ -32,7 +33,9 @@
 #include "migration/keximigratedata.h"
 #include <kexidb/cursor.h>
 #include <kexidb/field.h>
+#include <kexidb/utils.h>
 #include <kexidb/drivers/mySQL/mysqlconnection_p.cpp>
+#include <kexidb/drivermanager.h>
 #include <kexiutils/identifier.h>
 
 using namespace KexiMigration;
@@ -49,26 +52,32 @@ KEXIMIGRATE_DRIVER_INFO( MySQLMigrate, mysql )
 }*/
 
 //! Constructor (needed for trading interface)
-MySQLMigrate::MySQLMigrate(QObject *parent, const char *name,
-                           const QStringList &args) :
-	KexiMigrate(parent, name, args),
-	d(new MySqlConnectionInternal(0)) {
+MySQLMigrate::MySQLMigrate(QObject *parent, const QStringList &args) :
+	KexiMigrate(parent, args)
+	,d(new MySqlConnectionInternal(0))
+	,m_mysqlres(0)
+{
+	KexiDB::DriverManager manager;
+	m_kexiDBDriver = manager.driver("mysql");
 }
 
 /* ************************************************************************** */
 //! Destructor
-MySQLMigrate::~MySQLMigrate() {
+MySQLMigrate::~MySQLMigrate()
+{
+	if (m_mysqlres)
+		mysql_free_result(m_mysqlres);
+	m_mysqlres = 0;
 }
 
 
 /* ************************************************************************** */
 /*! Connect to the db backend */
-bool MySQLMigrate::drv_connect() {
-	if(d->db_connect(*m_migrateData->source)) {
-		return d->useDatabase(m_migrateData->sourceName);
-	} else {
+bool MySQLMigrate::drv_connect()
+{
+	if (!d->db_connect(*m_migrateData->source))
 		return false;
-	}
+	return d->useDatabase(m_migrateData->sourceName);
 }
 
 
@@ -90,109 +99,192 @@ bool MySQLMigrate::drv_readTableSchema(
 //	tableSchema.setCaption(table + " table");
 
 	//Perform a query on the table to get some data
-	QString query = QString("SELECT * FROM `") + d->escapeIdentifier(originalName) + "` LIMIT 0";
-	if(d->executeSQL(query)) {
-		MYSQL_RES *res = mysql_store_result(d->mysql);
-		if (res != NULL) {
-		
-			unsigned int numFlds = mysql_num_fields(res);
-			MYSQL_FIELD *fields = mysql_fetch_fields(res); 
-			
-			for(unsigned int i = 0; i < numFlds; i++) {
-				QString fldName(fields[i].name);
-				QString fldID( KexiUtils::string2Identifier(fldName) );
-
-				KexiDB::Field *fld = 
-				  new KexiDB::Field(fldID, type(originalName, &fields[i]));
-				
-				if(fld->type() == KexiDB::Field::Enum) {
-					QStringList values = examineEnumField(originalName, &fields[i]);
-				}
-				
-				fld->setCaption(fldName);
-				getConstraints(fields[i].flags, fld);
-				getOptions(fields[i].flags, fld);
-				tableSchema.addField(fld);
-			}
-			mysql_free_result(res);
-		} else {
-			kdDebug() << "MySQLMigrate::drv_tableNames: null result" << endl;
-		}
-		return true;
-	} else {
+	QString query = QString("SELECT * FROM `") + drv_escapeIdentifier(originalName) + "` LIMIT 0";
+	if (!d->executeSQL(query))
 	  return false;
+	MYSQL_RES *res = mysql_store_result(d->mysql);
+	if (!res) {
+		kDebug() << "MySQLMigrate::drv_tableNames: null result" << endl;
+		return true;
 	}
+	unsigned int numFlds = mysql_num_fields(res);
+	MYSQL_FIELD *fields = mysql_fetch_fields(res); 
+	
+	for(unsigned int i = 0; i < numFlds; i++) {
+		QString fldName(fields[i].name);
+		QString fldID( KexiUtils::string2Identifier(fldName) );
+
+		KexiDB::Field *fld = 
+			new KexiDB::Field(fldID, type(originalName, &fields[i]));
+		
+		if(fld->type() == KexiDB::Field::Enum) {
+			QStringList values = examineEnumField(originalName, &fields[i]);
+		}
+		
+		fld->setCaption(fldName);
+		getConstraints(fields[i].flags, fld);
+		getOptions(fields[i].flags, fld);
+		tableSchema.addField(fld);
+	}
+	mysql_free_result(res);
+	return true;
 }
 
 
 /*! Get a list of tables and put into the supplied string list */
 bool MySQLMigrate::drv_tableNames(QStringList& tableNames)
 {
-	if(d->executeSQL("SHOW TABLES")) {
-		MYSQL_RES *res = mysql_store_result(d->mysql);
-		if (res != NULL) {
-			MYSQL_ROW row;
-			while ((row = mysql_fetch_row(res)) != NULL) {
-			  tableNames << QString(row[0]);
-			}
-			mysql_free_result(res);
-		} else {
-			kdDebug() << "MySQLMigrate::drv_tableNames: null result" << endl;
-		}
-		return true;
-	} else {
+	if (!d->executeSQL("SHOW TABLES"))
 	  return false;
+	MYSQL_RES *res = mysql_store_result(d->mysql);
+	if (!res) {
+		kDebug() << "MySQLMigrate::drv_tableNames: null result" << endl;
+		return true;
 	}
+	MYSQL_ROW row;
+	while ((row = mysql_fetch_row(res)) != NULL) {
+		tableNames << QString::fromUtf8(row[0]); //utf8.. ok?
+	}
+	mysql_free_result(res);
+	return true;
 }
 
+/*! Fetches single string at column \a columnNumber for each record from result obtained 
+ by running \a sqlStatement.
+ On success the result is stored in \a stringList and true is returned. 
+ \return cancelled if there are no records available. */
+tristate MySQLMigrate::drv_queryStringListFromSQL(
+	const QString& sqlStatement, uint columnNumber, QStringList& stringList, int numRecords)
+{
+	stringList.clear();
+	if (!d->executeSQL(sqlStatement))
+		return false;
+	MYSQL_RES *res = mysql_use_result(d->mysql);
+	if (!res) {
+		kDebug() << "MySQLMigrate::drv_querySingleStringFromSQL(): null result" << endl;
+		return true;
+	}
+	for (int i=0; numRecords == -1 || i < numRecords; i++) {
+		MYSQL_ROW row = mysql_fetch_row(res);
+		if (!row) {
+			tristate r;
+			if (mysql_errno(d->mysql))
+				r = false;
+			else
+				r = (numRecords == -1) ? true : cancelled;
+			mysql_free_result(res);
+			return r;
+		}
+		uint numFields = mysql_num_fields(res);
+		if (columnNumber > (numFields-1)) {
+			kWarning() << "MySQLMigrate::drv_querySingleStringFromSQL("<<sqlStatement
+				<< "): columnNumber too large (" 
+				<< columnNumber << "), expected 0.." << numFields << endl;
+			mysql_free_result(res);
+			return false;
+		}
+		unsigned long *lengths = mysql_fetch_lengths(res);
+		if (!lengths) {
+			mysql_free_result(res);
+			return false;
+		}
+		stringList.append( QString::fromUtf8(row[columnNumber], lengths[columnNumber]) ); //ok? utf8?
+	}
+	mysql_free_result(res);
+	return true;
+}
+
+/*! Fetches single record from result obtained 
+ by running \a sqlStatement. */
+tristate MySQLMigrate::drv_fetchRecordFromSQL(const QString& sqlStatement, 
+	KexiDB::RowData& data, bool &firstRecord)
+{
+	if (firstRecord || !m_mysqlres) {
+		if (m_mysqlres) {
+			mysql_free_result(m_mysqlres);
+			m_mysqlres = 0;
+		}
+		if (!d->executeSQL(sqlStatement) || !(m_mysqlres = mysql_use_result(d->mysql)))
+			return false;
+		firstRecord = false;
+	}
+
+	MYSQL_ROW row = mysql_fetch_row(m_mysqlres);
+	if (!row) {
+		tristate r = cancelled;
+		if (mysql_errno(d->mysql))
+			r = false;
+		mysql_free_result(m_mysqlres);
+		m_mysqlres = 0;
+		return r;
+	}
+	const int numFields = mysql_num_fields(m_mysqlres);
+	unsigned long *lengths = mysql_fetch_lengths(m_mysqlres);
+	if (!lengths) {
+		mysql_free_result(m_mysqlres);
+		m_mysqlres = 0;
+		return false;
+	}
+	data.resize(numFields);
+	for (int i=0; i < numFields; i++)
+		data[i] = QString::fromUtf8(row[i], lengths[i] ); //ok? utf8?
+	return true;
+}
 
 /*! Copy MySQL table to KexiDB database */
 bool MySQLMigrate::drv_copyTable(const QString& srcTable, KexiDB::Connection *destConn, 
 	KexiDB::TableSchema* dstTable)
 {
-	if(d->executeSQL("SELECT * FROM " + d->escapeIdentifier(srcTable))) {
-		MYSQL_RES *res = mysql_use_result(d->mysql);
-		if (res != NULL) {
-			MYSQL_ROW row;
-			while ((row = mysql_fetch_row(res)) != NULL) {
-				int numFields = mysql_num_fields(res);
-				QValueList<QVariant> vals = QValueList<QVariant>();
-				for(int i = 0; i < numFields; i++) {
-					QVariant var = QVariant(row[i]);
-					vals << var;
-				}
-				destConn->insertRecord(*dstTable, vals);
-				updateProgress();
-			}
-			/*! @todo Check that wasn't an error, rather than end of result set */
-			mysql_free_result(res);
-		} else {
-			kdDebug() << "MySQLMigrate::drv_copyTable: null result" << endl;
-		}
+	if (!d->executeSQL("SELECT * FROM `" + drv_escapeIdentifier(srcTable)) + "`")
+		return false;
+	MYSQL_RES *res = mysql_use_result(d->mysql);
+	if (!res) {
+		kDebug() << "MySQLMigrate::drv_copyTable: null result" << endl;
 		return true;
-	} else {
+	}
+	MYSQL_ROW row;
+	const KexiDB::QueryColumnInfo::Vector fieldsExpanded( dstTable->query()->fieldsExpanded() );
+	while ((row = mysql_fetch_row(res))) {
+		const int numFields = qMin((int)fieldsExpanded.count(), (int)mysql_num_fields(res));
+		Q3ValueList<QVariant> vals;
+		unsigned long *lengths = mysql_fetch_lengths(res);
+		if (!lengths) {
+			mysql_free_result(res);
+			return false;
+		}
+		for(int i = 0; i < numFields; i++)
+			vals.append( KexiDB::cstringToVariant(row[i], fieldsExpanded.at(i)->field, (int)lengths[i]) );
+		if (!destConn->insertRecord(*dstTable, vals)) {
+			mysql_free_result(res);
+			return false;
+		}
+		updateProgress();
+	}
+	if (!row && mysql_errno(d->mysql)) {
+		mysql_free_result(res);
 		return false;
 	}
+	/*! @todo Check that wasn't an error, rather than end of result set */
+	mysql_free_result(res);
+	return true;
 }
 
-
-bool MySQLMigrate::drv_getTableSize(const QString& table, Q_ULLONG& size) {
-	if(d->executeSQL("SELECT COUNT(*) FROM " + d->escapeIdentifier(table))) {
-		MYSQL_RES *res = mysql_store_result(d->mysql);
-		if (res != NULL) {
-			MYSQL_ROW row;
-			while ((row = mysql_fetch_row(res)) != NULL) {
-				//! @todo check result valid
-				size = QString(row[0]).toULongLong();
-			}
-			mysql_free_result(res);
-		} else {
-			kdDebug() << "MySQLMigrate::drv_getTableSize: null result" << endl;
-		}
+bool MySQLMigrate::drv_getTableSize(const QString& table, quint64& size)
+{
+	if (!d->executeSQL("SELECT COUNT(*) FROM `" + drv_escapeIdentifier(table)) + "`")
+		return false;
+	MYSQL_RES *res = mysql_store_result(d->mysql);
+	if (!res) {
+		kDebug() << "MySQLMigrate::drv_getTableSize: null result" << endl;
 		return true;
-	} else {
-	  return false;
 	}
+	MYSQL_ROW row;
+	while ((row = mysql_fetch_row(res))) {
+		//! @todo check result valid
+		size = QString(row[0]).toULongLong();
+	}
+	mysql_free_result(res);
+	return true;
 }
 
 //! Convert a MySQL type to a KexiDB type, prompting user if necessary.
@@ -278,7 +370,6 @@ KexiDB::Field::Type MySQLMigrate::type(const QString& table,
 	return kexiType;
 }
 
-
 //! Distinguish between a BLOB and a TEXT field
 /*! MySQL uses the same field type to identify BLOB and TEXT fields.
     This method queries the server to find out if a field is a binary
@@ -288,45 +379,42 @@ KexiDB::Field::Type MySQLMigrate::type(const QString& table,
     \return KexiDB::Field::Text, KexiDB::Field::LongText or KexiDB::Field::BLOB
 */
 KexiDB::Field::Type MySQLMigrate::examineBlobField(const QString& table,
-    const MYSQL_FIELD* fld) {
+    const MYSQL_FIELD* fld)
+{
 	QString mysqlType;
-	KexiDB::Field::Type kexiType;
-	QString query = "SHOW COLUMNS FROM `" + d->escapeIdentifier(table) + 
-	                "` LIKE '" + QString::fromLatin1(fld->name) + "'";
+	const QString query( "SHOW COLUMNS FROM `" + drv_escapeIdentifier(table) + 
+	                "` LIKE '" + QString::fromLatin1(fld->name) + "'");
 
-	if(d->executeSQL(query)) {
-		MYSQL_RES *res = mysql_store_result(d->mysql);
-
-		if (res != NULL) {
-			MYSQL_ROW row;
-			while ((row = mysql_fetch_row(res)) != NULL) {
-				mysqlType = QString(row[1]);
-			}
-			mysql_free_result(res);
-		} else {
-			kdDebug() << "MySQLMigrate::examineBlobField: null result" << endl;
-		}
-	} else {
+	if (!d->executeSQL(query)) {
 		// Huh? MySQL wont tell us what kind of field it is! Lets guess.
 	  return KexiDB::Field::LongText;
 	}
-
-	kdDebug() << "MySQLMigrate::examineBlobField: considering "
-	          << mysqlType << endl;
-	if(mysqlType.contains("blob", false) != 0) {
-		// Doesn't matter how big it is, it's binary
-		kexiType = KexiDB::Field::BLOB;
-	} else if(mysqlType.contains("text", false) != 0) {
-		// All the TEXT types are too big for Kexi text.
-		kexiType = KexiDB::Field::BLOB;
-	} else if(fld->length < 200) {
-		kexiType = KexiDB::Field::Text;
-	} else {
-		kexiType = KexiDB::Field::LongText;
+	MYSQL_RES *res = mysql_store_result(d->mysql);
+	if (!res) {
+		kDebug() << "MySQLMigrate::examineBlobField: null result" << endl;
+	}
+	else {
+		MYSQL_ROW row;
+		if ((row = mysql_fetch_row(res)))
+			mysqlType = QString(row[1]);
+		mysql_free_result(res);
 	}
-	return kexiType;
-}
 
+	kDebug() << "MySQLMigrate::examineBlobField: considering "
+	          << mysqlType << endl;
+	if (mysqlType.contains("blob", Qt::CaseInsensitive)) {
+		// Doesn't matter how big it is, it's binary
+		return KexiDB::Field::BLOB;
+	}
+	else if (mysqlType.contains("text", Qt::CaseInsensitive)) {
+		// All the TEXT types are too big for Kexi text.
+		return KexiDB::Field::BLOB;
+	}
+	else if (fld->length < 200) {
+		return KexiDB::Field::Text;
+	}
+	return KexiDB::Field::LongText;
+}
 
 //! Get the strings that identify values in an enum field
 /*! Parse the type of a MySQL enum field as returned by the server in a 
@@ -337,39 +425,39 @@ KexiDB::Field::Type MySQLMigrate::examineBlobField(const QString& table,
     \return list of possible values the field can take
  */
 QStringList MySQLMigrate::examineEnumField(const QString& table,
-		const MYSQL_FIELD* fld) {
+		const MYSQL_FIELD* fld)
+{
 	QString vals;
-	QString query = "SHOW COLUMNS FROM `" + d->escapeIdentifier(table) + 
-			"` LIKE '" + QString::fromLatin1(fld->name) + "'";
+	const QString query("SHOW COLUMNS FROM `" + drv_escapeIdentifier(table) + 
+			"` LIKE '" + QString::fromLatin1(fld->name) + "'");
 
-	if(d->executeSQL(query)) {
-		MYSQL_RES *res = mysql_store_result(d->mysql);
-
-		if (res != NULL) {
-			MYSQL_ROW row;
-			while ((row = mysql_fetch_row(res)) != NULL) {
-				vals = QString(row[1]);
-			}
-			mysql_free_result(res);
-		} else {
-			kdDebug() << "MySQLMigrate::examineEnumField: null result" << endl;
-		}
-	} else {
+	if (!d->executeSQL(query))
 		// Huh? MySQL wont tell us what values it can take.
 		return QStringList();
+	
+	MYSQL_RES *res = mysql_store_result(d->mysql);
+
+	if (!res) {
+		kDebug() << "MySQLMigrate::examineEnumField: null result" << endl;
+	}
+	else {
+		MYSQL_ROW row;
+		if ((row = mysql_fetch_row(res)))
+			vals = QString(row[1]);
+		mysql_free_result(res);
 	}
 
-	kdDebug() << "MySQLMigrate::examineEnumField: considering " 
+	kDebug() << "MySQLMigrate::examineEnumField: considering " 
 						<< vals << endl;
 	
 	// Crash and burn if we get confused...
-	if(!vals.startsWith("enum(")) {
+	if (!vals.startsWith("enum(")) {
 		// Huh? We're supposed to be parsing an enum!
-		kdDebug() << "MySQLMigrate::examineEnumField:1 not an enum!" << endl;
+		kDebug() << "MySQLMigrate::examineEnumField:1 not an enum!" << endl;
 		return QStringList();
 	}
-	if(!vals.endsWith(")")) {
-		kdDebug() << "MySQLMigrate::examineEnumField:2 not an enum!" << endl;
+	if (!vals.endsWith(")")) {
+		kDebug() << "MySQLMigrate::examineEnumField:2 not an enum!" << endl;
 		return QStringList();
 	}
 	
@@ -381,18 +469,18 @@ QStringList MySQLMigrate::examineEnumField(const QString& table,
 	QStringList values = QStringList();
 	int index = 0;
 
-	while ((index = rx.search(vals, index, QRegExp::CaretAtOffset)) != -1) {
+	while ((index = rx.indexIn(vals, index, QRegExp::CaretAtOffset)) != -1) {
 		int len = rx.matchedLength();
 		if (len != -1) {
-			kdDebug() << "MySQLMigrate::examineEnumField:3 " << rx.cap(1) << endl;
+			kDebug() << "MySQLMigrate::examineEnumField:3 " << rx.cap(1) << endl;
 			values << rx.cap(1);
 		} else {
-			kdDebug() << "MySQLMigrate::examineEnumField:4 lost" << endl;
+			kDebug() << "MySQLMigrate::examineEnumField:4 lost" << endl;
 		}
 		
 		QChar next = vals[index + len];
 		if (next != QChar(',') && next != QChar(')')) {
-			kdDebug() << "MySQLMigrate::examineEnumField:5 " << (char)next << endl;
+			kDebug() << "MySQLMigrate::examineEnumField:5 " << next << endl;
 		}
 		index += len + 1;
 	}
@@ -400,8 +488,8 @@ QStringList MySQLMigrate::examineEnumField(const QString& table,
 	return values;
 }
 
-
-void MySQLMigrate::getConstraints(int flags, KexiDB::Field* fld) {
+void MySQLMigrate::getConstraints(int flags, KexiDB::Field* fld)
+{
 	fld->setPrimaryKey(flags & PRI_KEY_FLAG);
 	fld->setAutoIncrement(flags & AUTO_INCREMENT_FLAG);
 	fld->setNotNull(flags & NOT_NULL_FLAG);
@@ -409,8 +497,8 @@ void MySQLMigrate::getConstraints(int flags, KexiDB::Field* fld) {
 	//! @todo: Keys and uniqueness
 }
 
-
-void MySQLMigrate::getOptions(int flags, KexiDB::Field* fld) {
+void MySQLMigrate::getOptions(int flags, KexiDB::Field* fld)
+{
 	fld->setUnsigned(flags & UNSIGNED_FLAG);
 }
 
