@@ -21,8 +21,8 @@
 #define KEXIFORMDATAPROVIDER_H
 
 #include "kexiformdataiteminterface.h"
-#include <qptrdict.h>
-#include <qdict.h>
+#include <QSet>
+#include <QList>
 
 class KexiTableItem;
 namespace KexiDB {
@@ -54,7 +54,7 @@ class KEXIFORMUTILS_EXPORT KexiFormDataProvider : public KexiDataItemChangesList
 
 		QStringList usedDataSources() const { return m_usedDataSources; }
 
-		//unused QPtrList<KexiFormDataItemInterface>& dataItems() { return m_dataItems; }
+		//unused Q3PtrList<KexiFormDataItemInterface>& dataItems() { return m_dataItems; }
 
 		/*! Fills data items with appropriate data fetched from \a cursor. 
 		 \a newRowEditing == true means that we are at new (not yet inserted) database row. */
@@ -72,9 +72,9 @@ class KEXIFORMUTILS_EXPORT KexiFormDataProvider : public KexiDataItemChangesList
 
 		/*! Invalidates data sources collected by this provided.
 		 \a invalidSources is the set of data sources that should 
-		 be ommited for fillDataItems(). 
+		 be omitted for fillDataItems(). 
 		 Used by KexiFormView::initDataSource(). */
-		void invalidateDataSources( const QDict<char>& invalidSources, 
+		void invalidateDataSources( const QSet<QString>& invalidSources, 
 			KexiDB::QuerySchema* query = 0 );
 
 		/*! Fills the same data provided by \a value to every data item (other than \a item) 
@@ -84,9 +84,9 @@ class KEXIFORMUTILS_EXPORT KexiFormDataProvider : public KexiDataItemChangesList
 
 	protected:
 		QWidget *m_mainWidget;
-		QPtrDict<char> *m_duplicatedItems;
+		QSet<KexiDB::Field*> *m_duplicatedItems;
 		typedef QMap<KexiFormDataItemInterface*,uint> KexiFormDataItemInterfaceToIntMap;
-		QPtrList<KexiFormDataItemInterface> m_dataItems;
+		QList<KexiFormDataItemInterface*> m_dataItems;
 		QStringList m_usedDataSources;
 		KexiFormDataItemInterfaceToIntMap m_fieldNumbersForDataItems;
 		bool m_disableFillDuplicatedDataItems : 1;
