@@ -21,22 +21,29 @@
 
 #include <kdebug.h>
 #include <kgenericfactory.h>
-#include <kdialogbase.h>
-#include <klistview.h>
+#include <KDialog>
+#include <k3listview.h>
 #include <ktabwidget.h>
 #include <kiconloader.h>
 #include <kcombobox.h>
+#include <kapplication.h>
+#include <kconfig.h>
+#include <KAction>
+#include <KActionMenu>
+#include <KActionCollection>
 
-#include <kexiviewbase.h>
-#include <keximainwindow.h>
+#include <KexiView.h>
+#include <KexiWindow.h>
+#include <KexiMainWindowIface.h>
 #include <kexiproject.h>
 #include <kexipartitem.h>
-#include <kexidialogbase.h>
 #include <kexidatasourcecombobox.h>
 #include <kexidb/connection.h>
 #include <kexidb/fieldlist.h>
 #include <kexidb/field.h>
+#include <kexiutils/utils.h>
 
+#include <kexi_global.h>
 #include <form.h>
 #include <formIO.h>
 #include <widgetpropertyset.h>
@@ -68,34 +75,35 @@ class KexiFormPart::Private
 			delete static_cast<KFormDesigner::ObjectTreeView*>(objectTreeView);
 			delete static_cast<KexiDataSourcePage*>(dataSourcePage);
 		}
-//		QGuardedPtr<KFormDesigner::FormManager> manager;
-		QGuardedPtr<KFormDesigner::ObjectTreeView> objectTreeView;
-		QGuardedPtr<KexiDataSourcePage> dataSourcePage;
+//		QPointer<KFormDesigner::FormManager> manager;
+		QPointer<KFormDesigner::ObjectTreeView> objectTreeView;
+		QPointer<KexiDataSourcePage> dataSourcePage;
 		KexiDataSourceComboBox *dataSourceCombo;
 };
 
-KexiFormPart::KexiFormPart(QObject *parent, const char *name, const QStringList &l)
- : KexiPart::Part(parent, name, l)
+KexiFormPart::KexiFormPart(QObject *parent, const QStringList &l)
+ : KexiPart::Part((int)KexiPart::FormObjectType, parent, l)
  , d(new Private())
 {
-	// REGISTERED ID:
-	m_registeredPartID = (int)KexiPart::FormObjectType;
-
 	kexipluginsdbg << "KexiFormPart::KexiFormPart()" << endl;
-	m_names["instanceName"] 
-		= i18n("Translate this word using only lowercase alphanumeric characters (a..z, 0..9). "
+	setInternalPropertyValue("instanceName",
+		i18nc("Translate this word using only lowercase alphanumeric characters (a..z, 0..9). "
 		"Use '_' character instead of spaces. First character should be a..z character. "
-		"If you cannot use latin characters in your language, use english word.", 
-		"form");
-	m_names["instanceCaption"] = i18n("Form");
-	m_supportedViewModes = Kexi::DataViewMode | Kexi::DesignViewMode;
-	m_newObjectsAreDirty = true;
+		"If you cannot use latin characters in your language, use english word.",
+		"form"));
+	setInternalPropertyValue("instanceCaption", i18n("Form"));
+	setInternalPropertyValue("instanceToolTip", i18nc("tooltip", "Create new form"));
+	setInternalPropertyValue("instanceWhatsThis", i18nc("what's this", "Creates new form."));
+	setSupportedViewModes(Kexi::DataViewMode | Kexi::DesignViewMode);
+	setInternalPropertyValue("newObjectsAreDirty", true);
 
 	// Only create form manager if it's not yet created.
-	// KexiReportPart could have created is already.
+	// KexiReportPart could have created it already.
 	KFormDesigner::FormManager *formManager = KFormDesigner::FormManager::self();
-	if (!formManager) 
-		formManager = new KexiFormManager(this, "kexi_form_and_report_manager");
+	if (!formManager) {
+		formManager = new KexiFormManager(this);
+		formManager->setObjectName("kexi_form_and_report_manager");
+	}
 
 	// Create and store a handle to forms' library. Reports will have their own library too.
 /* @todo add configuration for supported factory groups */
@@ -104,9 +112,12 @@ KexiFormPart::KexiFormPart(QObject *parent, const char *name, const QStringList
 	static_formsLibrary = KFormDesigner::FormManager::createWidgetLibrary(
 		formManager, supportedFactoryGroups);
 	static_formsLibrary->setAdvancedPropertiesVisible(false);
+	connect(static_formsLibrary, SIGNAL(widgetCreated(QWidget*)),
+		this, SLOT(slotWidgetCreatedByFormsLibrary(QWidget*)));
 
-	connect(KFormDesigner::FormManager::self()->propertySet(), SIGNAL(widgetPropertyChanged(QWidget *, const QCString &, const QVariant&)),
-		this, SLOT(slotPropertyChanged(QWidget *, const QCString &, const QVariant&)));
+	connect(KFormDesigner::FormManager::self()->propertySet(),
+		SIGNAL(widgetPropertyChanged(QWidget *, const Q3CString &, const QVariant&)),
+		this, SLOT(slotPropertyChanged(QWidget *, const Q3CString &, const QVariant&)));
 	connect(KFormDesigner::FormManager::self(), SIGNAL(autoTabStopsSet(KFormDesigner::Form*,bool)),
 		this, SLOT(slotAutoTabStopsSet(KFormDesigner::Form*,bool)));
 }
@@ -138,8 +149,8 @@ void KexiFormPart::initInstanceActions( int mode, KActionCollection *col )
 {
 	if (mode==Kexi::DesignViewMode) {
 		KFormDesigner::FormManager::self()->createActions(col, 0);
-		new KAction(i18n("Edit Tab Order"), "tab_order", KShortcut(0), KFormDesigner::FormManager::self(), SLOT(editTabOrder()), col, "taborder");
-		new KAction(i18n("Adjust Size"), "viewmagfit", KShortcut(0), KFormDesigner::FormManager::self(), SLOT(ajustWidgetSize()), col, "adjust");
+		new KAction(i18n("Edit Tab Order..."), "tab_order", KShortcut(0), KFormDesigner::FormManager::self(), SLOT(editTabOrder()), col, "taborder");
+		new KAction(i18n("Adjust Size"), "zoom-best-fit", KShortcut(0), KFormDesigner::FormManager::self(), SLOT(ajustWidgetSize()), col, "adjust");
 	}
 	//TODO
 }
@@ -147,96 +158,125 @@ void KexiFormPart::initInstanceActions( int mode, KActionCollection *col )
 
 void KexiFormPart::initPartActions()
 {
-//	new KAction(i18n("Show Form UI Code"), "show_form_ui", CTRL+Key_U, m_manager, SLOT(showFormUICode()),
+//	new KAction(i18n("Show Form UI Code"), "show_form_ui", CTRL+Qt::Key_U, m_manager, SLOT(showFormUICode()),
 //		guiClient()->actionCollection(), "show_form_ui");
 }
 
 void KexiFormPart::initInstanceActions()
 {
-#ifdef KEXI_SHOW_DEBUG_ACTIONS
-	new KAction(i18n("Show Form UI Code"), "compfile", CTRL+Key_U, KFormDesigner::FormManager::self(), SLOT(showFormUICode()),
-		actionCollectionForMode(Kexi::DesignViewMode), "show_form_ui");
+	KActionCollection *col = actionCollectionForMode(Kexi::DesignViewMode);
+#ifdef KEXI_DEBUG_GUI
+	KConfigGroup generalGroup( KGlobal::config()->group("General") );
+	if (generalGroup.readEntry<bool>("showInternalDebugger", false)) {
+		KAction *a;
+		col->addAction("show_form_ui",
+			a = new KAction(KIcon("compfile"), i18n("Show Form UI Code"), this) );
+		a->setShortcut(Qt::CTRL+Qt::Key_U);
+		connect(a, SIGNAL(triggered()),
+			KFormDesigner::FormManager::self(), SLOT(showFormUICode()));
+	}
 #endif
 
-	KActionCollection *col = actionCollectionForMode(Kexi::DesignViewMode);
-	KFormDesigner::FormManager::self()->createActions( library(), col );
+	KFormDesigner::FormManager::self()->createActions( library(), col,
+		(KXMLGUIClient*)col->parentGUIClient() );
 
 	//connect actions provided by widget factories
-	connect( col->action("widget_assign_action"), SIGNAL(activated()), this, SLOT(slotAssignAction()));
+	connect( col->action("widget_assign_action"), SIGNAL(activated()),
+		this, SLOT(slotAssignAction()));
 
-	createSharedAction(Kexi::DesignViewMode, i18n("Clear Widget Contents"), "editclear", 0, "formpart_clear_contents");
-	createSharedAction(Kexi::DesignViewMode, i18n("Edit Tab Order"), "tab_order", 0, "formpart_taborder");
+	createSharedAction(Kexi::DesignViewMode, i18n("Clear Widget Contents"),
+		"edit-clear", KShortcut(), "formpart_clear_contents");
+	createSharedAction(Kexi::DesignViewMode, i18n("Edit Tab Order..."),
+		"tab_order", KShortcut(), "formpart_taborder");
 //TODO	createSharedAction(Kexi::DesignViewMode, i18n("Edit Pixmap Collection"), "icons", 0, "formpart_pixmap_collection");
 //TODO	createSharedAction(Kexi::DesignViewMode, i18n("Edit Form Connections"), "connections", 0, "formpart_connections");
 
 //	KFormDesigner::CreateLayoutCommand
 
-	KAction *action = createSharedAction(Kexi::DesignViewMode, i18n("Layout Widgets"), "", 0, "formpart_layout_menu", "KActionMenu");
+	KAction *action = createSharedAction(Kexi::DesignViewMode, i18n("Layout Widgets"),
+		"", KShortcut(), "formpart_layout_menu", "KActionMenu");
 	KActionMenu *menu = static_cast<KActionMenu*>(action);
 
-	menu->insert( createSharedAction(Kexi::DesignViewMode, i18n("&Horizontally"),
-		QString::null, 0, "formpart_layout_hbox"));
-	menu->insert( createSharedAction(Kexi::DesignViewMode, i18n("&Vertically"),
-		QString::null, 0, "formpart_layout_vbox"));
-	menu->insert( createSharedAction(Kexi::DesignViewMode, i18n("In &Grid"),
-		QString::null, 0, "formpart_layout_grid"));
+	menu->addAction( createSharedAction(Kexi::DesignViewMode, i18n("&Horizontally"),
+		QString(), KShortcut(), "formpart_layout_hbox"));
+	menu->addAction( createSharedAction(Kexi::DesignViewMode, i18n("&Vertically"),
+		QString(), KShortcut(), "formpart_layout_vbox"));
+	menu->addAction( createSharedAction(Kexi::DesignViewMode, i18n("In &Grid"),
+		QString(), KShortcut(), "formpart_layout_grid"));
 #ifdef KEXI_SHOW_SPLITTER_WIDGET
-	menu->insert( createSharedAction(Kexi::DesignViewMode, i18n("Horizontally in &Splitter"),
-		QString::null, 0, "formpart_layout_hsplitter"));
-	menu->insert( createSharedAction(Kexi::DesignViewMode, i18n("Verti&cally in Splitter"),
-		QString::null, 0, "formpart_layout_vsplitter"));
+	menu->addAction( createSharedAction(Kexi::DesignViewMode, i18n("Horizontally in &Splitter"),
+		QString(), KShortcut(), "formpart_layout_hsplitter"));
+	menu->addAction( createSharedAction(Kexi::DesignViewMode, i18n("Verti&cally in Splitter"),
+		QString(), KShortcut(), "formpart_layout_vsplitter"));
 #endif
 
-	createSharedAction(Kexi::DesignViewMode, i18n("&Break Layout"), QString::null, 0, "formpart_break_layout");
+	createSharedAction(Kexi::DesignViewMode, i18n("&Break Layout"), QString(),
+		KShortcut(), "formpart_break_layout");
 /*
-	createSharedAction(Kexi::DesignViewMode, i18n("Lay Out Widgets &Horizontally"), QString::null, 0, "formpart_layout_hbox");
-	createSharedAction(Kexi::DesignViewMode, i18n("Lay Out Widgets &Vertically"), QString::null, 0, "formpart_layout_vbox");
-	createSharedAction(Kexi::DesignViewMode, i18n("Lay Out Widgets in &Grid"), QString::null, 0, "formpart_layout_grid");
+	createSharedAction(Kexi::DesignViewMode, i18n("Lay Out Widgets &Horizontally"), QString(), 0, "formpart_layout_hbox");
+	createSharedAction(Kexi::DesignViewMode, i18n("Lay Out Widgets &Vertically"), QString(), 0, "formpart_layout_vbox");
+	createSharedAction(Kexi::DesignViewMode, i18n("Lay Out Widgets in &Grid"), QString(), 0, "formpart_layout_grid");
 */
-	createSharedAction(Kexi::DesignViewMode, i18n("Bring Widget to Front"), "raise", 0, "formpart_format_raise");
-	createSharedAction(Kexi::DesignViewMode, i18n("Send Widget to Back"), "lower", 0, "formpart_format_lower");
+	createSharedAction(Kexi::DesignViewMode, i18n("Bring Widget to Front"), "raise",
+		KShortcut(), "formpart_format_raise");
+	createSharedAction(Kexi::DesignViewMode, i18n("Send Widget to Back"), "lower",
+		KShortcut(), "formpart_format_lower");
 
 #ifndef KEXI_NO_UNFINISHED
-	action = createSharedAction(Kexi::DesignViewMode, i18n("Other Widgets"), "", 0, "other_widgets_menu", "KActionMenu");
+	action = createSharedAction(Kexi::DesignViewMode, i18n("Other Widgets"), "",
+		KShortcut(), "other_widgets_menu", "KActionMenu");
 #endif
 
-	action = createSharedAction(Kexi::DesignViewMode, i18n("Align Widgets Position"), "aoleft", 0, "formpart_align_menu", "KActionMenu");
+	action = createSharedAction(Kexi::DesignViewMode, i18n("Align Widgets Position"),
+		"aoleft", KShortcut(), "formpart_align_menu", "KActionMenu");
 	menu = static_cast<KActionMenu*>(action);
-	menu->insert( createSharedAction(Kexi::DesignViewMode, i18n("To Left"), "aoleft", 0, "formpart_align_to_left") );
-	menu->insert( createSharedAction(Kexi::DesignViewMode, i18n("To Right"), "aoright", 0, "formpart_align_to_right") );
-	menu->insert( createSharedAction(Kexi::DesignViewMode, i18n("To Top"), "aotop", 0, "formpart_align_to_top") );
-	menu->insert( createSharedAction(Kexi::DesignViewMode, i18n("To Bottom"), "aobottom", 0, "formpart_align_to_bottom") );
-	menu->insert( createSharedAction(Kexi::DesignViewMode, i18n("To Grid"), "aopos2grid", 0, "formpart_align_to_grid") );
+	menu->addAction( createSharedAction(Kexi::DesignViewMode, i18n("To Left"), "aoleft",
+		KShortcut(), "formpart_align_to_left") );
+	menu->addAction( createSharedAction(Kexi::DesignViewMode, i18n("To Right"), "aoright",
+		KShortcut(), "formpart_align_to_right") );
+	menu->addAction( createSharedAction(Kexi::DesignViewMode, i18n("To Top"), "aotop",
+		KShortcut(), "formpart_align_to_top") );
+	menu->addAction( createSharedAction(Kexi::DesignViewMode, i18n("To Bottom"), "aobottom",
+		KShortcut(), "formpart_align_to_bottom") );
+	menu->addAction( createSharedAction(Kexi::DesignViewMode, i18n("To Grid"), "aopos2grid",
+		KShortcut(), "formpart_align_to_grid") );
 
-	action = createSharedAction(Kexi::DesignViewMode, i18n("Adjust Widgets Size"), "aogrid", 0, "formpart_adjust_size_menu", "KActionMenu");
+	action = createSharedAction(Kexi::DesignViewMode, i18n("Adjust Widgets Size"), "aogrid",
+		KShortcut(), "formpart_adjust_size_menu", "KActionMenu");
 	menu = static_cast<KActionMenu*>(action);
-	menu->insert( createSharedAction(Kexi::DesignViewMode, i18n("To Fit"), "aofit", 0, "formpart_adjust_to_fit") );
-	menu->insert( createSharedAction(Kexi::DesignViewMode, i18n("To Grid"), "aogrid", 0, "formpart_adjust_size_grid") );
-	menu->insert( createSharedAction(Kexi::DesignViewMode, i18n("To Shortest"), "aoshortest", 0, "formpart_adjust_height_small") );
-	menu->insert( createSharedAction(Kexi::DesignViewMode, i18n("To Tallest"), "aotallest", 0, "formpart_adjust_height_big") );
-	menu->insert( createSharedAction(Kexi::DesignViewMode, i18n("To Narrowest"), "aonarrowest", 0, "formpart_adjust_width_small") );
-	menu->insert( createSharedAction(Kexi::DesignViewMode, i18n("To Widest"), "aowidest", 0, "formpart_adjust_width_big") );
+	menu->addAction( createSharedAction(Kexi::DesignViewMode, i18n("To Fit"), "aofit",
+		KShortcut(), "formpart_adjust_to_fit") );
+	menu->addAction( createSharedAction(Kexi::DesignViewMode, i18n("To Grid"), "aogrid",
+		KShortcut(), "formpart_adjust_size_grid") );
+	menu->addAction( createSharedAction(Kexi::DesignViewMode, i18n("To Shortest"), "aoshortest",
+		KShortcut(), "formpart_adjust_height_small") );
+	menu->addAction( createSharedAction(Kexi::DesignViewMode, i18n("To Tallest"), "aotallest",
+		KShortcut(), "formpart_adjust_height_big") );
+	menu->addAction( createSharedAction(Kexi::DesignViewMode, i18n("To Narrowest"), "aonarrowest",
+		KShortcut(), "formpart_adjust_width_small") );
+	menu->addAction( createSharedAction(Kexi::DesignViewMode, i18n("To Widest"), "aowidest",
+		KShortcut(), "formpart_adjust_width_big") );
 }
 
-KexiDialogTempData*
-KexiFormPart::createTempData(KexiDialogBase* dialog)
+KexiWindowData*
+KexiFormPart::createWindowData(KexiWindow* window)
 {
-	return new KexiFormPart::TempData(dialog);
+	return new KexiFormPart::TempData(window);
 }
 
-KexiViewBase* KexiFormPart::createView(QWidget *parent, KexiDialogBase* dialog,
-	KexiPart::Item &item, int viewMode, QMap<QString,QString>*)
+KexiView* KexiFormPart::createView(QWidget *parent, KexiWindow* window,
+	KexiPart::Item &item, Kexi::ViewMode viewMode, QMap<QString,QString>*)
 {
+	Q_UNUSED( window );
 	Q_UNUSED( viewMode );
 
 	kexipluginsdbg << "KexiFormPart::createView()" << endl;
-	KexiMainWindow *win = dialog->mainWin();
+	KexiMainWindowIface *win = KexiMainWindowIface::global();
 	if (!win || !win->project() || !win->project()->dbConnection())
 		return 0;
 
-	KexiFormView *view = new KexiFormView(win, parent, item.name().latin1(),
-		win->project()->dbConnection() );
-
+	KexiFormView *view = new KexiFormView(parent, win->project()->dbConnection() );
+	view->setObjectName(item.name().toLatin1());
 	return view;
 }
 
@@ -389,53 +429,65 @@ void KexiFormPart::slotAutoTabStopsSet(KFormDesigner::Form *form, bool set)
 {
 	Q_UNUSED( form );
 
-	(*KFormDesigner::FormManager::self()->propertySet())["autoTabStops"].setValue(QVariant(set, 4));
+	KoProperty::Property &p
+		= (*KFormDesigner::FormManager::self()->propertySet())["autoTabStops"];
+	if (!p.isNull())
+		p.setValue(QVariant(set));
 }
 
 void KexiFormPart::slotAssignAction()
 {
 	KexiDBForm *dbform;
-	if (!KFormDesigner::FormManager::self()->activeForm() || !KFormDesigner::FormManager::self()->activeForm()->designMode()
+	if (!KFormDesigner::FormManager::self()->activeForm()
+		|| !KFormDesigner::FormManager::self()->activeForm()->designMode()
 		|| !(dbform = dynamic_cast<KexiDBForm*>(KFormDesigner::FormManager::self()->activeForm()->formWidget())))
 		return;
 
-	KoProperty::Property &onClickActionProp = KFormDesigner::FormManager::self()->propertySet()->property("onClickAction");
+	KFormDesigner::WidgetPropertySet * propSet
+		= KFormDesigner::FormManager::self()->propertySet();
+
+	KoProperty::Property &onClickActionProp = propSet->property("onClickAction");
 	if (onClickActionProp.isNull())
 		return;
-	QString onClickActionValue( onClickActionProp.value().toString() );
+	KoProperty::Property &onClickActionOptionProp = propSet->property("onClickActionOption");
+	KexiFormEventAction::ActionData data;
+	data.string = onClickActionProp.value().toString();
+	if (!onClickActionOptionProp.isNull())
+		data.option = onClickActionOptionProp.value().toString();
 
-	KexiFormScrollView *scrollViewWidget = dynamic_cast<KexiFormScrollView*>(dbform->dataAwareObject());
+	KexiFormScrollView *scrollViewWidget
+		= dynamic_cast<KexiFormScrollView*>(dbform->dataAwareObject());
 	if (!scrollViewWidget)
 		return;
 	KexiFormView* formViewWidget = dynamic_cast<KexiFormView*>(scrollViewWidget->parent());
 	if (!formViewWidget)
 		return;
 
-	KexiMainWindow * mainWin = formViewWidget->parentDialog()->mainWin();
-	KexiActionSelectionDialog dlg(mainWin, dbform, onClickActionValue,
-		KFormDesigner::FormManager::self()->propertySet()->property("name").value().toCString());
+	KexiActionSelectionDialog dlg(dbform, data, 
+		propSet->property("name").value().toString());
 
-	if(dlg.exec() == QDialog::Accepted) {
-		onClickActionValue = dlg.currentActionName();
+	if (dlg.exec() == QDialog::Accepted) {
+		data = dlg.currentAction();
 		//update property value
-		(*KFormDesigner::FormManager::self()->propertySet())["onClickAction"].setValue(onClickActionValue);
+		propSet->property("onClickAction").setValue(data.string);
+		propSet->property("onClickActionOption").setValue(data.option);
 	}
 }
 
-QString
-KexiFormPart::i18nMessage(const QCString& englishMessage, KexiDialogBase* dlg) const
+KLocalizedString KexiFormPart::i18nMessage(
+	const QString& englishMessage, KexiWindow* window) const
 {
-	Q_UNUSED(dlg);
+	Q_UNUSED(window);
 	if (englishMessage=="Design of object \"%1\" has been modified.")
-		return i18n("Design of form \"%1\" has been modified.");
+		return ki18n(I18N_NOOP("Design of form \"%1\" has been modified."));
 	if (englishMessage=="Object \"%1\" already exists.")
-		return i18n("Form \"%1\" already exists.");
+		return ki18n(I18N_NOOP("Form \"%1\" already exists."));
 
-	return englishMessage;
+	return Part::i18nMessage(englishMessage, window);
 }
 
 void
-KexiFormPart::slotPropertyChanged(QWidget *w, const QCString &name, const QVariant &value)
+KexiFormPart::slotPropertyChanged(QWidget *w, const Q3CString &name, const QVariant &value)
 {
 	Q_UNUSED( w );
 
@@ -449,7 +501,8 @@ KexiFormPart::slotPropertyChanged(QWidget *w, const QCString &name, const QVaria
 	if (KFormDesigner::FormManager::self()->activeForm()->widget() && name == "geometry") {
 		//fall back to sizeInternal property....
 		if (KFormDesigner::FormManager::self()->propertySet()->contains("sizeInternal"))
-			KFormDesigner::FormManager::self()->propertySet()->property("sizeInternal").setValue(value.toRect().size());
+			KFormDesigner::FormManager::self()->propertySet()->property("sizeInternal").setValue(
+				value.toRect().size() );
 	}
 }
 
@@ -464,36 +517,75 @@ KexiDataSourcePage* KexiFormPart::dataSourcePage() const
 	return d->dataSourcePage;
 }
 
-void KexiFormPart::setupCustomPropertyPanelTabs(KTabWidget *tab, KexiMainWindow* mainWin)
+void KexiFormPart::setupCustomPropertyPanelTabs(KTabWidget *tab)
 {
 	if (!d->objectTreeView) {
-		d->objectTreeView = new KFormDesigner::ObjectTreeView(0, "KexiFormPart:ObjectTreeView");
+		d->objectTreeView = new KFormDesigner::ObjectTreeView(0);
+		d->objectTreeView->setObjectName("KexiFormPart:ObjectTreeView");
 		KFormDesigner::FormManager::self()->setObjectTreeView(d->objectTreeView); //important: assign to manager
-		d->dataSourcePage = new KexiDataSourcePage(0, "dataSourcePage");
-		connect(d->dataSourcePage, SIGNAL(jumpToObjectRequested(const QCString&, const QCString&)),
-			mainWin, SLOT(highlightObject(const QCString&, const QCString&)));
-		connect(d->dataSourcePage, SIGNAL(formDataSourceChanged(const QCString&, const QCString&)),
-			KFormDesigner::FormManager::self(), SLOT(setFormDataSource(const QCString&, const QCString&)));
-		connect(d->dataSourcePage, SIGNAL(dataSourceFieldOrExpressionChanged(const QString&, const QString&, KexiDB::Field::Type)),
-			KFormDesigner::FormManager::self(), SLOT(setDataSourceFieldOrExpression(const QString&, const QString&, KexiDB::Field::Type)));
-		connect(d->dataSourcePage, SIGNAL(insertAutoFields(const QString&, const QString&, const QStringList&)), 
-			KFormDesigner::FormManager::self(), SLOT(insertAutoFields(const QString&, const QString&, const QStringList&)));
+		d->dataSourcePage = new KexiDataSourcePage(0);
+		d->dataSourcePage->setObjectName("dataSourcePage");
+		connect(d->dataSourcePage,
+			SIGNAL(jumpToObjectRequested(const Q3CString&, const Q3CString&)),
+			KexiMainWindowIface::global()->thisWidget(),
+			SLOT(highlightObject(const Q3CString&, const Q3CString&)));
+		connect(d->dataSourcePage, 
+			SIGNAL(formDataSourceChanged(const Q3CString&, const Q3CString&)),
+			KFormDesigner::FormManager::self(),
+			SLOT(setFormDataSource(const Q3CString&, const Q3CString&)));
+		connect(d->dataSourcePage,
+			SIGNAL(dataSourceFieldOrExpressionChanged(const QString&, const QString&, KexiDB::Field::Type)),
+			KFormDesigner::FormManager::self(),
+			SLOT(setDataSourceFieldOrExpression(const QString&, const QString&, KexiDB::Field::Type)));
+		connect(d->dataSourcePage,
+			SIGNAL(insertAutoFields(const QString&, const QString&, const QStringList&)),
+			KFormDesigner::FormManager::self(),
+			SLOT(insertAutoFields(const QString&, const QString&, const QStringList&)));
 	}
 
-	KexiProject *prj = mainWin->project();
+	KexiProject *prj = KexiMainWindowIface::global()->project();
 	d->dataSourcePage->setProject(prj);
 
-	tab->addTab( d->dataSourcePage, SmallIconSet("database"), "");
-	tab->setTabToolTip( d->dataSourcePage, i18n("Data Source"));
+	tab->addTab( d->dataSourcePage, KIcon("database"), "");
+	tab->setTabToolTip( tab->indexOf(d->dataSourcePage), i18n("Data Source"));
 
-	tab->addTab( d->objectTreeView, SmallIconSet("widgets"), "");
-	tab->setTabToolTip( d->objectTreeView, i18n("Widgets"));
+	tab->addTab( d->objectTreeView, KIcon("widgets"), "");
+	tab->setTabToolTip( tab->indexOf(d->objectTreeView), i18n("Widgets"));
+}
+
+void KexiFormPart::slotWidgetCreatedByFormsLibrary(QWidget* widget)
+{
+	QList<QMetaMethod> _signals( KexiUtils::methodsForMetaObject(
+		widget->metaObject(), QMetaMethod::Signal) );
+
+	if (!_signals.isEmpty()) {
+		const char *handleDragMoveEventSignal = "handleDragMoveEvent(QDragMoveEvent*)";
+		const char *handleDropEventSignal = "handleDropEvent(QDropEvent*)";
+		KexiFormView *formView = KexiUtils::findParent<KexiFormView*>(widget);
+		
+		foreach (const QMetaMethod& method, _signals) {
+			if (0==qstrcmp(method.signature(), handleDragMoveEventSignal)) {
+				kDebug() << method.signature() <<  endl;
+				if (formView) {
+					connect(widget, SIGNAL(handleDragMoveEvent(QDragMoveEvent*)), 
+						formView, SLOT(slotHandleDragMoveEvent(QDragMoveEvent*)));
+				}
+			}
+			else if (0==qstrcmp(method.signature(), handleDropEventSignal)) {
+				kDebug() << method.signature() <<  endl;
+				if (formView) {
+					connect(widget, SIGNAL(handleDropEvent(QDropEvent*)), 
+						formView, SLOT(slotHandleDropEvent(QDropEvent*)));
+				}
+			}
+		}
+	}
 }
 
 //----------------
 
 KexiFormPart::TempData::TempData(QObject* parent)
- : KexiDialogTempData(parent)
+ : KexiWindowData(parent)
 {
 }
 
