@@ -20,8 +20,18 @@
 
 #include "kexiformview.h"
 
-#include <qobjectlist.h>
+#include <qobject.h>
 #include <qfileinfo.h>
+//Added by qt3to4:
+#include <Q3CString>
+#include <QFocusEvent>
+#include <QDragMoveEvent>
+#include <QEvent>
+#include <QDropEvent>
+#include <Q3ValueList>
+#include <Q3HBoxLayout>
+#include <QResizeEvent>
+#include <QApplication>
 
 #include <formeditor/form.h>
 #include <formeditor/formIO.h>
@@ -31,9 +41,10 @@
 #include <formeditor/widgetpropertyset.h>
 #include <formeditor/commands.h>
 #include <formeditor/widgetwithsubpropertiesinterface.h>
+#include <formeditor/objecttree.h>
 
 #include <kexi.h>
-#include <kexidialogbase.h>
+#include <kexi_global.h>
 #include <kexidragobjects.h>
 #include <kexidb/field.h>
 #include <kexidb/fieldlist.h>
@@ -44,7 +55,9 @@
 #include <tableview/kexitableitem.h>
 #include <tableview/kexitableviewdata.h>
 #include <widget/kexipropertyeditorview.h>
-#include <formeditor/objecttree.h>
+#include <widget/kexiqueryparameters.h>
+#include <kexiutils/utils.h>
+#include <KexiMainWindowIface.h>
 
 #include <koproperty/set.h>
 #include <koproperty/property.h>
@@ -58,9 +71,8 @@
 
 //! @todo #define KEXI_SHOW_SPLITTER_WIDGET
 
-KexiFormView::KexiFormView(KexiMainWindow *mainWin, QWidget *parent,
-	const char *name, bool /*dbAware*/)
- : KexiDataAwareView( mainWin, parent, name )
+KexiFormView::KexiFormView(QWidget *parent, bool /*dbAware*/)
+ : KexiDataAwareView( parent )
  , m_propertySet(0)
  , m_resizeMode(KexiFormView::ResizeDefault)
  , m_query(0)
@@ -71,14 +83,16 @@ KexiFormView::KexiFormView(KexiMainWindow *mainWin, QWidget *parent,
 	m_delayedFormContentsResizeOnShow = 0;
 
 	QHBoxLayout *l = new QHBoxLayout(this);
-	l->setAutoAdd(true);
+//Qt3	l->setAutoAdd(true);
 
 	m_scrollView = new KexiFormScrollView(this, viewMode()==Kexi::DataViewMode);
-
+	l->addWidget(m_scrollView);
+	
 //moved	setViewWidget(m_scrollView);
 //	m_scrollView->show();
 
-	m_dbform = new KexiDBForm(m_scrollView->viewport(), m_scrollView, name/*, conn*/);
+	m_dbform = new KexiDBForm(m_scrollView->viewport(), m_scrollView);
+	m_dbform->setObjectName("KexiDBForm");
 //	m_dbform->resize( m_scrollView->viewport()->size() - QSize(20, 20) );
 //	m_dbform->resize(QSize(400, 300));
 	m_scrollView->setWidget(m_dbform);
@@ -93,8 +107,8 @@ KexiFormView::KexiFormView(KexiMainWindow *mainWin, QWidget *parent,
 	}
 	else
 	{
-		connect(KFormDesigner::FormManager::self(), SIGNAL(propertySetSwitched(KoProperty::Set*, bool, const QCString&)),
-			this, SLOT(slotPropertySetSwitched(KoProperty::Set*, bool, const QCString&)));
+		connect(KFormDesigner::FormManager::self(), SIGNAL(propertySetSwitched(KoProperty::Set*, bool, const QByteArray&)),
+			this, SLOT(slotPropertySetSwitched(KoProperty::Set*, bool, const QByteArray&)));
 		connect(KFormDesigner::FormManager::self(), SIGNAL(dirty(KFormDesigner::Form *, bool)),
 			this, SLOT(slotDirty(KFormDesigner::Form *, bool)));
 
@@ -165,7 +179,7 @@ KexiFormView::KexiFormView(KexiMainWindow *mainWin, QWidget *parent,
 KexiFormView::~KexiFormView()
 {
 	if (m_cursor) {
-		KexiDB::Connection *conn = parentDialog()->mainWin()->project()->dbConnection();
+		KexiDB::Connection *conn = KexiMainWindowIface::global()->project()->dbConnection();
 		conn->deleteCursor(m_cursor);
 		m_cursor = 0;
 	}
@@ -182,7 +196,7 @@ void
 KexiFormView::deleteQuery()
 {
 	if (m_cursor) {
-		KexiDB::Connection *conn = parentDialog()->mainWin()->project()->dbConnection();
+		KexiDB::Connection *conn = KexiMainWindowIface::global()->project()->dbConnection();
 		conn->deleteCursor(m_cursor);
 		m_cursor = 0;
 	}
@@ -216,7 +230,8 @@ KexiFormView::setForm(KFormDesigner::Form *f)
 void
 KexiFormView::initForm()
 {
-	setForm( new KFormDesigner::Form(KexiFormPart::library(), 0, viewMode()==Kexi::DesignViewMode) );
+	setForm( 
+		new KFormDesigner::Form(KexiFormPart::library(), viewMode()==Kexi::DesignViewMode) );
 //	if (viewMode()==Kexi::DataViewMode)
 		//form()->setDesignMode(false);
 	form()->createToplevel(m_dbform, m_dbform);
@@ -227,13 +242,14 @@ KexiFormView::initForm()
 			KFormDesigner::FormManager::self(), SLOT(slotHistoryCommandExecuted()));
 	}
 
-	const bool newForm = parentDialog()->id() < 0;
+	const bool newForm = window()->id() < 0;
 
 	KexiDB::FieldList *fields = 0;
 	if (newForm) {
 		// Show the form wizard if this is a new Form
 #ifndef NO_DSWIZARD
-		KexiDataSourceWizard *w = new KexiDataSourceWizard(mainWin(), (QWidget*)mainWin(), "datasource_wizard");
+		KexiDataSourceWizard *w
+			= new KexiDataSourceWizard(KexiMainWindowIface::global()->thisWidget());
 		if(!w->exec())
 			fields = 0;
 		else
@@ -293,10 +309,10 @@ void KexiFormView::updateAutoFieldsDataSource()
 	//-inherit data types
 	//(this data has not been stored in the form)
 	QString dataSourceString( m_dbform->dataSource() );
-	QCString dataSourceMimeTypeString( m_dbform->dataSourceMimeType() );
-	KexiDB::Connection *conn = parentDialog()->mainWin()->project()->dbConnection();
+	QString dataSourceMimeTypeString( m_dbform->dataSourceMimeType() );
+	KexiDB::Connection *conn = KexiMainWindowIface::global()->project()->dbConnection();
 	KexiDB::TableOrQuerySchema tableOrQuery(
-		conn, dataSourceString.latin1(), dataSourceMimeTypeString=="kexi/table");
+		conn, dataSourceString.toLatin1(), dataSourceMimeTypeString=="kexi/table");
 	if (!tableOrQuery.table() && !tableOrQuery.query())
 		return;
 	for (KFormDesigner::ObjectTreeDictIterator it(*form()->objectTree()->dict());
@@ -322,10 +338,10 @@ void KexiFormView::updateValuesForSubproperties()
 	//-inherit data types
 	//(this data has not been stored in the form)
 	QString dataSourceString( m_dbform->dataSource() );
-	QCString dataSourceMimeTypeString( m_dbform->dataSourceMimeType() );
-	KexiDB::Connection *conn = parentDialog()->mainWin()->project()->dbConnection();
+	QString dataSourceMimeTypeString( m_dbform->dataSourceMimeType() );
+	KexiDB::Connection *conn = KexiMainWindowIface::global()->project()->dbConnection();
 	KexiDB::TableOrQuerySchema tableOrQuery(
-		conn, dataSourceString.latin1(), dataSourceMimeTypeString=="kexi/table");
+		conn, dataSourceString.toLatin1(), dataSourceMimeTypeString=="kexi/table");
 	if (!tableOrQuery.table() && !tableOrQuery.query())
 		return;
 
@@ -339,25 +355,24 @@ void KexiFormView::updateValuesForSubproperties()
 		if (subpropIface && subpropIface->subwidget() && it.current()->subproperties() ) {
 			QWidget *subwidget = subpropIface->subwidget();
 			QMap<QString, QVariant>* subprops = it.current()->subproperties();
-			for (QMapConstIterator<QString, QVariant> subpropIt = subprops->constBegin(); subpropIt!=subprops->constEnd(); ++subpropIt) {
+			for (QMap<QString, QVariant>::const_iterator subpropIt = subprops->constBegin(); subpropIt!=subprops->constEnd(); ++subpropIt) {
 				kexipluginsdbg << "KexiFormView::loadForm(): delayed setting of the subproperty: widget="
-					<< it.current()->widget()->name() << " prop=" << subpropIt.key() << " val=" << subpropIt.data() << endl;
+					<< it.current()->widget()->objectName() << " prop=" << subpropIt.key() << " val="
+					<< subpropIt.value() << endl;
 
-				const int count = subwidget->metaObject()->findProperty(subpropIt.key().latin1(), true);
-				const QMetaProperty *meta = count!=-1 ? subwidget->metaObject()->property(count, true) : 0;
-				if (meta) {
+				QMetaProperty meta = KexiUtils::findPropertyWithSuperclasses(
+					subwidget, subpropIt.key().toLatin1().constData());
+				if (meta.isValid()) {
 					// Special case: the property value of type enum (set) but is saved as a string list,
 					// not as int, so we need to translate it to int. It's been created as such
 					// by FormIO::readPropertyValue(). Example: "alignment" property.
-					if (meta->isSetType() && subpropIt.data().type()==QVariant::StringList) {
-						QStrList keys;
-						const QStringList list( subpropIt.data().toStringList() );
-						for (QStringList::ConstIterator it = list.constBegin(); it != list.constEnd(); ++it)
-							keys.append((*it).latin1());
-						subwidget->setProperty( subpropIt.key().latin1(), meta->keysToValue(keys) );
+					if (meta.isEnumType() && subpropIt.value().type()==QVariant::StringList) {
+						const QByteArray keysCombined( subpropIt.value().toStringList().join("|").toLatin1() );
+						subwidget->setProperty( subpropIt.key().toLatin1(),
+							meta.enumerator().keysToValue(keysCombined.constData()) );
 					}
 					else {
-						subwidget->setProperty( subpropIt.key().latin1(), subpropIt.data() );
+						subwidget->setProperty( subpropIt.key().toLatin1(), subpropIt.value() );
 					}
 				}
 			}//for
@@ -365,16 +380,36 @@ void KexiFormView::updateValuesForSubproperties()
 	}
 }
 
+//! Used in KexiFormView::loadForm()
+static void setUnsavedBLOBIdsForDataViewMode( 
+	QWidget* widget, const QHash<QByteArray, KexiBLOBBuffer::Id_t>& unsavedLocalBLOBsByName)
+{
+	if (-1 != KexiUtils::indexOfPropertyWithSuperclasses(widget, "pixmapId")) {
+		const KexiBLOBBuffer::Id_t blobID
+			= unsavedLocalBLOBsByName.value( widget->objectName().toLatin1() );
+		if (blobID > 0)
+			widget->setProperty(
+				"pixmapId",
+				(uint /* KexiBLOBBuffer::Id_t is unsafe and unsupported by QVariant - will be fixed in Qt4*/)blobID);
+	}
+	const QList<QWidget*> list( widget->findChildren<QWidget*>() );
+	if (list.isEmpty())
+		return;
+	foreach (QWidget *w, list) {
+		setUnsavedBLOBIdsForDataViewMode(w, unsavedLocalBLOBsByName);
+	}
+}
+
 void
 KexiFormView::loadForm()
 {
 //@todo also load m_resizeMode !
 
-	kexipluginsdbg << "KexiFormView::loadForm() Loading the form with id : " << parentDialog()->id() << endl;
+	kexipluginsdbg << "KexiFormView::loadForm() Loading the form with id : " << window()->id() << endl;
 	// If we are previewing the Form, use the tempData instead of the form stored in the db
-	if(viewMode()==Kexi::DataViewMode && !tempData()->tempForm.isNull() )
-	{
+	if(viewMode()==Kexi::DataViewMode && !tempData()->tempForm.isNull() ) {
 		KFormDesigner::FormIO::loadFormFromString(form(), m_dbform, tempData()->tempForm);
+		setUnsavedBLOBIdsForDataViewMode( m_dbform, tempData()->unsavedLocalBLOBsByName );
 		updateAutoFieldsDataSource();
 		updateValuesForSubproperties();
 		return;
@@ -393,9 +428,10 @@ KexiFormView::loadForm()
 }
 
 void
-KexiFormView::slotPropertySetSwitched(KoProperty::Set *set, bool forceReload, const QCString& propertyToSelect)
+KexiFormView::slotPropertySetSwitched(KoProperty::Set *set, bool forceReload,
+	const QByteArray& propertyToSelect)
 {
-//	if (set && parentDialog()!=parentDialog()->mainWin()->currentDialog())
+//	if (set && window()!=KexiMainWindowIface::global()->currentWindow())
 	if (form() != KFormDesigner::FormManager::self()->activeForm())
 		return; //this is not the current form view
 	m_propertySet = set;
@@ -408,7 +444,7 @@ KexiFormView::slotPropertySetSwitched(KoProperty::Set *set, bool forceReload, co
 }
 
 tristate
-KexiFormView::beforeSwitchTo(int mode, bool &dontStore)
+KexiFormView::beforeSwitchTo(Kexi::ViewMode mode, bool &dontStore)
 {
 	if (mode!=viewMode()) {
 		if (viewMode()==Kexi::DataViewMode) {
@@ -426,20 +462,30 @@ KexiFormView::beforeSwitchTo(int mode, bool &dontStore)
 
 	// we don't store on db, but in our TempData
 	dontStore = true;
-	if(dirty() && (mode == Kexi::DataViewMode) && form()->objectTree()) {
+	if (isDirty() && (mode == Kexi::DataViewMode) && form()->objectTree()) {
 		KexiFormPart::TempData* temp = tempData();
 		if (!KFormDesigner::FormIO::saveFormToString(form(), temp->tempForm))
 			return false;
+
+		//collect blobs from design mode by name for use in data view mode
+		temp->unsavedLocalBLOBsByName.clear();
+		for (QHash<QWidget*, KexiBLOBBuffer::Id_t>::const_iterator it
+			= temp->unsavedLocalBLOBs.constBegin(); 
+			it!=temp->unsavedLocalBLOBs.constEnd(); ++it)
+		{
+			if (!it.key())
+				continue;
+			temp->unsavedLocalBLOBsByName.insert( it.key()->objectName().toLatin1(), it.value() );
+		}
 	}
 
 	return true;
 }
 
-tristate
-KexiFormView::afterSwitchFrom(int mode)
+tristate KexiFormView::afterSwitchFrom(Kexi::ViewMode mode)
 {
 	if (mode == 0 || mode == Kexi::DesignViewMode) {
-		if (parentDialog()->neverSaved()) {
+		if (window()->neverSaved()) {
 			m_dbform->resize(QSize(400, 300));
 			m_scrollView->refreshContentsSizeLater(true,true);
 			//m_delayedFormContentsResizeOnShow = false;
@@ -460,7 +506,8 @@ KexiFormView::afterSwitchFrom(int mode)
 	if((mode == Kexi::DesignViewMode) && viewMode()==Kexi::DataViewMode) {
 		// The form may have been modified, so we must recreate the preview
 		delete m_dbform; // also deletes form()
-		m_dbform = new KexiDBForm(m_scrollView->viewport(), m_scrollView, "KexiDBForm");
+		m_dbform = new KexiDBForm(m_scrollView->viewport(), m_scrollView);
+		m_dbform->setObjectName("KexiDBForm");
 		m_scrollView->setWidget(m_dbform);
 
 		initForm();
@@ -490,35 +537,35 @@ KexiFormView::afterSwitchFrom(int mode)
 		initDataSource();
 
 		//handle events for this form
-		m_scrollView->setMainWidgetForEventHandling(parentDialog()->mainWin(), m_dbform);
+		m_scrollView->setMainWidgetForEventHandling(m_dbform);
 
 		//set focus on 1st focusable widget which has valid dataSource property set
-		if (!m_dbform->orderedFocusWidgets()->isEmpty()) {
+		QList<QWidget*> *orderedFocusWidgets = m_dbform->orderedFocusWidgets();
+		if (!orderedFocusWidgets->isEmpty()) {
 //			QWidget *www = focusWidget();
 			//if (Kexi::hasParent(this, qApp->focusWidget())) {
-				QEvent fe( QEvent::FocusOut );
-				QFocusEvent::setReason(QFocusEvent::Tab);
-				QApplication::sendEvent( qApp->focusWidget(), &fe );
-				QFocusEvent::resetReason();
+				KexiUtils::unsetFocusWithReason(QApplication::focusWidget(), Qt::TabFocusReason);
 			//}
-
-			QPtrListIterator<QWidget> it(*m_dbform->orderedFocusWidgets());
-			for (;it.current(); ++it) {
-				KexiFormDataItemInterface *iface = dynamic_cast<KexiFormDataItemInterface*>(it.current());
+			
+			QWidget *widget;
+			foreach (widget, *orderedFocusWidgets) {
+				KexiFormDataItemInterface *iface = dynamic_cast<KexiFormDataItemInterface*>(widget);
 				if (iface)
 					kexipluginsdbg << iface->dataSource() << endl;
 				if (iface && iface->columnInfo() && !iface->isReadOnly()
 /*! @todo add option for skipping autoincremented fields */
 					/* also skip autoincremented fields:*/
 					&& !iface->columnInfo()->field->isAutoIncrement()) //!iface->dataSource().isEmpty()
+				{
 					break;
+				}
 			}
-			if (!it.current()) //eventually, focus first available widget if nothing other is available
-				it.toFirst();
+			if (!widget) //eventually, focus first available widget if nothing other is available
+				widget = orderedFocusWidgets->first();
 
-			it.current()->setFocus();
-			SET_FOCUS_USING_REASON(it.current(), QFocusEvent::Tab);
-			m_setFocusInternalOnce = it.current();
+			widget->setFocus();
+			KexiUtils::setFocusWithReason(widget, Qt::TabFocusReason);
+			m_setFocusInternalOnce = widget;
 		}
 
 		if (m_query)
@@ -527,7 +574,7 @@ KexiFormView::afterSwitchFrom(int mode)
 
 	//dirty only if it's a new object
 	if (mode == 0)
-		setDirty( parentDialog()->partItem()->neverSaved() );
+		setDirty( window()->partItem()->neverSaved() );
 
 	if (mode==Kexi::DataViewMode && viewMode()==Kexi::DesignViewMode) {
 //		slotPropertySetSwitched
@@ -541,11 +588,11 @@ void KexiFormView::initDataSource()
 {
 	deleteQuery();
 	QString dataSourceString( m_dbform->dataSource() );
-	QCString dataSourceMimeTypeString( m_dbform->dataSourceMimeType() );
+	QString dataSourceMimeTypeString( m_dbform->dataSourceMimeType() );
 //! @todo also handle anonymous (not stored) queries provided as statements here
 	bool ok = !dataSourceString.isEmpty();
 
-/*			if (m_previousDataSourceString.lower()==dataSourceString.lower() && !m_cursor) {
+/*			if (m_previousDataSourceString.toLower()==dataSourceString.toLower() && !m_cursor) {
 			//data source changed: delete previous cursor
 			m_conn->deleteCursor(m_cursor);
 			m_cursor = 0;
@@ -562,7 +609,7 @@ void KexiFormView::initDataSource()
 		//collect all data-aware widgets and create query schema
 		m_scrollView->setMainDataSourceWidget(m_dbform);
 		sources = m_scrollView->usedDataSources();
-		conn = parentDialog()->mainWin()->project()->dbConnection();
+		conn = KexiMainWindowIface::global()->project()->dbConnection();
 		if (dataSourceMimeTypeString.isEmpty() /*table type is the default*/ 
 			|| dataSourceMimeTypeString=="kexi/table")
 		{
@@ -599,7 +646,7 @@ void KexiFormView::initDataSource()
 		}
 	}
 
-	QDict<char> invalidSources(997);
+	QSet<QString> invalidSources;
 	if (ok) {
 		KexiDB::IndexSchema *pkey = tableSchema ? tableSchema->primaryKey() : 0;
 		if (pkey) {
@@ -614,21 +661,21 @@ void KexiFormView::initDataSource()
 		for (QStringList::ConstIterator it = sources.constBegin();
 			it!=sources.constEnd(); ++it, index++) {
 /*! @todo add expression support */
-			QString fieldName( (*it).lower() );
+			QString fieldName( (*it).toLower() );
 			//remove "tablename." if it was prepended
-			if (tableSchema && fieldName.startsWith( tableSchema->name().lower()+"." ))
+			if (tableSchema && fieldName.startsWith( tableSchema->name().toLower()+"." ))
 				fieldName = fieldName.mid(tableSchema->name().length()+1);
 			//remove "queryname." if it was prepended
-			if (!tableSchema && fieldName.startsWith( m_query->name().lower()+"." ))
+			if (!tableSchema && fieldName.startsWith( m_query->name().toLower()+"." ))
 				fieldName = fieldName.mid(m_query->name().length()+1);
 			KexiDB::Field *f = tableSchema ? tableSchema->field(fieldName) : m_query->field(fieldName);
 			if (!f) {
 /*! @todo show error */
 				//remove this widget from the set of data widgets in the provider
 /*! @todo fieldName is ok, but what about expressions? */
-				invalidSources.insert( fieldName, (const char*)1 ); // += index;
-				kexipluginsdbg << "KexiFormView::initDataSource(): invalidSources+=" << index << " (" 
-					<< (*it) << ")" << endl;
+				invalidSources.insert( fieldName );
+				kexipluginsdbg << "KexiFormView::initDataSource(): invalidSources+=" 
+					<< index << " (" << (*it) << ")" << endl;
 				continue;
 			}
 			if (tableSchema) {
@@ -643,7 +690,15 @@ void KexiFormView::initDataSource()
 			deleteQuery();
 		}
 		else {
-			m_cursor = conn->executeQuery( *m_query );
+			KexiDB::debug( m_query->parameters() );
+			// like in KexiQueryView::executeQuery()
+			Q3ValueList<QVariant> params;
+			{
+				KexiUtils::WaitCursorRemover remover;
+				params = KexiQueryParameters::getParameters(this, *conn->driver(), *m_query, ok);
+			}
+			if (ok) //input cancelled
+				m_cursor = conn->executeQuery( *m_query, params );
 		}
 		m_scrollView->invalidateDataSources( invalidSources, m_query );
 		ok = m_cursor!=0;
@@ -678,14 +733,14 @@ void KexiFormView::initDataSource()
 void
 KexiFormView::slotDirty(KFormDesigner::Form *dirtyForm, bool isDirty)
 {
-	if(dirtyForm == form())
-		KexiViewBase::setDirty(isDirty);
+	if (dirtyForm == form())
+		KexiView::setDirty(isDirty);
 }
 
 KexiDB::SchemaData*
 KexiFormView::storeNewData(const KexiDB::SchemaData& sdata, bool &cancel)
 {
-	KexiDB::SchemaData *s = KexiViewBase::storeNewData(sdata, cancel);
+	KexiDB::SchemaData *s = KexiView::storeNewData(sdata, cancel);
 	kexipluginsdbg << "KexiDBForm::storeNewData(): new id:" << s->id() << endl;
 
 	if (!s || cancel) {
@@ -694,7 +749,7 @@ KexiFormView::storeNewData(const KexiDB::SchemaData& sdata, bool &cancel)
 	}
 	if (!storeData()) {
 		//failure: remove object's schema data to avoid garbage
-		KexiDB::Connection *conn = parentDialog()->mainWin()->project()->dbConnection();
+		KexiDB::Connection *conn = KexiMainWindowIface::global()->project()->dbConnection();
 		conn->removeObject( s->id() );
 		delete s;
 		return 0;
@@ -706,12 +761,12 @@ tristate
 KexiFormView::storeData(bool dontAsk)
 {
 	Q_UNUSED(dontAsk);
-	kexipluginsdbg << "KexiDBForm::storeData(): " << parentDialog()->partItem()->name() 
-		<< " [" << parentDialog()->id() << "]" << endl;
+	kexipluginsdbg << "KexiDBForm::storeData(): " << window()->partItem()->name() 
+		<< " [" << window()->id() << "]" << endl;
 
 	//-- first, store local BLOBs, so identifiers can be updated
 //! @todo remove unused data stored previously
-	KexiDB::Connection *conn = parentDialog()->mainWin()->project()->dbConnection();
+	KexiDB::Connection *conn = KexiMainWindowIface::global()->project()->dbConnection();
 	KexiDB::TableSchema *blobsTable = conn->tableSchema("kexi__blobs");
 	if (!blobsTable) { //compatibility check for older Kexi project versions
 //! @todo show message about missing kexi__blobs?
@@ -724,71 +779,63 @@ KexiFormView::storeData(bool dontAsk)
 	
 	KexiDB::PreparedStatement::Ptr st = conn->prepareStatement(
 		KexiDB::PreparedStatement::InsertStatement, *blobsFieldsWithoutID);
-//#if 0 
-////! @todo reenable when all drivers get PreparedStatement support
 	if (!st) {
 		delete blobsFieldsWithoutID;
 		//! @todo show message 
 		return false;
 	}
-//#endif
 	KexiBLOBBuffer *blobBuf = KexiBLOBBuffer::self();
-	for (QMapConstIterator<QWidget*, KexiBLOBBuffer::Id_t> it = m_unsavedLocalBLOBs.constBegin(); 
-		it!=m_unsavedLocalBLOBs.constEnd(); ++it)
-	{
-		if (!it.key()) {
-			kexipluginswarn << "KexiFormView::storeData(): it.key()==0 !" << endl;
-			continue;
-		}
-		kexipluginsdbg << "name=" << it.key()->name() << " dataID=" << it.data() << endl;
-		KexiBLOBBuffer::Handle h( blobBuf->objectForId(it.data(), /*!stored*/false) );
-		if (!h)
-			continue; //no BLOB assigned
+	KexiFormView *designFormView 
+		= dynamic_cast<KexiFormView*>( window()->viewForMode(Kexi::DesignViewMode) );
+	if (designFormView) {
+		for (QHash<QWidget*, KexiBLOBBuffer::Id_t>::const_iterator it
+			 = tempData()->unsavedLocalBLOBs.constBegin(); 
+			it!=tempData()->unsavedLocalBLOBs.constEnd(); ++it)
+		{
+			if (!it.key()) {
+				kexipluginswarn << "KexiFormView::storeData(): it.key()==0 !" << endl;
+				continue;
+			}
+			kexipluginsdbg << "name=" << it.key()->objectName() << " dataID=" << it.value() << endl;
+			KexiBLOBBuffer::Handle h( blobBuf->objectForId(it.value(), /*!stored*/false) );
+			if (!h)
+				continue; //no BLOB assigned
 
-		QString originalFileName(h.originalFileName());
-		QFileInfo fi(originalFileName);
-		QString caption(fi.baseName().replace('_', " ").simplifyWhiteSpace());
-////////
+			QString originalFileName(h.originalFileName());
+			QFileInfo fi(originalFileName);
+			QString caption(fi.baseName().replace('_', " ").simplified());
 
-//		KexiDB::PreparedStatement st(KexiDB::PreparedStatement::InsertStatement, *conn, *blobsTable);
-		if (st) {
-			*st /* << NO, (pgsql doesn't support this):QVariant()*/ /*id*/ 
-				<< h.data() << originalFileName << caption 
-				<< h.mimeType() << (uint)/*! @todo unsafe */h.folderId();
-			if (!st->execute()) {
-				delete blobsFieldsWithoutID;
-				kexipluginsdbg << " execute error" << endl;
+			if (st) {
+				*st /* << NO, (pgsql doesn't support this):QVariant()*/ /*id*/ 
+					<< h.data() << originalFileName << caption 
+					<< h.mimeType() << (uint)/*! @todo unsafe */h.folderId();
+				if (!st->execute()) {
+					delete blobsFieldsWithoutID;
+					kexipluginsdbg << " execute error" << endl;
+					return false;
+				}
+			}
+			delete blobsFieldsWithoutID;
+			blobsFieldsWithoutID=0;
+			const quint64 storedBLOBID = conn->lastInsertedAutoIncValue("o_id", "kexi__blobs");
+			if ((quint64)-1 == storedBLOBID) {
+	//! @todo show message?
 				return false;
 			}
+			kexipluginsdbg << " storedDataID=" << storedBLOBID << endl;
+			h.setStoredWidthID((KexiBLOBBuffer::Id_t /*unsafe - will be fixed in Qt4*/)storedBLOBID);
+			//set widget's internal property so it can be saved...
+			const QVariant oldStoredPixmapId( it.key()->property("storedPixmapId") );
+			it.key()->setProperty("storedPixmapId", 
+				QVariant((uint /* KexiBLOBBuffer::Id_t is unsafe and unsupported by QVariant - will be fixed in Qt4*/)storedBLOBID));
+			KFormDesigner::ObjectTreeItem *widgetItem
+				= designFormView->form()->objectTree()->lookup(it.key()->objectName());
+			if (widgetItem)
+				widgetItem->addModifiedProperty( "storedPixmapId", oldStoredPixmapId );
+			else
+				kexipluginswarn << "KexiFormView::storeData(): no '" << widgetItem->name() << "' widget found within a form" << endl;
 		}
-///////
-#if 0
-		if (!conn->insertRecord(*blobsFieldsWithoutID, h.data(), originalFileName, caption, h.mimeType())) {
-			delete blobsFieldsWithoutID;
-//! @todo show message?
-			return false;
-		}
-#endif
-		delete blobsFieldsWithoutID;
-		blobsFieldsWithoutID=0;
-		const Q_ULLONG storedBLOBID = conn->lastInsertedAutoIncValue("o_id", "kexi__blobs");
-		if ((Q_ULLONG)-1 == storedBLOBID) {
-//! @todo show message?
-			return false;
-		}
-		kexipluginsdbg << " storedDataID=" << storedBLOBID << endl;
-		h.setStoredWidthID((KexiBLOBBuffer::Id_t /*unsafe - will be fixed in Qt4*/)storedBLOBID);
-		//set widget's internal property so it can be saved...
-		const QVariant oldStoredPixmapId( it.key()->property("storedPixmapId") );
-		it.key()->setProperty("storedPixmapId", 
-			QVariant((uint /* KexiBLOBBuffer::Id_t is unsafe and unsupported by QVariant - will be fixed in Qt4*/)storedBLOBID));
-		KFormDesigner::ObjectTreeItem *widgetItem = form()->objectTree()->lookup(it.key()->name());
-		if (widgetItem)
-			widgetItem->addModifiedProperty( "storedPixmapId", oldStoredPixmapId );
-		else
-			kexipluginswarn << "KexiFormView::storeData(): no '" << widgetItem->name() << "' widget found within a form" << endl;
 	}
-//TODO: forall it.key()->setProperty(
 
 	//-- now, save form's XML
 	QString data;
@@ -798,9 +845,9 @@ KexiFormView::storeData(bool dontAsk)
 		return false;
 
 	//all blobs are now saved
-	m_unsavedLocalBLOBs.clear();
+	tempData()->unsavedLocalBLOBs.clear();
 
-	tempData()->tempForm = QString::null;
+	tempData()->tempForm.clear();
 	return true;
 }
 
@@ -941,15 +988,15 @@ KexiFormView::setRedoEnabled(bool enabled)
 QSize
 KexiFormView::preferredSizeHint(const QSize& otherSize)
 {
-	if (parentDialog()->neverSaved()) {
+	if (window()->neverSaved()) {
 		//ignore otherSize if possible
-//		return KexiViewBase::preferredSizeHint( (parentDialog() && parentDialog()->mdiParent()) ? QSize(10000,10000) : otherSize);
+//		return KexiView::preferredSizeHint( (window() && window()->mdiParent()) ? QSize(10000,10000) : otherSize);
 	}
 
 	return (m_dbform->size()
 			+QSize(m_scrollView->verticalScrollBar()->isVisible() ? m_scrollView->verticalScrollBar()->width()*3/2 : 10,
 			 m_scrollView->horizontalScrollBar()->isVisible() ? m_scrollView->horizontalScrollBar()->height()*3/2 : 10))
-		.expandedTo( KexiViewBase::preferredSizeHint(otherSize) );
+		.expandedTo( KexiView::preferredSizeHint(otherSize) );
 }
 
 void
@@ -961,7 +1008,7 @@ KexiFormView::resizeEvent( QResizeEvent *e )
 			e->size().height()!=e->oldSize().height()
 		);
 	}
-	KexiViewBase::resizeEvent(e);
+	KexiView::resizeEvent(e);
 	m_scrollView->updateNavPanelGeometry();
 	if (m_delayedFormContentsResizeOnShow>0) { // && isVisible()) {
 		m_delayedFormContentsResizeOnShow--;
@@ -976,7 +1023,7 @@ KexiFormView::setFocusInternal()
 		if (m_dbform->focusWidget()) {
 			//better-looking focus
 			if (m_setFocusInternalOnce) {
-				SET_FOCUS_USING_REASON(m_setFocusInternalOnce, QFocusEvent::Other);//Tab);
+				KexiUtils::setFocusWithReason(m_setFocusInternalOnce, Qt::OtherFocusReason);
 				m_setFocusInternalOnce = 0;
 			}
 			else {
@@ -999,7 +1046,7 @@ KexiFormView::show()
 	//	if (resizeMode() == KexiFormView::ResizeAuto)
 	if (viewMode()==Kexi::DataViewMode) {
 		if (resizeMode() == KexiFormView::ResizeAuto)
-			m_scrollView->setResizePolicy(QScrollView::AutoOneFit);
+			m_scrollView->setResizePolicy(Q3ScrollView::AutoOneFit);
 	}
 }
 
@@ -1016,10 +1063,10 @@ void
 KexiFormView::updateDataSourcePage()
 {
 	if (viewMode()==Kexi::DesignViewMode) {
-		QCString dataSourceMimeType, dataSource;
+		QString dataSourceMimeType, dataSource;
 		KFormDesigner::WidgetPropertySet *set = KFormDesigner::FormManager::self()->propertySet();
 		if (set->contains("dataSourceMimeType"))
-			dataSourceMimeType = (*set)["dataSourceMimeType"].value().toCString();
+			dataSourceMimeType = (*set)["dataSourceMimeType"].value().toString();
 		if (set->contains("dataSource"))
 			dataSource = (*set)["dataSource"].value().toCString();
 
@@ -1039,24 +1086,31 @@ KexiFormView::slotHandleDragMoveEvent(QDragMoveEvent* e)
 void
 KexiFormView::slotHandleDropEvent(QDropEvent* e)
 {
-	if (KexiFieldDrag::canDecodeMultiple( e )) {
+	const QWidget *targetContainerWidget = dynamic_cast<const QWidget*>(sender());
+	KFormDesigner::ObjectTreeItem *targetContainerWidgetItem = targetContainerWidget 
+		? form()->objectTree()->lookup( targetContainerWidget->objectName() ) : 0; 
+	if (targetContainerWidgetItem && targetContainerWidgetItem->container() 
+		&& KexiFieldDrag::canDecodeMultiple( e ))
+	{
 		QString sourceMimeType, sourceName;
 		QStringList fields;
 		if (!KexiFieldDrag::decodeMultiple( e, sourceMimeType, sourceName, fields ))
 			return;
-		insertAutoFields(sourceMimeType, sourceName, fields, e->pos());
+		insertAutoFields(sourceMimeType, sourceName, fields, 
+			targetContainerWidgetItem->container(), e->pos());
 	}
 }
 
 void
 KexiFormView::insertAutoFields(const QString& sourceMimeType, const QString& sourceName,
-	const QStringList& fields, const QPoint& _pos)
+	const QStringList& fields, KFormDesigner::Container* targetContainer, const QPoint& _pos)
 {
 	if (fields.isEmpty())
 		return;
 
-	KexiDB::Connection *conn = parentDialog()->mainWin()->project()->dbConnection();
-	KexiDB::TableOrQuerySchema tableOrQuery(conn, sourceName.latin1(), sourceMimeType=="kexi/table");
+	KexiDB::Connection *conn = KexiMainWindowIface::global()->project()->dbConnection();
+	KexiDB::TableOrQuerySchema tableOrQuery(conn, sourceName.toLatin1(),
+		sourceMimeType=="kexi/table");
 	if (!tableOrQuery.table() && !tableOrQuery.query()) {
 		kexipluginswarn << "KexiFormView::insertAutoFields(): no such table/query \""
 			<< sourceName << "\"" << endl;
@@ -1083,20 +1137,21 @@ KexiFormView::insertAutoFields(const QString& sourceMimeType, const QString& sou
 //		KFormDesigner::WidgetList* prevSelection = form()->selectedWidgets();
 	KFormDesigner::WidgetList widgetsToSelect;
 	KFormDesigner::CommandGroup *group = new KFormDesigner::CommandGroup(
-		fields.count()==1 ? i18n("Insert AutoField widget") : i18n("Insert %1 AutoField widgets").arg(fields.count()),
+		fields.count()==1
+			? i18n("Insert AutoField widget") : i18n("Insert %1 AutoField widgets", fields.count()),
 		KFormDesigner::FormManager::self()->propertySet()
 	);
 	
-	foreach( QStringList::ConstIterator, it, fields ) {
-		KexiDB::QueryColumnInfo* column = tableOrQuery.columnInfo(*it);
+	foreach( const QString& field, fields ) {
+		KexiDB::QueryColumnInfo* column = tableOrQuery.columnInfo(field);
 		if (!column) {
 			kexipluginswarn << "KexiFormView::insertAutoFields(): no such field \""
-				<< *it << "\" in table/query \"" << sourceName << "\"" << endl;
+				<< field << "\" in table/query \"" << sourceName << "\"" << endl;
 			continue;
 		}
 //! todo add autolabel using field's caption or name
-		KFormDesigner::Container *targetContainer;
-		QWidget* targetContainerWidget = QApplication::widgetAt(pos, true);
+		//KFormDesigner::Container *targetContainer;
+/*		QWidget* targetContainerWidget = QApplication::widgetAt(pos, true);
 		while (targetContainerWidget 
 			&& !dynamic_cast<KFormDesigner::Container*>(targetContainerWidget))
 		{
@@ -1105,7 +1160,7 @@ KexiFormView::insertAutoFields(const QString& sourceMimeType, const QString& sou
 		if (dynamic_cast<KFormDesigner::Container*>(targetContainerWidget))
 			targetContainer = dynamic_cast<KFormDesigner::Container*>(targetContainerWidget);
 		else
-			targetContainer = form()->toplevelContainer();
+			targetContainer = form()->toplevelContainer();*/
 		KFormDesigner::InsertWidgetCommand *insertCmd
 			= new KFormDesigner::InsertWidgetCommand(targetContainer,
 	//! todo this is hardcoded!
@@ -1124,7 +1179,7 @@ KexiFormView::insertAutoFields(const QString& sourceMimeType, const QString& sou
 //#if 0
 		KFormDesigner::CommandGroup *subGroup 
 			= new KFormDesigner::CommandGroup("", KFormDesigner::FormManager::self()->propertySet());
-		QMap<QCString, QVariant> propValues;
+		QMap<Q3CString, QVariant> propValues;
 		propValues.insert("dataSource", column->aliasOrName());
 		propValues.insert("fieldTypeInternal", (int)column->field->type());
 		propValues.insert("fieldCaptionInternal", column->captionOrAliasOrName());
@@ -1161,14 +1216,14 @@ KexiFormView::insertAutoFields(const QString& sourceMimeType, const QString& sou
 		//resize form if needed
 		QRect oldFormRect( m_dbform->geometry() );
 		QRect newFormRect( oldFormRect );
-		newFormRect.setWidth(QMAX(m_dbform->width(), widgetsToSelect.last()->geometry().right()+1));
-		newFormRect.setHeight(QMAX(m_dbform->height(), widgetsToSelect.last()->geometry().bottom()+1));
+		newFormRect.setWidth(qMax(m_dbform->width(), widgetsToSelect.last()->geometry().right()+1));
+		newFormRect.setHeight(qMax(m_dbform->height(), widgetsToSelect.last()->geometry().bottom()+1));
 		if (newFormRect != oldFormRect) {
 			//1. resize by hand
 			m_dbform->setGeometry( newFormRect );
 			//2. store information about resize
 			KFormDesigner::PropertyCommand *resizeFormCommand = new KFormDesigner::PropertyCommand(
-				KFormDesigner::FormManager::self()->propertySet(), m_dbform->name(),
+				KFormDesigner::FormManager::self()->propertySet(), m_dbform->objectName().toLatin1(),
 				oldFormRect, newFormRect, "geometry"); 
 			group->addCommand(resizeFormCommand, true/*will be executed on CommandGroup::execute()*/);
 		}
@@ -1208,9 +1263,9 @@ KexiFormView::setUnsavedLocalBLOB(QWidget *widget, KexiBLOBBuffer::Id_t id)
 {
 //! @todo if there already was data assigned, remember it should be dereferenced
 	if (id==0) 
-		m_unsavedLocalBLOBs.remove(widget);
+		tempData()->unsavedLocalBLOBs.remove(widget);
 	else
-		m_unsavedLocalBLOBs.insert(widget, id);
+		tempData()->unsavedLocalBLOBs.insert(widget, id);
 }
 
 /*
