@@ -19,10 +19,10 @@
 
 #include "kexicsvexportwizard.h"
 #include "kexicsvwidgets.h"
-#include <main/startup/KexiStartupFileDialog.h>
+#include <main/startup/KexiStartupFileWidget.h>
 #include <kexidb/cursor.h>
 #include <kexidb/utils.h>
-#include <core/keximainwindow.h>
+#include <core/KexiMainWindowIface.h>
 #include <core/kexiproject.h>
 #include <core/kexipartinfo.h>
 #include <core/kexipartmanager.h>
@@ -31,8 +31,15 @@
 #include <widget/kexicharencodingcombobox.h>
 
 #include <qcheckbox.h>
-#include <qgroupbox.h>
+#include <q3groupbox.h>
 #include <qclipboard.h>
+//Added by qt3to4:
+#include <Q3CString>
+#include <QTextStream>
+#include <Q3GridLayout>
+#include <QLabel>
+#include <Q3HBoxLayout>
+#include <QDesktopWidget>
 #include <kapplication.h>
 #include <klocale.h>
 #include <kiconloader.h>
@@ -41,17 +48,18 @@
 #include <kapplication.h>
 #include <kdebug.h>
 #include <ksavefile.h>
-
+#include <kglobal.h>
+#include <KDialog>
 
 KexiCSVExportWizard::KexiCSVExportWizard( const KexiCSVExport::Options& options,
-	KexiMainWindow* mainWin, QWidget * parent, const char * name )
- : KWizard(parent, name)
+	QWidget * parent )
+ : K3Wizard(parent)
  , m_options(options)
 // , m_mode(mode)
 // , m_itemId(itemId)
- , m_mainWin(mainWin)
  , m_fileSavePage(0)
  , m_defaultsBtn(0)
+ , m_importExportGroup( KGlobal::config()->group("ImportExport") )
  , m_rowCount(-1)
  , m_rowCountDetermined(false)
  , m_cancelled(false)
@@ -68,7 +76,7 @@ KexiCSVExportWizard::KexiCSVExportWizard( const KexiCSVExport::Options& options,
 	QString infoLblFromText;
 	KexiGUIMessageHandler msgh(this);
 	m_tableOrQuery = new KexiDB::TableOrQuerySchema(
-		m_mainWin->project()->dbConnection(), m_options.itemId);
+		KexiMainWindowIface::global()->project()->dbConnection(), m_options.itemId);
 	if (m_tableOrQuery->table()) {
 		if (m_options.mode==KexiCSVExport::Clipboard) {
 			setCaption(i18n("Copy Data From Table to Clipboard"));
@@ -90,7 +98,7 @@ KexiCSVExportWizard::KexiCSVExportWizard( const KexiCSVExport::Options& options,
 		}
 	}
 	else {
-		msgh.showErrorMessage(m_mainWin->project()->dbConnection(),
+		msgh.showErrorMessage(KexiMainWindowIface::global()->project()->dbConnection(),
 			i18n("Could not open data for exporting."));
 		m_cancelled = true;
 		return;
@@ -100,23 +108,25 @@ KexiCSVExportWizard::KexiCSVExportWizard( const KexiCSVExport::Options& options,
 	// Setup pages
 
 	// 1. File Save Page
-	if (m_options.mode==KexiCSVExport::File) {
-		m_fileSavePage = new KexiStartupFileDialog(
-			":CSVImportExport", //startDir
-			KexiStartupFileDialog::Custom | KexiStartupFileDialog::SavingFileBasedDB,
-			this, "m_fileSavePage");
-		m_fileSavePage->setMinimumHeight(kapp->desktop()->height()/2);
-		m_fileSavePage->setAdditionalFilters( csvMimeTypes() );
+	if (m_options.mode==KexiCSVExport::File) {	
+		m_fileSavePage = new KexiStartupFileWidget(
+			KUrl("kfiledialog:///CSVImportExport"), //startDir
+			KexiStartupFileWidget::Custom | KexiStartupFileWidget::SavingFileBasedDB,
+			this);
+		m_fileSavePage->setObjectName("m_fileSavePage");
+		m_fileSavePage->setMinimumHeight(kapp->desktop()->availableGeometry().height()/2);
+		m_fileSavePage->setAdditionalFilters( csvMimeTypes().toSet() );
 		m_fileSavePage->setDefaultExtension("csv");
-		m_fileSavePage->setLocationText( KexiUtils::stringToFileName(m_tableOrQuery->captionOrName()) );
+		m_fileSavePage->setLocationText(
+			KexiUtils::stringToFileName(m_tableOrQuery->captionOrName()) );
 		connect(m_fileSavePage, SIGNAL(rejected()), this, SLOT(reject()));
 		addPage(m_fileSavePage, i18n("Enter Name of File You Want to Save Data To"));
 	}
 
 	// 2. Export options
 	m_exportOptionsPage = new QWidget(this, "m_exportOptionsPage");
-	QGridLayout *exportOptionsLyr = new QGridLayout( m_exportOptionsPage, 6, 3,
-		KDialogBase::marginHint(), KDialogBase::spacingHint(), "exportOptionsLyr");
+	Q3GridLayout *exportOptionsLyr = new Q3GridLayout( m_exportOptionsPage, 6, 3,
+		KDialog::marginHint(), KDialog::spacingHint(), "exportOptionsLyr");
 	m_infoLblFrom = new KexiCSVInfoLabel( infoLblFromText, m_exportOptionsPage );
 	KexiPart::Info *partInfo = Kexi::partManager().infoForMimeType(
 		m_tableOrQuery->table() ? "kexi/table" : "kexi/query");
@@ -130,24 +140,26 @@ KexiCSVExportWizard::KexiCSVExportWizard( const KexiCSVExport::Options& options,
 		m_exportOptionsPage
 	);
 	if (m_options.mode==KexiCSVExport::Clipboard)
-		m_infoLblTo->setIcon("editpaste");
+		m_infoLblTo->setIcon("edit-paste");
 	exportOptionsLyr->addMultiCellWidget(m_infoLblTo, 1, 1, 0, 2);
 
-	m_showOptionsButton = new KPushButton(KGuiItem(i18n("Show Options >>"), "configure"),
+	m_showOptionsButton = new KPushButton(KGuiItem(i18n("Show Options >>"), "configure"), 
 		m_exportOptionsPage);
 	connect(m_showOptionsButton, SIGNAL(clicked()), this, SLOT(slotShowOptionsButtonClicked()));
 	exportOptionsLyr->addMultiCellWidget(m_showOptionsButton, 2, 2, 0, 0);
 	m_showOptionsButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
 
 	// -<options section>
-	m_exportOptionsSection = new QGroupBox(1, Vertical, i18n("Options"), m_exportOptionsPage,
-		"m_exportOptionsSection");
+	m_exportOptionsSection = new Q3GroupBox(1, Qt::Vertical, i18n("Options"), m_exportOptionsPage);
+	m_exportOptionsSection->setObjectName("m_exportOptionsSection");
 	m_exportOptionsSection->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
 	exportOptionsLyr->addMultiCellWidget(m_exportOptionsSection, 3, 3, 0, 1);
-	QWidget *exportOptionsSectionWidget
-		= new QWidget(m_exportOptionsSection, "exportOptionsSectionWidget");
-	QGridLayout *exportOptionsSectionLyr = new QGridLayout( exportOptionsSectionWidget, 5, 2,
-		0, KDialogBase::spacingHint(), "exportOptionsLyr");
+	QWidget *exportOptionsSectionWidget 
+		= new QWidget(m_exportOptionsSection);
+	exportOptionsSectionWidget->setObjectName("exportOptionsSectionWidget");
+	Q3GridLayout *exportOptionsSectionLyr = new Q3GridLayout( exportOptionsSectionWidget, 5, 2, 
+		0, KDialog::spacingHint());
+	exportOptionsLyr->setObjectName("exportOptionsLyr");
 
 	// -delimiter
 	m_delimiterWidget = new KexiCSVDelimiterWidget(false, //!lineEditOnBottom
@@ -159,7 +171,7 @@ KexiCSVExportWizard::KexiCSVExportWizard( const KexiCSVExport::Options& options,
 
 	// -text quote
 	QWidget *textQuoteWidget = new QWidget(exportOptionsSectionWidget);
-	QHBoxLayout *textQuoteLyr = new QHBoxLayout(textQuoteWidget);
+	Q3HBoxLayout *textQuoteLyr = new Q3HBoxLayout(textQuoteWidget);
 	exportOptionsSectionLyr->addWidget(textQuoteWidget, 1, 1);
 	m_textQuote = new KexiCSVTextQuoteComboBox( textQuoteWidget );
 	m_textQuote->setTextQuote(defaultTextQuote());
@@ -190,17 +202,19 @@ KexiCSVExportWizard::KexiCSVExportWizard( const KexiCSVExport::Options& options,
 	m_alwaysUseCheckBox->hide();
 	// -</options section>
 
-//	exportOptionsLyr->setColStretch(3, 1);
-	exportOptionsLyr->addMultiCell(
+//	exportOptionsLyr->setColumnStretch(3, 1);
+	exportOptionsLyr->addMultiCell( 
 		new QSpacerItem( 0, 0, QSizePolicy::Preferred, QSizePolicy::MinimumExpanding), 5, 5, 0, 1 );
 
 //	addPage(m_exportOptionsPage, i18n("Set Export Options"));
-	addPage(m_exportOptionsPage, m_options.mode==KexiCSVExport::Clipboard ? i18n("Copying") : i18n("Exporting"));
+	addPage(m_exportOptionsPage, 
+		m_options.mode==KexiCSVExport::Clipboard ? i18n("Copying") : i18n("Exporting"));
 	setFinishEnabled(m_exportOptionsPage, true);
 
 	// load settings
-	kapp->config()->setGroup("ImportExport");
-	if (m_options.mode!=KexiCSVExport::Clipboard && readBoolEntry("ShowOptionsInCSVExportDialog", false)) {
+	if (m_options.mode!=KexiCSVExport::Clipboard
+		&& readBoolEntry("ShowOptionsInCSVExportDialog", false))
+	{
 		show();
 		slotShowOptionsButtonClicked();
 	}
@@ -222,7 +236,7 @@ KexiCSVExportWizard::KexiCSVExportWizard( const KexiCSVExport::Options& options,
 	updateGeometry();
 
 	// -keep widths equal on page #2:
-	int width = QMAX( m_infoLblFrom->leftLabel()->sizeHint().width(),
+	int width = qMax( m_infoLblFrom->leftLabel()->sizeHint().width(),
 		m_infoLblTo->leftLabel()->sizeHint().width());
 	m_infoLblFrom->leftLabel()->setFixedWidth(width);
 	m_infoLblTo->leftLabel()->setFixedWidth(width);
@@ -245,7 +259,7 @@ void KexiCSVExportWizard::showPage ( QWidget * page )
 	}
 	else if (page==m_exportOptionsPage) {
 		if (m_options.mode==KexiCSVExport::File)
-			m_infoLblTo->setFileName( m_fileSavePage->currentFileName() );
+			m_infoLblTo->setFileName( m_fileSavePage->selectedFile() );
 		QString text = m_tableOrQuery->captionOrName();
 		if (!m_rowCountDetermined) {
 			//do this costly operation only once
@@ -255,9 +269,9 @@ void KexiCSVExportWizard::showPage ( QWidget * page )
 		int columns = KexiDB::fieldCount(*m_tableOrQuery);
 		text += "\n";
 		if (m_rowCount>0)
-			text += i18n("(rows: %1, columns: %2)").arg(m_rowCount).arg(columns);
+			text += i18n("(rows: %1, columns: %2)", m_rowCount, columns);
 		else
-			text += i18n("(columns: %1)").arg(columns);
+			text += i18n("(columns: %1)", columns);
 		m_infoLblFrom->setLabelText(text);
 		QFontMetrics fm(m_infoLblFrom->fileNameLabel()->font());
 		m_infoLblFrom->fileNameLabel()->setFixedHeight( fm.height() * 2 + fm.lineSpacing() );
@@ -270,26 +284,26 @@ void KexiCSVExportWizard::showPage ( QWidget * page )
 			m_defaultsBtn->hide();
 	}
 
-	KWizard::showPage(page);
+	K3Wizard::showPage(page);
 }
 
 void KexiCSVExportWizard::next()
 {
 	if (currentPage() == m_fileSavePage) {
-		if (!m_fileSavePage->checkFileName())
+		if (!m_fileSavePage->checkSelectedFile())
 			return;
-		KWizard::next();
+		K3Wizard::next();
 		finishButton()->setFocus();
 		return;
 	}
-	KWizard::next();
+	K3Wizard::next();
 }
 
 void KexiCSVExportWizard::done(int result)
 {
 	if (QDialog::Accepted == result) {
 		if (m_fileSavePage)
-			m_options.fileName = m_fileSavePage->currentFileName();
+			m_options.fileName = m_fileSavePage->selectedFile();
 		m_options.delimiter = m_delimiterWidget->delimiter();
 		m_options.textQuote = m_textQuote->textQuote();
 		m_options.addColumnNames = m_addColumnNamesCheckBox->isChecked();
@@ -301,7 +315,6 @@ void KexiCSVExportWizard::done(int result)
 	}
 
 	//store options
-	kapp->config()->setGroup("ImportExport");
 	if (m_options.mode!=KexiCSVExport::Clipboard)
 		writeEntry("ShowOptionsInCSVExportDialog", m_exportOptionsSection->isVisible());
 	const bool store = m_alwaysUseCheckBox->isChecked();
@@ -317,15 +330,17 @@ void KexiCSVExportWizard::done(int result)
 	else
 		deleteEntry("DefaultTextQuoteForExportingCSVFiles");
 	if (store && !m_characterEncodingCombo->defaultEncodingSelected())
-		writeEntry("DefaultEncodingForExportingCSVFiles", m_characterEncodingCombo->selectedEncoding());
+		writeEntry(
+			"DefaultEncodingForExportingCSVFiles", m_characterEncodingCombo->selectedEncoding());
 	else
 		deleteEntry("DefaultEncodingForExportingCSVFiles");
 	if (store && !m_addColumnNamesCheckBox->isChecked())
-		writeEntry("AddColumnNamesForExportingCSVFiles", m_addColumnNamesCheckBox->isChecked());
+		writeEntry(
+			"AddColumnNamesForExportingCSVFiles", m_addColumnNamesCheckBox->isChecked());
 	else
 		deleteEntry("AddColumnNamesForExportingCSVFiles");
 
-	KWizard::done(result);
+	K3Wizard::done(result);
 }
 
 void KexiCSVExportWizard::slotShowOptionsButtonClicked()
@@ -348,13 +363,13 @@ void KexiCSVExportWizard::slotShowOptionsButtonClicked()
 
 void KexiCSVExportWizard::layOutButtonRow( QHBoxLayout * layout )
 {
-	QWizard::layOutButtonRow( layout );
+	Q3Wizard::layOutButtonRow( layout );
 
 	//find the last sublayout
 	QLayout *l = 0;
 	for (QLayoutIterator lit( layout->iterator() ); lit.current(); ++lit)
 		l = lit.current()->layout();
-	if (dynamic_cast<QBoxLayout*>(l)) {
+	if (dynamic_cast<Q3BoxLayout*>(l)) {
 		if (!m_defaultsBtn) {
 			m_defaultsBtn = new KPushButton(i18n("Defaults"), this);
 			QWidget::setTabOrder(backButton(), m_defaultsBtn);
@@ -362,7 +377,7 @@ void KexiCSVExportWizard::layOutButtonRow( QHBoxLayout * layout )
 		}
 		if (!m_exportOptionsSection->isVisible())
 			m_defaultsBtn->hide();
-		dynamic_cast<QBoxLayout*>(l)->insertWidget(0, m_defaultsBtn);
+		dynamic_cast<Q3BoxLayout*>(l)->insertWidget(0, m_defaultsBtn);
 	}
 }
 
@@ -374,6 +389,7 @@ void KexiCSVExportWizard::slotDefaultsButtonClicked()
 	m_characterEncodingCombo->selectDefaultEncoding();
 }
 
+
 static QString convertKey(const char *key, KexiCSVExport::Mode mode)
 {
 	QString _key(QString::fromLatin1(key));
@@ -387,27 +403,27 @@ static QString convertKey(const char *key, KexiCSVExport::Mode mode)
 
 bool KexiCSVExportWizard::readBoolEntry(const char *key, bool defaultValue)
 {
-	return kapp->config()->readBoolEntry(convertKey(key, m_options.mode), defaultValue);
+	return m_importExportGroup.readEntry<bool>(convertKey(key, m_options.mode), defaultValue);
 }
 
 QString KexiCSVExportWizard::readEntry(const char *key, const QString& defaultValue)
 {
-	return kapp->config()->readEntry(convertKey(key, m_options.mode), defaultValue);
+	return m_importExportGroup.readEntry(convertKey(key, m_options.mode), defaultValue);
 }
 
 void KexiCSVExportWizard::writeEntry(const char *key, const QString& value)
 {
-	kapp->config()->writeEntry(convertKey(key, m_options.mode), value);
+	m_importExportGroup.writeEntry(convertKey(key, m_options.mode), value);
 }
 
 void KexiCSVExportWizard::writeEntry(const char *key, bool value)
 {
-	kapp->config()->writeEntry(convertKey(key, m_options.mode), value);
+	m_importExportGroup.writeEntry(convertKey(key, m_options.mode), value);
 }
 
 void KexiCSVExportWizard::deleteEntry(const char *key)
 {
-	kapp->config()->deleteEntry(convertKey(key, m_options.mode));
+	m_importExportGroup.deleteEntry(convertKey(key, m_options.mode));
 }
 
 QString KexiCSVExportWizard::defaultDelimiter() const
