@@ -24,6 +24,13 @@
 #include <qpainter.h>
 #include <qdom.h>
 #include <qregexp.h>
+//Added by qt3to4:
+#include <Q3CString>
+#include <QDragMoveEvent>
+#include <QDropEvent>
+#include <Q3ValueList>
+#include <Q3VBoxLayout>
+#include <q3tl.h>
 
 #include <kdebug.h>
 #include <klocale.h>
@@ -38,13 +45,12 @@
 #include <kexidb/roweditbuffer.h>
 #include <kexiutils/identifier.h>
 #include <kexiproject.h>
-#include <keximainwindow.h>
+#include <KexiMainWindowIface.h>
 #include <kexiinternalpart.h>
 #include <kexitableview.h>
 #include <kexitableitem.h>
 #include <kexitableviewdata.h>
 #include <kexidragobjects.h>
-#include <kexidialogbase.h>
 #include <kexidatatable.h>
 #include <kexi.h>
 #include <kexisectionheader.h>
@@ -53,8 +59,10 @@
 #include <widget/relations/kexirelationviewtable.h>
 #include <koproperty/property.h>
 #include <koproperty/set.h>
-
 #include "kexiquerypart.h"
+#include <KexiWindow.h>
+#include <KexiWindowData.h>
+#include <kexi_global.h>
 
 //! @todo remove KEXI_NO_QUERY_TOTALS later
 #define KEXI_NO_QUERY_TOTALS
@@ -99,7 +107,7 @@ public:
 
 	KexiTableViewData *data;
 	KexiDataTable *dataTable;
-	QGuardedPtr<KexiDB::Connection> conn;
+	QPointer<KexiDB::Connection> conn;
 
 	KexiRelationWidget *relations;
 	KexiSectionHeader *head;
@@ -116,7 +124,7 @@ public:
 	 This information is cached and entirely refreshed on updateColumnsData().
 	 The dict is filled with (char*)1 values (doesn't matter what it is);
 	*/
-	QDict<char> fieldColumnIdentifiers;
+	Q3Dict<char> fieldColumnIdentifiers;
 
 	KexiDataAwarePropertySet* sets;
 	KexiTableItem *droppedNewItem;
@@ -139,15 +147,16 @@ static bool sortingAllowed(const QString& fieldName, const QString& tableName) {
 //=========================================================
 
 KexiQueryDesignerGuiEditor::KexiQueryDesignerGuiEditor(
-	KexiMainWindow *mainWin, QWidget *parent, const char *name)
- : KexiViewBase(mainWin, parent, name)
+	QWidget *parent)
+ : KexiView(parent)
  , d( new Private() )
 {
-	d->conn = mainWin->project()->dbConnection();
+	d->conn = KexiMainWindowIface::global()->project()->dbConnection();
 
-	d->spl = new QSplitter(Vertical, this);
+	d->spl = new QSplitter(Qt::Vertical, this);
 	d->spl->setChildrenCollapsible(false);
-	d->relations = new KexiRelationWidget(mainWin, d->spl, "relations");
+	d->relations = new KexiRelationWidget(d->spl);
+	d->relations->setObjectName("relations");
 	connect(d->relations, SIGNAL(tableAdded(KexiDB::TableSchema&)),
 		this, SLOT(slotTableAdded(KexiDB::TableSchema&)));
 	connect(d->relations, SIGNAL(tableHidden(KexiDB::TableSchema&)),
@@ -155,8 +164,9 @@ KexiQueryDesignerGuiEditor::KexiQueryDesignerGuiEditor(
 	connect(d->relations, SIGNAL(tableFieldDoubleClicked(KexiDB::TableSchema*,const QString&)),
 		this, SLOT(slotTableFieldDoubleClicked(KexiDB::TableSchema*,const QString&)));
 
-	d->head = new KexiSectionHeader(i18n("Query Columns"), Vertical, d->spl);
-	d->dataTable = new KexiDataTable(mainWin, d->head, "guieditor_dataTable", false);
+	d->head = new KexiSectionHeader(i18n("Query Columns"), Qt::Vertical, d->spl);
+	d->dataTable = new KexiDataTable(d->head, false);
+	d->dataTable->setObjectName("guieditor_dataTable");
 	d->dataTable->dataAwareObject()->setSpreadSheetMode();
 
 	d->data = new KexiTableViewData(); //just empty data
@@ -164,7 +174,7 @@ KexiQueryDesignerGuiEditor::KexiQueryDesignerGuiEditor(
 	initTableColumns();
 	initTableRows();
 
-	QValueList<int> c;
+	Q3ValueList<int> c;
 	c << COLUMN_ID_COLUMN << COLUMN_ID_TABLE << COLUMN_ID_CRITERIA;
 	if (d->dataTable->tableView()/*sanity*/) {
 		d->dataTable->tableView()->adjustColumnWidthToContents(COLUMN_ID_VISIBLE);
@@ -187,7 +197,7 @@ KexiQueryDesignerGuiEditor::KexiQueryDesignerGuiEditor(
 	connect(d->relations, SIGNAL(aboutConnectionRemove(KexiRelationViewConnection*)),
 		this, SLOT(slotAboutConnectionRemove(KexiRelationViewConnection*)));
 
-	QVBoxLayout *l = new QVBoxLayout(this);
+	Q3VBoxLayout *l = new Q3VBoxLayout(this);
 	l->addWidget(d->spl);
 
 	addChildView(d->relations);
@@ -196,7 +206,7 @@ KexiQueryDesignerGuiEditor::KexiQueryDesignerGuiEditor(
 	d->relations->setSizePolicy(QSizePolicy::Expanding,QSizePolicy::Expanding);
 	d->head->setSizePolicy(QSizePolicy::Expanding,QSizePolicy::Expanding);
 	updateGeometry();
-	d->spl->setSizes(QValueList<int>()<< 800<<400);
+	d->spl->setSizes(Q3ValueList<int>()<< 800<<400);
 }
 
 KexiQueryDesignerGuiEditor::~KexiQueryDesignerGuiEditor()
@@ -222,14 +232,14 @@ KexiQueryDesignerGuiEditor::initTableColumns()
 
 	KexiTableViewColumn *col3 = new KexiTableViewColumn("visible", KexiDB::Field::Boolean, i18n("Visible"),
 		i18n("Describes visibility for a given field or expression."));
-	col3->field()->setDefaultValue( QVariant(false, 0) );
+	col3->field()->setDefaultValue( QVariant(false) );
 	col3->field()->setNotNull( true );
 	d->data->addColumn(col3);
 
 #ifndef KEXI_NO_QUERY_TOTALS
 	KexiTableViewColumn *col4 = new KexiTableViewColumn("totals", KexiDB::Field::Enum, i18n("Totals"),
 		i18n("Describes a way of computing totals for a given field or expression."));
-	QValueVector<QString> totalsTypes;
+	Q3ValueVector<QString> totalsTypes;
 	totalsTypes.append( i18n("Group by") );
 	totalsTypes.append( i18n("Sum") );
 	totalsTypes.append( i18n("Average") );
@@ -242,7 +252,7 @@ KexiQueryDesignerGuiEditor::initTableColumns()
 
 	KexiTableViewColumn *col5 = new KexiTableViewColumn("sort", KexiDB::Field::Enum, i18n("Sorting"),
 		i18n("Describes a way of sorting for a given field."));
-	QValueVector<QString> sortTypes;
+	Q3ValueVector<QString> sortTypes;
 	sortTypes.append( "" );
 	sortTypes.append( i18n("Ascending") );
 	sortTypes.append( i18n("Descending") );
@@ -264,7 +274,7 @@ void KexiQueryDesignerGuiEditor::initTableRows()
 	for (int i=0; i<(int)d->sets->size(); i++) {
 		KexiTableItem* item;
 		d->data->append(item = d->data->createItem());
-		item->at(COLUMN_ID_VISIBLE) = QVariant(false, 0);
+		item->at(COLUMN_ID_VISIBLE) = QVariant(false);
 	}
 	d->dataTable->dataAwareObject()->setData(d->data);
 
@@ -281,7 +291,7 @@ void KexiQueryDesignerGuiEditor::updateColumnsData()
 	qHeapSort( sortedTableNames );
 
 	//several tables can be hidden now, so remove rows for these tables
-	QValueList<int> rowsToDelete;
+	Q3ValueList<int> rowsToDelete;
 	for (int r = 0; r<(int)d->sets->size(); r++) {
 		KoProperty::Set *set = d->sets->at(r);
 		if (set) {
@@ -349,7 +359,7 @@ KexiRelationWidget *KexiQueryDesignerGuiEditor::relationView() const
 KexiQueryPart::TempData *
 KexiQueryDesignerGuiEditor::tempData() const
 {
-	return static_cast<KexiQueryPart::TempData*>(parentDialog()->tempData());
+	return static_cast<KexiQueryPart::TempData*>(window()->data());
 }
 
 static QString msgCannotSwitch_EmptyDesign() {
@@ -378,23 +388,25 @@ KexiQueryDesignerGuiEditor::buildSchema(QString *errMsg)
 	// -WHERE expression
 	// -ORDER BY list
 	KexiDB::BaseExpr *whereExpr = 0;
-	const uint count = QMIN(d->data->count(), d->sets->size());
+	const uint count = qMin(d->data->count(), d->sets->size());
 	bool fieldsFound = false;
 	KexiTableViewData::Iterator it(d->data->iterator());
 	for (uint i=0; i<count && it.current(); ++it, i++) {
-		if (!it.current()->at(COLUMN_ID_TABLE).isNull() && it.current()->at(COLUMN_ID_COLUMN).isNull()) {
+		if (!it.current()->at(COLUMN_ID_TABLE).isNull() 
+			&& it.current()->at(COLUMN_ID_COLUMN).isNull())
+		{
 			//show message about missing field name, and set focus to that cell
 			kexipluginsdbg << "no field provided!" << endl;
 			d->dataTable->dataAwareObject()->setCursorPosition(i,0);
 			if (errMsg)
-				*errMsg = i18n("Select column for table \"%1\"")
-					.arg(it.current()->at(COLUMN_ID_TABLE).toString());
+				*errMsg = i18n("Select column for table \"%1\"",
+					it.current()->at(COLUMN_ID_TABLE).toString());
 			return false;
 		}
 
 		KoProperty::Set *set = d->sets->at(i);
 		if (set) {
-			QString tableName = (*set)["table"].value().toString().stripWhiteSpace();
+			QString tableName = (*set)["table"].value().toString().trimmed();
 			QString fieldName = (*set)["field"].value().toString();
 			QString fieldAndTableName = fieldName;
 			KexiDB::Field *currentField = 0; // will be set if this column is a single field
@@ -403,14 +415,14 @@ KexiQueryDesignerGuiEditor::buildSchema(QString *errMsg)
 				fieldAndTableName.prepend(tableName+".");
 			const bool fieldVisible = (*set)["visible"].value().toBool();
 			QString criteriaStr = (*set)["criteria"].value().toString();
-			QCString alias = (*set)["alias"].value().toCString();
+			Q3CString alias = (*set)["alias"].value().toCString();
 			if (!criteriaStr.isEmpty()) {
 				int token;
 				KexiDB::BaseExpr *criteriaExpr = parseExpressionString(criteriaStr, token, 
 					true/*allowRelationalOperator*/);
 				if (!criteriaExpr) {//for sanity
 					if (errMsg)
-						*errMsg = i18n("Invalid criteria \"%1\"").arg(criteriaStr);
+						*errMsg = i18n("Invalid criteria \"%1\"", criteriaStr);
 					delete whereExpr;
 					return false;
 				}
@@ -431,7 +443,7 @@ KexiQueryDesignerGuiEditor::buildSchema(QString *errMsg)
 						false/*!allowRelationalOperator*/);
 					if (!columnExpr) {
 						if (errMsg)
-							*errMsg = i18n("Invalid expression \"%1\"").arg(fieldName);
+							*errMsg = i18n("Invalid expression \"%1\"", fieldName);
 						return false;
 					}
 					temp->query()->addExpression(columnExpr, fieldVisible);
@@ -546,7 +558,7 @@ KexiQueryDesignerGuiEditor::buildSchema(QString *errMsg)
 		if (!currentField || currentField->isExpression() || currentField->isQueryAsterisk())
 //! @todo support expressions here
 			continue;
-//! @todo ok, but not for expresions
+//! @todo ok, but not for expressions
 		QString aliasString( (*set)["alias"].value().toString() );
 		currentColumn = temp->query()->columnInfo( 
 			(*set)["table"].value().toString() + "."
@@ -567,7 +579,7 @@ KexiQueryDesignerGuiEditor::buildSchema(QString *errMsg)
 }
 
 tristate
-KexiQueryDesignerGuiEditor::beforeSwitchTo(int mode, bool &dontStore)
+KexiQueryDesignerGuiEditor::beforeSwitchTo(Kexi::ViewMode mode, bool &dontStore)
 {
 	kexipluginsdbg << "KexiQueryDesignerGuiEditor::beforeSwitch()" << mode << endl;
 
@@ -581,11 +593,11 @@ KexiQueryDesignerGuiEditor::beforeSwitchTo(int mode, bool &dontStore)
 //		if (!d->dataTable->dataAwareObject()->acceptRowEdit())
 	//		return cancelled;
 
-		if (!dirty() && parentDialog()->neverSaved()) {
+		if (!isDirty() && window()->neverSaved()) {
 			KMessageBox::information(this, msgCannotSwitch_EmptyDesign());
 			return cancelled;
 		}
-		if (dirty() || !tempData()->query()) {
+		if (isDirty() || !tempData()->query()) {
 			//remember current design in a temporary structure
 			dontStore=true;
 			QString errMsg;
@@ -615,31 +627,31 @@ KexiQueryDesignerGuiEditor::beforeSwitchTo(int mode, bool &dontStore)
 }
 
 tristate
-KexiQueryDesignerGuiEditor::afterSwitchFrom(int mode)
+KexiQueryDesignerGuiEditor::afterSwitchFrom(Kexi::ViewMode mode)
 {
-	const bool was_dirty = dirty();
-	KexiDB::Connection *conn = parentDialog()->mainWin()->project()->dbConnection();
+	const bool was_dirty = isDirty();
+	KexiDB::Connection *conn = KexiMainWindowIface::global()->project()->dbConnection();
 	if (mode==Kexi::NoViewMode || (mode==Kexi::DataViewMode && !tempData()->query())) {
 		//this is not a SWITCH but a fresh opening in this view mode
-		if (!m_dialog->neverSaved()) {
+		if (!window()->neverSaved()) {
 			if (!loadLayout()) {
 				//err msg
-				parentDialog()->setStatus(conn,
+				window()->setStatus(conn,
 					i18n("Query definition loading failed."),
 					i18n("Query design may be corrupted so it could not be opened even in text view.\n"
 						"You can delete the query and create it again."));
 				return false;
 			}
 			// Invalid queries case:
-			// KexiDialogBase::switchToViewMode() first opens DesignViewMode,
+			// KexiWindow::switchToViewMode() first opens DesignViewMode,
 			// and then KexiQueryPart::loadSchemaData() doesn't allocate QuerySchema object
-			// do we're carefully looking at parentDialog()->schemaData()
-			KexiDB::QuerySchema * q = dynamic_cast<KexiDB::QuerySchema *>(parentDialog()->schemaData());
+			// do we're carefully looking at window()->schemaData()
+			KexiDB::QuerySchema * q = dynamic_cast<KexiDB::QuerySchema *>(window()->schemaData());
 			if (q) {
 				KexiDB::ResultInfo result;
 				showFieldsForQuery( q, result );
 				if (!result.success) {
-					parentDialog()->setStatus(&result, i18n("Query definition loading failed."));
+					window()->setStatus(&result, i18n("Query definition loading failed."));
 					tempData()->proposeOpeningInTextViewModeBecauseOfProblems = true;
 					return false;
 				}
@@ -662,7 +674,7 @@ KexiQueryDesignerGuiEditor::afterSwitchFrom(int mode)
 				KexiDB::ResultInfo result;
 				showFieldsAndRelationsForQuery( tempData()->query(), result );
 				if (!result.success) {
-					parentDialog()->setStatus(&result, i18n("Query definition loading failed."));
+					window()->setStatus(&result, i18n("Query definition loading failed."));
 					return false;
 				}
 			}
@@ -710,8 +722,9 @@ KexiQueryDesignerGuiEditor::storeNewData(const KexiDB::SchemaData& sdata, bool &
 	}
 	(KexiDB::SchemaData&)*temp->query() = sdata; //copy main attributes
 
-	bool ok = m_mainWin->project()->dbConnection()->storeObjectSchemaData( *temp->query(), true /*newObject*/ );
-	m_dialog->setId( temp->query()->id() );
+	bool ok = KexiMainWindowIface::global()->project()->dbConnection()->storeObjectSchemaData(
+		*temp->query(), true /*newObject*/ );
+	window()->setId( temp->query()->id() );
 
 	if (ok)
 		ok = storeLayout();
@@ -730,8 +743,8 @@ tristate KexiQueryDesignerGuiEditor::storeData(bool dontAsk)
 	if (!d->dataTable->dataAwareObject()->acceptRowEdit())
 		return cancelled;
 
-	const bool was_dirty = dirty();
-	tristate res = KexiViewBase::storeData(dontAsk); //this clears dirty flag
+	const bool was_dirty = isDirty();
+	tristate res = KexiView::storeData(dontAsk); //this clears dirty flag
 	if (true == res)
 		res = buildSchema();
 	if (true == res)
@@ -791,9 +804,9 @@ void KexiQueryDesignerGuiEditor::showFieldsOrRelationsForQueryInternal(
 	KexiDB::QuerySchema *query, bool showFields, bool showRelations, KexiDB::ResultInfo& result)
 {
 	result.clear();
-	const bool was_dirty = dirty();
+	const bool was_dirty = isDirty();
 
-	//1. Show explicity declared relations:
+	//1. Show explicitly declared relations:
 	if (showRelations) {
 		KexiDB::Relationship *rel;
 		for (KexiDB::Relationship::ListIterator it(*query->relationships());
@@ -809,7 +822,7 @@ void KexiQueryDesignerGuiEditor::showFieldsOrRelationsForQueryInternal(
 	//2. Collect information about criterias
 	// --this must be top level chain of AND's
 	// --this will also show joins as: [table1.]field1 = [table2.]field2
-	QDict<KexiDB::BaseExpr> criterias(101, false);
+	Q3Dict<KexiDB::BaseExpr> criterias(101, false);
 	KexiDB::BaseExpr* e = query->whereExpression();
 	KexiDB::BaseExpr* eItem = 0;
 	while (e) {
@@ -877,8 +890,8 @@ void KexiQueryDesignerGuiEditor::showFieldsOrRelationsForQueryInternal(
 	//3. show fields (including * and table.*)
 	uint row_num = 0;
 	KexiDB::Field *field;
-	QPtrDict<char> usedCriterias(101); // <-- used criterias will be saved here
-	                                   //     so in step 4. we will be able to add
+	Q3PtrDict<char> usedCriterias(101); // <-- used criterias will be saved here
+	                                   //     so in step 4. we will be able to add 
 	                                   //     remaining invisible columns with criterias
 	for (KexiDB::Field::ListIterator it(*query->fields());
 		(field = it.current()); ++it, row_num++)
@@ -974,7 +987,7 @@ void KexiQueryDesignerGuiEditor::showFieldsOrRelationsForQueryInternal(
 		else if ((*orderByColumnsIt).field()) {
 			//this will be presented as invisible field: create new row
 			field = (*orderByColumnsIt).field();
-			QString tableName( field->table() ? field->table()->name() : QString::null );
+			QString tableName( field->table() ? field->table()->name() : QString() );
 			rowItem = createNewRow( tableName, field->name(), false /* !visible*/);
 			d->dataTable->dataAwareObject()->insertItem(rowItem, row_num);
 			rowPropertySet = createPropertySet( row_num, tableName, field->name(), true /*newOne*/ );
@@ -992,13 +1005,13 @@ void KexiQueryDesignerGuiEditor::showFieldsOrRelationsForQueryInternal(
 			d->data->saveRowChanges(*rowItem, true);
 			(*rowPropertySet)["sorting"].clearModifiedFlag(); // this property should look "fresh"
 			if (!rowItem->at(COLUMN_ID_VISIBLE).toBool()) //update
-				(*rowPropertySet)["visible"].setValue(QVariant(false,0), false/*rememberOldValue*/); 
+				(*rowPropertySet)["visible"].setValue(QVariant(false), false/*rememberOldValue*/); 
 		}
 	}
 
 	//5. Show fields for unused criterias (with "Visible" column set to false)
 	KexiDB::BaseExpr *criteriaArgument; // <-- contains field or table.field
-	for (QDictIterator<KexiDB::BaseExpr> it(criterias); (criteriaArgument = it.current()); ++it) {
+	for (Q3DictIterator<KexiDB::BaseExpr> it(criterias); (criteriaArgument = it.current()); ++it) {
 		if (usedCriterias[it.current()])
 			continue;
 		//unused: append a new row
@@ -1018,7 +1031,7 @@ void KexiQueryDesignerGuiEditor::showFieldsOrRelationsForQueryInternal(
 			}
 		}
 		KexiDB::Field* field = 0;
-		if (-1 == columnNameArgument->name.find('.') && query->tables()->count()==1) {
+		if (!columnNameArgument->name.contains('.') && query->tables()->count()==1) {
 			//extreme case: only field name provided for one-table query:
 			field = query->tables()->first()->field(columnNameArgument->name);
 		}
@@ -1052,7 +1065,7 @@ void KexiQueryDesignerGuiEditor::showFieldsOrRelationsForQueryInternal(
 //! @todo			set["alias"].setValue(columnAlias, false);
 ////		if (!criteriaString.isEmpty())
 		set["criteria"].setValue( criteriaString, false );
-		set["visible"].setValue( QVariant(false,1), false );
+		set["visible"].setValue( QVariant(false), false );
 	}
 
 	//current property set has most probably changed
@@ -1077,13 +1090,13 @@ bool KexiQueryDesignerGuiEditor::loadLayout()
 		//in a case when query layout was not saved, build layout by hand
 		// -- dynamic cast because of a need for handling invalid queries
 		//    (as in KexiQueryDesignerGuiEditor::afterSwitchFrom()):
-		KexiDB::QuerySchema * q =	dynamic_cast<KexiDB::QuerySchema *>(parentDialog()->schemaData());
+		KexiDB::QuerySchema * q =	dynamic_cast<KexiDB::QuerySchema *>(window()->schemaData());
 		if (q) {
 			showTablesForQuery( q );
 			KexiDB::ResultInfo result;
 			showRelationsForQuery( q, result );
 			if (!result.success) {
-				parentDialog()->setStatus(&result, i18n("Query definition loading failed."));
+				window()->setStatus(&result, i18n("Query definition loading failed."));
 				return false;
 			}
 		}
@@ -1098,7 +1111,7 @@ bool KexiQueryDesignerGuiEditor::loadLayout()
 		return false;
 	}
 
-	const bool was_dirty = dirty();
+	const bool was_dirty = isDirty();
 
 	//add tables and relations to the relation view
 	for (el = doc_el.firstChild().toElement(); !el.isNull(); el=el.nextSibling().toElement()) {
@@ -1133,12 +1146,13 @@ bool KexiQueryDesignerGuiEditor::storeLayout()
 	KexiQueryPart::TempData * temp = tempData();
 
 	// Save SQL without driver-escaped keywords.
-	KexiDB::Connection* dbConn = mainWin()->project()->dbConnection();
-	if (m_dialog->schemaData()) //set this instance as obsolete (only if it's stored)
-		dbConn->setQuerySchemaObsolete( m_dialog->schemaData()->name() );
+	KexiDB::Connection* dbConn = KexiMainWindowIface::global()->project()->dbConnection();
+	if (window()->schemaData()) //set this instance as obsolete (only if it's stored)
+		dbConn->setQuerySchemaObsolete( window()->schemaData()->name() );
 
 	KexiDB::Connection::SelectStatementOptions options;
 	options.identifierEscaping = KexiDB::Driver::EscapeKexi|KexiDB::Driver::EscapeAsNecessary;
+	options.addVisibleLookupColumns = false;
 	QString sqlText = dbConn->selectStatement( *temp->query(), options );
 	if (!storeDataBlock( sqlText, "sql" )) {
 		return false;
@@ -1170,9 +1184,6 @@ bool KexiQueryDesignerGuiEditor::storeLayout()
 	if (!storeDataBlock( xml, "query_layout" )) {
 		return false;
 	}
-
-//	mainWin()->project()->reloadPartItem( m_dialog );
-
 	return true;
 }
 
@@ -1180,7 +1191,7 @@ QSize KexiQueryDesignerGuiEditor::sizeHint() const
 {
 	QSize s1 = d->relations->sizeHint();
 	QSize s2 = d->head->sizeHint();
-	return QSize(QMAX(s1.width(),s2.width()), s1.height()+s2.height());
+	return QSize(qMax(s1.width(),s2.width()), s1.height()+s2.height());
 }
 
 KexiTableItem*
@@ -1198,7 +1209,7 @@ KexiQueryDesignerGuiEditor::createNewRow(const QString& tableName, const QString
 	}
 	(*newItem)[COLUMN_ID_COLUMN]=key;
 	(*newItem)[COLUMN_ID_TABLE]=tableName;
-	(*newItem)[COLUMN_ID_VISIBLE]=QVariant(visible, 1);
+	(*newItem)[COLUMN_ID_VISIBLE]=QVariant(visible);
 #ifndef KEXI_NO_QUERY_TOTALS
 	(*newItem)[COLUMN_ID_TOTALS]=QVariant(0);
 #endif
@@ -1235,7 +1246,7 @@ void KexiQueryDesignerGuiEditor::slotNewItemAppendedForAfterDeletingInSpreadShee
 {
 	KexiTableItem *item = d->data->last();
 	if (item)
-		item->at(COLUMN_ID_VISIBLE) = QVariant(false, 0); //the same init as in initTableRows()
+		item->at(COLUMN_ID_VISIBLE) = QVariant(false); //the same init as in initTableRows()
 }
 
 void KexiQueryDesignerGuiEditor::slotRowInserted(KexiTableItem* item, uint row, bool /*repaint*/)
@@ -1263,27 +1274,27 @@ void KexiQueryDesignerGuiEditor::slotTableHidden(KexiDB::TableSchema & /*t*/)
 }
 
 /*! @internal generates smallest unique alias */
-QCString KexiQueryDesignerGuiEditor::generateUniqueAlias() const
+Q3CString KexiQueryDesignerGuiEditor::generateUniqueAlias() const
 {
 //TODO: add option for using non-i18n'd "expr" prefix?
-	const QCString expStr
-		= i18n("short for 'expression' word (only latin letters, please)", "expr").latin1();
+	const Q3CString expStr
+		= i18nc("short for 'expression' word (only latin letters, please)", "expr").toLatin1();
 //TODO: optimization: cache it?
-	QAsciiDict<char> aliases(101);
+	Q3AsciiDict<char> aliases(101);
 	for (int r = 0; r<(int)d->sets->size(); r++) {
 		KoProperty::Set *set = d->sets->at(r);
 		if (set) {
-			const QCString a = (*set)["alias"].value().toCString().lower();
+			const Q3CString a = (*set)["alias"].value().toCString().toLower();
 			if (!a.isEmpty())
 				aliases.insert(a,(char*)1);
 		}
 	}
 	int aliasNr=1;
 	for (;;aliasNr++) {
-		if (!aliases[expStr+QString::number(aliasNr).latin1()])
+		if (!aliases[expStr+QString::number(aliasNr).toLatin1()])
 			break;
 	}
-	return expStr+QString::number(aliasNr).latin1();
+	return expStr+QString::number(aliasNr).toLatin1();
 }
 
 //! @todo this is primitive, temporary: reuse SQL parser
@@ -1291,7 +1302,7 @@ KexiDB::BaseExpr*
 KexiQueryDesignerGuiEditor::parseExpressionString(const QString& fullString, int& token,
  bool allowRelationalOperator)
 {
-	QString str = fullString.stripWhiteSpace();
+	QString str = fullString.trimmed();
 	int len = 0;
 	//KexiDB::BaseExpr *expr = 0;
 	//1. get token
@@ -1314,7 +1325,7 @@ KexiQueryDesignerGuiEditor::parseExpressionString(const QString& fullString, int
 		|| str.startsWith("<")
 		|| str.startsWith(">"))
 	{
-		token = str[0].latin1();
+		token = str[0].toLatin1();
 		len = 1;
 	}
 	else {
@@ -1327,7 +1338,7 @@ KexiQueryDesignerGuiEditor::parseExpressionString(const QString& fullString, int
 
 	//1. get expression after token
 	if (len>0)
-		str = str.mid(len).stripWhiteSpace();
+		str = str.mid(len).trimmed();
 	if (str.isEmpty())
 		return 0;
 
@@ -1347,24 +1358,24 @@ KexiQueryDesignerGuiEditor::parseExpressionString(const QString& fullString, int
 	else if ((re = QRegExp("(\\d{1,4})-(\\d{1,2})-(\\d{1,2})")).exactMatch( str ))
 	{
 			valueExpr = new KexiDB::ConstExpr(DATE_CONST, QDate::fromString(
-				re.cap(1).rightJustify(4, '0')+"-"+re.cap(2).rightJustify(2, '0')
-				+"-"+re.cap(3).rightJustify(2, '0'), Qt::ISODate));
+				re.cap(1).rightJustified(4, '0')+"-"+re.cap(2).rightJustified(2, '0')
+				+"-"+re.cap(3).rightJustified(2, '0'), Qt::ISODate));
 	}
 	else if ((re = QRegExp("(\\d{1,2}):(\\d{1,2})")).exactMatch( str )
 	      || (re = QRegExp("(\\d{1,2}):(\\d{1,2}):(\\d{1,2})")).exactMatch( str ))
 	{
-		QString res = re.cap(1).rightJustify(2, '0')+":"+re.cap(2).rightJustify(2, '0')
-			+":"+re.cap(3).rightJustify(2, '0');
+		QString res = re.cap(1).rightJustified(2, '0')+":"+re.cap(2).rightJustified(2, '0')
+			+":"+re.cap(3).rightJustified(2, '0');
 //		kexipluginsdbg << res << endl;
 		valueExpr = new KexiDB::ConstExpr(TIME_CONST, QTime::fromString(res, Qt::ISODate));
 	}
 	else if ((re = QRegExp("(\\d{1,4})-(\\d{1,2})-(\\d{1,2})\\s+(\\d{1,2}):(\\d{1,2})")).exactMatch( str )
 	      || (re = QRegExp("(\\d{1,4})-(\\d{1,2})-(\\d{1,2})\\s+(\\d{1,2}):(\\d{1,2}):(\\d{1,2})")).exactMatch( str ))
 	{
-		QString res = re.cap(1).rightJustify(4, '0')+"-"+re.cap(2).rightJustify(2, '0')
-			+"-"+re.cap(3).rightJustify(2, '0')
-			+"T"+re.cap(4).rightJustify(2, '0')+":"+re.cap(5).rightJustify(2, '0')
-			+":"+re.cap(6).rightJustify(2, '0');
+		QString res = re.cap(1).rightJustified(4, '0')+"-"+re.cap(2).rightJustified(2, '0')
+			+"-"+re.cap(3).rightJustified(2, '0')
+			+"T"+re.cap(4).rightJustified(2, '0')+":"+re.cap(5).rightJustified(2, '0')
+			+":"+re.cap(6).rightJustified(2, '0');
 //		kexipluginsdbg << res << endl;
 		valueExpr = new KexiDB::ConstExpr(DATETIME_CONST,
 			QDateTime::fromString(res, Qt::ISODate));
@@ -1373,9 +1384,9 @@ KexiQueryDesignerGuiEditor::parseExpressionString(const QString& fullString, int
 		//number
 		QString decimalSym = KGlobal::locale()->decimalSymbol();
 		bool ok;
-		int pos = str.find('.');
+		int pos = str.indexOf('.');
 		if (pos==-1) {//second chance: local decimal symbol
-			pos = str.find(decimalSym);
+			pos = str.indexOf(decimalSym);
 		}
 		if (pos>=0) {//real const number
 			const int left = str.left(pos).toInt(&ok);
@@ -1388,13 +1399,13 @@ KexiQueryDesignerGuiEditor::parseExpressionString(const QString& fullString, int
 		}
 		else {
 			//integer const
-			const Q_LLONG val = str.toLongLong(&ok);
+			const qint64 val = str.toLongLong(&ok);
 			if (!ok)
 				return 0;
 			valueExpr = new KexiDB::ConstExpr(INTEGER_CONST, val);
 		}
 	}
-	else if (str.lower()=="null") {
+	else if (str.toLower()=="null") {
 		valueExpr = new KexiDB::ConstExpr(SQL_NULL, QVariant());
 	}
 	else {//identfier
@@ -1419,7 +1430,8 @@ void KexiQueryDesignerGuiEditor::slotBeforeCellChanged(KexiTableItem *item, int
 	if (colnum == COLUMN_ID_COLUMN) {
 		if (newValue.isNull()) {
 			d->data->updateRowEditBuffer(item, COLUMN_ID_TABLE, QVariant(), false/*!allowSignals*/);
-			d->data->updateRowEditBuffer(item, COLUMN_ID_VISIBLE, QVariant(false,1));//invisible
+			d->data->updateRowEditBuffer(item, COLUMN_ID_VISIBLE, QVariant(false));//invisible
+			d->data->updateRowEditBuffer(item, COLUMN_ID_SORTING, QVariant());
 #ifndef KEXI_NO_QUERY_TOTALS
 			d->data->updateRowEditBuffer(item, COLUMN_ID_TOTALS, QVariant());//remove totals
 #endif
@@ -1428,10 +1440,10 @@ void KexiQueryDesignerGuiEditor::slotBeforeCellChanged(KexiTableItem *item, int
 		}
 		else {
 			//auto fill 'table' column
-			QString fieldId( newValue.toString().stripWhiteSpace() ); //tmp, can look like "table.field"
+			QString fieldId( newValue.toString().trimmed() ); //tmp, can look like "table.field"
 			QString fieldName; //"field" part of "table.field" or expression string
 			QString tableName; //empty for expressions
-			QCString alias;
+			Q3CString alias;
 			QString columnValueForExpr; //for setting pretty printed "alias: expr" in 1st column
 			const bool isExpression = !d->fieldColumnIdentifiers[fieldId];
 			if (isExpression) {
@@ -1439,20 +1451,20 @@ void KexiQueryDesignerGuiEditor::slotBeforeCellChanged(KexiTableItem *item, int
 				//any value in the combo box -- we're assuming this is an expression
 				//-table remains null
 				//-find "alias" in something like "alias : expr"
-				const int id = fieldId.find(':');
+				const int id = fieldId.indexOf(':');
 				if (id>0) {
-					alias = fieldId.left(id).stripWhiteSpace().latin1();
+					alias = fieldId.left(id).trimmed().toLatin1();
 					if (!KexiUtils::isIdentifier(alias)) {
 						result->success = false;
 						result->allowToDiscardChanges = true;
 						result->column = colnum;
-						result->msg = i18n("Entered column alias \"%1\" is not a valid identifier.")
-							.arg(alias);
+						result->msg = i18n(
+							"Entered column alias \"%1\" is not a valid identifier.", QString(alias));
 						result->desc = i18n("Identifiers should start with a letter or '_' character");
 						return;
 					}
 				}
-				fieldName = fieldId.mid(id+1).stripWhiteSpace();
+				fieldName = fieldId.mid(id+1).trimmed();
 				//check expr.
 				KexiDB::BaseExpr *e;
 				int dummyToken;
@@ -1466,7 +1478,7 @@ void KexiQueryDesignerGuiEditor::slotBeforeCellChanged(KexiTableItem *item, int
 					result->success = false;
 					result->allowToDiscardChanges = true;
 					result->column = colnum;
-					result->msg = i18n("Invalid expression \"%1\"").arg(fieldName);
+					result->msg = i18n("Invalid expression \"%1\"", fieldName);
 					return;
 				}
 			}
@@ -1497,7 +1509,7 @@ void KexiQueryDesignerGuiEditor::slotBeforeCellChanged(KexiTableItem *item, int
 				propertySetSwitched();
 			}
 			d->data->updateRowEditBuffer(item, COLUMN_ID_TABLE, QVariant(tableName), false/*!allowSignals*/);
-			d->data->updateRowEditBuffer(item, COLUMN_ID_VISIBLE, QVariant(true,1));
+			d->data->updateRowEditBuffer(item, COLUMN_ID_VISIBLE, QVariant(true));
 #ifndef KEXI_NO_QUERY_TOTALS
 			d->data->updateRowEditBuffer(item, COLUMN_ID_TOTALS, QVariant(0));
 #endif
@@ -1515,13 +1527,13 @@ void KexiQueryDesignerGuiEditor::slotBeforeCellChanged(KexiTableItem *item, int
 				if (alias.isEmpty()) //-generate smallest unique alias
 					alias = generateUniqueAlias();
 			}
-			(*set)["isExpression"].setValue(QVariant(isExpression,1), saveOldValue);
+			(*set)["isExpression"].setValue(QVariant(isExpression), saveOldValue);
 			if (!alias.isEmpty()) {
 				(*set)["alias"].setValue(alias, saveOldValue);
 				//pretty printed "alias: expr"
 				newValue = QString(alias) + ": " + fieldName;
 			}
-			(*set)["caption"].setValue(QString::null, saveOldValue);
+			(*set)["caption"].setValue(QString(), saveOldValue);
 			(*set)["table"].setValue(tableName, saveOldValue);
 			updatePropertiesVisibility(*set);
 		}
@@ -1530,7 +1542,7 @@ void KexiQueryDesignerGuiEditor::slotBeforeCellChanged(KexiTableItem *item, int
 		if (newValue.isNull()) {
 			if (!item->at(COLUMN_ID_COLUMN).toString().isEmpty())
 				d->data->updateRowEditBuffer(item, COLUMN_ID_COLUMN, QVariant(), false/*!allowSignals*/);
-			d->data->updateRowEditBuffer(item, COLUMN_ID_VISIBLE, QVariant(false,1));//invisible
+			d->data->updateRowEditBuffer(item, COLUMN_ID_VISIBLE, QVariant(false));//invisible
 #ifndef KEXI_NO_QUERY_TOTALS
 			d->data->updateRowEditBuffer(item, COLUMN_ID_TOTALS, QVariant());//remove totals
 #endif
@@ -1542,7 +1554,7 @@ void KexiQueryDesignerGuiEditor::slotBeforeCellChanged(KexiTableItem *item, int
 		if (set) {
 			if ((*set)["isExpression"].value().toBool()==false) {
 				(*set)["table"] = newValue;
-				(*set)["caption"] = QString::null;
+				(*set)["caption"] = QString();
 			}
 			else {
 				//do not set table for expr. columns
@@ -1587,15 +1599,15 @@ void KexiQueryDesignerGuiEditor::slotBeforeCellChanged(KexiTableItem *item, int
 			result->success = false;
 			result->allowToDiscardChanges = true;
 			result->column = colnum;
-			result->msg = i18n("Could not set sorting for multiple columns (%1)")
-				.arg(table=="*" ? table : (table+".*"));
+			result->msg = i18n("Could not set sorting for multiple columns (%1)",
+				table=="*" ? table : (table+".*"));
 		}
 	}
 	else if (colnum==COLUMN_ID_CRITERIA) {
 //! @todo this is primitive, temporary: reuse SQL parser
 		QString operatorStr, argStr;
 		KexiDB::BaseExpr* e = 0;
-		const QString str = newValue.toString().stripWhiteSpace();
+		const QString str = newValue.toString().trimmed();
 		int token;
 		QString field, table;
 		KoProperty::Set *set = d->sets->findPropertySetForItem(*item);
@@ -1603,14 +1615,14 @@ void KexiQueryDesignerGuiEditor::slotBeforeCellChanged(KexiTableItem *item, int
 			field = (*set)["field"].value().toString();
 			table = (*set)["table"].value().toString();
 		}
-		if (!str.isEmpty() && (!set || table=="*" || field.find("*")!=-1)) {
+		if (!str.isEmpty() && (!set || table=="*" || field.contains("*"))) {
 			//asterisk found! criteria not allowed
 			result->success = false;
 			result->allowToDiscardChanges = true;
 			result->column = colnum;
 			if (propertySet())
-				result->msg = i18n("Could not set criteria for \"%1\"")
-					.arg(table=="*" ? table : field);
+				result->msg = i18n("Could not set criteria for \"%1\"",
+					table=="*" ? table : field);
 			else
 				result->msg = i18n("Could not set criteria for empty row");
 			//moved to result->allowToDiscardChanges handler //d->dataTable->dataAwareObject()->cancelEditor(); //prevents further editing of this cell
@@ -1636,7 +1648,7 @@ void KexiQueryDesignerGuiEditor::slotBeforeCellChanged(KexiTableItem *item, int
 			result->success = false;
 			result->allowToDiscardChanges = true;
 			result->column = colnum;
-			result->msg = i18n("Invalid criteria \"%1\"").arg(newValue.toString());
+			result->msg = i18n("Invalid criteria \"%1\"", newValue.toString());
 		}
 	}
 }
@@ -1712,18 +1724,18 @@ KexiQueryDesignerGuiEditor::createPropertySet( int row,
 	set->addProperty(prop = new KoProperty::Property("field", QVariant(fieldName)) );
 	prop->setVisible(false);//always hidden
 
-	set->addProperty(prop = new KoProperty::Property("caption", QVariant(QString::null), i18n("Caption") ) );
+	set->addProperty(prop = new KoProperty::Property("caption", QVariant(QString()), i18n("Caption") ) );
 #ifdef KEXI_NO_UNFINISHED
 		prop->setVisible(false);
 #endif
 
-	set->addProperty(prop = new KoProperty::Property("alias", QVariant(QString::null), i18n("Alias")) );
+	set->addProperty(prop = new KoProperty::Property("alias", QVariant(QString()), i18n("Alias")) );
 
-	set->addProperty(prop = new KoProperty::Property("visible", QVariant(true, 4)) );
+	set->addProperty(prop = new KoProperty::Property("visible", QVariant(true)) );
 	prop->setVisible(false);
 
 /*TODO:
-	set->addProperty(prop = new KexiProperty("totals", QVariant(QString::null)) );
+	set->addProperty(prop = new KexiProperty("totals", QVariant(QString())) );
 	prop->setVisible(false);*/
 
 	//sorting
@@ -1731,13 +1743,13 @@ KexiQueryDesignerGuiEditor::createPropertySet( int row,
 	slist << "nosorting" << "ascending" << "descending";
 	nlist << i18n("None") << i18n("Ascending") << i18n("Descending");
 	set->addProperty(prop = new KoProperty::Property("sorting",
-		slist, nlist, *slist.at(0), i18n("Sorting")));
+		slist, nlist, slist[0], i18n("Sorting")));
 	prop->setVisible(false);
 
-	set->addProperty(prop = new KoProperty::Property("criteria", QVariant(QString::null)) );
+	set->addProperty(prop = new KoProperty::Property("criteria", QVariant(QString())) );
 	prop->setVisible(false);
 
-	set->addProperty(prop = new KoProperty::Property("isExpression", QVariant(false, 1)) );
+	set->addProperty(prop = new KoProperty::Property("isExpression", QVariant(false)) );
 	prop->setVisible(false);
 
 	connect(set, SIGNAL(propertyChanged(KoProperty::Set&, KoProperty::Property&)),
@@ -1756,13 +1768,13 @@ void KexiQueryDesignerGuiEditor::setFocus()
 
 void KexiQueryDesignerGuiEditor::slotPropertyChanged(KoProperty::Set& set, KoProperty::Property& property)
 {
-	const QCString& pname = property.name();
+	const Q3CString& pname = property.name();
 /*
  * TODO (js) use KexiProperty::setValidator(QString) when implemented as described in TODO #60
  */
 	if (pname=="alias" || pname=="name") {
 		const QVariant& v = property.value();
-		if (!v.toString().stripWhiteSpace().isEmpty() && !KexiUtils::isIdentifier( v.toString() )) {
+		if (!v.toString().trimmed().isEmpty() && !KexiUtils::isIdentifier( v.toString() )) {
 			KMessageBox::sorry(this,
 				KexiUtils::identifierExpectedMessage(property.caption(), v.toString()));
 			property.resetValue();
@@ -1784,18 +1796,17 @@ void KexiQueryDesignerGuiEditor::slotPropertyChanged(KoProperty::Set& set, KoPro
 
 void KexiQueryDesignerGuiEditor::slotNewItemStored(KexiPart::Item& item)
 {
-	d->relations->objectCreated(item.mimeType(), item.name().latin1());
+	d->relations->objectCreated(item.mimeType().toLatin1(), item.name().toLatin1());
 }
 
 void KexiQueryDesignerGuiEditor::slotItemRemoved(const KexiPart::Item& item)
 {
-	d->relations->objectDeleted(item.mimeType(), item.name().latin1());
+	d->relations->objectDeleted(item.mimeType().toLatin1(), item.name().toLatin1());
 }
 
-void KexiQueryDesignerGuiEditor::slotItemRenamed(const KexiPart::Item& item, const QCString& oldName)
+void KexiQueryDesignerGuiEditor::slotItemRenamed(const KexiPart::Item& item, const Q3CString& oldName)
 {
-	d->relations->objectRenamed(item.mimeType(), oldName, item.name().latin1());
+	d->relations->objectRenamed(item.mimeType().toLatin1(), oldName, item.name().toLatin1());
 }
 
 #include "kexiquerydesignerguieditor.moc"
-
