@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
    Copyright (C) 2004 Lucijan Busch <lucijan@kde.org>
-   Copyright (C) 2004 Jaroslaw Staniek <js@iidea.pl>
+   Copyright (C) 2004, 2006 Jaroslaw Staniek <js@iidea.pl>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -14,8 +14,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef KEXIQUERYVIEW_H
@@ -27,22 +27,30 @@ namespace KexiDB
 {
 	class QuerySchema;
 }
-class KexiMainWindow;
 
 class KexiQueryView : public KexiDataTable
 {
 	Q_OBJECT
 
 	public:
-		KexiQueryView(KexiMainWindow *win, QWidget *parent, const char *name=0);
-		~KexiQueryView();
+		KexiQueryView(QWidget *parent);
+		virtual ~KexiQueryView();
 
 	protected:
 		virtual tristate afterSwitchFrom(int mode);
 
-		bool executeQuery(KexiDB::QuerySchema *query);
+		virtual KexiDB::SchemaData* storeNewData(const KexiDB::SchemaData& sdata, bool &cancel);
 
-	private:
+		virtual tristate storeData(bool dontAsk = false);
+
+		/*! Executes query \a query, filling the table view with query results.
+		 \return true on success, false on failure and cancelled when user has 
+		 cancelled execution (for example when she pressed the Cancel button 
+		 of the "Enter Query Parameter" input dialog. */
+		tristate executeQuery(KexiDB::QuerySchema *query);
+
+		class Private;
+		Private * const d;
 };
 
 #endif
