@@ -1,7 +1,7 @@
 /***************************************************************************
  * kexidbcursor.h
  * This file is part of the KDE project
- * copyright (C)2004-2005 by Sebastian Sauer (mail@dipe.org)
+ * copyright (C)2004-2006 by Sebastian Sauer (mail@dipe.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -17,20 +17,16 @@
  * Boston, MA 02110-1301, USA.
  ***************************************************************************/
 
-#ifndef KROSS_KEXIDB_KEXIDBCURSOR_H
-#define KROSS_KEXIDB_KEXIDBCURSOR_H
+#ifndef SCRIPTING_KEXIDBCURSOR_H
+#define SCRIPTING_KEXIDBCURSOR_H
 
 #include <qstring.h>
-
-#include <api/object.h>
-#include <api/variant.h>
-#include <api/list.h>
-#include <api/class.h>
+#include <qobject.h>
 
 #include <kexidb/cursor.h>
 #include <kexidb/roweditbuffer.h>
 
-namespace Kross { namespace KexiDB {
+namespace Scripting {
 
     // Forward declaration.
     class KexiDBConnection;
@@ -49,7 +45,7 @@ namespace Kross { namespace KexiDB {
      * while(not cursor.eof()):
      *     # Iterate over the fields the record has.
      *     for i in range( cursor.fieldCount() ):
-     *         # Print some informations.
+     *         # Print some information.
      *         print "%s %s %s" % (cursor.at(), i, cursor.value(i))
      *     # and move on to the next record.
      *     cursor.moveNext()
@@ -82,14 +78,14 @@ namespace Kross { namespace KexiDB {
      * if not cursor.save(): raise "Failed to save changes"
      * @endcode
      */
-    class KexiDBCursor : public Kross::Api::Class<KexiDBCursor>
+    class KexiDBCursor : public QObject
     {
+            Q_OBJECT
         public:
-            KexiDBCursor(::KexiDB::Cursor* cursor);
+            KexiDBCursor(QObject* parent, ::KexiDB::Cursor* cursor, bool owner);
             virtual ~KexiDBCursor();
-            virtual const QString getClassName() const;
 
-        private:
+        public slots:
 
             /** Opens the cursor. */
             bool open();
@@ -117,7 +113,7 @@ namespace Kross { namespace KexiDB {
             /** Returns current internal position of the cursor's query. Records
             are numbered from 0; the value -1 means that the cursor does not
             point to a valid record. */
-            Q_LLONG at();
+            int at();
             /** Returns the number of fields available for this cursor. */
             uint fieldCount();
             /** Returns the value stored in the passed column number (counting from 0). */
@@ -132,8 +128,6 @@ namespace Kross { namespace KexiDB {
             bool save();
 
         private:
-            ::KexiDB::Cursor* m_cursor;
-
             class Record {
                 public:
                     ::KexiDB::RowData rowdata;
@@ -149,11 +143,13 @@ namespace Kross { namespace KexiDB {
                     }
             };
             QMap<Q_LLONG, Record*> m_modifiedrecords;
-
             void clearBuffers();
+
+            ::KexiDB::Cursor* m_cursor;
+            bool m_owner;
     };
 
-}}
+}
 
 #endif
 
