@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 2005-2006 Jaroslaw Staniek <js@iidea.pl>
+   Copyright (C) 2005-2007 Jaroslaw Staniek <js@iidea.pl>
 
    Based on KexiTableView code.
    Copyright (C) 2002 Till Busch <till@bux.at>
@@ -25,13 +25,18 @@
 
 #include "kexidataawareobjectiface.h"
 
-#include <qscrollview.h>
+#include <q3scrollview.h>
 #include <qlabel.h>
 #include <qtooltip.h>
+#include <Q3ValueList>
+#include <Q3Frame>
+#include <QStyle>
+#include <QStyleOptionComplex>
 
 #include <kmessagebox.h>
 
 #include <kexi.h>
+#include <kexi_global.h>
 #include <kexiutils/validator.h>
 #include <widget/utils/kexirecordnavigator.h>
 #include <widget/utils/kexirecordmarker.h>
@@ -40,6 +45,8 @@
 
 #include "kexitableviewheader.h"
 
+#include <limits.h>
+
 using namespace KexiUtils;
 
 KexiDataAwareObjectInterface::KexiDataAwareObjectInterface()
@@ -67,7 +74,7 @@ KexiDataAwareObjectInterface::KexiDataAwareObjectInterface()
 	m_updateEntireRowWhenMovingToOtherRow = false;
 	m_dragIndicatorLine = -1;
 	m_emptyRowInsertingEnabled = false;
-	m_popupMenu = 0;
+	m_contextMenu = 0;
 	m_contextMenuEnabled = true;
 	m_rowWillBeDeleted = -1;
 	m_alsoUpdateNextRow = false;
@@ -75,16 +82,21 @@ KexiDataAwareObjectInterface::KexiDataAwareObjectInterface()
 	m_vScrollBarValueChanged_enabled = true;
 	m_scrollbarToolTipsEnabled = true;
 	m_scrollBarTipTimerCnt = 0;
+	m_scrollBarTipTimer.setSingleShot(true);
 	m_scrollBarTip = 0;
+	m_recentSearchDirection = KexiSearchAndReplaceViewInterface::Options::DefaultSearchDirection;
 
 	// setup scrollbar tooltip and related members
-	m_scrollBarTip = new QLabel("",0, "vScrollBarToolTip",
-		Qt::WStyle_Customize |Qt::WStyle_NoBorder|Qt::WX11BypassWM|Qt::WStyle_StaysOnTop|Qt::WStyle_Tool);
+	m_scrollBarTip = new QLabel();
+	m_scrollBarTip->setObjectName("vScrollBarToolTip");
+	m_scrollBarTip->setWindowFlags(
+		Qt::WStyle_Customize|Qt::WStyle_NoBorder|Qt::WX11BypassWM
+		|Qt::WStyle_StaysOnTop|Qt::WStyle_Tool );
 	m_scrollBarTip->setPalette(QToolTip::palette());
 	m_scrollBarTip->setMargin(2);
 	m_scrollBarTip->setIndent(0);
 	m_scrollBarTip->setAlignment(Qt::AlignCenter);
-	m_scrollBarTip->setFrameStyle( QFrame::Plain | QFrame::Box );
+	m_scrollBarTip->setFrameStyle( Q3Frame::Plain | Q3Frame::Box );
 	m_scrollBarTip->setLineWidth(1);
 
 	clearVariables();
@@ -125,7 +137,7 @@ void KexiDataAwareObjectInterface::setData( KexiTableViewData *data, bool owner
 	if (m_data)
 		m_itemIterator = m_data->createIterator();
 
-	kdDebug(44021) << "KexiDataAwareObjectInterface::setData(): using shared data" << endl;
+	kDebug(44021) << "KexiDataAwareObjectInterface::setData(): using shared data" << endl;
 		//add columns
 //OK?
 	clearColumnsInternal(false);
@@ -141,7 +153,7 @@ void KexiDataAwareObjectInterface::setData( KexiTableViewData *data, bool owner
 					wid=KEXI_DEFAULT_DATA_COLUMN_WIDTH;//default col width in pixels
 //! @todo add col width configuration and storage
 				addHeaderColumn(it.current()->isHeaderTextVisible()
-					? it.current()->captionAliasOrName() : QString::null,
+					? it.current()->captionAliasOrName() : QString(),
 					f->description(), it.current()->icon(), wid);
 			}
 		}
@@ -162,8 +174,8 @@ void KexiDataAwareObjectInterface::setData( KexiTableViewData *data, bool owner
 		QObject* thisObject = dynamic_cast<QObject*>(this);
 		if (thisObject) {
 			QObject::connect(m_data, SIGNAL(destroying()), thisObject, SLOT(slotDataDestroying()));
-			QObject::connect(m_data, SIGNAL(rowsDeleted( const QValueList<int> & )), 
-				thisObject, SLOT(slotRowsDeleted( const QValueList<int> & )));
+			QObject::connect(m_data, SIGNAL(rowsDeleted( const Q3ValueList<int> & )), 
+				thisObject, SLOT(slotRowsDeleted( const Q3ValueList<int> & )));
 			QObject::connect(m_data, SIGNAL(aboutToDeleteRow(KexiTableItem&,KexiDB::ResultInfo*,bool)),
 				thisObject, SLOT(slotAboutToDeleteRow(KexiTableItem&,KexiDB::ResultInfo*,bool)));
 			QObject::connect(m_data, SIGNAL(rowDeleted()), thisObject, SLOT(slotRowDeleted()));
@@ -204,6 +216,7 @@ void KexiDataAwareObjectInterface::setData( KexiTableViewData *data, bool owner
 		m_verticalHeader->showInsertRow(m_data && isInsertingEnabled());
 
 	initDataContents();
+	updateIndicesForVisibleValues();
 
 	if (m_data)
 		/*emit*/ dataSet( m_data );
@@ -224,7 +237,7 @@ void KexiDataAwareObjectInterface::initDataContents()
 		if (m_data->columnsCount()>0) {
 			if (rows()>0) {
 				m_itemIterator->toFirst();
-				m_currentItem = **m_itemIterator; //m_data->first();
+				m_currentItem = **m_itemIterator;
 				curRow = 0;
 				curCol = 0;
 			}
@@ -438,20 +451,20 @@ void KexiDataAwareObjectInterface::setSpreadSheetMode()
 
 void KexiDataAwareObjectInterface::selectNextRow()
 {
-	selectRow( QMIN( rows() - 1 +(isInsertingEnabled()?1:0), m_curRow + 1 ) );
+	selectRow( qMin( rows() - 1 +(isInsertingEnabled()?1:0), m_curRow + 1 ) );
 }
 
 void KexiDataAwareObjectInterface::selectPrevPage()
 {
 	selectRow( 
-		QMAX( 0, m_curRow - rowsPerPage() )
+		qMax( 0, m_curRow - rowsPerPage() )
 	);
 }
 
 void KexiDataAwareObjectInterface::selectNextPage()
 {
 	selectRow( 
-		QMIN( 
+		qMin( 
 			rows() - 1 + (isInsertingEnabled()?1:0),
 			m_curRow + rowsPerPage()
 		)
@@ -478,7 +491,7 @@ void KexiDataAwareObjectInterface::selectRow(int row)
 
 void KexiDataAwareObjectInterface::selectPrevRow()
 {
-	selectRow( QMAX( 0, m_curRow - 1 ) );
+	selectRow( qMax( 0, m_curRow - 1 ) );
 }
 
 void KexiDataAwareObjectInterface::clearSelection()
@@ -522,18 +535,18 @@ void KexiDataAwareObjectInterface::setCursorPosition(int row, int col/*=-1*/, bo
 
 	if(col>=0)
 	{
-		newcol = QMAX(0, col);
-		newcol = QMIN(columns() - 1, newcol);
+		newcol = qMax(0, col);
+		newcol = qMin(columns() - 1, newcol);
 	}
 	else {
 		newcol = m_curCol; //no changes
-		newcol = QMAX(0, newcol); //may not be < 0 !
+		newcol = qMax(0, newcol); //may not be < 0 !
 	}
-	newrow = QMAX(0, row);
-	newrow = QMIN(rows() - 1 + (isInsertingEnabled()?1:0), newrow);
+	newrow = qMax(0, row);
+	newrow = qMin(rows() - 1 + (isInsertingEnabled()?1:0), newrow);
 
 //	d->pCurrentItem = itemAt(d->curRow);
-//	kdDebug(44021) << "setCursorPosition(): d->curRow=" << d->curRow << " oldRow=" << oldRow << " d->curCol=" << d->curCol << " oldCol=" << oldCol << endl;
+//	kDebug(44021) << "setCursorPosition(): d->curRow=" << d->curRow << " oldRow=" << oldRow << " d->curCol=" << d->curCol << " oldCol=" << oldCol << endl;
 
 	if ( forceSet || m_curRow != newrow || m_curCol != newcol )
 	{
@@ -547,14 +560,14 @@ void KexiDataAwareObjectInterface::setCursorPosition(int row, int col/*=-1*/, bo
 					return;
 				}
 				//update row num. again
-				newrow = QMIN( rows() - 1 + (isInsertingEnabled()?1:0), newrow);
+				newrow = qMin( rows() - 1 + (isInsertingEnabled()?1:0), newrow);
 			}
 		}
 		if (m_errorMessagePopup) {
 			m_errorMessagePopup->close();
 		}
 
-		if (m_curRow != newrow) {//update current row info
+		if (m_curRow != newrow || forceSet)  {//update current row info
 			m_navPanel->setCurrentRecordNumber(newrow+1);
 //			setNavRowNumber(newrow);
 //			d->navBtnPrev->setEnabled(newrow>0);
@@ -572,7 +585,7 @@ void KexiDataAwareObjectInterface::setCursorPosition(int row, int col/*=-1*/, bo
 				return;
 			}
 			//update row number, because number of rows changed
-			newrow = QMIN( rows() - 1 + (isInsertingEnabled()?1:0), newrow);
+			newrow = qMin( rows() - 1 + (isInsertingEnabled()?1:0), newrow);
 
 			m_navPanel->setCurrentRecordNumber(newrow+1); //refresh
 		}
@@ -587,7 +600,7 @@ void KexiDataAwareObjectInterface::setCursorPosition(int row, int col/*=-1*/, bo
 //		int rh = rowHeight();
 //		ensureVisible( columnPos( d->curCol ) + cw / 2, rowPos( d->curRow ) + rh / 2, cw / 2, rh / 2 );
 //		center(columnPos(d->curCol) + cw / 2, rowPos(d->curRow) + rh / 2, cw / 2, rh / 2);
-//	kdDebug(44021) << " contentsY() = "<< contentsY() << endl;
+//	kDebug(44021) << " contentsY() = "<< contentsY() << endl;
 
 //js		if (oldRow > d->curRow)
 //js			ensureVisible(columnPos(d->curCol), rowPos(d->curRow) + rh, columnWidth(d->curCol), rh);
@@ -604,6 +617,10 @@ void KexiDataAwareObjectInterface::setCursorPosition(int row, int col/*=-1*/, bo
 			}
 		}
 
+		// position changed, so subsequent searching should be started from scratch 
+		// (e.g. from the current cell or the top-left cell)
+		m_positionOfRecentlyFoundValue.exists = false;
+
 		//show editor-dependent focus, if needed
 		editorShowFocus( m_curRow, m_curCol );
 
@@ -619,7 +636,7 @@ void KexiDataAwareObjectInterface::setCursorPosition(int row, int col/*=-1*/, bo
 //		ensureVisible(pcenter.x(), pcenter.y(), columnWidth(d->curCol)/2, rh/2);
 
 //		ensureVisible(columnPos(d->curCol), rowPos(d->curRow) - contentsY(), columnWidth(d->curCol), rh);
-		if (m_verticalHeader && oldRow != m_curRow)
+		if (m_verticalHeader && (oldRow != m_curRow || forceSet))
 			m_verticalHeader->setCurrentRow(m_curRow);
 
 		if (m_updateEntireRowWhenMovingToOtherRow)
@@ -627,18 +644,18 @@ void KexiDataAwareObjectInterface::setCursorPosition(int row, int col/*=-1*/, bo
 		else
 			updateCell( m_curRow, m_curCol );
 
-		if (m_curCol != oldCol || m_curRow != oldRow ) {//ensure this is also refreshed
+		if (m_curCol != oldCol || m_curRow != oldRow || forceSet) {//ensure this is also refreshed
 			if (!m_updateEntireRowWhenMovingToOtherRow) //only if entire row has not been updated
 				updateCell( oldRow, m_curCol );
 		}
 		//update row
 		if (forceSet || m_curRow != oldRow) {
 			if (isInsertingEnabled() && m_curRow == rows()) {
-				kdDebug(44021) << "NOW insert item is current" << endl;
+				kDebug(44021) << "NOW insert item is current" << endl;
 				m_currentItem = m_insertItem;
 			}
 			else {
-				kdDebug(44021) << QString("NOW item at %1 (%2) is current")
+				kDebug(44021) << QString("NOW item at %1 (%2) is current")
 					.arg(m_curRow).arg((ulong)itemAt(m_curRow)) << endl;
 	//NOT EFFECTIVE!!!!!!!!!!!
 				//set item iterator
@@ -668,7 +685,7 @@ void KexiDataAwareObjectInterface::setCursorPosition(int row, int col/*=-1*/, bo
 		//quite clever: ensure the cell is visible:
 		ensureCellVisible(m_curRow, m_curCol);
 
-		if (m_horizontalHeader && oldCol != m_curCol)
+		if (m_horizontalHeader && (oldCol != m_curCol || forceSet))
 			m_horizontalHeader->setSelectedSection(m_curCol);
 
 		/*emit*/ itemSelected(m_currentItem);
@@ -698,7 +715,7 @@ bool KexiDataAwareObjectInterface::acceptRowEdit()
 	const int columnEditedBeforeAccepting = m_editor ? currentColumn() : -1;
 	if (!acceptEditor())
 		return false;
-	kdDebug() << "EDIT ROW ACCEPTING..." << endl;
+	kDebug() << "EDIT ROW ACCEPTING..." << endl;
 
 	bool success = true;
 //	bool allow = true;
@@ -710,18 +727,18 @@ bool KexiDataAwareObjectInterface::acceptRowEdit()
 	if (m_data->rowEditBuffer()->isEmpty() && !m_newRowEditing) {
 /*		if (d->newRowEditing) {
 			cancelRowEdit();
-			kdDebug() << "-- NOTHING TO INSERT!!!" << endl;
+			kDebug() << "-- NOTHING TO INSERT!!!" << endl;
 			return true;
 		}
 		else {*/
-			kdDebug() << "-- NOTHING TO ACCEPT!!!" << endl;
+			kDebug() << "-- NOTHING TO ACCEPT!!!" << endl;
 //		}
 	}
 	else {//not empty edit buffer or new row to insert:
 		if (m_newRowEditing) {
 //			emit aboutToInsertRow(d->pCurrentItem, m_data->rowEditBuffer(), success, &faultyColumn);
 //			if (success) {
-			kdDebug() << "-- INSERTING: " << endl;
+			kDebug() << "-- INSERTING: " << endl;
 			m_data->rowEditBuffer()->debug();
 			success = m_data->saveNewRow(*m_currentItem);
 //				if (!success) {
@@ -732,12 +749,12 @@ bool KexiDataAwareObjectInterface::acceptRowEdit()
 //			emit aboutToUpdateRow(d->pCurrentItem, m_data->rowEditBuffer(), success, &faultyColumn);
 			if (success) {
 				//accept changes for this row:
-				kdDebug() << "-- UPDATING: " << endl;
+				kDebug() << "-- UPDATING: " << endl;
 				m_data->rowEditBuffer()->debug();
-				kdDebug() << "-- BEFORE: " << endl;
+				kDebug() << "-- BEFORE: " << endl;
 				m_currentItem->debug();
 				success = m_data->saveRowChanges(*m_currentItem);//, &msg, &desc, &faultyColumn);
-				kdDebug() << "-- AFTER: " << endl;
+				kDebug() << "-- AFTER: " << endl;
 				m_currentItem->debug();
 
 //				if (!success) {
@@ -761,7 +778,7 @@ bool KexiDataAwareObjectInterface::acceptRowEdit()
 
 		updateAfterAcceptRowEdit();
 
-		kdDebug() << "EDIT ROW ACCEPTED:" << endl;
+		kDebug() << "EDIT ROW ACCEPTED:" << endl;
 //		/*debug*/itemAt(m_curRow);
 
 		if (inserting) {
@@ -777,10 +794,10 @@ bool KexiDataAwareObjectInterface::acceptRowEdit()
 	}
 	else {
 //		if (!allow) {
-//			kdDebug() << "INSERT/EDIT ROW - DISALLOWED by signal!" << endl;
+//			kDebug() << "INSERT/EDIT ROW - DISALLOWED by signal!" << endl;
 //		}
 //		else {
-//			kdDebug() << "EDIT ROW - ERROR!" << endl;
+//			kDebug() << "EDIT ROW - ERROR!" << endl;
 //		}
 		int faultyColumn = -1;
 		if (m_data->result()->column >= 0 && m_data->result()->column < columns())
@@ -883,20 +900,6 @@ bool KexiDataAwareObjectInterface::cancelEditor()
 	return true;
 }
 
-//! @internal
-class KexiDataAwareObjectInterfaceToolTip : public QToolTip {
-	public:
-	KexiDataAwareObjectInterfaceToolTip( const QString & text, const QPoint & pos, QWidget * widget )
-		: QToolTip(widget), m_text(text)
-	{
-		tip( QRect(pos, QSize(100, 100)), text );
-	}
-	virtual void maybeTip(const QPoint & p) {
-		tip( QRect(p, QSize(100, 100)), m_text);
-	}
-	QString m_text;
-};
-
 bool KexiDataAwareObjectInterface::acceptEditor()
 {
 	if (!hasData())
@@ -925,7 +928,7 @@ bool KexiDataAwareObjectInterface::acceptEditor()
 			//used e.g. for date or time values - the value can be null but not necessary invalid
 			res = Validator::Error;
 			editCurrentCellAgain = true;
-			QWidget *par = dynamic_cast<QScrollView*>(this) ? dynamic_cast<QScrollView*>(this)->viewport() :
+			QWidget *par = dynamic_cast<Q3ScrollView*>(this) ? dynamic_cast<Q3ScrollView*>(this)->viewport() :
 					dynamic_cast<QWidget*>(this);
 			QWidget *edit = dynamic_cast<QWidget*>(m_editor);
 			if (par && edit) {
@@ -934,7 +937,7 @@ bool KexiDataAwareObjectInterface::acceptEditor()
 				if (!m_errorMessagePopup) {
 //					m_errorMessagePopup->close();
 					m_errorMessagePopup = new KexiArrowTip(
-						i18n("Error: %1").arg(m_editor->columnInfo()->field->typeName())+"?", 
+						i18n("Error: %1", m_editor->columnInfo()->field->typeName())+"?", 
 						dynamic_cast<QWidget*>(this));
 					m_errorMessagePopup->move( 
 						par->mapToGlobal(edit->pos()) + QPoint(6, edit->height() + 0) );
@@ -946,7 +949,7 @@ bool KexiDataAwareObjectInterface::acceptEditor()
 		else if (m_editor->valueIsNull()) {//null value entered
 //			if (m_editor->columnInfo()->field->isNotNull() && !autoIncColumnCanBeOmitted) {
 			if (m_editor->field()->isNotNull() && !autoIncColumnCanBeOmitted) {
-				kdDebug() << "KexiDataAwareObjectInterface::acceptEditor(): NULL NOT ALLOWED!" << endl;
+				kDebug() << "KexiDataAwareObjectInterface::acceptEditor(): NULL NOT ALLOWED!" << endl;
 				res = Validator::Error;
 //				msg = Validator::msgColumnNotEmpty().arg(m_editor->columnInfo()->field->captionOrName())
 				msg = Validator::msgColumnNotEmpty().arg(m_editor->field()->captionOrName())
@@ -958,7 +961,7 @@ bool KexiDataAwareObjectInterface::acceptEditor()
 	//			return true;
 			}
 			else {
-				kdDebug() << "KexiDataAwareObjectInterface::acceptEditor(): NULL VALUE WILL BE SET" << endl;
+				kDebug() << "KexiDataAwareObjectInterface::acceptEditor(): NULL VALUE WILL BE SET" << endl;
 				//ok, just leave newval as NULL
 				setNull = true;
 			}
@@ -968,7 +971,7 @@ bool KexiDataAwareObjectInterface::acceptEditor()
 			if (m_editor->field()->hasEmptyProperty()) {
 //				if (m_editor->columnInfo()->field->isNotEmpty() && !autoIncColumnCanBeOmitted) {
 				if (m_editor->field()->isNotEmpty() && !autoIncColumnCanBeOmitted) {
-					kdDebug() << "KexiDataAwareObjectInterface::acceptEditor(): EMPTY NOT ALLOWED!" << endl;
+					kDebug() << "KexiDataAwareObjectInterface::acceptEditor(): EMPTY NOT ALLOWED!" << endl;
 					res = Validator::Error;
 //					msg = Validator::msgColumnNotEmpty().arg(m_editor->columnInfo()->field->captionOrName())
 					msg = Validator::msgColumnNotEmpty().arg(m_editor->field()->captionOrName())
@@ -980,13 +983,13 @@ bool KexiDataAwareObjectInterface::acceptEditor()
 	//				return true;
 				}
 				else {
-					kdDebug() << "KexiDataAwareObjectInterface::acceptEditor(): EMPTY VALUE WILL BE SET" << endl;
+					kDebug() << "KexiDataAwareObjectInterface::acceptEditor(): EMPTY VALUE WILL BE SET" << endl;
 				}
 			}
 			else {
 //				if (m_editor->columnInfo()->field->isNotNull() && !autoIncColumnCanBeOmitted) {
 				if (m_editor->field()->isNotNull() && !autoIncColumnCanBeOmitted) {
-					kdDebug() << "KexiDataAwareObjectInterface::acceptEditor(): NEITHER NULL NOR EMPTY VALUE CAN BE SET!" << endl;
+					kDebug() << "KexiDataAwareObjectInterface::acceptEditor(): NEITHER NULL NOR EMPTY VALUE CAN BE SET!" << endl;
 					res = Validator::Error;
 //					msg = Validator::msgColumnNotEmpty().arg(m_editor->columnInfo()->field->captionOrName())
 					msg = Validator::msgColumnNotEmpty().arg(m_editor->field()->captionOrName())
@@ -998,7 +1001,7 @@ bool KexiDataAwareObjectInterface::acceptEditor()
 	//				return true;
 				}
 				else {
-					kdDebug() << "KexiDataAwareObjectInterface::acceptEditor(): NULL VALUE WILL BE SET BECAUSE EMPTY IS NOT ALLOWED" << endl;
+					kDebug() << "KexiDataAwareObjectInterface::acceptEditor(): NULL VALUE WILL BE SET BECAUSE EMPTY IS NOT ALLOWED" << endl;
 					//ok, just leave newval as NULL
 					setNull = true;
 				}
@@ -1008,7 +1011,7 @@ bool KexiDataAwareObjectInterface::acceptEditor()
 
 	const int realFieldNumber = fieldNumberForColumn(m_curCol);
 	if (realFieldNumber < 0) {
-		kdWarning() << "KexiDataAwareObjectInterface::acceptEditor(): fieldNumberForColumn(m_curCol) < 0" << endl;
+		kWarning() << "KexiDataAwareObjectInterface::acceptEditor(): fieldNumberForColumn(m_curCol) < 0" << endl;
 		m_inside_acceptEditor = false;
 		return false;
 	}
@@ -1019,7 +1022,7 @@ bool KexiDataAwareObjectInterface::acceptEditor()
 	if (res == Validator::Ok) {
 		if ((!setNull && !valueChanged)
 			|| (m_editor->field()->type()!=KexiDB::Field::Boolean && setNull && m_currentItem->at( realFieldNumber ).isNull())) {
-			kdDebug() << "KexiDataAwareObjectInterface::acceptEditor(): VALUE NOT CHANGED." << endl;
+			kDebug() << "KexiDataAwareObjectInterface::acceptEditor(): VALUE NOT CHANGED." << endl;
 			removeEditor();
 			if (m_acceptsRowEditAfterCellAccepting || m_internal_acceptsRowEditAfterCellAccepting)
 				acceptRowEdit();
@@ -1032,7 +1035,7 @@ bool KexiDataAwareObjectInterface::acceptEditor()
 //! @todo validation rules for this value?
 /*
 			if (!ok) {
-				kdDebug() << "KexiDataAwareObjectInterface::acceptEditor(): INVALID VALUE - NOT CHANGED." << endl;
+				kDebug() << "KexiDataAwareObjectInterface::acceptEditor(): INVALID VALUE - NOT CHANGED." << endl;
 				res = KexiValidator::Error;
 //js: TODO get detailed info on why m_editor->value() failed
 				msg = i18n("Entered value is invalid.")
@@ -1087,10 +1090,10 @@ bool KexiDataAwareObjectInterface::acceptEditor()
 		if (m_data->updateRowEditBufferRef(m_currentItem, m_curCol, currentTVColumn, 
 			newval,	/*allowSignals*/true, currentTVColumn->visibleLookupColumnInfo ? &visibleValue : 0))
 		{
-			kdDebug() << "KexiDataAwareObjectInterface::acceptEditor(): ------ EDIT BUFFER CHANGED TO:" << endl;
+			kDebug() << "KexiDataAwareObjectInterface::acceptEditor(): ------ EDIT BUFFER CHANGED TO:" << endl;
 			m_data->rowEditBuffer()->debug();
 		} else {
-			kdDebug() << "KexiDataAwareObjectInterface::acceptEditor(): ------ CHANGE FAILED in KexiDataAwareObjectInterface::updateRowEditBuffer()" << endl;
+			kDebug() << "KexiDataAwareObjectInterface::acceptEditor(): ------ CHANGE FAILED in KexiDataAwareObjectInterface::updateRowEditBuffer()" << endl;
 			res = Validator::Error;
 
 			//now: there might be called cancelEditor() in updateRowEditBuffer() handler,
@@ -1133,7 +1136,7 @@ bool KexiDataAwareObjectInterface::acceptEditor()
 			m_editor->showWidget();
 			m_editor->setFocus();
 		}
-//		startEditCurrentCell(newval.type()==QVariant::String ? newval.toString() : QString::null);
+//		startEditCurrentCell(newval.type()==QVariant::String ? newval.toString() : QString());
 //		m_editor->setFocus();
 	}
 	return false;
@@ -1141,7 +1144,7 @@ bool KexiDataAwareObjectInterface::acceptEditor()
 
 void KexiDataAwareObjectInterface::startEditCurrentCell(const QString &setText)
 {
-	kdDebug() << "** KexiDataAwareObjectInterface::startEditCurrentCell("<<setText<<")"<<endl;
+	kDebug() << "** KexiDataAwareObjectInterface::startEditCurrentCell("<<setText<<")"<<endl;
 //	if (columnType(d->curCol) == KexiDB::Field::Boolean)
 //		return;
 	if (isReadOnly() || !columnEditable(m_curCol))
@@ -1174,7 +1177,7 @@ void KexiDataAwareObjectInterface::deleteAndStartEditCurrentCell()
 //		columnWidth(m_curCol), rowHeight());
 //OK?
 	ensureCellVisible(m_curRow+1, m_curCol);
-	createEditor(m_curRow, m_curCol, QString::null, false/*removeOld*/);
+	createEditor(m_curRow, m_curCol, QString(), false/*removeOld*/);
 	if (!m_editor)
 		return;
 	m_editor->clear();
@@ -1202,9 +1205,10 @@ void KexiDataAwareObjectInterface::deleteCurrentRow()
 	case ImmediateDelete:
 		break;
 	case AskDelete:
-		if (KMessageBox::Cancel == KMessageBox::warningContinueCancel(dynamic_cast<QWidget*>(this), 
-			i18n("Do you want to delete selected row?"), 0, 
-			KGuiItem(i18n("&Delete Row"),"editdelete"),
+		if (KMessageBox::Cancel == KMessageBox::warningContinueCancel(
+			dynamic_cast<QWidget*>(this), 
+			i18n("Do you want to delete selected row?"), QString(), 
+			KGuiItem(i18n("&Delete Row"),"edit-delete"), KStandardGuiItem::cancel(),
 			"dontAskBeforeDeleteRow"/*config entry*/,
 			KMessageBox::Notify|KMessageBox::Dangerous))
 			return;
@@ -1325,7 +1329,7 @@ tristate KexiDataAwareObjectInterface::deleteAllRows(bool ask, bool repaint)
 			tableName.append("\"");
 		}
 		if (KMessageBox::Cancel == KMessageBox::warningContinueCancel(dynamic_cast<QWidget*>(this),
-				i18n("Do you want to clear the contents of table %1?").arg(tableName),
+				i18n("Do you want to clear the contents of table %1?", tableName),
 				0, KGuiItem(i18n("&Clear Contents")) ))
 			return cancelled;
 	}
@@ -1364,6 +1368,7 @@ void KexiDataAwareObjectInterface::clearColumns(bool repaint)
 	m_data->clearInternal();
 
 	clearColumnsInternal(repaint);
+	updateIndicesForVisibleValues();
 
 	if (repaint)
 //		viewport()->repaint();
@@ -1574,7 +1579,7 @@ const QVariant* KexiDataAwareObjectInterface::bufferedValueAt(int col, bool useD
 			//get the stored value
 			const int realFieldNumber = fieldNumberForColumn(col);
 			if (realFieldNumber < 0) {
-				kdWarning() << "KexiDataAwareObjectInterface::bufferedValueAt(): "
+				kWarning() << "KexiDataAwareObjectInterface::bufferedValueAt(): "
 					"fieldNumberForColumn(m_curCol) < 0" << endl;
 				return 0;
 			}
@@ -1595,7 +1600,7 @@ const QVariant* KexiDataAwareObjectInterface::bufferedValueAt(int col, bool useD
 	//not db-aware data:
 	const int realFieldNumber = fieldNumberForColumn(col);
 	if (realFieldNumber < 0) {
-		kdWarning() << "KexiDataAwareObjectInterface::bufferedValueAt(): "
+		kWarning() << "KexiDataAwareObjectInterface::bufferedValueAt(): "
 			"fieldNumberForColumn(m_curCol) < 0" << endl;
 		return 0;
 	}
@@ -1661,15 +1666,18 @@ bool KexiDataAwareObjectInterface::handleKeyPress(QKeyEvent *e, int &curRow, int
 	if (moveToLastField)
 		*moveToLastField = false;
 
-	const bool nobtn = e->state()==Qt::NoButton;
+	const bool nobtn = e->modifiers()==Qt::NoModifier;
 	const int k = e->key();
-	//kdDebug() << "-----------" << e->state() << " " << k << endl;
 
-	if ((k == Qt::Key_Up && nobtn) || (k == Qt::Key_PageUp && e->state()==Qt::ControlButton)) {
+	if (  (k == Qt::Key_Up && nobtn) 
+	    ||(k == Qt::Key_PageUp && e->modifiers()==Qt::ControlModifier))
+	{
 		selectPrevRow();
 		e->accept();
 	}
-	else if ((k == Qt::Key_Down && nobtn) || (k == Qt::Key_PageDown && e->state()==Qt::ControlButton)) {
+	else if ((k == Qt::Key_Down && nobtn)
+	      || (k == Qt::Key_PageDown && e->modifiers()==Qt::ControlModifier))
+	{
 		selectNextRow();
 		e->accept();
 	}
@@ -1686,11 +1694,11 @@ bool KexiDataAwareObjectInterface::handleKeyPress(QKeyEvent *e, int &curRow, int
 			//we're in row-selection mode: home key always moves to 1st row
 			curRow = 0;//to 1st row
 		}
-		else {//cell selection mode: different actions depending on ctrl and shift keys state
+		else {//cell selection mode: different actions depending on ctrl and shift keys mods
 			if (nobtn) {
 				curCol = 0;//to 1st col
 			}
-			else if (e->state()==Qt::ControlButton) {
+			else if (e->modifiers() == Qt::ControlModifier) {
 				curRow = 0;//to 1st row and col
 				curCol = 0;
 			}
@@ -1707,11 +1715,11 @@ bool KexiDataAwareObjectInterface::handleKeyPress(QKeyEvent *e, int &curRow, int
 			//we're in row-selection mode: home key always moves to last row
 			curRow = m_data->count()-1+(isInsertingEnabled()?1:0);//to last row
 		}
-		else {//cell selection mode: different actions depending on ctrl and shift keys state
+		else {//cell selection mode: different actions depending on ctrl and shift keys mods
 			if (nobtn) {
 				curCol = columns()-1;//to last col
 			}
-			else if (e->state()==Qt::ControlButton) {
+			else if (e->modifiers()==Qt::ControlModifier) {
 				curRow = m_data->count()-1 /*+(isInsertingEnabled()?1:0)*/; //to last row and col
 				curCol = columns()-1;//to last col
 			}
@@ -1723,8 +1731,11 @@ bool KexiDataAwareObjectInterface::handleKeyPress(QKeyEvent *e, int &curRow, int
 		//do not accept yet
 		e->ignore();
 	}
-	else if (isInsertingEnabled() && (e->state()==Qt::ControlButton && k == Qt::Key_Equal
-		|| e->state()==(Qt::ControlButton|Qt::ShiftButton) && k == Qt::Key_Equal)) {
+	else if (isInsertingEnabled() 
+		&& (   (e->modifiers()==Qt::ControlModifier && k == Qt::Key_Equal)
+		    || (e->modifiers()==(Qt::ControlButton|Qt::ShiftButton) && k == Qt::Key_Equal)
+		   ))
+	{
 		curRow = m_data->count(); //to the new row
 		curCol = 0;//to first col
 		if (moveToFirstField)
@@ -1745,7 +1756,19 @@ void KexiDataAwareObjectInterface::vScrollBarValueChanged(int v)
 		return;
 
 	if (m_scrollbarToolTipsEnabled) {
-		const QRect r( verticalScrollBar()->sliderRect() );
+//		const QRect r( verticalScrollBar()->sliderRect() );
+		QStyleOptionComplex styleOption;
+		styleOption.initFrom(verticalScrollBar());
+#ifdef __GNUC__
+#warning ported but not tested KexiDataAwareObjectInterface::vScrollBarValueChanged()
+#else
+#pragma WARNING( ported but not tested KexiDataAwareObjectInterface::vScrollBarValueChanged() )
+#endif
+		QRect r;
+/*TODO		const QRect r( verticalScrollBar()->style()->subControlRect(
+			QStyle::CC_ScrollBar, &styleOption, 
+			QStyle::SC_ScrollBarSlider, verticalScrollBar()) ); */
+		
 		const int row = lastVisibleRow()+1;
 		if (row<=0) {
 			m_scrollBarTipTimer.stop();
@@ -1759,8 +1782,8 @@ void KexiDataAwareObjectInterface::vScrollBarValueChanged(int v)
 			thisWidget->mapToGlobal( r.topLeft() + verticalScrollBar()->pos() ) 
 				+ QPoint( - m_scrollBarTip->width()-5, 
 			r.height()/2 - m_scrollBarTip->height()/2) );
-		if (verticalScrollBar()->draggingSlider()) {
-			kdDebug(44021) << "  draggingSlider()  " << endl;
+		if (verticalScrollBar()->isSliderDown()) {
+			kDebug(44021) << "  isSliderDown()  " << endl;
 			m_scrollBarTipTimer.stop();
 			m_scrollBarTip->show();
 			m_scrollBarTip->raise();
@@ -1771,17 +1794,24 @@ void KexiDataAwareObjectInterface::vScrollBarValueChanged(int v)
 				m_scrollBarTipTimerCnt=0;
 				m_scrollBarTip->show();
 				m_scrollBarTip->raise();
-				m_scrollBarTipTimer.start(500, true);
+				m_scrollBarTipTimer.start(500);
 			}
 		}
 	}
 	//update bottom view region
-/*	if (m_navPanel && (contentsHeight() - contentsY() - clipper()->height()) <= QMAX(d->rowHeight,m_navPanel->height())) {
+/*	if (m_navPanel && (contentsHeight() - contentsY() - clipper()->height()) <= qMax(d->rowHeight,m_navPanel->height())) {
 		slotUpdate();
 		triggerUpdate();
 	}*/
 }
 
+void KexiDataAwareObjectInterface::setContextMenuTitle(const QIcon &icon, const QString &text)
+{
+	m_contextMenuTitleIcon = icon;
+	m_contextMenuTitleText = text;
+	/*emit*/ reloadActions();
+}
+
 bool KexiDataAwareObjectInterface::scrollbarToolTipsEnabled() const
 {
 	return m_scrollbarToolTipsEnabled;
@@ -1794,17 +1824,17 @@ void KexiDataAwareObjectInterface::setScrollbarToolTipsEnabled(bool set)
 
 void KexiDataAwareObjectInterface::vScrollBarSliderReleased()
 {
-	kdDebug(44021) << "vScrollBarSliderReleased()" << endl;
+	kDebug(44021) << "vScrollBarSliderReleased()" << endl;
 	m_scrollBarTip->hide();
 }
 
 void KexiDataAwareObjectInterface::scrollBarTipTimeout()
 {
 	if (m_scrollBarTip->isVisible()) {
-//		kdDebug(44021) << "TIMEOUT! - hide" << endl;
+//		kDebug(44021) << "TIMEOUT! - hide" << endl;
 		if (m_scrollBarTipTimerCnt>0) {
 			m_scrollBarTipTimerCnt=0;
-			m_scrollBarTipTimer.start(500, true);
+			m_scrollBarTipTimer.start(500);
 			return;
 		}
 		m_scrollBarTip->hide();
@@ -1826,9 +1856,11 @@ int KexiDataAwareObjectInterface::showErrorMessageForResult(KexiDB::ResultInfo*
 	QWidget *thisWidget = dynamic_cast<QWidget*>(this);
 	if (resultInfo->allowToDiscardChanges) {
 		return KMessageBox::questionYesNo(thisWidget, resultInfo->msg 
-			+ (resultInfo->desc.isEmpty() ? QString::null : ("\n"+resultInfo->desc)),
-			QString::null, 
-			KGuiItem(i18n("Correct Changes", "Correct"), QString::null, i18n("Correct changes")),
+			+ (resultInfo->desc.isEmpty() ? QString() : ("\n"+resultInfo->desc)),
+			QString(), 
+			KGuiItem(i18nc("Correct Changes", "Correct"), 
+			QString(), 
+			i18n("Correct changes")),
 			KGuiItem(i18n("Discard Changes")) );
 	}
 
@@ -1839,3 +1871,267 @@ int KexiDataAwareObjectInterface::showErrorMessageForResult(KexiDB::ResultInfo*
 	
 	return KMessageBox::Ok;
 }
+
+void KexiDataAwareObjectInterface::updateIndicesForVisibleValues()
+{
+	m_indicesForVisibleValues.resize( m_data ? m_data->columnsCount() : 0 );
+	if (!m_data)
+		return;
+	for (uint i=0; i < m_data->columnsCount(); i++) {
+		KexiTableViewColumn* tvCol = m_data->column(i);
+		if (tvCol->columnInfo && tvCol->columnInfo->indexForVisibleLookupValue()!=-1)
+			// retrieve visible value from lookup field
+			m_indicesForVisibleValues[ i ] = tvCol->columnInfo->indexForVisibleLookupValue();
+		else
+			m_indicesForVisibleValues[ i ] = i;
+	}
+}
+
+/*! Performs searching \a stringValue in \a where string.
+ \a matchAnyPartOfField, \a matchWholeField, \a wholeWordsOnly options are used to control how to search.
+
+ If \a matchWholeField is true, \a wholeWordsOnly is not checked.
+ \a firstCharacter is in/out parameter. If \a matchAnyPartOfField is true and \a matchWholeField is false,
+ \a firstCharacter >= 0, the search will be performed after skipping first \a firstCharacter characters.
+
+ If \a forward is false, we are searching backwart from \a firstCharacter position. \a firstCharacter == -1
+ means then the last character. \a firstCharacter == INT_MAX means "before first" place, so searching fails
+ immediately.
+ On success, true is returned and \a firstCharacter is set to position of the matched string. */
+static inline bool findInString(const QString& stringValue, int stringLength, 
+	const QString& where, 
+	int& firstCharacter, bool matchAnyPartOfField, bool matchWholeField, 
+	Qt::CaseSensitivity caseSensitivity, bool wholeWordsOnly, bool forward)
+{
+	if (where.isEmpty()) {
+		firstCharacter = -1;
+		return false;
+	}
+
+	if (matchAnyPartOfField) {
+		if (forward) {
+			int pos = firstCharacter == -1 ? 0 : firstCharacter;
+			if (wholeWordsOnly) {
+				const int whereLength = where.length();
+				while (true) {
+					pos = where.indexOf( stringValue, pos, caseSensitivity );
+					if (pos == -1)
+						break;
+					if ((pos > 0 && where.at(pos-1).isLetterOrNumber())
+						||((pos+stringLength-1) < (whereLength-1) && where.at(pos+stringLength-1+1).isLetterOrNumber()))
+					{
+						pos++; // invalid match because before or after the string there is non-white space
+					}
+					else
+						break;
+				}//while
+				firstCharacter = pos;
+			}
+			else {// !wholeWordsOnly
+				firstCharacter = where.indexOf( stringValue, pos, caseSensitivity );
+			}
+			return firstCharacter != -1;
+		}
+		else { // !matchAnyPartOfField
+			if (firstCharacter == INT_MAX) {
+				firstCharacter = -1; //next time we'll be looking at different cell
+				return false;
+			}
+			int pos = firstCharacter;
+			if (wholeWordsOnly) {
+				const int whereLength = where.length();
+				while (true) {
+					pos = where.lastIndexOf( stringValue, pos, caseSensitivity );
+					if (pos == -1)
+						break;
+					if ((pos > 0 && where.at(pos-1).isLetterOrNumber())
+						||((pos+stringLength-1) < (whereLength-1) && where.at(pos+stringLength-1+1).isLetterOrNumber()))
+					{
+						// invalid match because before or after the string there is non-white space
+						pos--;
+						if (pos < 0) // it can make pos < 0
+							break;
+					}
+					else
+						break;
+				}//while
+				firstCharacter = pos;
+			}
+			else {// !wholeWordsOnly
+				firstCharacter = where.lastIndexOf( stringValue, pos, caseSensitivity );
+			}
+			return firstCharacter != -1;
+		}
+	}
+	else if (matchWholeField) {
+		if (firstCharacter != -1 && firstCharacter != 0) { //we're not at 0-th char
+			firstCharacter = -1;
+		}
+		else if ( (caseSensitivity==Qt::CaseSensitive ? where : where.toLower()) == stringValue) {
+			firstCharacter = 0;
+			return true;
+		}
+	}
+	else {// matchStartOfField
+		if (firstCharacter != -1 && firstCharacter != 0) { //we're not at 0-th char
+			firstCharacter = -1;
+		}
+		else if (where.startsWith(stringValue, caseSensitivity)) {
+			if (wholeWordsOnly) {
+				// If where.length() < stringValue.length(), true will be returned too - fine.
+				return !where.at( stringValue.length() ).isLetterOrNumber();
+			}
+			firstCharacter = 0;
+			return true;
+		}
+	}
+	return false;
+}
+
+tristate KexiDataAwareObjectInterface::find(const QVariant& valueToFind, 
+	const KexiSearchAndReplaceViewInterface::Options& options, bool next)
+{
+	if (!hasData())
+		return cancelled;
+	const QVariant prevSearchedValue( m_recentlySearchedValue );
+	m_recentlySearchedValue = valueToFind;
+	const KexiSearchAndReplaceViewInterface::Options::SearchDirection prevSearchDirection = m_recentSearchDirection;
+	m_recentSearchDirection = options.searchDirection;
+	if (valueToFind.isNull() || valueToFind.toString().isEmpty())
+		return cancelled;
+
+	const bool forward = (options.searchDirection == KexiSearchAndReplaceViewInterface::Options::SearchUp) 
+		? !next : next; //direction can be reversed
+
+	if ((!prevSearchedValue.isNull() && prevSearchedValue!=valueToFind)
+		|| (prevSearchDirection!=options.searchDirection && options.searchDirection==KexiSearchAndReplaceViewInterface::Options::SearchAllRows))
+	{
+		// restart searching when value has been changed or new direction is SearchAllRows
+		m_positionOfRecentlyFoundValue.exists = false;
+	}
+
+	const bool startFrom1stRowAndCol = !m_positionOfRecentlyFoundValue.exists && next
+		&& options.searchDirection == KexiSearchAndReplaceViewInterface::Options::SearchAllRows;
+	const bool startFromLastRowAndCol = 
+		  (!m_positionOfRecentlyFoundValue.exists && !next && options.searchDirection == KexiSearchAndReplaceViewInterface::Options::SearchAllRows)
+		||(m_curRow >= rows() && !forward); //we're at "insert" row, and searching backwards: move to the last cell
+
+	if (!startFrom1stRowAndCol && !startFromLastRowAndCol && m_curRow >= rows()) {
+		//we're at "insert" row, and searching forward: no chances to find something
+		return false;
+	}
+	KexiTableViewData::Iterator it( (startFrom1stRowAndCol || startFromLastRowAndCol)
+		? m_data->iterator() : *m_itemIterator /*start from the current cell*/ );
+	if (startFromLastRowAndCol)
+		it.toLast();
+	int firstCharacter;
+	if (m_positionOfRecentlyFoundValue.exists) {// start after the next/prev char position
+		if (forward)
+			firstCharacter = m_positionOfRecentlyFoundValue.lastCharacter + 1;
+		else {
+			firstCharacter = (m_positionOfRecentlyFoundValue.firstCharacter > 0) ? 
+				(m_positionOfRecentlyFoundValue.firstCharacter - 1) : INT_MAX /* this means 'before first'*/;
+		}
+	}
+	else {
+		firstCharacter = -1; //forward ? -1 : INT_MAX;
+	}
+
+	const int columnsCount = m_data->columnsCount();
+	int row, col;
+	if (startFrom1stRowAndCol) {
+		row = 0;
+		col = 0;
+	}
+	else if (startFromLastRowAndCol) {
+		row = rows()-1;
+		col = columnsCount-1;
+	}
+	else {
+		row = m_curRow;
+		col = m_curCol;
+	}
+
+	//sache some flags for efficiency
+	const bool matchAnyPartOfField 
+		= options.textMatching == KexiSearchAndReplaceViewInterface::Options::MatchAnyPartOfField;
+	const bool matchWholeField 
+		= options.textMatching == KexiSearchAndReplaceViewInterface::Options::MatchWholeField;
+	const Qt::CaseSensitivity caseSensitivity
+		= options.caseSensitive ? Qt::CaseSensitive : Qt::CaseInsensitive;
+	const bool wholeWordsOnly = options.wholeWordsOnly;
+//unused	const bool promptOnReplace = options.promptOnReplace;
+	int columnNumber = (options.columnNumber == KexiSearchAndReplaceViewInterface::Options::CurrentColumn) 
+		? m_curCol : options.columnNumber;
+	if (columnNumber>=0)
+		col = columnNumber;
+	const bool lookInAllColumns = columnNumber == KexiSearchAndReplaceViewInterface::Options::AllColumns;
+	int firstColumn; // real number of the first column, can be smaller than lastColumn if forward==true
+	int lastColumn; // real number of the last column
+	if (lookInAllColumns) {
+		firstColumn = forward ? 0 : columnsCount-1;
+		lastColumn = forward ? columnsCount-1 : 0;
+	}
+	else {
+		firstColumn = columnNumber;
+		lastColumn = columnNumber;
+	}
+	const QString stringValue( 
+		caseSensitivity==Qt::CaseSensitive 
+		? valueToFind.toString() : valueToFind.toString().toLower() );
+	const int stringLength = stringValue.length();
+
+	// search
+	const int prevRow = m_curRow;
+	KexiTableItem *item;
+	while ( (item = it.current()) ) {
+		for (; forward ? col <= lastColumn : col >= lastColumn; 
+			col = forward ? (col+1) : (col-1))
+		{
+			const QVariant cell( item->at( m_indicesForVisibleValues[ col ] ) );
+			if (findInString(stringValue, stringLength, cell.toString(), firstCharacter, 
+				matchAnyPartOfField, matchWholeField, caseSensitivity, wholeWordsOnly, forward))
+			{
+				//*m_itemIterator = it;
+				//m_currentItem = *it;
+				//m_curRow = row;
+				//m_curCol = col;
+				setCursorPosition(row, col, true/*forceSet*/);
+				if (prevRow != m_curRow)
+					updateRow(prevRow);
+				// remember the exact position for the found value
+				m_positionOfRecentlyFoundValue.exists = true;
+				m_positionOfRecentlyFoundValue.firstCharacter = firstCharacter;
+//! @todo for regexp lastCharacter should be computed
+				m_positionOfRecentlyFoundValue.lastCharacter = firstCharacter + stringLength - 1;
+				return true;
+			}
+		}//for
+		if (forward) {
+			++it;
+			++row;
+		}
+		else {
+			--it;
+			--row;
+		}
+		col = firstColumn;
+	}//while
+	return false;
+}
+
+tristate KexiDataAwareObjectInterface::findNextAndReplace(
+	const QVariant& valueToFind, const QVariant& replacement, 
+	const KexiSearchAndReplaceViewInterface::Options& options, bool replaceAll)
+{
+	Q_UNUSED(replacement);
+	Q_UNUSED(options);
+	Q_UNUSED(replaceAll);
+	
+	if (isReadOnly())
+		return cancelled;
+	if (valueToFind.isNull() || valueToFind.toString().isEmpty())
+		return cancelled;
+	//! @todo implement KexiDataAwareObjectInterface::findAndReplace()
+	return false;
+}
