@@ -37,6 +37,8 @@
 #include <klocale.h>
 
 #include <qapplication.h>
+//Added by qt3to4:
+#include <Q3ValueList>
 
 unsigned short KexiTableViewData::charTable[]=
 {
@@ -121,11 +123,16 @@ KexiTableViewColumn::KexiTableViewColumn(
 		//todo: compute other auto-name?
 	}
 	init();
-	//setup column's readonly flag: 
-	// true if it's not from parent table's field or if the query itself is coming read-only connection
-	m_readOnly = (query.masterTable()!=columnInfo->field->table())
+	//setup column's readonly flag: true, if
+	// - it's not from parent table's field, or
+	// - if the query itself is coming from read-only connection, or
+	// - if the query itself is stored (i.e. has connection) and lookup column is defined
+	const bool columnFromMasterTable = query.masterTable()==columnInfo->field->table();
+	m_readOnly = !columnFromMasterTable
 		|| (query.connection() && query.connection()->isReadOnly());
-//	kdDebug() << "KexiTableViewColumn: query.masterTable()==" 
+//		|| (query.connection() && (query.connection()->isReadOnly() || visibleLookupColumnInfo));
+//! @todo 2.0: remove this when queries become editable            ^^^^^^^^^^^^^^
+//	kDebug() << "KexiTableViewColumn: query.masterTable()==" 
 //		<< (query.masterTable() ? query.masterTable()->name() : "notable") << ", columnInfo->field->table()=="
 //		<< (columnInfo->field->table() ? columnInfo->field->table()->name()  : "notable") << endl;
 
@@ -195,6 +202,11 @@ void KexiTableViewColumn::setRelatedDataEditable(bool set)
 	m_relatedDataEditable = set;
 }
 
+bool KexiTableViewColumn::isReadOnly() const
+{
+	return m_readOnly || (m_data && m_data->isReadOnly());
+}
+
 bool KexiTableViewColumn::acceptsFirstChar(const QChar& ch) const
 {
 	// the field we're looking at can be related to "visible lookup column" 
@@ -272,7 +284,7 @@ KexiTableViewData::KexiTableViewData(KexiDB::Cursor *c)
 }
 
 KexiTableViewData::KexiTableViewData(
-	const QValueList<QVariant> &keys, const QValueList<QVariant> &values,
+	const Q3ValueList<QVariant> &keys, const Q3ValueList<QVariant> &values,
 	KexiDB::Field::Type keyType, KexiDB::Field::Type valueType)
 	: QObject()
 	, KexiTableViewDataBase()
@@ -283,7 +295,7 @@ KexiTableViewData::KexiTableViewData(
 KexiTableViewData::KexiTableViewData(
 	KexiDB::Field::Type keyType, KexiDB::Field::Type valueType)
 {
-	const QValueList<QVariant> empty;
+	const Q3ValueList<QVariant> empty;
 	init(empty, empty, keyType, valueType);
 }
 
@@ -294,7 +306,7 @@ KexiTableViewData::~KexiTableViewData()
 }
 
 void KexiTableViewData::init(
-	const QValueList<QVariant> &keys, const QValueList<QVariant> &values,
+	const Q3ValueList<QVariant> &keys, const Q3ValueList<QVariant> &values,
 	KexiDB::Field::Type keyType, KexiDB::Field::Type valueType)
 {
 	init();
@@ -308,9 +320,9 @@ void KexiTableViewData::init(
 	KexiTableViewColumn *valueColumn = new KexiTableViewColumn(*valueField, true);
 	addColumn(valueColumn);
 
-	uint cnt = QMIN(keys.count(), values.count());
-	QValueList<QVariant>::ConstIterator it_keys = keys.constBegin();
-	QValueList<QVariant>::ConstIterator it_values = values.constBegin();
+	uint cnt = qMin(keys.count(), values.count());
+	Q3ValueList<QVariant>::ConstIterator it_keys = keys.constBegin();
+	Q3ValueList<QVariant>::ConstIterator it_values = values.constBegin();
 	for (;cnt>0;++it_keys, ++it_values, cnt--) {
 		KexiTableItem *item = new KexiTableItem(2);
 		(*item)[0] = (*it_keys);
@@ -357,12 +369,12 @@ void KexiTableViewData::addColumn( KexiTableViewColumn* col )
 //	}
 	columns.append( col );
 	col->m_data = this;
-	if (m_globalColumnsIDs.size() < columns.count()) {//sanity
+	if (m_globalColumnsIDs.size() < (int)columns.count()) {//sanity
 		m_globalColumnsIDs.resize( m_globalColumnsIDs.size()*2 );
 	}
 	if (col->visible()) {
 		m_visibleColumnsCount++;
-		if (m_visibleColumnsIDs.size() < m_visibleColumnsCount) {//sanity
+		if ((uint)m_visibleColumnsIDs.size() < m_visibleColumnsCount) {//sanity
 			m_visibleColumnsIDs.resize( m_visibleColumnsIDs.size()*2 );
 		}
 		m_visibleColumnsIDs[ columns.count()-1 ] = m_visibleColumnsCount-1;
@@ -380,7 +392,7 @@ QString KexiTableViewData::dbTableName() const
 {
 	if (m_cursor && m_cursor->query() && m_cursor->query()->masterTable())
 		return m_cursor->query()->masterTable()->name();
-	return QString::null;
+	return QString();
 }
 
 void KexiTableViewData::setSorting(int column, bool ascending)
@@ -512,7 +524,7 @@ int KexiTableViewData::cmpStr(Item item1, Item item2)
 	unsigned short au;
 	unsigned short bu;
 
-	int l=QMIN(as.length(),bs.length());
+	int l=qMin(as.length(),bs.length());
 
 	au = a->unicode();
 	bu = b->unicode();
@@ -577,10 +589,10 @@ bool KexiTableViewData::updateRowEditBufferRef(KexiTableItem *item,
 	if (!m_result.success)
 		return false;
 
-	kdDebug() << "KexiTableViewData::updateRowEditBufferRef() column #" 
+	kDebug() << "KexiTableViewData::updateRowEditBufferRef() column #" 
 		<< colnum << " = " << newval.toString() << endl;
 	if (!col) {
-		kdWarning() << "KexiTableViewData::updateRowEditBufferRef(): column #" 
+		kWarning() << "KexiTableViewData::updateRowEditBufferRef(): column #" 
 			<< colnum << " not found! col==0" << endl;
 		return false;
 	}
@@ -588,7 +600,7 @@ bool KexiTableViewData::updateRowEditBufferRef(KexiTableItem *item,
 		m_pRowEditBuffer = new KexiDB::RowEditBuffer(isDBAware());
 	if (m_pRowEditBuffer->isDBAware()) {
 		if (!(col->columnInfo)) {
-			kdWarning() << "KexiTableViewData::updateRowEditBufferRef(): column #" 
+			kWarning() << "KexiTableViewData::updateRowEditBufferRef(): column #" 
 				<< colnum << " not found!" << endl;
 			return false;
 		}
@@ -601,13 +613,13 @@ bool KexiTableViewData::updateRowEditBufferRef(KexiTableItem *item,
 		return true;
 	}
 	if (!(col->field())) {
-		kdDebug() << "KexiTableViewData::updateRowEditBufferRef(): column #" << colnum<<" not found!" << endl;
+		kDebug() << "KexiTableViewData::updateRowEditBufferRef(): column #" << colnum<<" not found!" << endl;
 		return false;
 	}
 	//not db-aware:
 	const QString colname = col->field()->name();
 	if (colname.isEmpty()) {
-		kdDebug() << "KexiTableViewData::updateRowEditBufferRef(): column #" << colnum<<" not found!" << endl;
+		kDebug() << "KexiTableViewData::updateRowEditBufferRef(): column #" << colnum<<" not found!" << endl;
 		return false;
 	}
 	m_pRowEditBuffer->insert(colname, newval);
@@ -644,8 +656,8 @@ bool KexiTableViewData::saveRow(KexiTableItem& item, bool insert, bool repaint)
 			//check it
 			if (val->isNull() && !f->isAutoIncrement()) {
 				//NOT NULL violated
-				m_result.msg = i18n("\"%1\" column requires a value to be entered.")
-					.arg(f->captionOrName()) + "\n\n" + Kexi::msgYouCanImproveData();
+				m_result.msg = i18n("\"%1\" column requires a value to be entered.",
+					f->captionOrName()) + "\n\n" + Kexi::msgYouCanImproveData();
 				m_result.desc = i18n("The column's constraint is declared as NOT NULL.");
 				m_result.column = col;
 				return false;
@@ -655,8 +667,8 @@ bool KexiTableViewData::saveRow(KexiTableItem& item, bool insert, bool repaint)
 			GET_VALUE;
 			if (!f->isAutoIncrement() && (val->isNull() || KexiDB::isEmptyValue( f, *val ))) {
 				//NOT EMPTY violated
-				m_result.msg = i18n("\"%1\" column requires a value to be entered.")
-					.arg(f->captionOrName()) + "\n\n" + Kexi::msgYouCanImproveData();
+				m_result.msg = i18n("\"%1\" column requires a value to be entered.",
+					f->captionOrName()) + "\n\n" + Kexi::msgYouCanImproveData();
 				m_result.desc = i18n("The column's constraint is declared as NOT EMPTY.");
 				m_result.column = col;
 				return false;
@@ -675,9 +687,9 @@ bool KexiTableViewData::saveRow(KexiTableItem& item, bool insert, bool repaint)
 
 /*			if (desc)
 			*desc = 
-js: TODO: use KexiMainWindowImpl::showErrorMessage(const QString &title, KexiDB::Object *obj)
+js: TODO: use KexiMainWindow::showErrorMessage(const QString &title, KexiDB::Object *obj)
 	after it will be moved somewhere to kexidb (this will require moving other 
-	  showErrorMessage() methods from KexiMainWindowImpl to libkexiutils....)
+	  showErrorMessage() methods from KexiMainWindow to libkexiutils....)
 	then: just call: *desc = KexiDB::errorMessage(m_cursor);
 */
 				return false;
@@ -702,8 +714,9 @@ js: TODO: use KexiMainWindowImpl::showErrorMessage(const QString &title, KexiDB:
 			uint i=0;
 			for (KexiTableViewColumn::ListIterator it2(columns);it2.current();++it2, i++) {
 				if (it2.current()->field()->name()==it.key()) {
-					kdDebug() << it2.current()->field()->name()<< ": "<<item[i].toString()<<" -> "<<it.data().toString()<<endl;
-					item[i] = it.data();
+					kDebug() << it2.current()->field()->name()<< ": "<<item[i].toString()
+						<<" -> "<<it.value().toString()<<endl;
+					item[i] = it.value();
 				}
 			}
 		}
@@ -718,7 +731,7 @@ js: TODO: use KexiMainWindowImpl::showErrorMessage(const QString &title, KexiDB:
 
 bool KexiTableViewData::saveRowChanges(KexiTableItem& item, bool repaint)
 {
-	kdDebug() << "KexiTableViewData::saveRowChanges()..." << endl;
+	kDebug() << "KexiTableViewData::saveRowChanges()..." << endl;
 	m_result.clear();
 	emit aboutToUpdateRow(&item, m_pRowEditBuffer, &m_result);
 	if (!m_result.success)
@@ -733,7 +746,7 @@ bool KexiTableViewData::saveRowChanges(KexiTableItem& item, bool repaint)
 
 bool KexiTableViewData::saveNewRow(KexiTableItem& item, bool repaint)
 {
-	kdDebug() << "KexiTableViewData::saveNewRow()..." << endl;
+	kDebug() << "KexiTableViewData::saveNewRow()..." << endl;
 	m_result.clear();
 	emit aboutToInsertRow(&item, &m_result, repaint);
 	if (!m_result.success)
@@ -766,7 +779,7 @@ bool KexiTableViewData::deleteRow(KexiTableItem& item, bool repaint)
 
 	if (!removeRef(&item)) {
 		//aah - this shouldn't be!
-		kdWarning() << "KexiTableViewData::deleteRow(): !removeRef() - IMPL. ERROR?" << endl;
+		kWarning() << "KexiTableViewData::deleteRow(): !removeRef() - IMPL. ERROR?" << endl;
 		m_result.success = false;
 		return false;
 	}
@@ -774,7 +787,7 @@ bool KexiTableViewData::deleteRow(KexiTableItem& item, bool repaint)
 	return true;
 }
 
-void KexiTableViewData::deleteRows( const QValueList<int> &rowsToDelete, bool repaint )
+void KexiTableViewData::deleteRows( const Q3ValueList<int> &rowsToDelete, bool repaint )
 {
 	Q_UNUSED( repaint );
 
@@ -782,7 +795,7 @@ void KexiTableViewData::deleteRows( const QValueList<int> &rowsToDelete, bool re
 		return;
 	int last_r=0;
 	first();
-	for (QValueList<int>::ConstIterator r_it = rowsToDelete.constBegin(); r_it!=rowsToDelete.constEnd(); ++r_it) {
+	for (Q3ValueList<int>::ConstIterator r_it = rowsToDelete.constBegin(); r_it!=rowsToDelete.constEnd(); ++r_it) {
 		for (; last_r<(*r_it); last_r++) {
 			next();
 		}
@@ -796,7 +809,7 @@ void KexiTableViewData::deleteRows( const QValueList<int> &rowsToDelete, bool re
 
 void KexiTableViewData::insertRow(KexiTableItem& item, uint index, bool repaint)
 {
-	if (!insert( index = QMIN(index, count()), &item ))
+	if (!insert( index = qMin(index, count()), &item ))
 		return;
 	emit rowInserted(&item, index, repaint);
 }
@@ -812,7 +825,7 @@ void KexiTableViewData::clearInternal()
 		removeLast();
 #ifndef KEXI_NO_PROCESS_EVENTS
 		if (i % 1000 == 0)
-			qApp->processEvents( 1 );
+			qApp->processEvents( QEventLoop::AllEvents, 1 );
 #endif
 	}
 }
@@ -863,7 +876,7 @@ void KexiTableViewData::preloadAllRows()
 		m_cursor->moveNext();
 #ifndef KEXI_NO_PROCESS_EVENTS
 		if ((i % 1000) == 0)
-			qApp->processEvents( 1 );
+			qApp->processEvents( QEventLoop::AllEvents, 1 );
 #endif
 	}
 }
