@@ -2,7 +2,7 @@
    Copyright (C) 2002 Lucijan Busch <lucijan@gmx.at>
    Copyright (C) 2002 Till Busch <till@bux.at>
    Copyright (C) 2002 Daniel Molkentin <molkentin@kde.org>
-   Copyright (C) 2003-2006 Jaroslaw Staniek <js@iidea.pl>
+   Copyright (C) 2003-2007 Jaroslaw Staniek <js@iidea.pl>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -23,69 +23,36 @@
 #include "kexirecordmarker.h"
 
 #include <qcolor.h>
-#include <qstyle.h>
 #include <qpixmap.h>
 #include <qpainter.h>
 #include <qimage.h>
 #include <qapplication.h>
+#include <QPolygon>
+#include <QPaintEvent>
+#include <QStyle>
+#include <QStyleOptionHeader>
 
 #include <kdebug.h>
-#include <kstaticdeleter.h>
 
 #include <kexiutils/utils.h>
+#include <kexi_global.h>
 
-static KStaticDeleter<QImage> KexiRecordMarker_pen_deleter, KexiRecordMarker_plus_deleter;
-QImage* KexiRecordMarker_pen = 0, *KexiRecordMarker_plus = 0;
+#include "../../pics/tableview_pen.xpm"
+#include "../../pics/tableview_plus.xpm"
 
-static const unsigned char img_pen_data[] = {
-    0x00,0x00,0x03,0x30,0x78,0x9c,0xfb,0xff,0xff,0x3f,0xc3,0x7f,0x32,0x30,
-    0x10,0x80,0x88,0xff,0xe4,0xe8,0x85,0xe9,0xc7,0xc6,0x26,0x55,0x3f,0x3a,
-    0x4d,0x8e,0x7e,0x72,0xfc,0x32,0xd2,0xf5,0xa3,0xeb,0xa5,0xb5,0x7e,0x5c,
-    0xe9,0x85,0x54,0xfb,0xb1,0xa5,0x1b,0x52,0xdc,0x0e,0x00,0xf2,0xea,0x0a,
-    0x13
-};
-static const unsigned char img_plus_data[] = {
-    0x00,0x00,0x01,0x90,0x78,0x9c,0xfb,0xff,0xff,0x3f,0xc3,0x7f,0x28,0x86,
-    0x82,0xff,0x50,0x0c,0x17,0x47,0xc7,0xd4,0x50,0x87,0x05,0xc0,0xd5,0xe1,
-    0x10,0xa7,0x16,0x26,0xca,0x5e,0x7c,0xfe,0x20,0x47,0x1d,0xb2,0x5a,0x5c,
-    0xea,0x40,0x72,0x00,0x03,0x6e,0x74,0x8c
-};
-
-static struct EmbedImage {
-    int width, height, depth;
-    const unsigned char *data;
-    ulong compressed;
-    int numColors;
-    const QRgb *colorTable;
-    bool alpha;
-    const char *name;
-} embed_image[] = {
-    { 17, 12, 32, (const unsigned char*)img_pen_data, 57, 0, 0, true, "tableview_pen.png" },
-    { 10, 10, 32, (const unsigned char*)img_pen_data, 50, 0, 0, true, "tableview_plus.png" }
-};
-
-QImage* getImg(const unsigned char* data, int id)
-{
-	QByteArray baunzip;
-	baunzip = qUncompress( data, embed_image[id].compressed );
-	QImage *img = new QImage( QImage((uchar*)baunzip.data(),
-			embed_image[id].width, embed_image[id].height,
-			embed_image[id].depth, (QRgb*)embed_image[id].colorTable,
-			embed_image[id].numColors, QImage::BigEndian
-	).copy() );
-	if ( embed_image[id].alpha )
-		img->setAlphaBuffer(true);
-	return img;
-}
-
-static void initRecordMarkerImages()
-{
-	if (!KexiRecordMarker_pen) {
+//! @internal
 /*! @warning not reentrant! */
-		KexiRecordMarker_pen_deleter.setObject( KexiRecordMarker_pen, getImg(img_pen_data, 0) );
-		KexiRecordMarker_plus_deleter.setObject( KexiRecordMarker_plus, getImg(img_plus_data, 1) );
+struct KexiRecordMarkerStatic
+{
+	KexiRecordMarkerStatic()
+	 : pen( tableview_pen_xpm )
+	 , plus( tableview_plus_xpm )
+	{
 	}
-}
+	QImage pen, plus;
+};
+
+K_GLOBAL_STATIC(KexiRecordMarkerStatic, KexiRecordMarker_static)
 
 //----------------------------------------------------------------
 
@@ -100,7 +67,6 @@ public:
 	 , highlightedRow(-1)
 	 , editRow(-1)
 	 , rows(0)
-	 , selectionBackgroundColor(qApp->palette().active().highlight())
 	 , showInsertRow(true)
 	{
 	}
@@ -116,11 +82,11 @@ public:
 
 //----------------------------------------------------------------
 
-KexiRecordMarker::KexiRecordMarker(QWidget *parent, const char* name)
- : QWidget(parent, name)
+KexiRecordMarker::KexiRecordMarker(QWidget *parent)
+ : QWidget(parent)
  , d( new Private() )
 {
-	initRecordMarkerImages();
+	setSelectionBackgroundColor( parent->palette().color(QPalette::Highlight) );
 }
 
 KexiRecordMarker::~KexiRecordMarker()
@@ -130,14 +96,12 @@ KexiRecordMarker::~KexiRecordMarker()
 
 QImage* KexiRecordMarker::penImage()
 {
-	initRecordMarkerImages();
-	return KexiRecordMarker_pen;
+	return &KexiRecordMarker_static->pen;
 }
 
 QImage* KexiRecordMarker::plusImage()
 {
-	initRecordMarkerImages();
-	return KexiRecordMarker_plus;
+	return &KexiRecordMarker_static->plus;
 }
 
 void KexiRecordMarker::addLabel(bool upd)
@@ -185,60 +149,64 @@ void KexiRecordMarker::paintEvent(QPaintEvent *e)
 
 	int first = (r.top()    + d->offset) / d->rowHeight;
 	int last  = (r.bottom() + d->offset) / d->rowHeight;
-	if(last > (d->rows-1+(d->showInsertRow?1:0)))
+	if (last > (d->rows - 1 + (d->showInsertRow?1:0)))
 		last = d->rows-1+(d->showInsertRow?1:0);
 
-	QColorGroup selectedColorGroup(colorGroup());
-	selectedColorGroup.setColor( QColorGroup::Button, 
-		KexiUtils::blendedColors( selectedColorGroup.color(QColorGroup::Background), 
-			d->selectionBackgroundColor, 2, 1) );
-	selectedColorGroup.setColor( QColorGroup::Background, 
-		selectedColorGroup.color(QColorGroup::Button) ); //set background color as well (e.g. for thinkeramik)
-	QColorGroup highlightedColorGroup(colorGroup());
-	highlightedColorGroup.setColor( QColorGroup::Button, 
-		KexiUtils::blendedColors( highlightedColorGroup.color(QColorGroup::Background), 
-			d->selectionBackgroundColor, 4, 1) );
-	highlightedColorGroup.setColor( QColorGroup::Background, 
-		highlightedColorGroup.color(QColorGroup::Button) ); //set background color as well (e.g. for thinkeramik)
-	for(int i=first; i <= last; i++)
-	{
+	for (int i = first; i <= last; i++) {
 		int y = ((d->rowHeight * i)-d->offset);
-		QRect r(0, y, width(), d->rowHeight);
 		p.drawRect(r);
-		style().drawPrimitive( QStyle::PE_HeaderSection, &p, r,
-			(d->currentRow == i) ? selectedColorGroup : (d->highlightedRow == i ? highlightedColorGroup : colorGroup()), 
-			QStyle::Style_Raised | (isEnabled() ? QStyle::Style_Enabled : 0));
+		QStyleOptionHeader optionHeader;
+		optionHeader.initFrom(this);
+		optionHeader.orientation = Qt::Vertical;
+		optionHeader.rect = QRect(0, y, width(), d->rowHeight);
+////		optionHeader.state = QStyle::State_Raised;
+		// alter background for selected or highlighted row
+		QColor alteredColor;
+//! @todo Qt4: blend entire QBrush?
+		if (d->currentRow == i)
+			alteredColor = KexiUtils::blendedColors(
+				palette().color(QPalette::Window), d->selectionBackgroundColor, 2, 1);
+		else if (d->highlightedRow == i)
+			alteredColor = KexiUtils::blendedColors(
+				palette().color(QPalette::Window), d->selectionBackgroundColor, 4, 1);
+
+		if (alteredColor.isValid()) {
+			optionHeader.palette.setColor(QPalette::Button, alteredColor);
+			//set background color as well (e.g. for thinkeramik)
+			optionHeader.palette.setColor(QPalette::Window, alteredColor);
+		}
+		style()->drawControl( QStyle::CE_HeaderSection, &optionHeader, &p );
 	}
 	if (d->editRow!=-1 && d->editRow >= first && d->editRow <= (last/*+1 for insert row*/)) {
 		//show pen when editing
 		int ofs = d->rowHeight / 4;
 		int pos = ((d->rowHeight*(d->currentRow>=0?d->currentRow:0))-d->offset)-ofs/2+1;
-		p.drawImage((d->rowHeight-KexiRecordMarker_pen->width())/2,
-			(d->rowHeight-KexiRecordMarker_pen->height())/2+pos,*KexiRecordMarker_pen);
+		p.drawImage((d->rowHeight-KexiRecordMarker_static->pen.width())/2,
+			(d->rowHeight-KexiRecordMarker_static->pen.height())/2+pos, KexiRecordMarker_static->pen);
 	}
 	else if (d->currentRow >= first && d->currentRow <= last 
 		&& (!d->showInsertRow || (d->showInsertRow && d->currentRow < last)))/*don't display marker for 'insert' row*/ 
 	{
 		//show marker
-		p.setBrush(colorGroup().foreground());
+		p.setBrush( palette().brush(foregroundRole()) );
 		p.setPen(QPen(Qt::NoPen));
-		QPointArray points(3);
+		QPolygon points(3);
 		int ofs = d->rowHeight / 4;
 		int ofs2 = (width() - ofs) / 2 -1;
 		int pos = ((d->rowHeight*d->currentRow)-d->offset)-ofs/2+2;
 		points.putPoints(0, 3, ofs2, pos+ofs, ofs2 + ofs, pos+ofs*2, 
 			ofs2,pos+ofs*3);
 		p.drawPolygon(points);
-//		kdDebug() <<"KexiRecordMarker::paintEvent(): POLYGON" << endl;
+//		kDebug() <<"KexiRecordMarker::paintEvent(): POLYGON" << endl;
 /*		int half = d->rowHeight / 2;
 		points.setPoints(3, 2, pos + 2, width() - 5, pos + half, 2, pos + (2 * half) - 2);*/
 	}
 	if (d->showInsertRow && d->editRow < last
 		&& last == (d->rows-1+(d->showInsertRow?1:0)) ) {
 		//show plus sign
-		int pos = ((d->rowHeight*last)-d->offset)+(d->rowHeight-KexiRecordMarker_plus->height())/2;
+		int pos = ((d->rowHeight*last)-d->offset)+(d->rowHeight-KexiRecordMarker_static->plus.height())/2;
 //		p.drawImage((width()-d->plusImg.width())/2-1, pos, d->plusImg);
-		p.drawImage((width()-KexiRecordMarker_plus->width())/2, pos, *KexiRecordMarker_plus);
+		p.drawImage((width()-KexiRecordMarker_static->plus.width())/2, pos, KexiRecordMarker_static->plus);
 	}
 }
 
