@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include "kexisharedactionclient.h"
@@ -22,7 +22,6 @@
 #include <kaction.h>
 
 KexiSharedActionClient::KexiSharedActionClient()
- : m_sharedActions(101, false)
 {
 }
 
@@ -30,10 +29,10 @@ KexiSharedActionClient::~KexiSharedActionClient()
 {
 }
 
-void KexiSharedActionClient::plugSharedAction(KAction* a)
+void KexiSharedActionClient::plugSharedAction(QAction* a)
 {
 	if (!a)
 		return;
-	m_sharedActions.insert(a->name(), a);
+	m_sharedActions.insert(a->objectName(), a);
 }
 
