@@ -14,17 +14,21 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef KFORMULAWIDGET_H
 #define KFORMULAWIDGET_H
 
-#include <qdom.h>
-#include <qpixmap.h>
-#include <qpoint.h>
-#include <qwidget.h>
+#include <QDomDocument>
+#include <QPixmap>
+#include <QPoint>
+#include <QWidget>
+#include <QMouseEvent>
+#include <QFocusEvent>
+#include <QKeyEvent>
+#include <QPaintEvent>
 
 #include <kformuladefs.h>
 #include <kformulaview.h>
@@ -45,7 +49,7 @@ class KFormulaWidget : public QWidget {
     Q_OBJECT
 
 public:
-    KFormulaWidget(KFormula::Container*, QWidget* parent=0, const char* name=0, WFlags f=0);
+    explicit KFormulaWidget( KFormula::Container*, QWidget* parent=0, const char* name=0, Qt::WFlags f=0 );
     ~KFormulaWidget();
 
 
@@ -78,7 +82,7 @@ protected slots:
     /**
      * The formula has changed and needs to be redrawn.
      */
-    void slotFormulaChanged(int width, int height);
+    void slotFormulaChanged( double width, double height );
 
     void slotCursorChanged(bool visible, bool selecting);
 
