@@ -14,10 +14,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 #include "kivio_canvas.h"
-#include "kivio_guidelines.h"
 #include "kivio_page.h"
 #include "kivio_map.h"
 #include "kivio_view.h"
@@ -30,6 +29,7 @@
 #include "kivio_stackbar.h"
 #include "kivio_screen_painter.h"
 #include "kivio_grid_data.h"
+#include "kivio_layer.h"
 
 #include "kivio_pluginmanager.h"
 
@@ -37,17 +37,17 @@
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kcursor.h>
-#include <koGlobal.h>
-#include <kozoomhandler.h>
-#include <koSize.h>
-#include <koRuler.h>
-#include <koPoint.h>
-#include <kotabbar.h>
+#include <KoGlobal.h>
+#include <KoZoomHandler.h>
+#include <KoSize.h>
+#include <KoRuler.h>
+#include <KoPoint.h>
+#include <KoTabBar.h>
 #include <kapplication.h>
 
 #include <assert.h>
 #include <stdio.h>
-#include <qlabel.h>
+#include <QLabel>
 #include <qpixmap.h>
 #include <qscrollbar.h>
 #include <qtimer.h>
@@ -60,7 +60,8 @@ KivioCanvas::KivioCanvas( QWidget *par, KivioView* view, KivioDoc* doc, QScrollB
   m_pView(view),
   m_pDoc(doc),
   m_pVertScrollBar(vs),
-  m_pHorzScrollBar(hs)
+  m_pHorzScrollBar(hs),
+  m_guides(view, view->zoomHandler())
 {
   setBackgroundMode(NoBackground);
   setAcceptDrops(true);
@@ -68,9 +69,8 @@ KivioCanvas::KivioCanvas( QWidget *par, KivioView* view, KivioDoc* doc, QScrollB
   setFocusPolicy(StrongFocus);
   setFocus();
 
+  m_showConnectorTargets = false;
   delegateThisEvent = true;
-  storedCursor = 0;
-  pressGuideline = 0;
 
   m_pVertScrollBar->setLineStep(1);
   m_pHorzScrollBar->setLineStep(1);
@@ -88,6 +88,9 @@ KivioCanvas::KivioCanvas( QWidget *par, KivioView* view, KivioDoc* doc, QScrollB
   m_pScrollX = 0;
   m_pScrollY = 0;
 
+  m_pageOffsetX = 0;
+  m_pageOffsetY = 0;
+
   m_pasteMoving = false;
 
   m_buffer = new QPixmap();
@@ -98,17 +101,12 @@ KivioCanvas::KivioCanvas( QWidget *par, KivioView* view, KivioDoc* doc, QScrollB
 
   m_borderTimer = new QTimer(this);
   connect(m_borderTimer,SIGNAL(timeout()),SLOT(borderTimerTimeout()));
-
-  m_guideLinesTimer = new QTimer(this);
-  connect(m_guideLinesTimer,SIGNAL(timeout()),SLOT(guideLinesTimerTimeout()));
 }
 
 KivioCanvas::~KivioCanvas()
 {
   delete m_buffer;
   delete m_borderTimer;
-  delete m_guideLinesTimer;
-  delete storedCursor;
   delete unclippedPainter;
 }
 
@@ -129,8 +127,6 @@ KivioPage* KivioCanvas::activePage()
 
 void KivioCanvas::scrollH( int value )
 {
-  eraseGuides();
-
   // Relative movement
   int dx = m_iXOffset - value;
   // New absolute position
@@ -144,8 +140,6 @@ void KivioCanvas::scrollH( int value )
 
 void KivioCanvas::scrollV( int value )
 {
-  eraseGuides();
-
   // Relative movement
   int dy = m_iYOffset - value;
   // New absolute position
@@ -177,7 +171,6 @@ void KivioCanvas::scrollDy( int dy )
 
 void KivioCanvas::resizeEvent( QResizeEvent* )
 {
-  KivioGuideLines::resize(size(),m_pDoc);
   m_buffer->resize(size());
   updateScrollBars();
 
@@ -190,9 +183,9 @@ void KivioCanvas::wheelEvent( QWheelEvent* ev )
   
   if( (ev->delta()>0))
   {
-     if(ev->state() == ControlButton) {
+     if(ev->state() == Qt::ControlButton) {
        zoomIn(ev->pos());
-     } else if(ev->state() == ShiftButton) {
+     } else if(ev->state() == Qt::ShiftButton) {
        m_pVertScrollBar->setValue(m_pVertScrollBar->value() - height());
      } else {
        m_pVertScrollBar->setValue(m_pVertScrollBar->value() - 30);
@@ -200,9 +193,9 @@ void KivioCanvas::wheelEvent( QWheelEvent* ev )
   }
   else
   {
-     if(ev->state() == ControlButton) {
+     if(ev->state() == Qt::ControlButton) {
        zoomOut(ev->pos());
-     } else if(ev->state() == ShiftButton) {
+     } else if(ev->state() == Qt::ShiftButton) {
        m_pVertScrollBar->setValue(m_pVertScrollBar->value() + height());
      } else {
        m_pVertScrollBar->setValue(m_pVertScrollBar->value() + 30);
@@ -263,7 +256,6 @@ void KivioCanvas::paintEvent( QPaintEvent* ev )
     return;
 
   KivioPage* page = activePage();
-  eraseGuides();
 
   QPainter painter;
   painter.begin(m_buffer);
@@ -274,9 +266,9 @@ void KivioCanvas::paintEvent( QPaintEvent* ev )
   QRect fillRect(0, 0, pw, ph);
   QRect paintRect = ev->rect();
   QRegion grayRegion(paintRect);
-  grayRegion.translate(m_iXOffset, m_iYOffset);
+  grayRegion.translate(m_iXOffset - m_pageOffsetX, m_iYOffset - m_pageOffsetY);
   grayRegion -= fillRect;
-  grayRegion.translate(-m_iXOffset, -m_iYOffset);
+  grayRegion.translate(-m_iXOffset + m_pageOffsetX, -m_iYOffset + m_pageOffsetY);
 
   // This code comes from KPresenter's kprcanvas.cpp
   // Copyright (C) 1998, 1999 Reginald Stadlbauer <reggie@kde.org>
@@ -287,50 +279,46 @@ void KivioCanvas::paintEvent( QPaintEvent* ev )
   painter.restore();
   // end of copy...
 
-  painter.translate(-m_iXOffset, -m_iYOffset);
+  painter.translate(-m_iXOffset + m_pageOffsetX, -m_iYOffset +m_pageOffsetY);
   painter.fillRect(fillRect, white);
 
   // Draw Grid
-  if (m_pDoc->grid().isShow) {
-    int x = paintRect.x();
-    int y = paintRect.y();
-    int w = QMIN(x + paintRect.width() + m_iXOffset, pw);
-    int h = QMIN(y + paintRect.height() + m_iYOffset, ph);
+  if(m_pDoc->grid().isShow) {
+    KoPoint topLeft(0, 0);
+    KoPoint bottomRight(pl.ptWidth, pl.ptHeight);
+    QPoint zoomedTL = m_pView->zoomHandler()->zoomPoint(topLeft);
+    QPoint zoomedBR = m_pView->zoomHandler()->zoomPoint(bottomRight);
+
+    KoSize freq = m_pDoc->grid().freq;
 
-    QSize dxy = m_pView->zoomHandler()->zoomSize(m_pDoc->grid().freq);
-    
-    if(m_pView->zoomHandler()->zoom() >= 150) {
-      dxy = dxy / 2;
-    } else if(m_pView->zoomHandler()->zoom() <= 50) {
-      dxy = dxy * 2;
-    }
-    
     painter.setPen(m_pDoc->grid().color);
-    
-    x = qRound(x / dxy.width()) * dxy.width();
 
-    while (x <= w) {
-      painter.drawLine(x, y, x, h);
-      x += dxy.width();
+    double x = qRound(topLeft.x() / freq.width()) * freq.width();
+    int zoomed = 0;
+
+    while(x <= bottomRight.x()) {
+      zoomed = m_pView->zoomHandler()->zoomItX(x);
+      painter.drawLine(zoomed, zoomedTL.y(), zoomed, zoomedBR.y());
+      x += freq.width();
     }
 
-    x = paintRect.x();
-    y = qRound(y / dxy.height()) * dxy.height();
+    double y = qRound(topLeft.y() / freq.height()) * freq.height();
 
-    while (y <= h) {
-      painter.drawLine(x, y, w, y);
-      y += dxy.height();
+    while(y <= bottomRight.y()) {
+      zoomed = m_pView->zoomHandler()->zoomItY(y);
+      painter.drawLine(zoomedTL.x(), zoomed, zoomedBR.x(), zoomed);
+      y += freq.height();
     }
   }
 
-  if (m_pView->isShowPageMargins()) {
+  if(m_pView->isShowPageMargins()) {
     int ml = m_pView->zoomHandler()->zoomItX(pl.ptLeft);
     int mt = m_pView->zoomHandler()->zoomItY(pl.ptTop);
     int mr = m_pView->zoomHandler()->zoomItX(pl.ptRight);
     int mb = m_pView->zoomHandler()->zoomItY(pl.ptBottom);
 
     painter.save();
-    painter.setPen(QPen(blue,1,DotLine));
+    painter.setPen(QPen("#C7C7C7",1,SolidLine));
     painter.drawRect(ml,mt,pw-ml-mr,ph-mt-mb);
     painter.restore();
   }
@@ -343,12 +331,15 @@ void KivioCanvas::paintEvent( QPaintEvent* ev )
 
   // Draw content
   KivioScreenPainter kpainter;
-  kpainter.start( m_buffer );
-  kpainter.translateBy( -m_iXOffset, -m_iYOffset );
-  m_pDoc->paintContent(kpainter, paintRect, false, page, QPoint(0, 0), m_pView->zoomHandler(), true);
+  kpainter.start(m_buffer);
+  kpainter.translateBy(-m_iXOffset + m_pageOffsetX, -m_iYOffset + m_pageOffsetY);
+  m_pDoc->paintContent(kpainter, paintRect, false, page, QPoint(0, 0), m_pView->zoomHandler(), showConnectorTargets(), true);
   kpainter.stop();
 
-  paintGuides(false);
+  if(m_pView->isShowGuides()) {
+    m_guides.paintGuides(painter);
+  }
+
   painter.end();
 
   bitBlt(this, paintRect.left(), paintRect.top(), m_buffer,
@@ -357,9 +348,16 @@ void KivioCanvas::paintEvent( QPaintEvent* ev )
 
 void KivioCanvas::updateScrollBars()
 {
+  if(!activePage()) {
+    return;
+  }
+
   KoPageLayout pl = activePage()->paperLayout();
-  m_pScrollX = QMAX(m_pView->zoomHandler()->zoomItX(pl.ptWidth) - width(), 0);
-  m_pScrollY = QMAX(m_pView->zoomHandler()->zoomItY(pl.ptHeight) - height(), 0);
+  int pw = m_pView->zoomHandler()->zoomItX(pl.ptWidth);
+  int ph = m_pView->zoomHandler()->zoomItY(pl.ptHeight);
+
+  m_pScrollX = qMax(pw - width(), 0);
+  m_pScrollY = qMax(ph - height(), 0);
 
   m_pHorzScrollBar->setRange(0, m_pScrollX);
   if ( m_pHorzScrollBar->value() > m_pHorzScrollBar->maxValue() ||
@@ -377,9 +375,21 @@ void KivioCanvas::updateScrollBars()
 
   m_pVertScrollBar->setPageStep( height() );
   m_pHorzScrollBar->setPageStep( width() );
+
+  if(pw >= width()) {
+    m_pageOffsetX = 0;
+  } else {
+    m_pageOffsetX = (width() - pw) / 2;
+  }
+
+  if(ph >= height()) {
+    m_pageOffsetY = 0;
+  } else {
+    m_pageOffsetY = (height() - ph) / 2;
+  }
 }
 
-QSize KivioCanvas::actualSize()
+QSize KivioCanvas::actualSize() const
 {
   return QSize(m_pScrollX, m_pScrollY);
 }
@@ -409,46 +419,19 @@ void KivioCanvas::mousePressEvent(QMouseEvent* e)
 {
     if(!m_pDoc->isReadWrite())
         return;
+
     if(m_pasteMoving) {
       endPasteMoving();
       return;
     }
 
-    if(m_pView->isShowGuides())
-    {
-        lastPoint = e->pos();
-        KoPoint p = mapFromScreen(e->pos());
-        KivioGuideLines* gl = activePage()->guideLines();
+    Kivio::PluginManager* pluginManager = view()->pluginManager();
 
-        bool unselectAllGuideLines = true;
-        pressGuideline = 0;
-
-        if ((e->state() & ~ShiftButton) == NoButton) {
-            KivioGuideLineData* gd = gl->find(p.x(),p.y(), m_pView->zoomHandler()->unzoomItY(2));
-            if (gd) {
-                pressGuideline = gd;
-                if ((e->button() == RightButton) || ((e->button() & ShiftButton) == ShiftButton)) {
-                    if (gd->isSelected())
-                        gl->unselect(gd);
-                    else
-                        gl->select(gd);
-                } else {
-                    if (!gd->isSelected()) {
-                        gl->unselectAll();
-                        gl->select(gd);
-                    }
-                }
-                unselectAllGuideLines = false;
-                delegateThisEvent = false;
-                updateGuides();
-                m_guideLinesTimer->start(500,true);
-            }
-        }
-
-        if (unselectAllGuideLines && gl->hasSelected()) {
-            gl->unselectAll();
-            updateGuides();
-        }
+    if(m_pView->isShowGuides() && (!pluginManager || (pluginManager->defaultTool() == pluginManager->activeTool()))) {
+      if(m_guides.mousePressEvent(e)) {
+        delegateThisEvent = false;
+        return;
+      }
     }
 }
 
@@ -457,29 +440,13 @@ void KivioCanvas::mouseReleaseEvent(QMouseEvent* e)
   if(!m_pDoc->isReadWrite())
     return;
 
-  if (pressGuideline) {
-    m_guideLinesTimer->stop();
-    KoPoint p = mapFromScreen(e->pos());
-    bool insideCanvas = geometry().contains(mapFromGlobal(e->globalPos()));
-    KivioGuideLines* gl = activePage()->guideLines();
+  Kivio::PluginManager* pluginManager = view()->pluginManager();
 
-    if(!insideCanvas) {
-      eraseGuides();
-      gl->remove(pressGuideline);
-      paintGuides();
+  if(view()->isShowGuides() && (!pluginManager || (pluginManager->defaultTool() == pluginManager->activeTool()))) {
+    if(m_guides.mouseReleaseEvent(e)) {
       delegateThisEvent = false;
-      pressGuideline = 0;
       return;
     }
-
-    KivioGuideLineData* gd = gl->find(p.x(),p.y(),m_pView->zoomHandler()->unzoomItY(2));
-    if (gd) {
-      setCursor(gd->orientation()==Qt::Vertical ? sizeHorCursor:sizeVerCursor);
-    } else {
-      updateGuidesCursor();
-    }
-    delegateThisEvent = false;
-    pressGuideline = 0;
   }
 }
 
@@ -491,63 +458,33 @@ void KivioCanvas::mouseMoveEvent(QMouseEvent* e)
   if(m_pasteMoving) {
     continuePasteMoving(e->pos());
   } else {
-    if(m_pView->isShowGuides())
-    {
-      m_pView->setMousePos(e->pos().x(),e->pos().y());
+    Kivio::PluginManager* pluginManager = view()->pluginManager();
 
-      KivioGuideLines* gl = activePage()->guideLines();
-
-      if ((e->state() & LeftButton == LeftButton) && gl->hasSelected()) {
-        if (m_guideLinesTimer->isActive()) {
-          m_guideLinesTimer->stop();
-          guideLinesTimerTimeout();
-        }
-        delegateThisEvent = false;
-        eraseGuides();
-        QPoint p = e->pos();
-        p -= lastPoint;
-        if (p.x() != 0)
-          gl->moveSelectedByX(m_pView->zoomHandler()->unzoomItX(p.x()));
-        if (p.y() != 0)
-          gl->moveSelectedByY(m_pView->zoomHandler()->unzoomItY(p.y()));
-        m_pDoc->setModified( true );
-        paintGuides();
-      } else {
-        if ((e->state() & ~ShiftButton) == NoButton) {
-          KoPoint p = mapFromScreen(e->pos());
-          KivioGuideLineData* gd = gl->find(p.x(), p.y(), m_pView->zoomHandler()->unzoomItY(2));
-          if (gd) {
-            delegateThisEvent = false;
-            if (!storedCursor)
-              storedCursor = new QCursor(cursor());
-            setCursor(gd->orientation()==Qt::Vertical ? sizeHorCursor:sizeVerCursor);
-          } else {
-            updateGuidesCursor();
-          }
-        }
-      }
+    if(m_pView->isShowGuides() && (!pluginManager || (pluginManager->defaultTool() == pluginManager->activeTool()))) {
+      delegateThisEvent = !m_guides.mouseMoveEvent(e);
     }
   }
 
   lastPoint = e->pos();
+  view()->setMousePos(lastPoint.x(), lastPoint.y());
 }
 
-QPoint KivioCanvas::mapToScreen( KoPoint pos )
+QPoint KivioCanvas::mapToScreen(const KoPoint& pos)
 {
   QPoint p;
   int x = m_pView->zoomHandler()->zoomItX(pos.x());
   int y = m_pView->zoomHandler()->zoomItY(pos.y());
 
-  p.setX( x - m_iXOffset );
-  p.setY( y - m_iYOffset );
+  p.setX( x - m_iXOffset + m_pageOffsetX);
+  p.setY( y - m_iYOffset + m_pageOffsetY);
 
   return p;
 }
 
 KoPoint KivioCanvas::mapFromScreen( const QPoint & pos )
 {
-  int x = pos.x() + m_iXOffset;
-  int y = pos.y() + m_iYOffset;
+  int x = pos.x() + m_iXOffset - m_pageOffsetX;
+  int y = pos.y() + m_iYOffset - m_pageOffsetY;
   double xf = m_pView->zoomHandler()->unzoomItX(x);
   double yf = m_pView->zoomHandler()->unzoomItY(y);
 
@@ -619,7 +556,7 @@ void KivioCanvas::startSpawnerDragDraw( const QPoint &p )
   // do so now.
   if( m_pDragStencil )
   {
-    kdDebug(43000) << "KivioCanvas::startSpawnerDragDraw() - m_pDragStencil still exists.  BUG!" << endl;
+    kDebug(43000) <<"KivioCanvas::startSpawnerDragDraw() - m_pDragStencil still exists.  BUG!";
     delete m_pDragStencil;
     m_pDragStencil = 0L;
   }
@@ -640,7 +577,7 @@ void KivioCanvas::startSpawnerDragDraw( const QPoint &p )
 
   // Translate the painter so that 0,0 means where the page starts on the canvas
   unclippedSpawnerPainter->painter()->save();
-  unclippedSpawnerPainter->painter()->translate( -m_iXOffset, -m_iYOffset );
+  unclippedSpawnerPainter->painter()->translate(-m_iXOffset + m_pageOffsetX, -m_iYOffset + m_pageOffsetY);
 
   // Assign the painter object to the intra-stencil data object, as well
   // as the zoom factor
@@ -662,7 +599,7 @@ void KivioCanvas::continueSpawnerDragDraw( const QPoint &p )
 
   // Translate the painter so that 0,0 means where the page starts on the canvas
   unclippedSpawnerPainter->painter()->save();
-  unclippedSpawnerPainter->painter()->translate( -m_iXOffset, -m_iYOffset );
+  unclippedSpawnerPainter->painter()->translate(-m_iXOffset + m_pageOffsetX, -m_iYOffset + m_pageOffsetY);
 
   // Undraw the old outline
   if( oldRectValid )
@@ -690,6 +627,17 @@ void KivioCanvas::continueSpawnerDragDraw( const QPoint &p )
     m_pDragStencil->setY(qp.y() - m_pDragStencil->h());
   }
 
+  qp.setCoords(orig.x() + (m_pDragStencil->w() / 2.0), orig.y() + (m_pDragStencil->h() / 2.0));
+  qp = snapToGuides(qp, snappedX, snappedY);
+
+  if(snappedX) {
+    m_pDragStencil->setX(qp.x() - (m_pDragStencil->w() / 2.0));
+  }
+
+  if(snappedY) {
+    m_pDragStencil->setY(qp.y() - (m_pDragStencil->h() / 2.0));
+  }
+
   qp.setCoords(orig.x(), orig.y());
   qp = snapToGuides(qp, snappedX, snappedY);
 
@@ -722,7 +670,7 @@ void KivioCanvas::endSpawnerDragDraw()
   if ( oldRectValid )
   {
     unclippedSpawnerPainter->painter()->save();
-    unclippedSpawnerPainter->painter()->translate( -m_iXOffset, -m_iYOffset );
+    unclippedSpawnerPainter->painter()->translate(-m_iXOffset + m_pageOffsetX, -m_iYOffset + m_pageOffsetY);
     m_pDragStencil->paintOutline( &m_dragStencilData );
     unclippedSpawnerPainter->painter()->restore();
   }
@@ -828,25 +776,25 @@ void KivioCanvas::borderTimerTimeout()
   int hmin = m_pHorzScrollBar->minValue();
 
   if ( p.x() < 0 && hpos > hmin ) {
-    dx = QMIN(d,hpos-hmin);
+    dx = qMin(d,hpos-hmin);
     r.setRight(r.right()+dx);
     rectAnchor.setX(rectAnchor.x()+dx);
   }
 
   if ( p.y() < 0 && vpos > vmin ) {
-    dy = QMIN(d,vpos-vmin);
+    dy = qMin(d,vpos-vmin);
     r.setBottom(r.bottom()+dy);
     rectAnchor.setY(rectAnchor.y()+dy);
   }
 
   if ( p.x() > width() && hpos < hmax ) {
-    dx = -QMIN(d,hmax-hpos);
+    dx = -qMin(d,hmax-hpos);
     r.setLeft(r.left()+dx);
     rectAnchor.setX(rectAnchor.x()+dx);
   }
 
   if ( p.y() > height() && vpos < vmax  ) {
-    dy = -QMIN(d,vmax-vpos);
+    dy = -qMin(d,vmax-vpos);
     r.setTop(r.top()+dy);
     rectAnchor.setY(rectAnchor.y()+dy);
   }
@@ -877,6 +825,8 @@ void KivioCanvas::dragEnterEvent( QDragEnterEvent *e )
     {
         e->accept();
         startSpawnerDragDraw( e->pos() );
+        activePage()->unselectAllStencils();
+        updateAutoGuideLines();
     }
 }
 
@@ -954,7 +904,7 @@ void KivioCanvas::drawSelectedStencilsXOR()
 
     // Translate the painter so that 0,0 means where the page starts on the canvas
     unclippedSpawnerPainter->painter()->save();
-    unclippedSpawnerPainter->painter()->translate( -m_iXOffset, -m_iYOffset );
+    unclippedSpawnerPainter->painter()->translate(-m_iXOffset + m_pageOffsetX, -m_iYOffset + m_pageOffsetY);
 
     // Assign the painter object to the intra-stencil data object, as well
     // as the zoom factor
@@ -981,7 +931,7 @@ void KivioCanvas::drawStencilXOR( KivioStencil *pStencil )
 
     // Translate the painter so that 0,0 means where the page starts on the canvas
     unclippedSpawnerPainter->painter()->save();
-    unclippedSpawnerPainter->painter()->translate( -m_iXOffset, -m_iYOffset );
+    unclippedSpawnerPainter->painter()->translate(-m_iXOffset + m_pageOffsetX, -m_iYOffset + m_pageOffsetY);
 
     // Assign the painter object to the intra-stencil data object, as well
     // as the zoom factor
@@ -994,43 +944,34 @@ void KivioCanvas::drawStencilXOR( KivioStencil *pStencil )
     unclippedSpawnerPainter->painter()->restore();
 }
 
-void KivioCanvas::keyReleaseEvent( QKeyEvent *e )
+void KivioCanvas::keyPressEvent( QKeyEvent *e )
 {
-    switch( e->key() )
-    {
-        case Key_Delete: {
-            KivioGuideLines* gl = activePage()->guideLines();
-            if (gl->hasSelected()) {
-              eraseGuides();
-              gl->removeSelected();
-              paintGuides();
-              updateGuidesCursor();
-              m_pDoc->setModified( true );
-            } else {
-              activePage()->deleteSelectedStencils();
-              m_pDoc->updateView(activePage());
-            }
-            break;
-        }
-        case Key_Escape: {
-            m_pView->pluginManager()->activateDefaultTool();
-        }break;
-    }
+  if(view()->isShowGuides() && m_guides.keyPressEvent(e)) {
+    return;
+  }
 }
 
-KoPoint KivioCanvas::snapToGridAndGuides(KoPoint point)
+KoPoint KivioCanvas::snapToGridAndGuides(const KoPoint& point)
 {
   KoPoint p = point;
 
   p = snapToGrid(p);
 
   bool snappedX, snappedY;
-  p = snapToGuides(p, snappedX, snappedY);
+  KoPoint guidePoint = snapToGuides(point, snappedX, snappedY);
+
+  if(snappedX) {
+    p.setX(guidePoint.x());
+  }
+
+  if(snappedY) {
+    p.setY(guidePoint.y());
+  }
 
   return p;
 }
 
-KoPoint KivioCanvas::snapToGrid(KoPoint point)
+KoPoint KivioCanvas::snapToGrid(const KoPoint& point)
 {
   if (!m_pDoc->grid().isSnap)
     return point;
@@ -1040,30 +981,24 @@ KoPoint KivioCanvas::snapToGrid(KoPoint point)
   KoSize dist = m_pDoc->grid().snap;
   KoSize freq = m_pDoc->grid().freq;
 
-  if(m_pView->zoomHandler()->zoom() >= 150) {
-    freq = freq / 2;
-  } else if(m_pView->zoomHandler()->zoom() <= 50) {
-    freq = freq * 2;
-  }
+  double dx = qRound(p.x() / freq.width());
+  double dy = qRound(p.y() / freq.height());
 
-  int dx = qRound(p.x() / freq.width());
-  int dy = qRound(p.y() / freq.height());
-
-  double distx = QABS(p.x() - freq.width() * dx);
-  double disty = QABS(p.y() - freq.height() * dy);
+  double distx = QABS(p.x() - (freq.width() * dx));
+  double disty = QABS(p.y() - (freq.height() * dy));
 
   if(distx < dist.width()) {
-    p.setX(m_pView->zoomHandler()->unzoomItX(m_pView->zoomHandler()->zoomItX(freq.width()) * dx));
+    p.setX(freq.width() * dx);
   }
 
   if(disty < dist.height()) {
-    p.setY(m_pView->zoomHandler()->unzoomItY(m_pView->zoomHandler()->zoomItY(freq.height()) * dy));
+    p.setY(freq.height() * dy);
   }
 
   return p;
 }
 
-KoPoint KivioCanvas::snapToGuides(KoPoint point, bool &snappedX, bool &snappedY)
+KoPoint KivioCanvas::snapToGuides(const KoPoint& point, bool &snappedX, bool &snappedY)
 {
   snappedX = false;
   snappedY = false;
@@ -1071,176 +1006,32 @@ KoPoint KivioCanvas::snapToGuides(KoPoint point, bool &snappedX, bool &snappedY)
 
   if (m_pView->isSnapGuides())
   {
-    double four = m_pView->zoomHandler()->unzoomItY(4);
-    KivioGuideLines *pGuides = activePage()->guideLines();
-    KivioGuideLineData *pData = pGuides->findHorizontal( point.y(), four );
+    KoGuides::SnapStatus status = KoGuides::SNAP_NONE;
+    KoPoint diff;
+    m_guides.snapToGuideLines(p, 4, status, diff);
+    p += diff;
 
-    if(pData)
-    {
+    if(status & KoGuides::SNAP_HORIZ) {
       snappedY = true;
-      p.ry() = pData->position();
     }
-
-    pData = pGuides->findVertical( point.x(), four );
-
-    if(pData)
-    {
+    if(status & KoGuides::SNAP_VERT) {
       snappedX = true;
-      p.rx() = pData->position();
     }
+
+    m_guides.repaintSnapping(p, status);
   }
 
   return p;
 }
 
-double KivioCanvas::snapToGridX(double z)
-{
-  KoPoint p(z, 0);
-  return snapToGrid(p).x();
-}
-
-double KivioCanvas::snapToGridY(double z)
-{
-  KoPoint p(0, z);
-  return snapToGrid(p).y();
-}
-
-void KivioCanvas::updateGuides()
-{
-  eraseGuides();
-  paintGuides();
-}
-
-void KivioCanvas::guideLinesTimerTimeout()
-{
-  if (!storedCursor) {
-    storedCursor = new QCursor(cursor());
-  }
-
-  setCursor(sizeAllCursor);
-}
-
-void KivioCanvas::updateGuidesCursor()
-{
-  if (storedCursor) {
-    setCursor(*storedCursor);
-    delete storedCursor;
-    storedCursor = 0;
-  }
-}
-
-bool KivioCanvas::eventFilter(QObject* o, QEvent* e)
-{
-  if ((o == view()->vertRuler() || o == view()->horzRuler()) && (e->type() == QEvent::MouseMove || e->type() ==
-    QEvent::MouseButtonRelease) && m_pView->isShowGuides())
-  {
-    QMouseEvent* me = (QMouseEvent*)e;
-    QPoint p = mapFromGlobal(me->globalPos());
-    KivioGuideLines* gl = activePage()->guideLines();
-
-    if (e->type() == QEvent::MouseMove) {
-      bool f = geometry().contains(p);
-      if (!pressGuideline && f && (me->state() == QMouseEvent::LeftButton)) {
-        enterEvent(0);
-
-        eraseGuides();
-        gl->unselectAll();
-        KivioGuideLineData* gd;
-        KoPoint tp = mapFromScreen(p);
-
-        if (o == view()->vertRuler()) {
-          gd = gl->add(tp.x(),Qt::Vertical);
-        } else {
-          gd = gl->add(tp.y(),Qt::Horizontal);
-        }
-
-        pressGuideline = gd;
-        gl->select(gd);
-        paintGuides();
-
-        updateGuidesCursor();
-        QWidget* w = (QWidget*)o;
-        storedCursor = new QCursor(w->cursor());
-        w->setCursor(sizeAllCursor);
-
-        lastPoint = p;
-      } else if (pressGuideline && !f) {
-        leaveEvent(0);
-
-        eraseGuides();
-        gl->remove(pressGuideline);
-        paintGuides();
-
-        if (storedCursor) {
-          QWidget* w = (QWidget*)o;
-          w->setCursor(*storedCursor);
-          delete storedCursor;
-          storedCursor = 0;
-        }
-
-        pressGuideline = 0;
-      } else if (pressGuideline && f) {
-        QMouseEvent* m = new QMouseEvent(QEvent::MouseMove, p, me->globalPos(), me->button(), me->state());
-        mouseMoveEvent(m);
-        delete m;
-        delegateThisEvent = true;
-      }
-    }
-
-    if (e->type() == QEvent::MouseButtonRelease && pressGuideline) {
-      eraseGuides();
-      gl->unselect(pressGuideline);
-      paintGuides();
-
-      pressGuideline = 0;
-      if (storedCursor) {
-        QWidget* w = (QWidget*)o;
-        w->setCursor(*storedCursor);
-        delete storedCursor;
-        storedCursor = 0;
-      }
-      enterEvent(0);
-      QMouseEvent* m = new QMouseEvent(QEvent::MouseMove, p, me->globalPos(), NoButton, NoButton);
-      mouseMoveEvent(m);
-      delete m;
-      delegateThisEvent = true;
-    }
-
-    if(o == view()->vertRuler()) {
-      view()->vertRuler()->update();
-    } else {
-      view()->horzRuler()->update();
-    }
-  }
-
-  return QWidget::eventFilter(o, e);
-}
-
-void KivioCanvas::eraseGuides()
-{
-  KivioGuideLines* gl = activePage()->guideLines();
-  gl->erase(m_buffer,this);
-}
-
-void KivioCanvas::paintGuides(bool show)
-{
-  if (!m_pView->isShowGuides())
-    return;
-
-  KivioGuideLines* gl = activePage()->guideLines();
-  gl->paint(m_buffer,this);
-  if (show)
-    bitBlt(this,0,0,m_buffer);
-}
-
 void KivioCanvas::setViewCenterPoint(const KoPoint &p)
 {
   setUpdatesEnabled(false);
 
   KoRect va = visibleArea();
 
-  float x = QMAX(0, p.x() - (va.width() / 2));
-  float y = QMAX(0, p.y() - (va.height() / 2));
+  double x = qMax(0.0, p.x() - (va.width() / 2.0));
+  double y = qMax(0.0, p.y() - (va.height() / 2.0));
 
   m_pVertScrollBar->setValue(m_pView->zoomHandler()->zoomItY(y));
   m_pHorzScrollBar->setValue(m_pView->zoomHandler()->zoomItX(x));
@@ -1268,7 +1059,7 @@ void KivioCanvas::setVisibleArea(KoRect r, int margin)
 
   float zw = cw / (float)zoom.zoomItX(r.width());
   float zh = ch / (float)zoom.zoomItY(r.height());
-  float z = QMIN(zw, zh);
+  float z = qMin(zw, zh);
 
   m_pView->viewZoom(qRound(z * 100));
 
@@ -1384,6 +1175,17 @@ void KivioCanvas::continuePasteMoving(const QPoint &pos)
     newY = p.y() - selectedRect.height();
   }
 
+  p.setCoords(selectedRect.x() + dx + (selectedRect.width() / 2.0), selectedRect.y() + dy + (selectedRect.height() / 2.0));
+  p = snapToGuides(p, snappedX, snappedY);
+
+  if(snappedX) {
+    newX = p.x() - (selectedRect.width() / 2.0);
+  }
+
+  if(snappedY) {
+    newY = p.y() - (selectedRect.height() / 2.0);
+  }
+
   p.setCoords(selectedRect.x() + dx, selectedRect.y() + dy);
   p = snapToGuides(p, snappedX, snappedY);
 
@@ -1448,4 +1250,42 @@ void KivioCanvas::endPasteMoving()
   m_pasteMoving = false;
 }
 
+void KivioCanvas::updateAutoGuideLines()
+{
+  QValueList<double> hGuideLines;
+  QValueList<double> vGuideLines;
+  QPtrList<KivioLayer> layerList = *(activePage()->layers());
+  QPtrListIterator<KivioLayer> layerIt(layerList);
+  KivioLayer* layer = 0;
+  QPtrList<KivioStencil> stencilList;
+  QPtrListIterator<KivioStencil> stencilIt(stencilList);
+  KivioStencil* stencil = 0;
+
+  while((layer = layerIt.current()) != 0) {
+    ++layerIt;
+
+    if(layer->visible()) {
+      stencilList = *(layer->stencilList());
+      stencilIt.toFirst();
+
+      while((stencil = stencilIt.current()) != 0) {
+        ++stencilIt;
+
+        if(!stencil->isSelected()) {
+          hGuideLines << stencil->y() << (stencil->y() + (stencil->h() / 2.0)) << (stencil->y() + stencil->h());
+          vGuideLines << stencil->x() << (stencil->x() + (stencil->w() / 2.0)) << (stencil->x() + stencil->w());
+        }
+      }
+    }
+  }
+
+  KoPageLayout pl = activePage()->paperLayout();
+
+  // Add the middle of the page and the margins
+  hGuideLines << (pl.ptHeight / 2.0) << pl.ptTop << pl.ptBottom;
+  vGuideLines << (pl.ptWidth / 2.0) << pl.ptLeft << pl.ptRight;
+
+  guideLines().setAutoGuideLines(hGuideLines, vGuideLines);
+}
+
 #include "kivio_canvas.moc"
