@@ -13,22 +13,24 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef kiviocommand_h
 #define kiviocommand_h
 
 #include <kcommand.h>
-#include <qfont.h>
-#include <qcolor.h>
-#include <koRect.h>
-#include <koPageLayout.h>
+#include <QFont>
+#include <QColor>
+#include <qvaluelist.h>
+#include <KoRect.h>
+#include <KoPageLayout.h>
 #include <koffice_export.h>
 class KivioPage;
 class KivioLayer;
 class KivioStencil;
+class KivioGroupStencil;
 struct KoPageLayout;
 
 class KivioChangePageNameCommand : public KNamedCommand
@@ -124,7 +126,7 @@ public:
 class KIVIO_EXPORT KivioChangeStencilTextCommand : public KNamedCommand
 {
 public:
-    KivioChangeStencilTextCommand( const QString &_name, KivioStencil *_stencil, const QString & _oldText, const QString & _newText, KivioPage *_page);
+  KivioChangeStencilTextCommand( const QString &_name, KivioStencil *_stencil, const QString & _oldText, const QString & _newText, KivioPage *_page, const QString& textBoxName = QString::null);
     ~KivioChangeStencilTextCommand();
     virtual void execute();
     virtual void unexecute();
@@ -133,6 +135,7 @@ protected:
     QString oldText;
     QString newText;
     KivioPage *m_page;
+    QString m_textBoxName;
 };
 
 class KivioAddLayerCommand : public KNamedCommand
@@ -225,69 +228,79 @@ protected:
 
 class KivioChangeStencilHAlignmentCommand : public KNamedCommand
 {
-public:
-    KivioChangeStencilHAlignmentCommand( const QString &_name, KivioPage *_page, KivioStencil * _stencil, int _oldAlign,  int _newAlign);
+  public:
+    KivioChangeStencilHAlignmentCommand(const QString& _name, KivioPage* _page, KivioStencil* _stencil,
+                                        int _oldAlign, int _newAlign, const QString& textBoxName = QString::null);
     ~KivioChangeStencilHAlignmentCommand();
 
     virtual void execute();
     virtual void unexecute();
 
-protected:
+  protected:
     KivioPage *m_page;
     KivioStencil *m_stencil;
     int oldAlign;
     int newAlign;
+    QString m_textBoxName;
 };
 
 class KivioChangeStencilVAlignmentCommand : public KNamedCommand
 {
-public:
-    KivioChangeStencilVAlignmentCommand( const QString &_name, KivioPage *_page, KivioStencil * _stencil, int _oldAlign,  int _newAlign);
+  public:
+    KivioChangeStencilVAlignmentCommand(const QString& _name, KivioPage* _page, KivioStencil* _stencil,
+                                        int _oldAlign, int _newAlign, const QString& textBoxName = QString::null);
     ~KivioChangeStencilVAlignmentCommand();
 
     virtual void execute();
     virtual void unexecute();
 
-protected:
+  protected:
     KivioPage *m_page;
     KivioStencil *m_stencil;
     int oldAlign;
     int newAlign;
+    QString m_textBoxName;
 };
 
 
 class KivioChangeStencilFontCommand : public KNamedCommand
 {
-public:
-    KivioChangeStencilFontCommand( const QString &_name, KivioPage *_page, KivioStencil * _stencil, const QFont & _oldFont,  const QFont & _newFont);
+  public:
+    KivioChangeStencilFontCommand(const QString& _name, KivioPage* _page, KivioStencil* _stencil,
+                                  const QFont& _oldFont,  const QFont& _newFont,
+                                  const QString& textBoxName = QString::null);
     ~KivioChangeStencilFontCommand();
 
     virtual void execute();
     virtual void unexecute();
 
-protected:
+  protected:
     KivioPage *m_page;
     KivioStencil *m_stencil;
     QFont oldFont;
     QFont newFont;
+    QString m_textBoxName;
 };
 
 class KivioChangeStencilColorCommand : public KNamedCommand
 {
-public:
+  public:
     enum ColorType { CT_TEXTCOLOR, CT_FGCOLOR, CT_BGCOLOR };
-    KivioChangeStencilColorCommand( const QString &_name, KivioPage *_page, KivioStencil * _stencil, const QColor & _oldColor,  const QColor & _newColor, ColorType _type);
+    KivioChangeStencilColorCommand(const QString& _name, KivioPage* _page, KivioStencil*  _stencil,
+                                   const QColor& _oldColor,  const QColor& _newColor, ColorType _type,
+                                   const QString& textBoxName = QString::null);
     ~KivioChangeStencilColorCommand();
 
     virtual void execute();
     virtual void unexecute();
 
-protected:
+  protected:
     KivioPage *m_page;
     KivioStencil *m_stencil;
     QColor oldColor;
     QColor newColor;
     ColorType type;
+    QString m_textBoxName;
 };
 
 class KivioChangeRotationCommand : public KNamedCommand
@@ -397,6 +410,64 @@ protected:
     bool m_bValue;
 };
 
+class KivioAddConnectorTargetCommand : public KNamedCommand
+{
+  public:
+    KivioAddConnectorTargetCommand(const QString& name, KivioPage* page,
+                                   KivioStencil* stencil, const KoPoint& targetPoint);
+
+    virtual void execute();
+    virtual void unexecute();
+
+  protected:
+    KivioPage* m_page;
+    KivioStencil* m_stencil;
+    KoPoint m_targetPoint;
+};
+
+class KivioCustomDragCommand : public KNamedCommand
+{
+  public:
+    KivioCustomDragCommand(const QString& name, KivioPage* page, KivioStencil* stencil,
+                           int customID, const KoPoint& originalPoint, const KoPoint& newPoint);
+
+    virtual void execute();
+    virtual void unexecute();
+
+  protected:
+    KivioPage* m_page;
+    KivioStencil* m_stencil;
+
+    int m_customID;
+    KoPoint m_originalPoint;
+    KoPoint m_newPoint;
+};
+
+class KivioGroupCommand : public KNamedCommand
+{
+  public:
+    KivioGroupCommand(const QString& name, KivioPage* page, KivioLayer* layer, KivioGroupStencil* group);
+
+    virtual void execute();
+    virtual void unexecute();
+
+  protected:
+    KivioPage* m_page;
+    KivioLayer* m_layer;
+
+    KivioGroupStencil* m_groupStencil;
+};
+
+class KivioUnGroupCommand : public KivioGroupCommand
+{
+  public:
+    KivioUnGroupCommand(const QString& name, KivioPage* page, KivioLayer* layer, KivioGroupStencil* group)
+      : KivioGroupCommand(name, page, layer, group)
+    {}
+
+    virtual void execute() { KivioGroupCommand::unexecute(); }
+    virtual void unexecute() { KivioGroupCommand::execute(); }
+};
 
 #endif
 
