@@ -14,29 +14,29 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 #ifndef KIVIO_FACTORY_H
 #define KIVIO_FACTORY_H
 
-#include <koFactory.h>
-
-class KInstance;
+#include <KoFactory.h>
+#include <koffice_export.h>
+class KComponentData;
 class KAboutData;
 
-class KivioFactory : public KoFactory
+class KIVIO_EXPORT KivioFactory : public KoFactory
 { Q_OBJECT
 public:
   KivioFactory( QObject* parent = 0, const char* name = 0 );
   ~KivioFactory();
 
-  virtual KParts::Part *createPart( QWidget *parentWidget = 0, const char *widgetName = 0, QObject *parent = 0, const char *name = 0, const char *classname = "KoDocument", const QStringList &args = QStringList() );
+  virtual KParts::Part *createPartObject( QWidget *parentWidget = 0, const char *widgetName = 0, QObject *parent = 0, const char *name = 0, const char *classname = "KoDocument", const QStringList &args = QStringList() );
 
-  static KInstance* global();
+  static const KComponentData &global();
   static KAboutData* aboutData();
 
 private:
-  static KInstance* s_global;
+  static KComponentData* s_global;
   static KAboutData* s_aboutData;
 };
 
