@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 #include <stdlib.h>
 #include <stdio.h>
@@ -24,8 +24,8 @@
 #include <qpainter.h>
 #include <qdrawutil.h>
 #include <qkeycode.h>
-#include <qregexp.h>
-#include <qpoint.h>
+#include <QRegExp>
+#include <QPoint>
 #include <qcursor.h>
 #include <qptrstack.h>
 #include <qbuffer.h>
@@ -43,17 +43,24 @@
 #include <klocale.h>
 #include <kglobal.h>
 #include <kmessagebox.h>
-#include <koUnit.h>
-#include <kozoomhandler.h>
+#include <KoUnit.h>
+#include <KoPoint.h>
+#include <KoRect.h>
+#include <KoZoomHandler.h>
 #include <kapplication.h>
+#include <KoXmlWriter.h>
+#include <KoXmlNS.h>
+#include <KoDom.h>
+#include <KoStore.h>
+#include <KoOasisStyles.h>
+#include <KoGenStyles.h>
 
 #include "kivio_page.h"
 #include "kivio_map.h"
 #include "kivio_doc.h"
 #include "kivio_canvas.h"
-#include "kivio_guidelines.h"
-#include "kivio_config.h"
 #include "kivio_view.h"
+#include "kivio_config.h"
 
 #include "kivio_common.h"
 #include "kivio_connector_point.h"
@@ -61,8 +68,6 @@
 #include "kivio_intra_stencil_data.h"
 #include "kivio_layer.h"
 #include "kivio_painter.h"
-#include "kivio_point.h"
-#include "kivio_ps_printer.h"
 #include "kivio_stencil.h"
 #include "kivio_1d_stencil.h"
 #include "KIvioPageIface.h"
@@ -70,6 +75,8 @@
 #include "kivioglobal.h"
 #include "kiviodragobject.h"
 
+#include <fixx11h.h> // for None
+
 int KivioPage::s_id = 0L;
 QIntDict<KivioPage>* KivioPage::s_mapPages;
 
@@ -105,8 +112,7 @@ KivioPage::KivioPage( KivioMap *_map, const QString &pageName, const char *_name
     setName( s.data() );
   }
 
-  m_pPageLayout = m_pDoc->config()->defaultPageLayout();
-  gLines = new KivioGuideLines(this);
+  m_pPageLayout = Kivio::Config::defaultPageLayout();
 }
 
 DCOPObject* KivioPage::dcopObject()
@@ -119,8 +125,7 @@ DCOPObject* KivioPage::dcopObject()
 
 KivioPage::~KivioPage()
 {
-  kdDebug(43000)<<" KivioPage::~KivioPage()************ :"<<this<<endl;
-  delete gLines;
+  kDebug(43000)<<" KivioPage::~KivioPage()************ :"<<this;
   s_mapPages->remove(m_id);
   delete m_dcop;
 }
@@ -133,19 +138,6 @@ KivioPage* KivioPage::find( int _id )
   return (*s_mapPages)[ _id ];
 }
 
-void KivioPage::print( KivioPSPrinter *printer )
-{
-    KivioLayer *pLayer = m_lstLayers.first();
-    while( pLayer )
-    {
-        if( pLayer->visible() )
-        {
-            pLayer->printContent( *printer );
-            pLayer = m_lstLayers.next();
-        }
-    }
-}
-
 void KivioPage::print( QPainter &/*painter*/, KPrinter */*_printer*/ )
 {
 }
@@ -168,7 +160,7 @@ QDomElement KivioPage::save( QDomDocument& doc )
     // Save guides
     QDomElement guidesElement = doc.createElement("GuidesLayout");
     page.appendChild(guidesElement);
-    gLines->save(guidesElement);
+    saveGuideLines(guidesElement);
 
     // Iterate through all layers saving them as child elements
     KivioLayer *pLayer = m_lstLayers.first();
@@ -177,7 +169,7 @@ QDomElement KivioPage::save( QDomDocument& doc )
         QDomElement layerE = pLayer->saveXML(doc);
         if( layerE.isNull() )
         {
-	   kdDebug(43000) << "KivioPage::save() - Oh shit.  KivioLayer::saveXML() returned a bad element!" << endl;
+	   kDebug(43000) <<"KivioPage::save() - Oh shit.  KivioLayer::saveXML() returned a bad element!";
         }
 	else
 	{
@@ -190,6 +182,49 @@ QDomElement KivioPage::save( QDomDocument& doc )
     return page;
 }
 
+void KivioPage::saveOasis(KoStore* /*store*/, KoXmlWriter* docWriter, KoGenStyles* styles)
+{
+  docWriter->startElement("draw:page");
+  docWriter->addAttribute("draw:name", m_strName);
+
+  if(m_pPageLayout == Kivio::Config::defaultPageLayout()) {
+    docWriter->addAttribute("draw:master-page-name", "Standard");
+  } else {
+    KoGenStyle pageLayout = m_pPageLayout.saveOasis();
+    QString layoutName = styles->lookup(pageLayout, "PL");
+
+    KoGenStyle masterPage(KoGenStyle::StyleMaster);
+    masterPage.addAttribute("style:page-layout-name", layoutName);
+    QString masterName = styles->lookup(masterPage, "MP");
+
+    docWriter->addAttribute("draw:master-page-name", masterName);
+  }
+
+  // TODO OASIS: Save guidelines!
+
+  QBuffer layerBuffer;
+  layerBuffer.open(QIODevice::WriteOnly);
+  KoXmlWriter layerWriter(&layerBuffer);
+  layerWriter.startElement("draw:layer-set");
+
+  // Iterate through all layers
+  KivioLayer* layer = m_lstLayers.first();
+
+  while(layer) {
+    layer->saveOasis(&layerWriter);
+    layer = m_lstLayers.next();
+  }
+
+  layerWriter.endElement(); // draw:layer-set
+  QString layerSet = QString::fromUtf8(layerBuffer.buffer(), layerBuffer.buffer().size());
+  KoGenStyle pageStyle(Kivio::STYLE_PAGE, "drawing-page");
+  pageStyle.addChildElement("draw:layer-set", layerSet);
+  QString styleName = styles->lookup(pageStyle, "PS");
+  docWriter->addAttribute("draw:style-name", styleName);
+
+  docWriter->endElement(); // draw:page
+}
+
 QDomElement KivioPage::saveLayout( QDomDocument &doc )
 {
     QDomElement e = doc.createElement("PageLayout");
@@ -244,11 +279,11 @@ bool KivioPage::loadXML( const QDomElement& pageE )
 	  loadLayout( node.toElement() );
        }
        else if ( node.nodeName() == "GuidesLayout" ) {
-	  gLines->load(node.toElement());
+	  loadGuideLines(node.toElement());
        }
        else
        {
-	  kdDebug(43000) << "KivioLayer::loadXML() - unknown node found, " <<  node.nodeName() << endl;
+	  kDebug(43000) <<"KivioLayer::loadXML() - unknown node found," <<  node.nodeName();
        }
 
        node = node.nextSibling();
@@ -257,7 +292,7 @@ bool KivioPage::loadXML( const QDomElement& pageE )
     m_pCurLayer = m_lstLayers.first();
     if( !m_pCurLayer )
     {
-       kdDebug(43000) << "KivioLayer::loadXML() - No layers loaded!! BIGGGGG PROBLEMS!" << endl;
+       kDebug(43000) <<"KivioLayer::loadXML() - No layers loaded!! BIGGGGG PROBLEMS!";
     }
 
     // Now that we are done loading, fix all the connections
@@ -268,7 +303,7 @@ bool KivioPage::loadXML( const QDomElement& pageE )
     {
        pLayerBak = pLayer;
 
-       kdDebug(43000) << "KivioLayer::loadXML() - loading layer connections" << endl;
+       kDebug(43000) <<"KivioLayer::loadXML() - loading layer connections";
        pLayer->searchForConnections(this);
 
        m_lstLayers.find( pLayerBak );
@@ -279,6 +314,54 @@ bool KivioPage::loadXML( const QDomElement& pageE )
   return true;
 }
 
+bool KivioPage::loadOasis(const QDomElement& page, KoOasisStyles& oasisStyles)
+{
+  m_strName = page.attributeNS( KoXmlNS::draw, "name", QString::null);
+  QDomElement* masterPage = oasisStyles.masterPages()[page.attributeNS( KoXmlNS::draw, "master-page-name", QString::null)];
+
+  if(!masterPage) {
+    kDebug(430000) <<"Couldn't find the master page!" << page.attributeNS( KoXmlNS::draw,"master-page-name", QString::null);
+    return false;
+  }
+
+  const QDomElement *pageLayout = oasisStyles.findStyle(masterPage->attributeNS( KoXmlNS::style, "page-layout-name", QString::null ) );
+
+  if(!pageLayout) {
+    kDebug(430000) <<"Couldn't find the pagelayout!";
+    return false;
+  }
+
+  m_pPageLayout.loadOasis(*pageLayout);
+
+  if(m_pPageLayout.ptWidth <= 1e-13 || m_pPageLayout.ptHeight <= 1e-13) {
+    kDebug(430000) <<"Non valid pagelayout!";
+    return false;
+  }
+
+  const QDomElement* style = oasisStyles.findStyle(page.attributeNS( KoXmlNS::draw, "style-name", QString::null) ); // Find the page style
+
+  if(!style) {
+    return false;
+  }
+
+  QDomNode styleNode = KoDom::namedItemNS( *style, KoXmlNS::style, "properties");
+  styleNode = KoDom::namedItemNS( styleNode, KoXmlNS::draw, "layer-set");
+  QDomNode currentNode = styleNode.firstChild();
+
+  // Load the layers
+  while(!currentNode.isNull()) {
+    if(currentNode.nodeName() == "draw:layer") {
+      KivioLayer* layer = new KivioLayer(this);
+      layer->loadOasis(currentNode.toElement());
+      m_lstLayers.append(layer);
+    }
+
+    currentNode = currentNode.nextSibling();
+  }
+
+  return true;
+}
+
 void KivioPage::update()
 {
 }
@@ -317,7 +400,7 @@ bool KivioPage::setPageName( const QString& name, bool init )
  * most visible.
  */
 void KivioPage::paintContent( KivioPainter& painter, const QRect& rect, bool transparent,
-  QPoint p0, KoZoomHandler* zoom, bool drawHandles )
+  QPoint p0, KoZoomHandler* zoom, bool drawConnectorTargets, bool drawSelection )
 {
   KivioLayer *pLayer = m_lstLayers.first();
   while( pLayer )
@@ -332,15 +415,13 @@ void KivioPage::paintContent( KivioPainter& painter, const QRect& rect, bool tra
 
   // Now the second iteration - connection targets
   // Only draw targets if the zoom is higher than a certain value
-  if( zoom->zoom() >= 50 )
-  {
-    if( drawHandles )
-    {
+  if(zoom->zoom() >= 50) {
+    if(drawConnectorTargets) {
       m_pCurLayer->paintConnectorTargets( painter, rect, transparent, p0, zoom );
       pLayer = m_lstLayers.first();
-      while( pLayer )
-      {
-        if( pLayer->connectable() ) {
+
+      while(pLayer) {
+        if(pLayer->connectable() && (pLayer != m_pCurLayer)) {
           pLayer->paintConnectorTargets( painter, rect, transparent, p0, zoom );
         }
 
@@ -350,8 +431,7 @@ void KivioPage::paintContent( KivioPainter& painter, const QRect& rect, bool tra
   }
 
   // Now the third iteration - selection handles
-  if( drawHandles )
-  {
+  if(drawSelection) {
     m_pCurLayer->paintSelectionHandles( painter, rect, transparent, p0, zoom );
   }
 }
@@ -359,11 +439,11 @@ void KivioPage::paintContent( KivioPainter& painter, const QRect& rect, bool tra
 void KivioPage::printContent( KivioPainter& painter, int xdpi, int ydpi )
 {
   if(!xdpi) {
-    xdpi = QPaintDevice::x11AppDpiX();
+    xdpi = KoGlobal::dpiX();
   }
 
   if(!ydpi) {
-    ydpi = QPaintDevice::x11AppDpiY();
+    ydpi = KoGlobal::dpiY();
   }
 
   KivioLayer *pLayer = m_lstLayers.first();
@@ -379,14 +459,29 @@ void KivioPage::printContent( KivioPainter& painter, int xdpi, int ydpi )
   }
 }
 
+void KivioPage::printContent(KivioPainter& painter, KoZoomHandler* zoomHandler)
+{
+  KivioLayer *pLayer = m_lstLayers.first();
+
+  while( pLayer )
+  {
+    if(pLayer->visible())
+    {
+      pLayer->printContent(painter, zoomHandler);
+    }
+
+    pLayer = m_lstLayers.next();
+  }
+}
+
 void KivioPage::printSelected( KivioPainter& painter, int xdpi, int ydpi )
 {
   if(!xdpi) {
-    xdpi = QPaintDevice::x11AppDpiX();
+    xdpi = KoGlobal::dpiX();
   }
 
   if(!ydpi) {
-    ydpi = QPaintDevice::x11AppDpiY();
+    ydpi = KoGlobal::dpiY();
   }
 
   KivioStencil *pStencil;
@@ -408,7 +503,7 @@ void KivioPage::printSelected( KivioPainter& painter, int xdpi, int ydpi )
 
       while( pStencil )
       {
-        if( isStencilSelected(pStencil)==true )
+        if(pStencil->isSelected())
         {
           pStencil->paint(&data);
         }
@@ -424,22 +519,20 @@ void KivioPage::printSelected( KivioPainter& painter, int xdpi, int ydpi )
 
 bool KivioPage::addStencil( KivioStencil *pStencil )
 {
-    if( !pStencil )
-    {
-       kdDebug(43000) << "KivioPage::addStencil() - Null stencil passed" << endl;
-        return false;
-    }
+  if(!pStencil) {
+    kDebug(43000) <<"KivioPage::addStencil() - Null stencil passed";
+    return false;
+  }
 
-    if( !m_pCurLayer )
-    {
-       kdDebug(43000) << "KivioPage::addStencil() - NULL current layer" << endl;
-        return false;
-    }
+  if(!m_pCurLayer) {
+    kDebug(43000) <<"KivioPage::addStencil() - NULL current layer";
+    return false;
+  }
 
-    KivioAddStencilCommand *cmd = new KivioAddStencilCommand(i18n("Add Stencil"), this, m_pCurLayer, pStencil );
-    m_pDoc->addCommand(cmd);
+  KivioAddStencilCommand *cmd = new KivioAddStencilCommand(i18n("Add Stencil"), this, m_pCurLayer, pStencil );
+  m_pDoc->addCommand(cmd);
 
-    return m_pCurLayer->addStencil( pStencil );
+  return m_pCurLayer->addStencil( pStencil );
 }
 
 void KivioPage::selectStencils( double x, double y, double w, double h )
@@ -447,11 +540,9 @@ void KivioPage::selectStencils( double x, double y, double w, double h )
   // Iterate through all stencils of this layer
   KivioStencil *pStencil = m_pCurLayer->stencilList()->first();
 
-  while( pStencil )
-  {
+  while(pStencil) {
     // Is it in the rectangle?
-    if( stencilInRect( x, y, w, h, pStencil )==true )
-    {
+    if(pStencil->isInRect(KoRect(x, y, w, h))) {
       selectStencil( pStencil );
     }
 
@@ -461,37 +552,21 @@ void KivioPage::selectStencils( double x, double y, double w, double h )
   m_pDoc->slotSelectionChanged();
 }
 
-bool KivioPage::stencilInRect( double x, double y, double w, double h, KivioStencil *pStencil )
-{
-  double sx, sy, sw, sh;
-
-  sx = pStencil->x();
-  sy = pStencil->y();
-  sw = pStencil->w();
-  sh = pStencil->h();
-
-  if( sx >= x && sy >= y && sx+sw <= x+w && sy+sh <= y+h )
-    return true;
-
-  return false;
-}
-
-
 void KivioPage::selectStencil( KivioStencil *pStencil )
 {
-  if( !pStencil )
-  {
-    kdDebug(43000) << "KivioPage::selectStencil - AHHHH! NULL STENCIL!" << endl;
+  if(!pStencil) {
+    kDebug(43000) <<"KivioPage::selectStencil - AHHHH! NULL STENCIL!";
     return;
   }
 
   // Don't allow reselection
-  if( m_lstSelection.findRef( pStencil ) != -1 )
+  if(m_lstSelection.findRef(pStencil) != -1) {
     return;
+  }
 
-  kdDebug(43000) <<"KivioPage::selectStencil - Selecting stencil" << endl;
+  kDebug(43000) <<"KivioPage::selectStencil - Selecting stencil";
   pStencil->select();
-  m_lstSelection.append( pStencil );
+  m_lstSelection.append(pStencil);
   m_pDoc->slotSelectionChanged();
 }
 
@@ -504,16 +579,14 @@ bool KivioPage::unselectStencil( KivioStencil *pStencil )
 
 void KivioPage::selectAllStencils()
 {
-    unselectAllStencils();
+  unselectAllStencils();
+  KivioStencil* pStencil = m_pCurLayer->stencilList()->first();
 
-    KivioStencil* pStencil = m_pCurLayer->stencilList()->first();
-    while( pStencil )
-    {
-        pStencil->select();
-        m_lstSelection.append(pStencil);
-
-        pStencil = m_pCurLayer->stencilList()->next();
-    }
+  while(pStencil) {
+    pStencil->select();
+    m_lstSelection.append(pStencil);
+    pStencil = m_pCurLayer->stencilList()->next();
+  }
 
 
     /*
@@ -539,29 +612,26 @@ void KivioPage::selectAllStencils()
         pLayer = m_lstLayers.next();
     }
 */
-    m_pDoc->slotSelectionChanged();
+  m_pDoc->slotSelectionChanged();
 }
 
 void KivioPage::unselectAllStencils()
 {
-    KivioStencil *pStencil;
+  KivioStencil* pStencil = m_lstSelection.first();
 
-    pStencil = m_lstSelection.first();
-    while( pStencil )
-    {
-        pStencil->unselect();
+  while(pStencil)
+  {
+    pStencil->unselect();
+    pStencil = m_lstSelection.next();
+  }
 
-        pStencil = m_lstSelection.next();
-    }
-
-    m_lstSelection.clear();
-
-    m_pDoc->slotSelectionChanged();
+  m_lstSelection.clear();
+  m_pDoc->slotSelectionChanged();
 }
 
-bool KivioPage::isStencilSelected( KivioStencil *pStencil )
+bool KivioPage::isStencilSelected(KivioStencil *pStencil)
 {
-    return m_lstSelection.findRef( pStencil )==-1 ? false : true;
+  return m_lstSelection.findRef( pStencil ) == -1;
 }
 
 /**
@@ -573,7 +643,7 @@ bool KivioPage::isStencilSelected( KivioStencil *pStencil )
  * for stencils.  The first one it finds will be returned.
  * If none are found, it will return NULL.
  */
-KivioStencil *KivioPage::checkForStencil( KivioPoint *pPoint, int *collisionType, double threshold, bool selectedOnly )
+KivioStencil *KivioPage::checkForStencil( KoPoint *pPoint, int *collisionType, double threshold, bool selectedOnly )
 {
     KivioStencil *pStencil;
     int colType;
@@ -613,141 +683,96 @@ KivioStencil *KivioPage::checkForStencil( KivioPoint *pPoint, int *collisionType
 
 void KivioPage::deleteSelectedStencils()
 {
-    KivioStencil *pStencil;
+  // Make sure none of them have deletion protection
+  KivioStencil* pStencil = m_lstSelection.first();
 
-    // Make sure none of them have deletion protection
-    pStencil = m_lstSelection.first();
-    while( pStencil )
-    {
-       if( pStencil->protection()->at(kpDeletion)==true )
-       {
-	  KMessageBox::information(NULL, i18n("One of the selected stencils has protection from deletion and cannot be deleted."),
-				   i18n("Protection From Deletion") );
-	  return;
-       }
-
-       pStencil = m_lstSelection.next();
+  while(pStencil) {
+    if(pStencil->protection()->at(kpDeletion)) {
+      KMessageBox::information(NULL, i18n("One of the selected stencils has protection from deletion and cannot be deleted."),
+                                i18n("Protection From Deletion") );
+      return;
+    }
+
+    pStencil = m_lstSelection.next();
+  }
+
+  // Iterate through all items in the selection list
+  m_lstSelection.first();
+  pStencil = m_lstSelection.take();
+  KMacroCommand *macro = new KMacroCommand( i18n("Remove Stencil"));
+  bool createMacro = false;
+
+  while(pStencil) {
+    KivioRemoveStencilCommand *cmd =new KivioRemoveStencilCommand(i18n("Remove Stencil"), this,  m_pCurLayer , pStencil );
+    createMacro = true;
+    macro->addCommand(cmd);
+
+    if(pStencil->type() == kstConnector) {
+      static_cast<Kivio1DStencil*>(pStencil)->disconnectFromTargets();
     }
 
-    // Iterate through all items in the selection list
-    m_lstSelection.first();
     pStencil = m_lstSelection.take();
-    KMacroCommand *macro = new KMacroCommand( i18n("Remove Stencil"));
-    bool createMacro = false;
-    while( pStencil )
-    {
-        KivioRemoveStencilCommand *cmd =new KivioRemoveStencilCommand(i18n("Remove Stencil"), this,  m_pCurLayer , pStencil );
-        createMacro = true;
-        macro->addCommand( cmd);
+  }
 
-        if(pStencil->type() == kstConnector) {
-            static_cast<Kivio1DStencil*>(pStencil)->disconnectFromTargets();
-        }
-
-        pStencil = m_lstSelection.take();
-    }
-    if ( createMacro )
-    {
-        macro->execute();
-        m_pDoc->addCommand( macro );
-    }
-    else
-        delete macro;
+  if (createMacro) {
+    macro->execute();
+    m_pDoc->addCommand( macro );
+  } else {
+    delete macro;
+  }
 }
 
 void KivioPage::groupSelectedStencils()
 {
-    KivioGroupStencil *pGroup;
-    KivioStencil *pTake;
-    KivioStencil *pStencil;
+  // Can't group 0 or 1 stencils
+  if(!m_pCurLayer || (m_lstSelection.count() <= 1)) {
+    return;
+  }
 
+  KivioGroupStencil* pGroup = new KivioGroupStencil();
 
-    // Can't group 0 or 1 stencils
-    if( m_lstSelection.count() <= 1 )
-        return;
+  // Iterate through all items in the selection list, taking them from the layer, then adding
+  // them to the group
 
-    pGroup = new KivioGroupStencil();
+  KivioStencil* pStencil = m_pCurLayer->firstStencil();
+  KivioStencil* pTake = 0;
 
-    // Iterate through all items in the selection list, taking them from the layer, then adding
-    // them to the group
+  while(pStencil) {
+    if(pStencil->isSelected()) {
+      // Take the stencil out of it's layer
+      pTake = m_pCurLayer->takeStencil(pStencil);
 
-    pStencil = m_lstSelection.first();
-    while( pStencil )
-    {
-        // Take the stencil out of it's layer
-        pTake = m_pCurLayer->takeStencil( pStencil );
-        if( !pTake )
-        {
-	   kdDebug(43000) << "KivioPage::groupSelectedStencil() - Failed to take() one of the selected stencils. CRAP!" << endl;
-        }
-        else
-        {
-            // Add it to the group
-            pGroup->addToGroup( pTake );
-        }
-
-        pStencil = m_lstSelection.next();
+      if(!pTake) {
+        kDebug(43000) <<"KivioPage::groupSelectedStencil() - Failed to take() one of the selected stencils. CRAP!";
+      } else {
+        // Add it to the group
+        pGroup->addToGroup(pTake);
+        pStencil = m_pCurLayer->currentStencil();
+      }
+    } else {
+      pStencil = m_pCurLayer->nextStencil();
     }
+  }
 
-    // Unselect the old ones
-    unselectAllStencils();
+  // Unselect the old ones
+  unselectAllStencils();
 
+  // Add the group as the selected stencil
+  m_pCurLayer->addStencil(pGroup);
 
-    // Add the group as the selected stencil
-    m_pCurLayer->addStencil( pGroup );
+  selectStencil(pGroup);
 
-    selectStencil( pGroup );
+  KivioGroupCommand* cmd = new KivioGroupCommand(i18n("Group Selection"), this, m_pCurLayer, pGroup);
+  doc()->addCommand(cmd);
 }
 
-// The following is the old implementation of groupSelectedStencils.  It did
-// not preserve connections so a new method was devised.
-/*
-void KivioPage::groupSelectedStencils()
-{
-    KivioGroupStencil *pGroup;
-    KivioStencil *pTake;
-    KivioStencil *pStencil;
-
-
-    debug("*GROUP* About to group");
-    // Can't group 0 or 1 stencils
-    if( m_lstSelection.count() <= 1 )
-        return;
-
-    pGroup = new KivioGroupStencil();
-
-    // Iterate through all items in the selection list, duplicating them, then adding
-    // them to the group
-
-    pStencil = m_lstSelection.first();
-    while( pStencil )
-    {
-
-        debug("*GROUP* Duplicating 1");
-
-        // Dup the stencil & group it
-        pTake  = pStencil->duplicate();
-
-        pGroup->addToGroup( pDuplicate );
-
-        pStencil = m_lstSelection.next();
-    }
-
-    // Kill the old selections
-    deleteSelectedStencils();
-
-
-    // Add the group as the selected stencil
-    m_pCurLayer->addStencil( pGroup );
-
-    selectStencil( pGroup );
-}
-*/
 void KivioPage::ungroupSelectedStencils()
 {
   KivioStencil *pSelStencil, *pStencil;
   QPtrList<KivioStencil> *pList;
   QPtrList<KivioStencil> *pSelectThese = new QPtrList<KivioStencil>;
+  KMacroCommand* macro = new KMacroCommand(i18n("Ungroup"));
+  bool ungrouped = false;
 
   pSelectThese->setAutoDelete(false);
 
@@ -757,49 +782,34 @@ void KivioPage::ungroupSelectedStencils()
   {
     // If there is a list, it is a group stencil
     pList = pSelStencil->groupList();
-    if( pList )
+    if(pList)
     {
       pList->first();
-      pStencil = pList->take();
+      pStencil = pList->first();
 
       while( pStencil )
       {
-        addStencil( pStencil );
+        m_pCurLayer->addStencil( pStencil );
         pSelectThese->append( pStencil );
 
-        pStencil = pList->take();
+        pStencil = pList->next();
       }
 
-      /*
-      *  The following is commented out because the group should be on the
-      * current layer since selections must be on the current layer.
-      */
-      // Since this was a group, it is now an empty stencil, so we remove it
-      // from the selection list, and then remove it from the layer it came
-      // from, but we have to search for that.
-      /*
-      pSelStencil = m_lstSelection.take();
-      KivioLayer *pLayer = m_lstLayers.first();
-      while( pLayer )
-      {
-          if( pLayer->removeStencil( pSelStencil )==true )
-              break;
-
-          pLayer = m_lstLayers.next();
-      }
-      */
-
       // Remove the current stencil from the selection list(the group we just disassembled)
       m_lstSelection.take();
 
       // Remove it permanently from the layer
-      if( m_pCurLayer->removeStencil( pSelStencil )==false )
+      if(!m_pCurLayer->takeStencil(pSelStencil))
       {
-        kdDebug(43000) << "KivioPage::ungroupSelectedStencil() - Failed to locate the group shell for deletion"
+        kDebug(43000) <<"KivioPage::ungroupSelectedStencil() - Failed to locate the group shell for deletion"
           << endl;
       }
-    }
 
+      KivioUnGroupCommand* cmd = new KivioUnGroupCommand(i18n("Ungroup"), this, m_pCurLayer,
+          static_cast<KivioGroupStencil*>(pSelStencil));
+      macro->addCommand(cmd);
+      ungrouped = true;
+    }
 
     pSelStencil = m_lstSelection.next();
   }
@@ -811,12 +821,20 @@ void KivioPage::ungroupSelectedStencils()
   {
     selectStencil( pStencil );
 
+    if(pStencil->type() == kstConnector) {
+      pStencil->searchForConnections(this, 4.0);
+    }
+
     pStencil = pSelectThese->next();
   }
 
-
-
   delete pSelectThese;
+
+  if(ungrouped) {
+    doc()->addCommand(macro);
+  } else {
+    delete macro;
+  }
 }
 
 void KivioPage::bringToFront()
@@ -856,53 +874,6 @@ void KivioPage::bringToFront()
         }
     }
 
-    // push them back in, in reverse order
-    pStencil = newList.first();
-    while( pStencil )
-    {
-        pLayer->stencilList()->append(pStencil);
-
-        pStencil = newList.next();
-    }
-}
-
-void KivioPage::sendToBack()
-{
-    KivioStencil *pStencil, *pMove;
-    KivioLayer *pLayer;
-
-    QPtrList <KivioStencil> newList;
-
-    pLayer = m_pCurLayer;
-
-    newList.setAutoDelete(false);
-
-    /*
-     * We iterate through all stencils since order must be maintained
-     * amongst the selection during the move.
-     */
-    pStencil = pLayer->firstStencil();
-    while( pStencil )
-    {
-        if( isStencilSelected( pStencil )==true )
-        {
-            pMove = pLayer->takeStencil();
-            if( pMove )
-            {
-                newList.append(pMove);
-                pStencil = pLayer->currentStencil();
-            }
-            else  // In the case of error, the outside else won't execute
-            {
-                pStencil = pLayer->nextStencil();
-            }
-        }
-        else
-        {
-            pStencil = pLayer->nextStencil();
-        }
-    }
-
     // push them back in, in reverse order
     pStencil = newList.last();
     while( pStencil )
@@ -913,6 +884,53 @@ void KivioPage::sendToBack()
     }
 }
 
+void KivioPage::sendToBack()
+{
+    KivioStencil *pStencil, *pMove;
+    KivioLayer *pLayer;
+
+    QPtrList <KivioStencil> newList;
+
+    pLayer = m_pCurLayer;
+
+    newList.setAutoDelete(false);
+
+    /*
+     * We iterate through all stencils since order must be maintained
+     * amongst the selection during the move.
+     */
+    pStencil = pLayer->firstStencil();
+    while( pStencil )
+    {
+        if( isStencilSelected( pStencil )==true )
+        {
+            pMove = pLayer->takeStencil();
+            if( pMove )
+            {
+                newList.append(pMove);
+                pStencil = pLayer->currentStencil();
+            }
+            else  // In the case of error, the outside else won't execute
+            {
+                pStencil = pLayer->nextStencil();
+            }
+        }
+        else
+        {
+            pStencil = pLayer->nextStencil();
+        }
+    }
+
+    // push them back in, in reverse order
+    pStencil = newList.first();
+    while( pStencil )
+    {
+        pLayer->stencilList()->append(pStencil);
+
+        pStencil = newList.next();
+    }
+}
+
 void KivioPage::copy()
 {
   if(m_lstSelection.count() <= 0) {
@@ -923,7 +941,7 @@ void KivioPage::copy()
   KivioDragObject* kdo = new KivioDragObject();
   kdo->setStencilList(m_lstSelection);
   kdo->setStencilRect(getRectForAllSelectedStencils());
-  QApplication::clipboard()->setData(kdo);
+  QApplication::clipboard()->setData(kdo, QClipboard::Clipboard);
 }
 
 void KivioPage::cut()
@@ -969,7 +987,7 @@ void KivioPage::paste(KivioView* view)
   list.setAutoDelete(false);
   KivioDragObject kdo;
 
-  if(kdo.decode(QApplication::clipboard()->data(), list, this)) {
+  if(kdo.decode(QApplication::clipboard()->data(QClipboard::Clipboard), list, this)) {
     unselectAllStencils();
     KivioStencil* stencil = list.first();
 
@@ -1033,7 +1051,7 @@ bool KivioPage::removeCurrentLayer()
     {
         if( m_lstLayers.find( m_pCurLayer )==false )
         {
-	   kdDebug(43000) << "KivioLayer::removeCurrentLayer() - Couldn't find current layer in the list. Bad!" << endl;
+	   kDebug(43000) <<"KivioLayer::removeCurrentLayer() - Couldn't find current layer in the list. Bad!";
             return false;
         }
     }
@@ -1047,7 +1065,7 @@ bool KivioPage::removeCurrentLayer()
 
     if( !pLayer )
     {
-       kdDebug(43000) << "KivioLayer::removeCurrentLayer() - Couldn't find a next layer." << endl;
+       kDebug(43000) <<"KivioLayer::removeCurrentLayer() - Couldn't find a next layer.";
         return false;
     }
 
@@ -1057,7 +1075,7 @@ bool KivioPage::removeCurrentLayer()
 /*
     if( m_lstLayers.remove( m_pCurLayer )==false )
     {
-       kdDebug(43000) << "KivioLayer::removeCurrentLayer() - Couldn't find current layer in the list. Bad!" << endl;
+       kDebug(43000) <<"KivioLayer::removeCurrentLayer() - Couldn't find current layer in the list. Bad!";
         return false;
     }
 */
@@ -1104,7 +1122,7 @@ void KivioPage::alignStencils(AlignData d)
 
         while( pStencil )
         {
-            KivioRect oldRect = pStencil->rect();
+            KoRect oldRect = pStencil->rect();
 
             switch (d.v) {
                 case AlignData::Top:
@@ -1146,14 +1164,14 @@ void KivioPage::alignStencils(AlignData d)
         KMacroCommand *macro = new KMacroCommand(i18n("Move Stencil"));
         double w = m_pPageLayout.ptWidth;
         double h = m_pPageLayout.ptHeight;
-        KivioRect r = getRectForAllSelectedStencils();
-        double dx = ((w - r.w()) / 2.0) - r.x();
-        double dy = ((h - r.h()) / 2.0) - r.y();
+        KoRect r = getRectForAllSelectedStencils();
+        double dx = ((w - r.width()) / 2.0) - r.x();
+        double dy = ((h - r.height()) / 2.0) - r.y();
         pStencil = m_lstSelection.first();
 
         while( pStencil )
         {
-            KivioRect oldRect = pStencil->rect();
+            KoRect oldRect = pStencil->rect();
             pStencil->setPosition(pStencil->x() + dx, pStencil->y() + dy);
             KivioMoveStencilCommand * cmd = new KivioMoveStencilCommand( i18n("Move Stencil"),
               pStencil, oldRect, pStencil->rect(), this);
@@ -1207,7 +1225,7 @@ void KivioPage::distributeStencils(DistributeData d)
 
   XYSortedStencilList xSortList(true);
   XYSortedStencilList ySortList(false);
-  QValueList<KivioRect> oldRects;
+  QValueList<KoRect> oldRects;
 
   while( pStencil )
   {
@@ -1234,10 +1252,10 @@ void KivioPage::distributeStencils(DistributeData d)
       y1 = y + pStencil->h();
       while( pStencil )
       {
-          x = QMIN(x,pStencil->x());
-          y = QMIN(y,pStencil->y());
-          x1 = QMAX(x1,pStencil->x() + pStencil->w());
-          y1 = QMAX(y1,pStencil->y() + pStencil->h());
+          x = qMin(x,pStencil->x());
+          y = qMin(y,pStencil->y());
+          x1 = qMax(x1,pStencil->x() + pStencil->w());
+          y1 = qMax(y1,pStencil->y() + pStencil->h());
           pStencil = m_lstSelection.next();
       }
       break;
@@ -1396,7 +1414,7 @@ void KivioPage::distributeStencils(DistributeData d)
 
   if(d.v != DistributeData::None || d.h != DistributeData::None) {
     KMacroCommand *macro = new KMacroCommand(i18n("Move Stencil"));
-    QValueListIterator<KivioRect> it;
+    QValueListIterator<KoRect> it;
     pStencil = m_lstSelection.first();
 
     for(it = oldRects.begin(); it != oldRects.end(); ++it) {
@@ -1414,9 +1432,9 @@ void KivioPage::distributeStencils(DistributeData d)
 /**
  * Returns a rectangle representing the bounds of all the selected stencils (in points).
  */
-KivioRect KivioPage::getRectForAllSelectedStencils()
+KoRect KivioPage::getRectForAllSelectedStencils()
 {
-    KivioRect rTotal, r;
+    KoRect rTotal, r;
 
     KivioStencil *pStencil = m_lstSelection.first();
 
@@ -1444,9 +1462,9 @@ KivioRect KivioPage::getRectForAllSelectedStencils()
 /**
  * Returns a rectangle representing the bounds of all the selected stencils (in points).
  */
-KivioRect KivioPage::getRectForAllStencils()
+KoRect KivioPage::getRectForAllStencils()
 {
-    KivioRect rTotal, r;
+    KoRect rTotal, r;
 
     bool firstTime = true;
 
@@ -1547,7 +1565,7 @@ KoPoint KivioPage::snapToTarget( const KoPoint& p, double thresh, bool& hit )
           }
       }
 
-      retVal = pLayer->snapToTarget(p, 8.0f, hit);
+      retVal = pLayer->snapToTarget(p, thresh, hit);
 
       pLayer = nextLayer();
    }
@@ -1564,6 +1582,98 @@ void KivioPage::setHidePage(bool _hide)
         emit sig_PageShown(this);
 }
 
+void KivioPage::setPaintSelected(bool paint)
+{
+  KivioStencil *pStencil = m_lstSelection.first();
+
+  while( pStencil )
+  {
+    pStencil->setHidden(!paint);
+    pStencil = m_lstSelection.next();
+  }
+}
+
+bool KivioPage::checkForStencilTypeInSelection(KivioStencilType type)
+{
+  KivioStencil *pStencil = m_lstSelection.first();
+
+  while( pStencil )
+  {
+    if(pStencil->type() == type) {
+      return true;
+    }
+
+    pStencil = m_lstSelection.next();
+  }
+
+  return false;
+}
+
+bool KivioPage::checkForTextBoxesInSelection()
+{
+  KivioStencil *pStencil = m_lstSelection.first();
+
+  while(pStencil) {
+    if(pStencil->hasTextBox()) {
+      return true;
+    }
+
+    pStencil = m_lstSelection.next();
+  }
+
+  return false;
+}
+
+void KivioPage::setGuideLines(const QValueList<double> hGuideLines, const QValueList<double> vGuideLines)
+{
+  m_hGuideLines = hGuideLines;
+  m_vGuideLines = vGuideLines;
+}
+
+void KivioPage::saveGuideLines(QDomElement& element)
+{
+  QValueList<double>::iterator it;
+  QValueList<double>::iterator itEnd = m_hGuideLines.end();
+
+  for(it = m_hGuideLines.begin(); it != itEnd; ++it) {
+    QDomElement e = element.ownerDocument().createElement("Guideline");
+    element.appendChild(e);
+    XmlWriteDouble(e, "pos", *it);
+    XmlWriteInt(e, "orient", (int)Qt::Horizontal);
+  }
+
+  itEnd = m_vGuideLines.end();
+
+  for(it = m_vGuideLines.begin(); it != itEnd; ++it) {
+    QDomElement e = element.ownerDocument().createElement("Guideline");
+    element.appendChild(e);
+    XmlWriteDouble(e, "pos", *it);
+    XmlWriteInt(e, "orient", (int)Qt::Vertical);
+  }
+}
+
+void KivioPage::loadGuideLines(const QDomElement& element)
+{
+  m_hGuideLines.clear();
+  m_vGuideLines.clear();
+
+  QDomElement e = element.firstChild().toElement();
+
+  for( ; !e.isNull(); e = e.nextSibling().toElement() )
+  {
+    double pos = XmlReadDouble(e, "pos", 0.0);
+    Qt::Orientation orient = (Qt::Orientation)XmlReadInt(e, "orient", 0);
+    addGuideLine(orient, pos);
+  }
+}
+
+void KivioPage::addGuideLine(Qt::Orientation orientation, double position)
+{
+  if(orientation == Qt::Horizontal) {
+    m_hGuideLines.append(position);
+  } else {
+    m_vGuideLines.append(position);
+  }
+}
 
 #include "kivio_page.moc"
-
