@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 2003 Peter Simonsson <psn@linux.se>
+   Copyright (C) 2003-2004 Peter Simonsson <psn@linux.se>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -13,17 +13,29 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #include "kivioglobal.h"
-#include "kivio_common.h"
 
 #include <qdom.h>
 #include <qpixmap.h>
+#include <qprinter.h>
 
 #include <kdebug.h>
+#include <kglobal.h>
+#include <klocale.h>
+
+#include <KoGenStyles.h>
+#include <KoZoomHandler.h>
+#include <KoGlobal.h>
+
+#include "kivio_common.h"
+#include "kivio_settings.h"
+#include "kivio_stencil.h"
+#include "kivio_intra_stencil_data.h"
+#include "kivio_screen_painter.h"
 
 struct PaperSizeDef {
   const char* title;
@@ -32,7 +44,7 @@ struct PaperSizeDef {
   int unit;
 };
 
-void Kivio::savePageLayout(QDomElement& e, KoPageLayout layout)
+void Kivio::savePageLayout(QDomElement& e, const KoPageLayout& layout)
 {
   XmlWriteFloat(e, "width", layout.ptWidth);
   XmlWriteFloat(e, "height", layout.ptHeight);
@@ -44,22 +56,28 @@ void Kivio::savePageLayout(QDomElement& e, KoPageLayout layout)
   XmlWriteString(e, "orientation", Kivio::orientationString(layout.orientation));
 }
 
+// ## TODO: remove this method, now that layout.saveOasis() does it all
+KoGenStyle Kivio::savePageLayout(const KoPageLayout& layout)
+{
+  return layout.saveOasis();
+}
+
 KoPageLayout Kivio::loadPageLayout(const QDomElement& e)
 {
   KoPageLayout layout;
 
   if(e.hasAttribute("unit")) {
     // Compatibility with Kivio <= 1.2.x
-    kdDebug(43000) << "Compatibility mode..." << endl;
-    KoUnit::Unit unit = Kivio::convToKoUnit(XmlReadInt(e, "unit", 0));
-    layout.ptWidth = KoUnit::ptFromUnit(XmlReadFloat(e, "width", 0.0), unit);
-    layout.ptHeight = KoUnit::ptFromUnit(XmlReadFloat(e, "height", 0.0), unit);
-    layout.ptLeft = KoUnit::ptFromUnit(XmlReadFloat(e, "marginLeft", 0.0), unit);
-    layout.ptRight = KoUnit::ptFromUnit(XmlReadFloat(e, "marginRight", 0.0), unit);
-    layout.ptTop = KoUnit::ptFromUnit(XmlReadFloat(e, "marginTop", 0.0), unit);
-    layout.ptBottom = KoUnit::ptFromUnit(XmlReadFloat(e, "marginBottom", 0.0), unit);
+    kDebug(43000) <<"Compatibility mode...";
+    KoUnit unit = Kivio::convToKoUnit(XmlReadInt(e, "unit", 0));
+    layout.ptWidth = KoUnit::fromUserValue(XmlReadFloat(e, "width", 0.0), unit);
+    layout.ptHeight = KoUnit::fromUserValue(XmlReadFloat(e, "height", 0.0), unit);
+    layout.ptLeft = KoUnit::fromUserValue(XmlReadFloat(e, "marginLeft", 0.0), unit);
+    layout.ptRight = KoUnit::fromUserValue(XmlReadFloat(e, "marginRight", 0.0), unit);
+    layout.ptTop = KoUnit::fromUserValue(XmlReadFloat(e, "marginTop", 0.0), unit);
+    layout.ptBottom = KoUnit::fromUserValue(XmlReadFloat(e, "marginBottom", 0.0), unit);
     Kivio::setFormatOrientation(layout);
-    kdDebug(43000) << "Ready." << endl;
+    kDebug(43000) <<"Ready.";
   } else {
     layout.ptWidth = XmlReadFloat(e, "width", 0.0);
     layout.ptHeight = XmlReadFloat(e, "height", 0.0);
@@ -67,80 +85,80 @@ KoPageLayout Kivio::loadPageLayout(const QDomElement& e)
     layout.ptRight = XmlReadFloat(e, "marginRight", 0.0);
     layout.ptTop = XmlReadFloat(e, "marginTop", 0.0);
     layout.ptBottom = XmlReadFloat(e, "marginBottom", 0.0);
-    layout.format = KoPageFormat::formatFromString(XmlReadString(e, "format", "A4"));
+    layout.format = KoPageFormat::formatFromString(XmlReadString(e, "format", pageSizeString(KGlobal::locale()->pageSize())));
     layout.orientation = Kivio::orientationFromString(XmlReadString(e, "orientation", "Portrait"));
   }
 
   return layout;
 }
 
-KoUnit::Unit Kivio::convToKoUnit(int tkUnit)
+KoUnit Kivio::convToKoUnit(int tkUnit)
 {
   switch(tkUnit) {
     case 0:
-      return KoUnit::U_PT;
+      return KoUnit::Point;
     case 1:
-      return KoUnit::U_MM;
+      return KoUnit::Millimeter;
     case 2:
-      return KoUnit::U_INCH;
+      return KoUnit::Inch;
     case 3:
-      return KoUnit::U_PI;
+      return KoUnit::Pica;
     case 4:
-      return KoUnit::U_CM;
+      return KoUnit::Centimeter;
     case 5:
-      return KoUnit::U_DD;
+      return KoUnit::Didot;
     case 6:
-      return KoUnit::U_CC;
+      return KoUnit::Cicero;
   }
 
-  return KoUnit::U_PT;
+  return KoUnit::Point;
 }
 
-QString Kivio::orientationString(KoOrientation o)
+QString Kivio::orientationString(KoPageFormat::Orientation o)
 {
-  if(o == PG_LANDSCAPE) {
+  if(o == KoPageFormat::Landscape) {
     return "Landscape";
   }
 
   return "Portrait";
 }
 
-KoOrientation Kivio::orientationFromString(const QString& s)
+KoPageFormat::Orientation Kivio::orientationFromString(const QString& s)
 {
   if(s == "Landscape") {
-    return PG_LANDSCAPE;
+    return KoPageFormat::Landscape;
   }
 
-  return PG_PORTRAIT;
+  return KoPageFormat::Portrait;
 }
 
 void Kivio::setFormatOrientation(KoPageLayout& layout)
 {
   const PaperSizeDef PapersTable[] = {
-    {"A0",841,1189,KoUnit::U_MM},
-    {"A1",594,841,KoUnit::U_MM},
-    {"A2",420,594,KoUnit::U_MM},
-    {"A3",297,420,KoUnit::U_MM},
-    {"A4",210,297,KoUnit::U_MM},
-    {"A5",148,210,KoUnit::U_MM},
+    {"A0",841,1189,KoUnit::Millimeter},
+    {"A1",594,841,KoUnit::Millimeter},
+    {"A2",420,594,KoUnit::Millimeter},
+    {"A3",297,420,KoUnit::Millimeter},
+    {"A4",210,297,KoUnit::Millimeter},
+    {"A5",148,210,KoUnit::Millimeter},
 
-    {"B4",250,353,KoUnit::U_MM},
-    {"B6",125,176,KoUnit::U_MM},
+    {"B4",250,353,KoUnit::Millimeter},
+    {"B6",125,176,KoUnit::Millimeter},
 
-    {"C4",229,324,KoUnit::U_MM},
-    {"C5",162,229,KoUnit::U_MM},
-    {"C5",114,162,KoUnit::U_MM},
+    {"C4",229,324,KoUnit::Millimeter},
+    {"C5",162,229,KoUnit::Millimeter},
+    {"C5",114,162,KoUnit::Millimeter},
 
-    {"DL",110,220,KoUnit::U_MM},
+    {"DL",110,220,KoUnit::Millimeter},
 
-    {"Letter",8.5,11,KoUnit::U_INCH},
-    {"Legal",8.5,14,KoUnit::U_INCH},
+    {"Letter",8.5,11,KoUnit::Inch},
+    {"Legal",8.5,14,KoUnit::Inch},
 
-    {"A",8.5,11,KoUnit::U_INCH},
-    {"B",11,17,KoUnit::U_INCH},
-    {"C",17,22,KoUnit::U_INCH},
-    {"D",22,34,KoUnit::U_INCH},
-    {"E",34,44,KoUnit::U_INCH},
+    {"A",8.5,11,KoUnit::Inch},
+    {"B",11,17,KoUnit::Inch},
+    {"C",17,22,KoUnit::Inch},
+    {"D",22,34,KoUnit::Inch},
+    {"E",34,44,KoUnit::Inch},
 
     {"null",0,0,-2}     // -2 for end of list
   };
@@ -148,20 +166,20 @@ void Kivio::setFormatOrientation(KoPageLayout& layout)
   PaperSizeDef sizeDef = PapersTable[0];
   bool found = false;
   float width, height;
-  layout.format = PG_CUSTOM;
-  layout.orientation = PG_PORTRAIT;
+  layout.format = KoPageFormat::CustomSize;
+  layout.orientation = KoPageFormat::Portrait;
 
   while((sizeDef.unit != -2) && !found) {
-    width = KoUnit::ptFromUnit(sizeDef.width, static_cast<KoUnit::Unit>(sizeDef.unit));
-    height = KoUnit::ptFromUnit(sizeDef.height, static_cast<KoUnit::Unit>(sizeDef.unit));
+    width = KoUnit::fromUserValue(sizeDef.width, static_cast<KoUnit>(sizeDef.unit));
+    height = KoUnit::fromUserValue(sizeDef.height, static_cast<KoUnit>(sizeDef.unit));
 
     if((layout.ptWidth == width) && (layout.ptHeight == height)) {
       layout.format = KoPageFormat::formatFromString(sizeDef.title);
-      layout.orientation = PG_PORTRAIT;
+      layout.orientation = KoPageFormat::Portrait;
       found = true;
     } else if((layout.ptWidth == height) && (layout.ptHeight == width)) {
       layout.format = KoPageFormat::formatFromString(sizeDef.title);
-      layout.orientation = PG_LANDSCAPE;
+      layout.orientation = KoPageFormat::Landscape;
       found = true;
     }
 
@@ -174,9 +192,9 @@ KoSize Kivio::loadSize(const QDomElement& e, const QString& name, const KoSize&
   KoSize size;
   if(e.hasAttribute(name + "Unit")) {
     // Compatibility with Kivio <= 1.2.x
-    KoUnit::Unit unit = Kivio::convToKoUnit(XmlReadInt(e, name + "Unit", 0));
-    size.setWidth(KoUnit::ptFromUnit(XmlReadFloat(e, name + "Width", def.width()), unit));
-    size.setHeight(KoUnit::ptFromUnit(XmlReadFloat(e, name + "Height", def.height()), unit));
+    KoUnit unit = Kivio::convToKoUnit(XmlReadInt(e, name + "Unit", 0));
+    size.setWidth(KoUnit::fromUserValue(XmlReadFloat(e, name + "Width", def.width()), unit));
+    size.setHeight(KoUnit::fromUserValue(XmlReadFloat(e, name + "Height", def.height()), unit));
   } else {
     size.setWidth(XmlReadFloat(e, name + "Width", def.width()));
     size.setHeight(XmlReadFloat(e, name + "Height", def.height()));
@@ -191,12 +209,116 @@ void Kivio::saveSize(QDomElement& e, const QString& name, const KoSize& size)
   XmlWriteFloat(e, name + "Height", size.height());
 }
 
+QString Kivio::pageSizeString(int pageSize)
+{
+  QString psStr = "A4";
+
+  switch(pageSize) {
+    case QPrinter::A0:
+      psStr = "A0";
+      break;
+    case QPrinter::A1:
+      psStr = "A1";
+      break;
+    case QPrinter::A2:
+      psStr = "A2";
+      break;
+    case QPrinter::A3:
+      psStr = "A3";
+      break;
+    case QPrinter::A5:
+      psStr = "A5";
+      break;
+    case QPrinter::A6:
+      psStr = "A6";
+      break;
+    case QPrinter::A7:
+      psStr = "A7";
+      break;
+    case QPrinter::A8:
+      psStr = "A8";
+      break;
+    case QPrinter::A9:
+      psStr = "A9";
+      break;
+    case QPrinter::B0:
+      psStr = "B0";
+      break;
+    case QPrinter::B1:
+      psStr = "B1";
+      break;
+    case QPrinter::B10:
+      psStr = "B10";
+      break;
+    case QPrinter::B2:
+      psStr = "B2";
+      break;
+    case QPrinter::B3:
+      psStr = "B3";
+      break;
+    case QPrinter::B4:
+      psStr = "B4";
+      break;
+    case QPrinter::B5:
+      psStr = "B5";
+      break;
+    case QPrinter::B6:
+      psStr = "B6";
+      break;
+    case QPrinter::B7:
+      psStr = "B7";
+      break;
+    case QPrinter::B8:
+      psStr = "B8";
+      break;
+    case QPrinter::B9:
+      psStr = "B9";
+      break;
+    case QPrinter::C5E:
+      psStr = "C5";
+      break;
+    case QPrinter::Comm10E:
+      psStr = "Comm10";
+      break;
+    case QPrinter::DLE:
+      psStr = "DL";
+      break;
+    case QPrinter::Executive:
+      psStr = "Executive";
+      break;
+    case QPrinter::Folio:
+      psStr = "Folio";
+      break;
+    case QPrinter::Ledger:
+      psStr = "Ledger";
+      break;
+    case QPrinter::Legal:
+      psStr = "Legal";
+      break;
+    case QPrinter::Letter:
+      psStr = "Letter";
+      break;
+    case QPrinter::Tabloid:
+      psStr = "Tabloid";
+      break;
+    case QPrinter::Custom:
+      psStr = "Custom";
+      break;
+    case QPrinter::A4:
+    default:
+      psStr = "A4";
+      break;
+  };
+
+  return psStr;
+}
+
 QPixmap Kivio::arrowHeadPixmap()
 {
   const char* lineends[] = {
     "50 272 2 1",
-    "  c Gray0",
-    "X c Gray100",
+    "  c #000000",
+    "X c #ffffff",
     "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX",
     "X                                                X",
     "X XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX X",
@@ -1119,3 +1241,77 @@ QPixmap Kivio::arrowHeadPixmap()
 
   return QPixmap(lineends);
 }
+
+QPixmap Kivio::connectorTargetPixmap()
+{
+  const char * connectorTarget_xpm[] = {
+  "7 7 3 1",
+  "       c None",
+  ".      c #FFFFFF",
+  "+      c #051EFF",
+  " .   . ",
+  ".+. .+.",
+  " .+.+. ",
+  "  .+.  ",
+  " .+.+. ",
+  ".+. .+.",
+  " .   . "};
+
+  return QPixmap(connectorTarget_xpm);
+}
+
+QPixmap Kivio::lockPixmap()
+{
+  const char * lock_xpm[] = {
+  "10 10 3 1",
+  " 	c None",
+  ".	c #FFFFFF",
+  "+	c #000000",
+  "    ..    ",
+  "   .++.   ",
+  "  .+..+.  ",
+  "  .+..+.  ",
+  " .++++++. ",
+  " .+....+. ",
+  " .+.  .+. ",
+  " .+....+. ",
+  " .++++++. ",
+  "  ......  "};
+
+  return QPixmap(lock_xpm);
+}
+
+QString Kivio::systemDefaultUnit()
+{
+  QString defMS = "cm";
+
+  if(KGlobal::locale()->measureSystem() == KLocale::Imperial) {
+    defMS = "in";
+  }
+
+  return defMS;
+}
+
+QPixmap Kivio::generatePixmapFromStencil(int width, int height, KivioStencil* stencil)
+{
+  KoZoomHandler zoomHandler;
+  QRect rect = zoomHandler.zoomRect(stencil->rect());
+
+  double zw = (double)(width - 2) / (double)rect.width();
+  double zh = (double)(height - 2) / (double)rect.height();
+  zoomHandler.setZoomAndResolution(qRound(qMin(zw, zh) * 100.0), KoGlobal::dpiX(), KoGlobal::dpiY());
+  rect = zoomHandler.zoomRect(stencil->rect());
+
+  QPixmap pix(width, height);
+  pix.fill(Qt::white);
+  KivioScreenPainter kpainter;
+  kpainter.start(&pix);
+  kpainter.translateBy(-rect.x() + ((width - rect.width()) / 2), -rect.y() + ((height - rect.height()) / 2));
+  KivioIntraStencilData data;
+  data.painter = &kpainter;
+  data.zoomHandler = &zoomHandler;
+  stencil->paint(&data);
+  kpainter.stop();
+
+  return pix;
+}
