@@ -14,12 +14,12 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 #ifndef KIVIO_PAINTER_H
 #define KIVIO_PAINTER_H
 
-#include <qfont.h>
+#include <QFont>
 #include <qptrlist.h>
 #include <qpaintdevice.h>
 #include <qpixmap.h>
@@ -145,7 +145,7 @@ public:
     virtual void rotateBy(int) {;}
     virtual int rotation() { return 0; }
 
-    virtual void setWorldMatrix(QWMatrix, bool) {;}
+    virtual void setMatrix(QMatrix, bool) {;}
 };
 
 #endif
