@@ -14,19 +14,22 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
-#include "kivio_config.h"
+#include "kivioglobal.h"
 #include "kivio_line_style.h"
 #include "kivio_point.h"
 #include "kivio_screen_painter.h"
 
+#include <qimage.h>
 #include <qpen.h>
 #include <qbrush.h>
+#include <qsimplerichtext.h>
+#include <qpalette.h>
 
 #include <kdebug.h>
 
-#define PAINTER_CHECK() { if(!m_pPainter) { kdDebug() << "KivioScreenPainter::PAINTER_CHECK() - no QPainter exists." << endl; } }
+#define PAINTER_CHECK() { if(!m_pPainter) { kDebug(43000) <<"KivioScreenPainter::PAINTER_CHECK() - no QPainter exists."; } }
 
 
 KivioScreenPainter::KivioScreenPainter()
@@ -34,14 +37,22 @@ KivioScreenPainter::KivioScreenPainter()
 {
    m_transX = 0.0f;
    m_transY = 0.0f;
-   m_rotation = 0.0f;
+   m_rotation = 0;
+}
+
+KivioScreenPainter::KivioScreenPainter(QPainter* painter)
+    : m_pPainter(painter)
+{
+   m_transX = 0.0f;
+   m_transY = 0.0f;
+   m_rotation = 0;
 }
 
 KivioScreenPainter::~KivioScreenPainter()
 {
     if( m_pPainter )
     {
-       kdDebug() << "KivioScreenPainter::~KivioScreenPainter - A QPainter slipped through the cracks" << endl;
+       kDebug(43000) <<"KivioScreenPainter::~KivioScreenPainter - A QPainter slipped through the cracks";
         delete m_pPainter;
         m_pPainter = NULL;
     }
@@ -61,13 +72,13 @@ bool KivioScreenPainter::start( QPaintDevice *dev )
     // Bomb out if one exists already
     if( m_pPainter )
     {
-       kdDebug() << "KivioScreenPainter::start() - A QPainter already exists" << endl;
+       kDebug(43000) <<"KivioScreenPainter::start() - A QPainter already exists";
         return false;
     }
 
     // Allocate a new drawing thingy
     m_pPainter = new QPainter(dev);
-    
+
     return true;
 }
 
@@ -84,14 +95,14 @@ bool KivioScreenPainter::stop()
     // called @ref start().
     if( !m_pPainter )
     {
-       kdDebug() <<"KivioScreenPainter::stop() called without previous call to start" << endl;
+       kDebug(43000) <<"KivioScreenPainter::stop() called without previous call to start";
         return false;
     }
 
     // Otherwise delete and nullify the pointer
     delete m_pPainter;
     m_pPainter = NULL;
-    
+
     return true;
 }
 
@@ -110,12 +121,12 @@ bool KivioScreenPainter::stop()
  */
 void KivioScreenPainter::drawLine( float x1, float y1, float x2, float y2 )
 {
-    PAINTER_CHECK();        
-    
+    PAINTER_CHECK();
+
     m_pPainter->setPen(m_pLineStyle->pen(1.0f));
-    
+
     m_pPainter->drawLine( int(x1), int(y1), int(x2), int(y2) );
-    
+
 }
 
 
@@ -134,7 +145,7 @@ void KivioScreenPainter::drawLine( float x1, float y1, float x2, float y2 )
 void KivioScreenPainter::drawArc( float x1, float y1, float w1, float h1, float a1, float a2 )
 {
     PAINTER_CHECK();
-    
+
     m_pPainter->setPen(m_pLineStyle->pen(1.0f));
 
     m_pPainter->drawArc( int(x1), int(y1), int(w1), int(h1), int(a1), int(a2) );
@@ -152,10 +163,10 @@ void KivioScreenPainter::drawArc( float x1, float y1, float w1, float h1, float
 void KivioScreenPainter::drawBezier( QPointArray &pArray )
 {
     PAINTER_CHECK();
-    
+
     m_pPainter->setPen(m_pLineStyle->pen(1.0f));
 
-    m_pPainter->drawQuadBezier(pArray);
+    m_pPainter->drawCubicBezier(pArray);
 }
 
 
@@ -170,7 +181,7 @@ void KivioScreenPainter::drawBezier( QPointArray &pArray )
 void KivioScreenPainter::drawRect( float x1, float y1, float w1, float h1 )
 {
     PAINTER_CHECK();
-    
+
     m_pPainter->setPen(m_pLineStyle->pen(1.0f));
     m_pPainter->setBrush(QBrush::NoBrush);
     m_pPainter->drawRect( int(x1), int(y1), int(w1), int(h1) );
@@ -191,33 +202,23 @@ void KivioScreenPainter::drawRect( float x1, float y1, float w1, float h1 )
 void KivioScreenPainter::fillRect( float x1, float y1, float w1, float h1 )
 {
     PAINTER_CHECK();
-    
+
     QBrush b;
-    
+    b = m_pFillStyle->brush();
 
-    switch( m_pFillStyle->colorStyle() )
-    {
-        case KivioFillStyle::kcsSolid:
-            b.setColor( m_pFillStyle->color() );
-            b.setStyle( QBrush::SolidPattern );
-            break;
-            
-        case KivioFillStyle::kcsGradient:
-	   kdDebug() << "KivioScreenPainter::fillRect() - Gradient not supported yet" << endl;
-            return;
-
-        case KivioFillStyle::kcsNone:
-	   kdDebug() << "KivioScreenPainter::fillRect() - don't call fillRect() without wanting to fill it!" << endl;
-            return;
-            
-        default:
-	   kdDebug() << "KivioScreenpainter::fillRect() - unknown color style" << endl;
-            return;
+    if(m_pFillStyle->colorStyle() == KivioFillStyle::kcsGradient) {
+      QPixmap pix((int)w1, (int)h1);
+      QImage image = KImageEffect::gradient(pix.size(), m_pFillStyle->color(), m_pFillStyle->color2(),
+        (KImageEffect::GradientType) m_pFillStyle->gradientType());
+      pix.convertFromImage(image);
+      b.setPixmap(pix);
+      m_pPainter->setBrushOrigin(int(x1 + m_transX), int(y1 + m_transY));
     }
-    
+
     m_pPainter->setPen(m_pLineStyle->pen(1.0f));
     m_pPainter->setBrush(b);
     m_pPainter->drawRect( int(x1), int(y1), int(w1), int(h1) );
+    m_pPainter->setBrushOrigin(0, 0);
 }
 
 
@@ -237,7 +238,7 @@ void KivioScreenPainter::fillRect( float x1, float y1, float w1, float h1 )
 void KivioScreenPainter::drawRoundRect( float x1, float y1, float w1, float h1, float a1, float a2 )
 {
     PAINTER_CHECK();
-    
+
     m_pPainter->setPen(m_pLineStyle->pen(1.0f));
     m_pPainter->setBrush(QBrush::NoBrush);
     m_pPainter->drawRoundRect( int(x1), int(y1), int(w1), int(h1), int(a1), int(a2) );
@@ -261,33 +262,23 @@ void KivioScreenPainter::drawRoundRect( float x1, float y1, float w1, float h1,
 void KivioScreenPainter::fillRoundRect( float x1, float y1, float w1, float h1, float a1, float a2 )
 {
     PAINTER_CHECK();
-    
+
     QBrush b;
-    
+    b = m_pFillStyle->brush();
 
-    switch( m_pFillStyle->colorStyle() )
-    {
-        case KivioFillStyle::kcsSolid:
-            b.setColor( m_pFillStyle->color() );
-            b.setStyle( QBrush::SolidPattern );
-            break;
-            
-        case KivioFillStyle::kcsGradient:
-	   kdDebug() << "fillRoundRect() - Gradient not supported yet" << endl;
-            return;
-
-        case KivioFillStyle::kcsNone:
-	   kdDebug() << "don't call fillRoundRect() without wanting to fill it!" << endl;
-            return;
-            
-        default:
-           kdDebug() << "fillRoundRect() - unknown color style" << endl;
-            return;
+    if(m_pFillStyle->colorStyle() == KivioFillStyle::kcsGradient) {
+      QPixmap pix((int)w1, (int)h1);
+      QImage image = KImageEffect::gradient(pix.size(), m_pFillStyle->color(), m_pFillStyle->color2(),
+        (KImageEffect::GradientType) m_pFillStyle->gradientType());
+      pix.convertFromImage(image);
+      b.setPixmap(pix);
+      m_pPainter->setBrushOrigin(int(x1 + m_transX), int(y1 + m_transY));
     }
-    
+
     m_pPainter->setPen(m_pLineStyle->pen(1.0f));
     m_pPainter->setBrush(b);
     m_pPainter->drawRoundRect( int(x1), int(y1), int(w1), int(h1), int(a1), int(a2) );
+    m_pPainter->setBrushOrigin(0, 0);
 }
 
 
@@ -307,7 +298,7 @@ void KivioScreenPainter::fillRoundRect( float x1, float y1, float w1, float h1,
 void KivioScreenPainter::drawPie( float x1, float y1, float w1, float h1, float a1, float a2 )
 {
     PAINTER_CHECK();
-    
+
     m_pPainter->setPen(m_pLineStyle->pen(1.0f));
     m_pPainter->setBrush(QBrush::NoBrush);
     m_pPainter->drawPie( int(x1), int(y1), int(w1), int(h1), int(a1), int(a2) );
@@ -330,32 +321,23 @@ void KivioScreenPainter::drawPie( float x1, float y1, float w1, float h1, float
 void KivioScreenPainter::fillPie( float x1, float y1, float w1, float h1, float a1, float a2 )
 {
     PAINTER_CHECK();
-    
-    QBrush b;
-    
-    switch( m_pFillStyle->colorStyle() )
-    {
-        case KivioFillStyle::kcsSolid:
-            b.setColor( m_pFillStyle->color() );
-            b.setStyle( QBrush::SolidPattern );
-            break;
-            
-        case KivioFillStyle::kcsGradient:
-	   kdDebug() << "fillPie() - Gradient not supported yet" << endl;
-            return;
 
-        case KivioFillStyle::kcsNone:
-	   kdDebug() << "don't call fillPie() without wanting to fill it!" << endl;
-            return;
-            
-        default:
-	   kdDebug() << "fillPie() - unknown color style" << endl;
-            return;
+    QBrush b;
+    b = m_pFillStyle->brush();
+
+    if(m_pFillStyle->colorStyle() == KivioFillStyle::kcsGradient) {
+      QPixmap pix((int)w1, (int)h1);
+      QImage image = KImageEffect::gradient(pix.size(), m_pFillStyle->color(), m_pFillStyle->color2(),
+        (KImageEffect::GradientType) m_pFillStyle->gradientType());
+      pix.convertFromImage(image);
+      b.setPixmap(pix);
+      m_pPainter->setBrushOrigin(int(x1 + m_transX), int(y1 + m_transY));
     }
-    
+
     m_pPainter->setPen(m_pLineStyle->pen(1.0f));
     m_pPainter->setBrush(b);
     m_pPainter->drawPie( int(x1), int(y1), int(w1), int(h1), int(a1), int(a2) );
+    m_pPainter->setBrushOrigin(0, 0);
 }
 
 
@@ -375,7 +357,7 @@ void KivioScreenPainter::fillPie( float x1, float y1, float w1, float h1, float
 void KivioScreenPainter::drawChord( float x1, float y1, float w1, float h1, float a1, float a2 )
 {
     PAINTER_CHECK();
-    
+
     m_pPainter->setPen(m_pLineStyle->pen(1.0f));
     m_pPainter->setBrush(QBrush::NoBrush);
     m_pPainter->drawChord( int(x1), int(y1), int(w1), int(h1), int(a1), int(a2) );
@@ -398,32 +380,23 @@ void KivioScreenPainter::drawChord( float x1, float y1, float w1, float h1, floa
 void KivioScreenPainter::fillChord( float x1, float y1, float w1, float h1, float a1, float a2 )
 {
     PAINTER_CHECK();
-    
-    QBrush b;
-    
-    switch( m_pFillStyle->colorStyle() )
-    {
-        case KivioFillStyle::kcsSolid:
-            b.setColor( m_pFillStyle->color() );
-            b.setStyle( QBrush::SolidPattern );
-            break;
-            
-        case KivioFillStyle::kcsGradient:
-	   kdDebug() << "fillChord() - Gradient not supported yet" << endl;
-            return;
 
-        case KivioFillStyle::kcsNone:
-	   kdDebug() << "don't call fillChord() without wanting to fill it!" << endl;
-            return;
-            
-        default:
-	   kdDebug() << "fillChord() - unknown color style" << endl;
-            return;
+    QBrush b;
+    b = m_pFillStyle->brush();
+
+    if(m_pFillStyle->colorStyle() == KivioFillStyle::kcsGradient) {
+      QPixmap pix((int)w1, (int)h1);
+      QImage image = KImageEffect::gradient(pix.size(), m_pFillStyle->color(),
+        m_pFillStyle->color2(), m_pFillStyle->gradientType());
+      pix.convertFromImage(image);
+      b.setPixmap(pix);
+      m_pPainter->setBrushOrigin(int(x1 + m_transX), int(y1 + m_transY));
     }
-    
+
     m_pPainter->setPen(m_pLineStyle->pen(1.0f));
     m_pPainter->setBrush(b);
     m_pPainter->drawChord( int(x1), int(y1), int(w1), int(h1), int(a1), int(a2) );
+    m_pPainter->setBrushOrigin(0, 0);
 }
 
 
@@ -441,7 +414,7 @@ void KivioScreenPainter::fillChord( float x1, float y1, float w1, float h1, floa
 void KivioScreenPainter::drawEllipse( float x1, float y1, float w1, float h1 )
 {
     PAINTER_CHECK();
-    
+
     m_pPainter->setPen(m_pLineStyle->pen(1.0f));
     m_pPainter->setBrush(QBrush::NoBrush);
     m_pPainter->drawEllipse( int(x1), int(y1), int(w1), int(h1) );
@@ -462,32 +435,23 @@ void KivioScreenPainter::drawEllipse( float x1, float y1, float w1, float h1 )
 void KivioScreenPainter::fillEllipse( float x1, float y1, float w1, float h1 )
 {
     PAINTER_CHECK();
-    
-    QBrush b;
-    
-    switch( m_pFillStyle->colorStyle() )
-    {
-        case KivioFillStyle::kcsSolid:
-            b.setColor( m_pFillStyle->color() );
-            b.setStyle( QBrush::SolidPattern );
-            break;
-            
-        case KivioFillStyle::kcsGradient:
-	   kdDebug() << "fillEllipse() - Gradient not supported yet" << endl;
-            return;
 
-        case KivioFillStyle::kcsNone:
-	   kdDebug() << "don't call fillEllipse() without wanting to fill it!" << endl;
-            return;
-            
-        default:
-	   kdDebug() << "fillEllipse() - unknown color style" << endl;
-            return;
+    QBrush b;
+    b = m_pFillStyle->brush();
+
+    if(m_pFillStyle->colorStyle() == KivioFillStyle::kcsGradient) {
+      QPixmap pix((int)w1, (int)h1);
+      QImage image = KImageEffect::gradient(pix.size(), m_pFillStyle->color(), m_pFillStyle->color2(),
+        (KImageEffect::GradientType) m_pFillStyle->gradientType());
+      pix.convertFromImage(image);
+      b.setPixmap(pix);
+      m_pPainter->setBrushOrigin(int(x1 + m_transX), int(y1 + m_transY));
     }
-    
+
     m_pPainter->setPen(m_pLineStyle->pen(1.0f));
     m_pPainter->setBrush(b);
     m_pPainter->drawEllipse( int(x1), int(y1), int(w1), int(h1) );
+    m_pPainter->setBrushOrigin(0, 0);
 }
 
 
@@ -499,30 +463,30 @@ void KivioScreenPainter::fillEllipse( float x1, float y1, float w1, float h1 )
  * The list of points should contain a list of points in
  * pairs.  Lines are drawn from p1->p2 p3->p4 p5->p6, etc...
  */
-void KivioScreenPainter::drawLineArray( QList<KivioPoint> *pList )
+void KivioScreenPainter::drawLineArray( QPtrList<KivioPoint> *pList )
 {
-    PAINTER_CHECK();
-    
-    KivioPoint *pPoint;
-    QPointArray points(pList->count());
-    int i;
-    QBrush b;
-    
-    b.setStyle( QBrush::NoBrush );
-    
-    i=0;
-    pPoint = pList->first();
-    while( pPoint )
-    {
-        points.setPoint( i++, int(pPoint->x()), int(pPoint->y()) );
-        
-        pPoint = pList->next();
-    }
-    
-    m_pPainter->setPen(m_pLineStyle->pen(1.0f));
-    m_pPainter->setBrush(b);
+  PAINTER_CHECK();
 
-    m_pPainter->drawLineSegments(points);
+  KivioPoint *pPoint;
+  QPointArray points(pList->count());
+  int i;
+  QBrush b;
+
+  b.setStyle( QBrush::NoBrush );
+
+  i=0;
+  pPoint = pList->first();
+  while( pPoint )
+  {
+    points.setPoint( i++, int(pPoint->x()), int(pPoint->y()) );
+
+    pPoint = pList->next();
+  }
+
+  m_pPainter->setPen(m_pLineStyle->pen(1.0f));
+  m_pPainter->setBrush(b);
+
+  m_pPainter->drawLineSegments(points);
 }
 
 
@@ -533,26 +497,22 @@ void KivioScreenPainter::drawLineArray( QList<KivioPoint> *pList )
  *
  * Draws a polyline (hollow) from p1->p2->p3->pn
  */
-void KivioScreenPainter::drawPolyline( QList<KivioPoint> *pList )
+void KivioScreenPainter::drawPolyline( QPtrList<KivioPoint> *pList )
 {
-    PAINTER_CHECK();
-    
-    KivioPoint *pPoint;
-    QPointArray points( pList->count() );
-    int i;
+  PAINTER_CHECK();
 
-    i=0;
-    pPoint = pList->first();
-    while( pPoint )
-    {
-        points.setPoint(i++, int(pPoint->x()), int(pPoint->y()) );
-        
-        pPoint = pList->next();
-    }
-    
-    m_pPainter->setPen(m_pLineStyle->pen(1.0f));
-    m_pPainter->setBrush(QBrush::NoBrush);
-    m_pPainter->drawPolyline(points);
+  KivioPoint *pPoint;
+  QPointArray points( pList->count() );
+  int i = 0;
+  pPoint = pList->first();
+
+  while( pPoint )
+  {
+    points.setPoint(i++, int(pPoint->x()), int(pPoint->y()) );
+    pPoint = pList->next();
+  }
+
+  drawPolyline(points);
 }
 
 
@@ -564,96 +524,76 @@ void KivioScreenPainter::drawPolyline( QList<KivioPoint> *pList )
  *
  * Draws a filled (if set) polygon from p1->p2->p3->pn->p1
  */
-void KivioScreenPainter::drawPolygon( QList<KivioPoint> *pList )
+void KivioScreenPainter::drawPolygon( QPtrList<KivioPoint> *pList )
 {
-    PAINTER_CHECK();
-    
-    KivioPoint *pPoint;
-    QPointArray points( pList->count() );
-    int i;
-    QBrush b;
-    
-    switch( m_pFillStyle->colorStyle() )
-    {
-        case KivioFillStyle::kcsSolid:
-            b.setColor( m_pFillStyle->color() );
-            b.setStyle( QBrush::SolidPattern );
-            break;
-            
-        case KivioFillStyle::kcsGradient:
-	   kdDebug() << "drawPolygon() - Gradient not supported yet" << endl;
-            return;
+  PAINTER_CHECK();
 
-        case KivioFillStyle::kcsNone:
-            b.setStyle(QBrush::NoBrush);
-            return;
-            
-        default:
-           kdDebug() << "drawPolygon() - unknown color style" << endl;
-            return;
-    }    
-    
-    i=0;
-    pPoint = pList->first();
-    while( pPoint )
-    {
-        points.setPoint(i++, int(pPoint->x()), int(pPoint->y()) );
-        
-        pPoint = pList->next();
-    }
-    
-    m_pPainter->setPen(m_pLineStyle->pen(1.0f));
-    m_pPainter->setBrush(b);
-    m_pPainter->drawPolygon(points,true);
+  KivioPoint *pPoint;
+  QPointArray points( pList->count() );
+  int i = 0;
+  pPoint = pList->first();
 
+  while( pPoint )
+  {
+    points.setPoint(i++, int(pPoint->x()), int(pPoint->y()) );
+    pPoint = pList->next();
+  }
+
+  drawPolygon(points);
 }
 
 void KivioScreenPainter::drawPolyline( QPointArray &pArray )
 {
-    PAINTER_CHECK();
-    
-    m_pPainter->setPen(m_pLineStyle->pen(1.0f));
-    m_pPainter->setBrush( QBrush::NoBrush );
+  PAINTER_CHECK();
 
-    m_pPainter->drawPolyline( pArray );
+  m_pPainter->setPen(m_pLineStyle->pen(1.0f));
+  m_pPainter->setBrush( QBrush::NoBrush );
+
+  m_pPainter->drawPolyline( pArray, 0, pArray.size() );
 }
 
 void KivioScreenPainter::drawPolygon( QPointArray &pArray )
 {
-    PAINTER_CHECK();
-    
-    QBrush b;
-    
-    switch( m_pFillStyle->colorStyle() )
-    {
-        case KivioFillStyle::kcsSolid:
-            b.setColor( m_pFillStyle->color() );
-            b.setStyle( QBrush::SolidPattern );
-            break;
-            
-        case KivioFillStyle::kcsGradient:
-	   kdDebug() << "drawPolygon() - Gradient not supported yet" << endl;
-            return;
+  PAINTER_CHECK();
 
-        case KivioFillStyle::kcsNone:
-            b.setStyle(QBrush::NoBrush);
-            return;
-            
-        default:
-	   kdDebug() << "drawPolygon() - unknown color style" << endl;
-            return;
-    }    
-    
-    m_pPainter->setPen(m_pLineStyle->pen(1.0f));
-    m_pPainter->setBrush(b);
+  QBrush b;
+  b = m_pFillStyle->brush();
 
-    m_pPainter->drawPolygon( pArray, true );
+  if(m_pFillStyle->colorStyle() == KivioFillStyle::kcsGradient) {
+    int x1, y1, w1, h1;
+    x1 = pArray[0].x();
+    y1 = pArray[0].y();
+    w1 = h1 = 0;
+
+    for(unsigned int i = 0; i < pArray.count(); i++) {
+      x1 = qMin(x1, pArray[i].x());
+      y1 = qMin(y1, pArray[i].y());
+      w1 = qMax(w1, pArray[i].x());
+      h1 = qMax(h1, pArray[i].y());
+    }
+
+    w1 = w1 - x1;
+    h1 = h1 - y1;
+
+    QPixmap pix(w1, h1);
+    QImage image = KImageEffect::gradient(pix.size(), m_pFillStyle->color(), m_pFillStyle->color2(),
+      (KImageEffect::GradientType) m_pFillStyle->gradientType());
+    pix.convertFromImage(image);
+    b.setPixmap(pix);
+    m_pPainter->setBrushOrigin(x1 + (int)m_transX, y1 + (int)m_transY);
+  }
+
+  m_pPainter->setPen(m_pLineStyle->pen(1.0f));
+  m_pPainter->setBrush(b);
+
+  m_pPainter->drawPolygon( pArray, true );
+  m_pPainter->setBrushOrigin(0, 0);
 }
 
 void KivioScreenPainter::drawLineArray( QPointArray &pArray )
 {
     PAINTER_CHECK();
-    
+
     m_pPainter->setPen(m_pLineStyle->pen(1.0f));
     m_pPainter->setBrush(QBrush::NoBrush);
 
@@ -669,16 +609,16 @@ void KivioScreenPainter::drawLineArray( QPointArray &pArray )
  * Draws a filled (if set) curve with the points stored
  * in pPoints.  They can be made up of bezier, arc, and normal points.
  */
-void KivioScreenPainter::drawClosedPath( QList<KivioPoint> *pPoints )
+void KivioScreenPainter::drawClosedPath( QPtrList<KivioPoint> *pPoints )
 {
     PAINTER_CHECK();
 
     QBrush brush;
-    
+
     KivioPoint *pPoint, *pPoint2, *pPoint3, *pPoint4;
-    QList <KivioPoint> *pPointList = pPoints;
+    QPtrList <KivioPoint> *pPointList = pPoints;
     QPointArray controlPoints(4), bPoints(0), tmpPoints;
-    
+
     int pointIndex=0;
     pPoint = pPointList->first();
     while( pPoint )
@@ -693,54 +633,54 @@ void KivioScreenPainter::drawClosedPath( QList<KivioPoint> *pPoints )
             pPoint2 = pPointList->next();
             pPoint3 = pPointList->next();
             pPoint4 = pPointList->next();
-            
+
             if( !pPoint2 || !pPoint3 || !pPoint4 )
             {
-	       kdDebug() << "drawClosedPath() - incorrect # of bezier points" << endl;
+                kDebug(43000) <<"drawClosedPath() - incorrect # of bezier points";
                 return;
             }
-            
+
             if( pPoint2->pointType() != KivioPoint::kptBezier ||
                 pPoint3->pointType() != KivioPoint::kptBezier ||
                 pPoint4->pointType() != KivioPoint::kptBezier )
             {
-	       kdDebug() << "drawClosedPath() - bezier curves must have 4 points" << endl;
+                kDebug(43000) <<"drawClosedPath() - bezier curves must have 4 points";
                 return;
             }
-            
-            controlPoints.setPoint( 0, pPoint->x(), pPoint->y() );
-			controlPoints.setPoint( 1, pPoint2->x(), pPoint2->y() );
-			controlPoints.setPoint( 2, pPoint3->x(), pPoint3->y() );
-			controlPoints.setPoint( 3, pPoint4->x(), pPoint4->y() );
-			
-			tmpPoints = controlPoints.quadBezier();
-			
-			for( int j=0; j<int(tmpPoints.size()); j++ )
-			{
-			    bPoints.putPoints( pointIndex, 1, tmpPoints.point(j).x(), tmpPoints.point(j).y() );
-			    pointIndex++;
-			}
+
+            controlPoints.setPoint( 0, qRound(pPoint->x()), qRound(pPoint->y()) );
+            controlPoints.setPoint( 1, qRound(pPoint2->x()), qRound(pPoint2->y()) );
+            controlPoints.setPoint( 2, qRound(pPoint3->x()), qRound(pPoint3->y()) );
+            controlPoints.setPoint( 3, qRound(pPoint4->x()), qRound(pPoint4->y()) );
+
+            tmpPoints = controlPoints.cubicBezier();
+
+            for( int j=0; j<int(tmpPoints.size()); j++ )
+            {
+                bPoints.putPoints( pointIndex, 1, tmpPoints.point(j).x(), tmpPoints.point(j).y() );
+                pointIndex++;
+            }
         } // end pointtype==bezier
         else if( pPoint->pointType() == KivioPoint::kptArc )
         {
             pPoint2 = pPointList->next();
             pPoint3 = pPointList->next();
-            
+
             if( !pPoint2 || !pPoint3 )
             {
-	       kdDebug() << "drawClosedPath() - incorrect # of arc points" << endl;
+                kDebug(43000) <<"drawClosedPath() - incorrect # of arc points";
                 return;
             }
             if( pPoint2->pointType() != KivioPoint::kptArc ||
                 pPoint3->pointType() != KivioPoint::kptArc )
             {
-	       kdDebug() << "drawClosedPath() - Arc points must come in triplets" << endl;
+                kDebug(43000) <<"drawClosedPath() - Arc points must come in triplets";
                 return;
             }
-            
-            tmpPoints.makeArc( pPoint->x(), pPoint->y(), pPoint2->x(), pPoint2->y(),
-                               pPoint3->x(), pPoint3->y() );
-                               
+
+            tmpPoints.makeArc( qRound(pPoint->x()), qRound(pPoint->y()), qRound(pPoint2->x()), qRound(pPoint2->y()),
+                               qRound(pPoint3->x()), qRound(pPoint3->y()) );
+
             for( int j=0; j<int(tmpPoints.size()); j++ )
             {
                 bPoints.putPoints( pointIndex, 1, tmpPoints.point(j).x(),tmpPoints.point(j).y());
@@ -749,56 +689,43 @@ void KivioScreenPainter::drawClosedPath( QList<KivioPoint> *pPoints )
         } // end pointtype==arc
         else
         {
-	   kdDebug() << "drawClosedPath() - Unknown point type discovered. WOOO!!!" << endl;
+          kDebug(43000) <<"drawClosedPath() - Unknown point type discovered. WOOO!!!";
         }
-        
+
         pPoint = pPointList->next();
     }
-    
+
     // If we make it here, the list is built
     switch( m_pFillStyle->colorStyle() )
     {
         case KivioFillStyle::kcsNone:
-            m_pPainter->setPen(m_pLineStyle->pen(1.0f));
-            m_pPainter->setBrush( QBrush::NoBrush );
-            
             // A hollow path? That's a polypath!
-            m_pPainter->drawPolyline( bPoints );
+            drawPolyline( bPoints );
             break;
-    
-        case KivioFillStyle::kcsSolid:
-            // Setup the line style
-            m_pPainter->setPen(m_pLineStyle->pen(1.0f));
-			
-			// Setup the fill color
-			brush.setColor( m_pFillStyle->color() );
-			brush.setStyle( QBrush::SolidPattern );
-			m_pPainter->setBrush( brush );
 
-			// draw the bitch
-			m_pPainter->drawPolygon( bPoints, true );        
-            break;
-        
+        case KivioFillStyle::kcsSolid:
         case KivioFillStyle::kcsGradient:
-	   kdDebug() << "drawClosedPath() - Gradient unsupported" << endl;
+        {
+            drawPolygon(bPoints);
             break;
-        
+        }
+
         default:
-	   kdDebug() << "drawClosedPath() - Unknown colors style" << endl;
+            kDebug(43000) <<"drawClosedPath() - Unknown colors style";
             break;
     }
 }
 
-void KivioScreenPainter::drawOpenPath( QList<KivioPoint> *pPoints )
+void KivioScreenPainter::drawOpenPath( QPtrList<KivioPoint> *pPoints )
 {
     PAINTER_CHECK();
 
     QBrush brush;
-    
+
     KivioPoint *pPoint, *pPoint2, *pPoint3, *pPoint4;
-    QList <KivioPoint> *pPointList = pPoints;
+    QPtrList <KivioPoint> *pPointList = pPoints;
     QPointArray controlPoints(4), bPoints(0), tmpPoints;
-    
+
     int pointIndex=0;
     pPoint = pPointList->first();
     while( pPoint )
@@ -813,54 +740,54 @@ void KivioScreenPainter::drawOpenPath( QList<KivioPoint> *pPoints )
             pPoint2 = pPointList->next();
             pPoint3 = pPointList->next();
             pPoint4 = pPointList->next();
-            
+
             if( !pPoint2 || !pPoint3 || !pPoint4 )
             {
-	       kdDebug() << "drawOpenPath() - incorrect # of bezier points" << endl;
+                kDebug(43000) <<"drawOpenPath() - incorrect # of bezier points";
                 return;
             }
-            
+
             if( pPoint2->pointType() != KivioPoint::kptBezier ||
                 pPoint3->pointType() != KivioPoint::kptBezier ||
                 pPoint4->pointType() != KivioPoint::kptBezier )
             {
-	       kdDebug() << "drawOpenPath() - bezier curves must have 4 points" << endl;
+                kDebug(43000) <<"drawOpenPath() - bezier curves must have 4 points";
                 return;
             }
-            
-            controlPoints.setPoint( 0, pPoint->x(), pPoint->y() );
-			controlPoints.setPoint( 1, pPoint2->x(), pPoint2->y() );
-			controlPoints.setPoint( 2, pPoint3->x(), pPoint3->y() );
-			controlPoints.setPoint( 3, pPoint4->x(), pPoint4->y() );
-			
-			tmpPoints = controlPoints.quadBezier();
-			
-			for( int j=0; j<int(tmpPoints.size()); j++ )
-			{
-			    bPoints.putPoints( pointIndex, 1, tmpPoints.point(j).x(), tmpPoints.point(j).y() );
-			    pointIndex++;
-			}
+
+            controlPoints.setPoint( 0, qRound(pPoint->x()), qRound(pPoint->y()) );
+            controlPoints.setPoint( 1, qRound(pPoint2->x()), qRound(pPoint2->y()) );
+            controlPoints.setPoint( 2, qRound(pPoint3->x()), qRound(pPoint3->y()) );
+            controlPoints.setPoint( 3, qRound(pPoint4->x()), qRound(pPoint4->y()) );
+
+            tmpPoints = controlPoints.cubicBezier();
+
+            for( int j=0; j<int(tmpPoints.size()); j++ )
+            {
+                bPoints.putPoints( pointIndex, 1, tmpPoints.point(j).x(), tmpPoints.point(j).y() );
+                pointIndex++;
+            }
         } // end pointtype==bezier
         else if( pPoint->pointType() == KivioPoint::kptArc )
         {
             pPoint2 = pPointList->next();
             pPoint3 = pPointList->next();
-            
+
             if( !pPoint2 || !pPoint3 )
             {
-	       kdDebug() << "drawOpenPath() - incorrect # of arc points" << endl;
+                kDebug(43000) <<"drawOpenPath() - incorrect # of arc points";
                 return;
             }
             if( pPoint2->pointType() != KivioPoint::kptArc ||
                 pPoint3->pointType() != KivioPoint::kptArc )
             {
-	       kdDebug() << "drawOpenPath() - Arc points must come in triplets" << endl;
+                kDebug(43000) <<"drawOpenPath() - Arc points must come in triplets";
                 return;
             }
-            
-            tmpPoints.makeArc( pPoint->x(), pPoint->y(), pPoint2->x(), pPoint2->y(),
-                               pPoint3->x(), pPoint3->y() );
-                               
+
+            tmpPoints.makeArc( qRound(pPoint->x()), qRound(pPoint->y()), qRound(pPoint2->x()), qRound(pPoint2->y()),
+                               qRound(pPoint3->x()), qRound(pPoint3->y()) );
+
             for( int j=0; j<int(tmpPoints.size()); j++ )
             {
                 bPoints.putPoints( pointIndex, 1, tmpPoints.point(j).x(),tmpPoints.point(j).y());
@@ -869,15 +796,15 @@ void KivioScreenPainter::drawOpenPath( QList<KivioPoint> *pPoints )
         } // end pointtype==arc
         else
         {
-	   kdDebug() << "drawOpenPath() - Unknown point type discovered. WOOO!!!" << endl;
+            kDebug(43000) <<"drawOpenPath() - Unknown point type discovered. WOOO!!!";
         }
-        
+
         pPoint = pPointList->next();
     }
-    
+
     m_pPainter->setPen(m_pLineStyle->pen(1.0f));
     m_pPainter->setBrush( QBrush::NoBrush );
-            
+
     m_pPainter->drawPolyline( bPoints );
 }
 
@@ -894,6 +821,13 @@ void KivioScreenPainter::drawText( int x, int y, int w, int h, int tf, const QSt
 
     m_pPainter->setPen( m_textColor );
     m_pPainter->drawText( x, y, w, h, tf, str );
+/*    QSimpleRichText textArea(str, m_pPainter->font());
+    textArea.setWidth(w);
+    QColorGroup cg;
+    cg.setColor(QColorGroup::Base, m_pFillStyle->color());
+    cg.setColor(QColorGroup::Text, m_textColor);
+    QBrush b = m_pFillStyle->brush();
+    textArea.draw(m_pPainter, x, y, QRect(0, 0, 0, 0), cg, &b);*/
 }
 
 QRect KivioScreenPainter::boundingRect( int x, int y, int w, int h, int tf, const QString &str )
@@ -905,76 +839,81 @@ QRect KivioScreenPainter::boundingRect( int x, int y, int w, int h, int tf, cons
 
 void KivioScreenPainter::drawPixmap( float x, float y, const QPixmap &pix )
 {
-   PAINTER_CHECK();
+  PAINTER_CHECK();
   m_pPainter->drawPixmap( (int)x, (int)y, pix );
 }
 
 void KivioScreenPainter::drawHandle( float x, float y, int flags )
 {
-   PAINTER_CHECK();
-   QColor fillColor;
-   QBrush b;
-   QPen p;
-   QPixmap *pLock;
+  PAINTER_CHECK();
+  QColor fillColor, penColor;
+  QBrush b;
+  QPen p;
 
-   const float HW = 6.0f;
-   const float HWP1 = HW+1.0f;
-   const float HWo2 = HW/2.0f;
+  const float HW = 6.0f;
+  const float HWP1 = HW+1.0f;
+  const float HWo2 = HW/2.0f;
 
-   float x1, y1;
+  float x1, y1;
 
-   // Is it a locked handle?
-   if( flags & cpfLock )
-   {
-      x1 = x - 4;
-      y1 = y - 4;
+  // Is it a locked handle?
+  if( flags & cpfLock )
+  {
+    x1 = x - 4;
+    y1 = y - 4;
 
-      pLock = KivioConfig::config()->lockPixmap();
+    m_pPainter->drawPixmap( qRound(x1), qRound(y1), Kivio::lockPixmap() );
+    return;
+  }
 
-      m_pPainter->drawPixmap( x1, y1, *pLock ); 
-      return;
-   }
+  if( flags & cpfConnected )
+  {
+    fillColor = QColor(200,0,0);
+  }
+  else
+  {
+    fillColor = QColor(0,200,0);
+  }
 
-   if( flags & cpfConnected )
-   {
-      fillColor = QColor(200,0,0);
-   }
-   else
-   {
-      fillColor = QColor(0,200,0);
-   }
+  penColor.setRgb(0, 0, 0);
 
-   b.setColor(fillColor);
-   b.setStyle(Qt::SolidPattern);
-   p.setColor(QColor(0,0,0));
-   m_pPainter->setPen(p);
-   m_pPainter->setBrush(b);
+  b.setColor(fillColor);
+  b.setStyle(Qt::SolidPattern);
+  p.setColor(penColor);
+  m_pPainter->setPen(p);
+  m_pPainter->setBrush(b);
 
 
-   x1 = x - HWo2;
-   y1 = y - HWo2;
+  x1 = x - HWo2;
+  y1 = y - HWo2;
 
-   // first fill it
+  // first fill it
 //   m_pPainter->fillRect( x1, y1, HWP1, HWP1, b );
-   m_pPainter->drawRect( x1, y1, HWP1, HWP1 );
 
-   // Now put something in it if needed
-   if( flags & cpfStart )
-   {
-      m_pPainter->drawLine( x, y1+2, x, y1+4 );
-      m_pPainter->drawLine( x1+2, y, x1+4, y );
-   }
-   else if( flags & cpfEnd )
-   {
-      m_pPainter->drawLine( x1+2, y1+2, x1+4, y1+4 );
-      m_pPainter->drawLine( x1+2, y1+4, x1+4, y1+2 );
-   }
-   else if( flags & cpfConnectable )
-   {
-      b.setColor(QColor(0,0,0));
+  if(flags & cpfEnd) {
+    m_pPainter->drawEllipse( qRound(x1), qRound(y1), qRound(HWP1), qRound(HWP1) );
+  } else {
+    m_pPainter->drawRect( qRound(x1), qRound(y1), qRound(HWP1), qRound(HWP1) );
+  }
 
-      m_pPainter->fillRect(x-1,y-1,3,3, b);
-   }
+  // Now put something in it if needed
+  if( flags & cpfConnectable )
+  {
+    b.setColor(QColor(0,0,0));
+
+    m_pPainter->fillRect(qRound(x-1),qRound(y-1),3,3, b);
+  }
+}
+
+void KivioScreenPainter::drawSelectionBox( const QRect& r )
+{
+   PAINTER_CHECK();
+   QPen p;
+   p.setColor(QColor(0,200,0));
+   p.setStyle(Qt::DashLine);
+   m_pPainter->setBrush(Qt::NoBrush);
+   m_pPainter->setPen(p);
+   m_pPainter->drawRect(r);
 }
 
 void KivioScreenPainter::saveState()
@@ -1011,7 +950,7 @@ void KivioScreenPainter::translateBy( float _x, float _y )
    m_pPainter->translate( m_transX, m_transY );
 }
 
-void KivioScreenPainter::setRotation( float _d )
+void KivioScreenPainter::setRotation( int _d )
 {
    PAINTER_CHECK();
 
@@ -1020,7 +959,7 @@ void KivioScreenPainter::setRotation( float _d )
    m_pPainter->rotate(_d);
 }
 
-void KivioScreenPainter::rotateBy( float _d )
+void KivioScreenPainter::rotateBy( int _d )
 {
    PAINTER_CHECK();
 
@@ -1028,3 +967,14 @@ void KivioScreenPainter::rotateBy( float _d )
 
    m_pPainter->rotate(m_rotation);
 }
+
+int KivioScreenPainter::rotation()
+{
+  return m_rotation;
+}
+
+void KivioScreenPainter::setMatrix(QMatrix m, bool c)
+{
+  PAINTER_CHECK();
+  m_pPainter->setMatrix(m, c);
+}
