@@ -21,7 +21,7 @@
 
 #include "kivio_painter.h"
 
-#include <qfont.h>
+#include <QFont>
 #include <qpainter.h>
 #include <qpixmap.h>
 
@@ -103,7 +103,7 @@ public:
     virtual void rotateBy(int);
     virtual int rotation();
 
-    virtual void setWorldMatrix(QWMatrix, bool);
+    virtual void setMatrix(QMatrix, bool);
 };
 
 #endif
