@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 #include <stdio.h>
 #include <kdebug.h>
@@ -90,7 +90,7 @@ bool KivioShape::loadXML( const QDomElement &e )
     if( m_shapeData.name().isEmpty() ||
         m_shapeData.shapeType() == -1 )
     {
-       kdWarning() << "-LOAD KivioShape::loadXML() - Unknown shape or bad name read. Shape load aborted." << endl;
+       kWarning(43000) << "-LOAD KivioShape::loadXML() - Unknown shape or bad name read. Shape load aborted." << endl;
        return false;
     }
 
@@ -230,7 +230,7 @@ KivioShape *KivioShape::loadShapeBezier( const QDomElement &e )
             pPoint->loadXML( node.toElement() );
             if( pPoint->pointType() != KivioPoint::kptBezier )
             {
-	       kdDebug(43000) << "KivioShape::loadShapeBezier() - Non-bezier point found.  Aborting shape." << endl;
+	       kDebug(43000) <<"KivioShape::loadShapeBezier() - Non-bezier point found.  Aborting shape.";
                 delete pPoint;
                 delete pShape;
                 return NULL;
@@ -248,7 +248,7 @@ KivioShape *KivioShape::loadShapeBezier( const QDomElement &e )
     
     if( pShape->m_shapeData.m_pOriginalPointList->count() != 4 )
     {
-       kdDebug(43000) << "KivioShape::loadShapeBezier() - Wrong number of points loaded, should be 4, shape aborted" << endl;
+       kDebug(43000) <<"KivioShape::loadShapeBezier() - Wrong number of points loaded, should be 4, shape aborted";
         delete pShape;
         return NULL;
     }
