@@ -14,9 +14,10 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
-#include <koApplication.h>
+#include <koffice_export.h>
+#include <KoApplication.h>
 #include <kcmdlineargs.h>
 #include <klocale.h>
 
@@ -24,15 +25,12 @@
 
 #include "kivio_aboutdata.h"
 
-static const KCmdLineOptions options[]=
-{
-  {"+[file]", I18N_NOOP("File to open"),0},
-  KCmdLineLastOption
-};
-
-int main( int argc, char **argv )
+extern "C" KDE_EXPORT int kdemain( int argc, char **argv )
 {
   KCmdLineArgs::init( argc, argv, newKivioAboutData() );
+
+  KCmdLineOptions options;
+  options.add("+[file]", ki18n("File to open"));
   KCmdLineArgs::addCmdLineOptions( options );
 
   KoApplication app;
