@@ -14,15 +14,17 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 #include "stencilbarbutton.h"
 
 #include <kiconloader.h>
+#include <kstringhandler.h>
 #include <qapplication.h>
 #include <qstyle.h>
 #include <qpainter.h>
 #include <qpixmap.h>
+#include <QToolTip>
 #include <kdebug.h>
 #include "qdrawutil.h"
 
@@ -36,6 +38,7 @@ DragBarButton::DragBarButton( const QString& text, QWidget* parent, const char*
   m_bDragged = false;
   m_bMouseOn = false;
   m_bClose = false;
+  m_orientation = Qt::Vertical;
 
   const char* stencil_xpm[] = {
   "12 12 17 1",
@@ -92,24 +95,34 @@ DragBarButton::DragBarButton( const QString& text, QWidget* parent, const char*
   "xxxxxxxx"
   };
   m_pClosePix = new QPixmap(close_xpm);
+
+  this->setToolTip( text);
 }
 
 DragBarButton::~DragBarButton()
 {
   delete m_pClosePix;
-  if (m_pIcon)
-    delete m_pIcon;
+  delete m_pIcon;
 
-  kdDebug(43000) << "DragBarButton - AHHHHHH I'M DYING!" << endl;
+  kDebug(43000) <<"DragBarButton - AHHHHHH I'M DYING!";
 }
 
 void DragBarButton::drawButton( QPainter* paint )
 {
-#ifdef __GNUC__
-#warning "Left out for now, lacking a style expert (Werner)"
-#endif
+  QSize pixSize;
+
+  if(m_orientation == Qt::Vertical) {
+    pixSize = QSize(width(), height());
+  } else {
+    pixSize = QSize(height(), width());
+  }
+
+  QPixmap pix(pixSize.width(), pixSize.height());
+  pix.fill(eraseColor());
+  QPainter pixPainter(&pix);
+
   const QColorGroup& g = colorGroup();
-  style().drawControl( QStyle::CE_PushButton, paint, this, QRect(0, 0, width(), height()), colorGroup() );
+  style().drawControl( QStyle::CE_PushButton, &pixPainter, this, QRect(0, 0, pixSize.width(), pixSize.height()), colorGroup() );
 
   int m = 3;
   int tw = 0;
@@ -117,7 +130,7 @@ void DragBarButton::drawButton( QPainter* paint )
 
   if ( m_pIcon ) {
     pw = m_pIcon->width();
-    style().drawItem( paint, QRect( m, 0, pw, height() ),
+    style().drawItem( &pixPainter, QRect( m, 0, pw, pixSize.height() ),
                       AlignLeft | AlignVCenter,
                       colorGroup(), isEnabled(),
                       m_pIcon, QString::null, -1,
@@ -129,27 +142,35 @@ void DragBarButton::drawButton( QPainter* paint )
     QSize sz = fm.size( ShowPrefix, text() );
     tw = sz.width();
     int x = m + pw + (tw!=0 && pw!=0 ?m:0);
-    style().drawItem( paint, QRect( x, 0, tw, height() ),
+    QString t = KStringHandler::rPixelSqueeze(text(), fm, pixSize.width() - (x + m + 22));
+
+    style().drawItem( &pixPainter, QRect( x, 0, tw, pixSize.height() ),
                       AlignLeft | AlignVCenter|ShowPrefix,
                       colorGroup(), isEnabled(),
-                      0L, text(), -1,
+                      0L, t, -1,
                       &g.buttonText());
   }
 
 
-  QPoint p1(width()-10,0);
-  QPoint p2(width()-10,height());
-  qDrawShadeLine( paint, p1, p2, g, true, 0, 1 );
+  QPoint p1(pixSize.width() - 10, 0);
+  QPoint p2(pixSize.width() - 10, pixSize.height());
+  qDrawShadeLine( &pixPainter, p1, p2, g, true, 0, 1 );
 
-  p1 += QPoint(2,0);
-  p2 += QPoint(2,0);
-  qDrawShadeLine( paint, p1, p2, g, true, 0, 1 );
+  p1 += QPoint(2, 0);
+  p2 += QPoint(2, 0);
+  qDrawShadeLine( &pixPainter, p1, p2, g, true, 0, 1 );
 
-// Temporary fix
-//  if (m_bMouseOn) {
+  if (m_bMouseOn) {
     int z = m_bClose ? 1:0;
-    paint->drawPixmap(width()-20+z, (height()-m_pClosePix->height())/2+z, *m_pClosePix );
-//  }
+    pixPainter.drawPixmap(pixSize.width() - 20 + z, (pixSize.height() - m_pClosePix->height()) / 2 + z, *m_pClosePix);
+  }
+
+  if(m_orientation == Qt::Vertical) {
+    paint->drawPixmap(0, 0, pix);
+  } else {
+    paint->rotate(-90);
+    paint->drawPixmap(1 - pixSize.width(), 0, pix);
+  }
 }
 
 void DragBarButton::setIcon( const QString& name )
@@ -174,7 +195,7 @@ QSize DragBarButton::sizeHint() const
   if ( !text().isEmpty() ) {
     QFontMetrics fm = fontMetrics();
     QSize sz = fm.size( ShowPrefix, text() );
-    tw = sz.width();
+    tw = 64; // Minimum size
     th = sz.height();
   }
 
@@ -183,16 +204,31 @@ QSize DragBarButton::sizeHint() const
     ph = m_pIcon->height();
   }
 
-  int h = QMAX(ph,th)+2*m;
+  int h = qMax(ph,th)+2*m;
   int w = m + pw + (tw!=0 && pw!=0 ?m:0) + tw + m + 22;
 
-  return QSize(w,h).expandedTo( QApplication::globalStrut() );
+  QSize size;
+  
+  if(m_orientation == Qt::Vertical) {
+    size = QSize(w, h).expandedTo(QApplication::globalStrut());
+  } else {
+    size = QSize(h, w).expandedTo(QApplication::globalStrut());
+  }
+  
+  return size;
 }
 
 void DragBarButton::mousePressEvent( QMouseEvent* ev )
 {
   m_bClose = false;
-  QRect closeRect(width()-20,0,m_pClosePix->width(),height());
+  QRect closeRect;
+
+  if(m_orientation == Qt::Vertical) {
+    closeRect.setRect(width() - 20, 0, m_pClosePix->width(), height());
+  } else {
+    closeRect.setRect(0, 20 - m_pClosePix->width(), width(), m_pClosePix->width());
+  }
+
   if ( closeRect.contains(ev->pos())) {
     m_bClose = true;
     repaint();
@@ -208,10 +244,17 @@ void DragBarButton::mouseReleaseEvent( QMouseEvent* ev )
   if ( m_bClose ) {
     m_bClose = false;
     repaint();
-    QRect closeRect(width()-20,0,m_pClosePix->width(),height());
+    QRect closeRect;
+
+    if(m_orientation == Qt::Vertical) {
+      closeRect.setRect(width() - 20, 0, m_pClosePix->width(), height());
+    } else {
+      closeRect.setRect(0, 20 - m_pClosePix->width(), width(), m_pClosePix->width());
+    }
+
     if ( closeRect.contains(ev->pos()))
     {
-       kdDebug(43000) << "DragBarButton::mouseReleaseEvent() - Emitting closeRequest" << endl;
+       kDebug(43000) <<"DragBarButton::mouseReleaseEvent() - Emitting closeRequest";
         emit closeRequired(this);
     }
     return;
@@ -251,4 +294,16 @@ void DragBarButton::leaveEvent( QEvent* ev )
   m_bMouseOn = false;
   repaint();
 }
+
+void DragBarButton::setOrientation(Orientation orientation)
+{
+  m_orientation = orientation;
+  
+  if(m_orientation == Qt::Vertical) {
+    setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed);
+  } else {
+    setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Minimum);
+  }
+}
+
 #include "stencilbarbutton.moc"
