@@ -13,14 +13,14 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #include "kiviostencilformatdlg.h"
 
-#include <qlabel.h>
-#include <qlayout.h>
+#include <QLabel>
+#include <QLayout>
 #include <qbitmap.h>
 #include <qpixmap.h>
 #include <qpainter.h>
@@ -28,14 +28,14 @@
 #include <kcolorbutton.h>
 #include <klocale.h>
 
-#include <koUnitWidgets.h>
+#include <KoUnitDoubleSpinBox.h>
 
 #include "kivio_view.h"
 
 KivioStencilFormatDlg::KivioStencilFormatDlg(KivioView* parent, const char* name)
   : KDialogBase(parent, name, true, i18n("Stencil & Connector Format"), Ok|Cancel|Default, Ok)
 {
-  m_unit = KoUnit::U_PT;
+  m_unit = KoUnit::Point;
   init();
 }
 
@@ -180,7 +180,7 @@ int KivioStencilFormatDlg::lineEndStyle()
   return m_lineEndStyleCBox->currentItem() * 0x10;
 }
 
-void KivioStencilFormatDlg::setLineWidth(double w, KoUnit::Unit u)
+void KivioStencilFormatDlg::setLineWidth(double w, KoUnit u)
 {
   m_unit = u;
   m_lineWidthUSBox->setUnit(u);
