@@ -14,33 +14,27 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 #include "plugin.h"
 #include "tool_text.h"
 
 #include "kivio_view.h"
 
-#include <kinstance.h>
+#include <kcomponentdata.h>
 #include <kiconloader.h>
 
 /***************************************************
  * Factory
  ***************************************************/
-extern "C"
-{
-  void* init_libkiviotexttool()
-  {
-    return new TextToolFactory;
-  }
-}
+K_EXPORT_COMPONENT_FACTORY( libkiviotexttool, TextToolFactory )
 
-KInstance* TextToolFactory::s_global = 0;
+KComponentData TextToolFactory::s_global = 0;
 
 TextToolFactory::TextToolFactory( QObject* parent, const char* name )
 : KLibFactory( parent, name )
 {
-  s_global = new KInstance("kivio");
+  s_global("kivio");
 }
 
 TextToolFactory::~TextToolFactory()
@@ -57,7 +51,7 @@ QObject* TextToolFactory::createObject( QObject* parent, const char*, const char
   return obj;
 }
 
-KInstance* TextToolFactory::global()
+KComponentData TextToolFactory::global()
 {
   return s_global;
 }
