@@ -26,21 +26,27 @@
 namespace KPlato
 {
 
-AccountsDialog::AccountsDialog(Accounts &acc, QWidget *p, const char *n)
-    : KDialogBase(Swallow, i18n("Edit Accounts"), Ok|Cancel, Ok, p, n, true, true)
+AccountsDialog::AccountsDialog(Accounts &acc, QWidget *p)
+    : KDialog(p)
 {
+    setCaption( i18n("Edit Accounts") );
+    setButtons( Ok|Cancel );
+    setDefaultButton( Ok );
+    showButtonSeparator( true );
     m_panel = new AccountsPanel(acc, this);
     setMainWidget(m_panel);
-    
-    enableButtonOK(false);
-    connect(m_panel, SIGNAL(changed(bool)), SLOT(enableButtonOK(bool)));
+
+    enableButtonOk(false);
+    connect(m_panel, SIGNAL(changed(bool)), SLOT(enableButtonOk(bool)));
+    connect(this,SIGNAL(okClicked()),this,SLOT(slotOk()));
 }
 
-KCommand *AccountsDialog::buildCommand(Part *part) {
+K3Command *AccountsDialog::buildCommand(Part *part) {
     return m_panel->buildCommand(part);
 }
 
 void AccountsDialog::slotOk() {
+    kDebug()<<"Dialog : slotok : appel panel";
     m_panel->slotOk();
     accept();
 }
