@@ -31,11 +31,14 @@ public:
     KPrAnimationDisappear( KoShape * shape, int step );
     virtual ~KPrAnimationDisappear();
 
-    virtual KPrAnimationData * animationData( KoCanvasBase * canvas, KoShapeManager * shapeManager, const QRectF & pageRect );
-    virtual bool animate( QPainter &painter, const KoViewConverter &converter, KPrAnimationData * animationData );
-    virtual void animateRect( QRectF & rect, KPrAnimationData * animationData );
-    virtual void next( int currentTime, KPrAnimationData * animationData );
-    virtual void finish( KPrAnimationData * animationData );
+    virtual bool animate( QPainter &painter );
+    virtual void animateRect( QRectF & rect );
+    virtual void next( int currentTime, KoCanvasBase * canvas );
+    virtual void finish( KoCanvasBase * canvas );
+
+private:
+    QPointF m_translate;
+    QRectF m_shapeRect;
 };
 
 #endif /* KPRANIMATIONDISAPPEAR_H */
