@@ -33,10 +33,10 @@ public:
     KisCImgFilterConfiguration();
     virtual QString toString();
     virtual void fromXML(const QString & s);
-    
+
 public:
 
-    Q_INT32 nb_iter;    // Number of smoothing iterations
+    qint32 nb_iter;    // Number of smoothing iterations
     double dt;         // Time step
     double dlength;    // Integration step
     double dtheta;     // Angular step (in degrees)
@@ -54,15 +54,15 @@ class KisCImgFilter : public KisFilter
 public:
     KisCImgFilter();
 public:
-    virtual void process(KisPaintDeviceSP,KisPaintDeviceSP, KisFilterConfiguration* , const QRect&);
-    static inline KisID id() { return KisID("cimg", i18n("Image Restauration (cimg-based)")); };
+    virtual void process(const KisPaintDeviceSP src, const QPoint& srcTopLeft, KisPaintDeviceSP dst, const QPoint& dstTopLeft, const QSize& size, const KisFilterConfiguration* config);
+    static inline KoID id() { return KoID("cimg", i18n("Image Restoration (cimg-based)")); }
     virtual bool supportsPainting() { return false; }
     virtual bool supportsPreview() { return false; }
     virtual ColorSpaceIndependence colorSpaceIndependence();
 public:
     virtual KisFilterConfigWidget * createConfigurationWidget(QWidget* parent, KisPaintDeviceSP dev);
     virtual KisFilterConfiguration * configuration(QWidget*);
-    virtual KisFilterConfiguration * configuration() { return new KisCImgFilterConfiguration();};
+    virtual KisFilterConfiguration * configuration() { return new KisCImgFilterConfiguration();}
 private:
 
     bool process();
@@ -81,7 +81,7 @@ private:
         // Average all the LIC's
         void compute_average_LIC();
 
-        // Prepare datas
+        // Prepare data
         bool prepare();
         bool prepare_restore();
         bool prepare_inpaint();
@@ -91,7 +91,7 @@ private:
         // Check arguments
         bool check_args();
 
-        // Clean up memory (CImg datas) to save memory
+        // Clean up memory (CImg data) to save memory
         void cleanup();
 
 private:
@@ -117,8 +117,6 @@ private:
         cimg_library::CImgl<> eigen;
         cimg_library::CImg<unsigned char> mask;
 
-
-
 };
 
 #endif
