@@ -25,23 +25,21 @@
 #include <time.h>
 #include <vector>
 
-#include <qpoint.h>
-#include <qspinbox.h>
+#include <QPoint>
+#include <QSpinBox>
 
 #include <klocale.h>
 #include <kiconloader.h>
-#include <kinstance.h>
 #include <kmessagebox.h>
 #include <kstandarddirs.h>
-#include <ktempfile.h>
 #include <kdebug.h>
 #include <kgenericfactory.h>
 #include <knuminput.h>
 
 #include <kis_painter.h>
-#include <kis_meta_registry.h>
-#include <kis_colorspace_factory_registry.h>
-#include <kis_doc.h>
+
+#include <KoColorSpaceRegistry.h>
+#include <kis_doc2.h>
 #include <kis_image.h>
 #include <kis_iterators_pixel.h>
 #include <kis_layer.h>
@@ -49,12 +47,12 @@
 #include <kis_global.h>
 #include <kis_types.h>
 #include <kis_progress_display_interface.h>
-#include <kis_vec.h>
+
 
 #include "kis_multi_integer_filter_widget.h"
 #include "kis_cubism_filter.h"
 #include "kis_polygon.h"
-#include "kis_point.h"
+
 
 #define RANDOMNESS       5
 #define SUPERSAMPLE      4
@@ -65,24 +63,24 @@ KisCubismFilter::KisCubismFilter() : KisFilter(id(), "artistic", i18n("&Cubism..
 {
 }
 
-bool KisCubismFilter::workWith(KisColorSpace* /*cs*/)
+bool KisCubismFilter::workWith(KoColorSpace* /*cs*/)
 {
     return true;
 }
 
 
 void KisCubismFilter::process(KisPaintDeviceSP src, KisPaintDeviceSP dst,
-                               KisFilterConfiguration* configuration, const QRect& rect)
+                               const KisFilterConfiguration* configuration, const QRect& rect)
 {
     Q_ASSERT(src);
     Q_ASSERT(dst);
     Q_ASSERT(configuration);
-    
-    //read the filter configuration values from the KisFilterConfiguration object
-    Q_UINT32 tileSize = ((KisCubismFilterConfiguration*)configuration)->tileSize();
-    Q_UINT32 tileSaturation = ((KisCubismFilterConfiguration*)configuration)->tileSaturation();
 
-    KisColorSpace * cs = src->colorSpace();
+    //read the filter configuration values from the KisFilterConfiguration object
+    quint32 tileSize = ((KisCubismFilterConfiguration*)configuration)->tileSize();
+    quint32 tileSaturation = ((KisCubismFilterConfiguration*)configuration)->tileSaturation();
+
+    KoColorSpace * cs = src->colorSpace();
     QString id = cs->id().id();
 
     if (id == "RGBA" || id == "GRAY" || id == "CMYK") {
@@ -90,33 +88,33 @@ void KisCubismFilter::process(KisPaintDeviceSP src, KisPaintDeviceSP dst,
     }
     else {
         if (src->image()) src->image()->lock();
-    
-        KisPaintDeviceSP dev = new KisPaintDevice(KisMetaRegistry::instance()->csRegistry()->getRGB8(), "temporary");
+
+        KisPaintDeviceSP dev = new KisPaintDevice(KoColorSpaceRegistry::instance()->rgb8(), "temporary");
         KisPainter gc(dev);
         gc.bitBlt(0, 0, COMPOSITE_COPY, src, rect.x(), rect.y(), rect.width(), rect.height());
         gc.end();
-        
-        kdDebug() << src->colorSpace()->id().id() << endl;
+
+//         kDebug() << src->colorSpace()->id().id();
         cubism(dev, dev, QRect(0, 0, rect.width(), rect.height()), tileSize, tileSaturation);
 
         gc.begin(dst);
         gc.bitBlt(rect.x(), rect.y(), COMPOSITE_COPY, dev, 0, 0, rect.width(), rect.height());
-        gc.end();      
+        gc.end();
         if (src->image()) src->image()->unlock();
-    
-        kdDebug() << src->colorSpace()->id().id() << endl;
+
+//         kDebug() << src->colorSpace()->id().id();
     }
 }
 
-void KisCubismFilter::randomizeIndices (Q_INT32 count, Q_INT32* indices)
+void KisCubismFilter::randomizeIndices (qint32 count, qint32* indices)
 {
-        Q_INT32 index1, index2;
-        Q_INT32 tmp;
+        qint32 index1, index2;
+        qint32 tmp;
 
         //initialize random number generator with time
         srand(static_cast<unsigned int>(time(0)));
 
-        for (Q_INT32 i = 0; i < count * RANDOMNESS; i++)
+        for (qint32 i = 0; i < count * RANDOMNESS; i++)
         {
                 index1 = randomIntNumber(0, count);
                 index2 = randomIntNumber(0, count);
@@ -126,11 +124,11 @@ void KisCubismFilter::randomizeIndices (Q_INT32 count, Q_INT32* indices)
         }
 }
 
-Q_INT32 KisCubismFilter::randomIntNumber(Q_INT32 lowestNumber, Q_INT32 highestNumber)
+qint32 KisCubismFilter::randomIntNumber(qint32 lowestNumber, qint32 highestNumber)
 {
         if(lowestNumber > highestNumber)
         {
-                Q_INT32 temp = lowestNumber;
+                qint32 temp = lowestNumber;
                 lowestNumber = highestNumber;
                 highestNumber = temp;
         }
@@ -167,20 +165,20 @@ double KisCubismFilter::calcAlphaBlend (double* vec, double  oneOverDist, double
         }
 }
 
-void KisCubismFilter::convertSegment (Q_INT32 x1, Q_INT32 y1, Q_INT32 x2, Q_INT32  y2, Q_INT32 offset, Q_INT32* min, Q_INT32* max, Q_INT32 xmin, Q_INT32 xmax)
+void KisCubismFilter::convertSegment (qint32 x1, qint32 y1, qint32 x2, qint32  y2, qint32 offset, qint32* min, qint32* max, qint32 xmin, qint32 xmax)
 {
         if (y1 > y2)
         {
-                Q_INT32 tmp = y2; y2 = y1; y1 = tmp;
+                qint32 tmp = y2; y2 = y1; y1 = tmp;
                 tmp = x2; x2 = x1; x1 = tmp;
         }
-        Q_INT32 ydiff = (y2 - y1);
+        qint32 ydiff = (y2 - y1);
 
         if (ydiff)
         {
                 double xinc = static_cast<double>(x2 - x1) / static_cast<double>(ydiff);
                 double xstart = x1 + 0.5 * xinc;
-                for (Q_INT32 y = y1 ; y < y2; y++)
+                for (qint32 y = y1 ; y < y2; y++)
                 {
                     if(xstart >= xmin && xstart <= xmax)
                     {
@@ -200,25 +198,25 @@ void KisCubismFilter::convertSegment (Q_INT32 x1, Q_INT32 y1, Q_INT32 x2, Q_INT3
 
 #define USE_READABLE_BUT_SLOW_CODE
 
-void KisCubismFilter::fillPolyColor (KisPaintDeviceSP src, KisPaintDeviceSP dst, KisPolygon* poly, const Q_UINT8* col, Q_UINT8* /*s*/, QRect rect)
+void KisCubismFilter::fillPolyColor (KisPaintDeviceSP src, KisPaintDeviceSP dst, KisPolygon* poly, const quint8* col, quint8* /*s*/, QRect rect)
 {
-        Q_INT32         val;
-        Q_INT32         alpha;
-        Q_UINT8         buf[4];
-        Q_INT32         x, y;
+        qint32         val;
+        qint32         alpha;
+        quint8         buf[4];
+        qint32         x, y;
         double          xx, yy;
         double          vec[2];
-        Q_INT32         x1 = rect.left(), y1 = rect.top(), x2 = rect.right(), y2 = rect.bottom();
-//         Q_INT32         selWidth, selHeight;
-        Q_INT32         *vals, *valsIter, *valsEnd;
-        Q_INT32         b;
-        Q_INT32         xs, ys, xe, ye;
+        qint32         x1 = rect.left(), y1 = rect.top(), x2 = rect.right(), y2 = rect.bottom();
+//         qint32         selWidth, selHeight;
+        qint32         *vals, *valsIter, *valsEnd;
+        qint32         b;
+        qint32         xs, ys, xe, ye;
 
 
-        Q_INT32 sx = (Q_INT32) (*poly)[0].x();
-        Q_INT32 sy = (Q_INT32) (*poly)[0].y();
-        Q_INT32 ex = (Q_INT32) (*poly)[1].x();
-        Q_INT32 ey = (Q_INT32) (*poly)[1].y();
+        qint32 sx = (qint32) (*poly)[0].x();
+        qint32 sy = (qint32) (*poly)[0].y();
+        qint32 ex = (qint32) (*poly)[1].x();
+        qint32 ey = (qint32) (*poly)[1].y();
 
         double dist = sqrt (SQR (ex - sx) + SQR (ey - sy));
         double oneOverDist = 0.0;
@@ -229,23 +227,23 @@ void KisCubismFilter::fillPolyColor (KisPaintDeviceSP src, KisPaintDeviceSP dst,
                 vec[1] = (ey - sy) * oneOverDist;
         }
 
-        Q_INT32 pixelSize = src->pixelSize();
+        qint32 pixelSize = src->pixelSize();
         //get the extents of the polygon
         double dMinX, dMinY, dMaxX, dMaxY;
         poly->extents (dMinX, dMinY, dMaxX, dMaxY);
-        Q_INT32 minX = static_cast<Q_INT32>(dMinX);
-        Q_INT32 minY = static_cast<Q_INT32>(dMinY);
-        Q_INT32 maxX = static_cast<Q_INT32>(dMaxX);
-        Q_INT32 maxY = static_cast<Q_INT32>(dMaxY);
-        Q_INT32 sizeX = (maxX - minX) * SUPERSAMPLE;
-        Q_INT32 sizeY = (maxY - minY) * SUPERSAMPLE;
+        qint32 minX = static_cast<qint32>(dMinX);
+        qint32 minY = static_cast<qint32>(dMinY);
+        qint32 maxX = static_cast<qint32>(dMaxX);
+        qint32 maxY = static_cast<qint32>(dMaxY);
+        qint32 sizeX = (maxX - minX) * SUPERSAMPLE;
+        qint32 sizeY = (maxY - minY) * SUPERSAMPLE;
 
-        Q_INT32 *minScanlines = new Q_INT32[sizeY];
-        Q_INT32 *minScanlinesIter = minScanlines;
-        Q_INT32 *maxScanlines = new Q_INT32[sizeY];
-        Q_INT32 *maxScanlinesIter = maxScanlines;
+        qint32 *minScanlines = new qint32[sizeY];
+        qint32 *minScanlinesIter = minScanlines;
+        qint32 *maxScanlines = new qint32[sizeY];
+        qint32 *maxScanlinesIter = maxScanlines;
 
-        for (Q_INT32 i = 0; i < sizeY; i++)
+        for (qint32 i = 0; i < sizeY; i++)
         {
             minScanlines[i] = maxX * SUPERSAMPLE;
             maxScanlines[i] = minX * SUPERSAMPLE;
@@ -253,12 +251,12 @@ void KisCubismFilter::fillPolyColor (KisPaintDeviceSP src, KisPaintDeviceSP dst,
 
         if ( poly->numberOfPoints() )
         {
-                Q_INT32 polyNpts = poly->numberOfPoints();
+                qint32 polyNpts = poly->numberOfPoints();
 
-                xs = static_cast<Q_INT32>((*poly)[polyNpts-1].x());
-                ys = static_cast<Q_INT32>((*poly)[polyNpts-1].y());
-                xe = static_cast<Q_INT32>((*poly)[0].x());
-                ye = static_cast<Q_INT32>((*poly)[0].y());
+                xs = static_cast<qint32>((*poly)[polyNpts-1].x());
+                ys = static_cast<qint32>((*poly)[polyNpts-1].y());
+                xe = static_cast<qint32>((*poly)[0].x());
+                ye = static_cast<qint32>((*poly)[0].y());
 
                 xs *= SUPERSAMPLE;
                 ys *= SUPERSAMPLE;
@@ -271,14 +269,14 @@ void KisCubismFilter::fillPolyColor (KisPaintDeviceSP src, KisPaintDeviceSP dst,
 
                 for ( it = poly->begin(); it != poly->end(); )
                 {
-                        xs = static_cast<Q_INT32>((*it).x());
-                        ys = static_cast<Q_INT32>((*it).y());
+                        xs = static_cast<qint32>((*it).x());
+                        ys = static_cast<qint32>((*it).y());
                         ++it;
-                        
+
                         if( it != poly->end() )
                         {
-                            xe = static_cast<Q_INT32>((*it).x());
-                            ye = static_cast<Q_INT32>((*it).y());
+                            xe = static_cast<qint32>((*it).x());
+                            ye = static_cast<qint32>((*it).y());
 
                             xs *= SUPERSAMPLE;
                             ys *= SUPERSAMPLE;
@@ -290,18 +288,18 @@ void KisCubismFilter::fillPolyColor (KisPaintDeviceSP src, KisPaintDeviceSP dst,
                 }
         }
 
-        vals = new Q_INT32[sizeX];
+        vals = new qint32[sizeX];
 //         x1 = minX; x2 = maxX; y1 = minY; y2 = maxY;
-        for (Q_INT32 i = 0; i < sizeY; i++, minScanlinesIter++, maxScanlinesIter++)
+        for (qint32 i = 0; i < sizeY; i++, minScanlinesIter++, maxScanlinesIter++)
         {
                 if (! (i % SUPERSAMPLE))
                 {
-                        memset (vals, 0, sizeof( Q_INT32 ) * sizeX);
+                        memset (vals, 0, sizeof( qint32 ) * sizeX);
                 }
 
                 yy = static_cast<double>(i) / static_cast<double>(SUPERSAMPLE) + minY;
 
-                for (Q_INT32 j = *minScanlinesIter; j < *maxScanlinesIter; j++)
+                for (qint32 j = *minScanlinesIter; j < *maxScanlinesIter; j++)
                 {
                         x = j - minX * SUPERSAMPLE;
                         vals[x] += 255;
@@ -312,7 +310,7 @@ void KisCubismFilter::fillPolyColor (KisPaintDeviceSP src, KisPaintDeviceSP dst,
                         y = (i / SUPERSAMPLE) + minY;
                         if (y >= y1 && y <= y2)
                         {
-                                for (Q_INT32 j = 0; j < sizeX; j += SUPERSAMPLE)
+                                for (qint32 j = 0; j < sizeX; j += SUPERSAMPLE)
                                 {
                                         x = (j / SUPERSAMPLE) + minX;
 
@@ -327,20 +325,20 @@ void KisCubismFilter::fillPolyColor (KisPaintDeviceSP src, KisPaintDeviceSP dst,
                                                 if (val > 0)
                                                 {
                                                         xx = static_cast<double>(j) / static_cast<double>(SUPERSAMPLE) + minX;
-                                                        alpha = static_cast<Q_INT32>(val * calcAlphaBlend (vec, oneOverDist, xx - sx, yy - sy));
+                                                        alpha = static_cast<qint32>(val * calcAlphaBlend (vec, oneOverDist, xx - sx, yy - sy));
 
 //                                                         KisRectIteratorPixel srcIt = src->createRectIterator(x,y,1,1, false);
-//                                                         const Q_UINT8* srcPixel = srcIt.oldRawData();
-//                                                         memcpy( buf, srcPixel, sizeof(Q_UINT8) * pixelSize );
+//                                                         const quint8* srcPixel = srcIt.oldRawData();
+//                                                         memcpy( buf, srcPixel, sizeof(quint8) * pixelSize );
                                                         src->readBytes(buf, x, y, 1, 1);
                                                 #ifndef USE_READABLE_BUT_SLOW_CODE
-                                                        Q_UINT8 *bufIter = buf;
-                                                        const Q_UINT8 *colIter = col;
-                                                        Q_UINT8 *bufEnd = buf+pixelSize;
+                                                        quint8 *bufIter = buf;
+                                                        const quint8 *colIter = col;
+                                                        quint8 *bufEnd = buf+pixelSize;
 
                                                         for(; bufIter < bufEnd; bufIter++, colIter++)
-                                                        *bufIter = (static_cast<Q_UINT8>(*colIter * alpha)
-                                                                        + (static_cast<Q_UINT8>(*bufIter)
+                                                        *bufIter = (static_cast<quint8>(*colIter * alpha)
+                                                                        + (static_cast<quint8>(*bufIter)
                                                                         * (256 - alpha))) >> 8;
                                                 #else  //original, pre-ECL code
                                                         for (b = 0; b < pixelSize; b++)
@@ -348,7 +346,7 @@ void KisCubismFilter::fillPolyColor (KisPaintDeviceSP src, KisPaintDeviceSP dst,
                                                             buf[b] = ((col[b] * alpha) + (buf[b] * (255 - alpha))) / 255;
                                                         }
                                                 #endif
-                                                        
+
                                                         dst->writeBytes(buf, x, y, 1, 1);
                                                 }
                                         }
@@ -361,17 +359,17 @@ void KisCubismFilter::fillPolyColor (KisPaintDeviceSP src, KisPaintDeviceSP dst,
     delete[] maxScanlines;
 }
 
-void KisCubismFilter::cubism(KisPaintDeviceSP src, KisPaintDeviceSP dst, const QRect& rect, Q_UINT32 tileSize, Q_UINT32 tileSaturation)
+void KisCubismFilter::cubism(KisPaintDeviceSP src, KisPaintDeviceSP dst, const QRect& rect, quint32 tileSize, quint32 tileSaturation)
 {
     Q_ASSERT(src);
     Q_ASSERT(dst);
-    
+
         //fill the destination image with the background color (black for now)
         KisRectIteratorPixel dstIt = dst->createRectIterator(rect.x(), rect.y(), rect.width(), rect.height(), true );
-        Q_INT32 depth = src->colorSpace()->nColorChannels();
+        qint32 depth = src->colorSpace()->colorChannelCount();
         while( ! dstIt.isDone() )
         {
-                for( Q_INT32 i = 0; i < depth; i++)
+                for( qint32 i = 0; i < depth; i++)
                 {
                         dstIt.rawData()[i] = 0;
                 }
@@ -379,27 +377,27 @@ void KisCubismFilter::cubism(KisPaintDeviceSP src, KisPaintDeviceSP dst, const Q
         }
 
         //compute number of rows and columns
-        Q_INT32 cols = ( rect.width() + tileSize - 1) / tileSize;
-        Q_INT32 rows = ( rect.height() + tileSize - 1) / tileSize;
-        Q_INT32 numTiles = (rows + 1) * (cols + 1);
+        qint32 cols = ( rect.width() + tileSize - 1) / tileSize;
+        qint32 rows = ( rect.height() + tileSize - 1) / tileSize;
+        qint32 numTiles = (rows + 1) * (cols + 1);
 
         setProgressTotalSteps(numTiles);
         setProgressStage(i18n("Applying cubism filter..."),0);
 
-        Q_INT32* randomIndices = new Q_INT32[numTiles];
-        for (Q_INT32 i = 0; i < numTiles; i++)
+        qint32* randomIndices = new qint32[numTiles];
+        for (qint32 i = 0; i < numTiles; i++)
         {
                 randomIndices[i] = i;
         }
         randomizeIndices (numTiles, randomIndices);
 
-        Q_INT32 count = 0;
-        Q_INT32 i, j, ix, iy;
+        qint32 count = 0;
+        qint32 i, j, ix, iy;
         double x, y, width, height, theta;
         KisPolygon *poly = new KisPolygon();
-        Q_INT32 pixelSize = src->pixelSize();
-        const Q_UINT8 *srcPixel /*= new Q_UINT8[ pixelSize ]*/;
-        Q_UINT8 *dstPixel = 0;
+        qint32 pixelSize = src->pixelSize();
+        const quint8 *srcPixel /*= new quint8[ pixelSize ]*/;
+        quint8 *dstPixel = 0;
         while (count < numTiles)
         {
                 i = randomIndices[count] / (cols + 1);
@@ -417,8 +415,8 @@ void KisCubismFilter::cubism(KisPaintDeviceSP src, KisPaintDeviceSP dst, const Q
                 poly->rotate( theta );
                 poly->translate ( x, y );
                 //  bounds check on x, y
-                ix = (Q_INT32) CLAMP (x, rect.x(), rect.x() + rect.width() - 1);
-                iy = (Q_INT32) CLAMP (y, rect.y(), rect.y() + rect.height() - 1);
+                ix = (qint32) CLAMP (x, rect.x(), rect.x() + rect.width() - 1);
+                iy = (qint32) CLAMP (y, rect.y(), rect.y() + rect.height() - 1);
 
                 //read the pixel at ix, iy
                 KisRectIteratorPixel srcIt = src->createRectIterator(ix,iy,1,1, false);
