@@ -21,17 +21,23 @@
 #ifndef __filltool_h__
 #define __filltool_h__
 
-#include <qpoint.h>
+#include <QPoint>
+//Added by qt3to4:
+#include <QLabel>
+
 
-#include "kis_point.h"
 #include "kis_tool_paint.h"
+#include <kis_layer_shape.h>
 
 class KisPainter;
+class KisFillPainter;
 class QWidget;
 class QLabel;
 class QCheckBox;
 class KIntNumInput;
-class KActionCollection;
+//class KActionCollection;
+
+class KoCanvasBase;
 
 class KisToolFill : public KisToolPaint {
 
@@ -40,21 +46,17 @@ class KisToolFill : public KisToolPaint {
 
 public:
 
-    KisToolFill();
+    KisToolFill(KoCanvasBase * canvas);
     virtual ~KisToolFill();
 
-    virtual void setup(KActionCollection *collection);
-    virtual enumToolType toolType() { return TOOL_FILL; }
-    virtual Q_UINT32 priority() { return 0; }
+    //     virtual enumToolType toolType() { return TOOL_FILL; }
 
-    virtual void update(KisCanvasSubject *subject);
-
-    virtual void buttonPress(KisButtonPressEvent*);
-    virtual void buttonRelease(KisButtonReleaseEvent*);
+    virtual void mousePressEvent(KoPointerEvent *event);
+    virtual void mouseReleaseEvent(KoPointerEvent *event);
 
     bool flood(int startX, int startY);
 
-    virtual QWidget* createOptionWidget(QWidget* parent);
+    virtual QWidget * createOptionWidget();
 
 public slots:
     virtual void slotSetThreshold(int);
@@ -63,14 +65,14 @@ public slots:
     virtual void slotSetFillSelection(bool);
 
 private:
-    KisPoint m_startPos;
+    QPointF m_startPos;
     int m_threshold;
-    Q_INT32 m_depth;
+    qint32 m_depth;
     KisLayerSP m_lay;
-    Q_UINT8* m_oldColor, *m_color;
+    quint8* m_oldColor, *m_color;
     KisPainter *m_painter;
-    KisCanvasSubject *m_subject;
-    KisImageSP m_currentImage;
+    KisFillPainter *m_fillPainter;
+
     bool *m_map, m_unmerged, m_usePattern, m_fillOnlySelection;
     KisSelectionSP m_selection;
 
@@ -79,30 +81,33 @@ private:
     QCheckBox *m_checkUsePattern;
     QCheckBox *m_checkSampleMerged;
     QCheckBox *m_checkFillSelection;
-    bool m_wasPressed; // use for preventing bug:133148
 };
 
 
-#include "kis_tool_factory.h"
+#include "KoToolFactory.h"
+
+class KisToolFillFactory : public KoToolFactory {
 
-class KisToolFillFactory : public KisToolFactory {
-    typedef KisToolFactory super;
 public:
-    KisToolFillFactory() : super() {};
-    virtual ~KisToolFillFactory(){};
+    KisToolFillFactory(QObject *parent, const QStringList&)
+        : KoToolFactory(parent, "KritaFill/KisTooLFill", i18n( "Contiguous Fill" ))
+        {
+            setToolTip( i18n( "Fill a contiguous area of color with a color, or fill a selection." ) );
+            setToolType( TOOL_TYPE_FILL );
+            setActivationShapeId( KIS_LAYER_SHAPE_ID );
+            setIcon( "color_fill" );
+            //setShortcut( QKeySequence( Qt::Key_F ) );
+            setPriority( 12 );
+            setInputDeviceAgnostic(false);
+	}
 
-    virtual KisTool * createTool(KActionCollection * ac) {
-        KisToolFill * t = new KisToolFill();
-        Q_CHECK_PTR(t);
-        t->setup(ac);
-        return t;
+    virtual ~KisToolFillFactory(){}
+
+    virtual KoTool * createTool(KoCanvasBase *canvas) {
+        return new KisToolFill(canvas);
     }
-    virtual KisID id() { return KisID("fill", i18n("Fill Tool")); }
 
 };
 
-
-
-
 #endif //__filltool_h__
 
