@@ -25,58 +25,56 @@
 #include <stdlib.h>
 #include <vector>
 
-#include <qcolor.h>
+#include <QColor>
 
 #include <klocale.h>
 #include <kiconloader.h>
-#include <kinstance.h>
 #include <kmessagebox.h>
 #include <kstandarddirs.h>
-#include <ktempfile.h>
 #include <kdebug.h>
 #include <kgenericfactory.h>
 #include <knuminput.h>
 
-#include <kis_doc.h>
+#include <kis_doc2.h>
 #include <kis_image.h>
 #include <kis_iterators_pixel.h>
 #include <kis_layer.h>
 #include <kis_paint_layer.h>
 #include <kis_group_layer.h>
-#include "kis_meta_registry.h"
+
 #include <kis_transaction.h>
 #include <kis_undo_adapter.h>
 #include <kis_global.h>
 #include <kis_types.h>
 #include <kis_progress_subject.h>
 #include <kis_progress_display_interface.h>
-#include <kis_colorspace.h>
-#include <kis_colorspace_factory_registry.h>
-#include <kis_view.h>
+#include <KoColorSpace.h>
+#include <KoColorSpaceRegistry.h>
+#include <kis_view2.h>
 #include <kis_paint_device.h>
-#include <kis_channelinfo.h>
+#include <KoChannelInfo.h>
 #include <kis_convolution_painter.h>
-#include "kis_rgb_colorspace.h"
-
+#include <kis_layer_commands.h>
+#include <kis_layer_manager.h>
 #include "kis_dropshadow.h"
 
 #define MIN(a, b) (((a) < (b)) ? (a) : (b))
 #define MAX(a, b) (((a) > (b)) ? (a) : (b))
 
-KisDropshadow::KisDropshadow(KisView * view)
+KisDropshadow::KisDropshadow(KisView2 * view)
     : m_view(view)
 {
 }
 
-void KisDropshadow::dropshadow(KisProgressDisplayInterface * progress, Q_INT32 xoffset, Q_INT32 yoffset, Q_INT32 blurradius, QColor color, Q_UINT8 opacity, bool allowResize)
+void KisDropshadow::dropshadow(KisProgressDisplayInterface * progress, qint32 xoffset, qint32 yoffset, qint32 blurradius, QColor color, quint8 opacity, bool allowResize)
 {
-    KisImageSP image = m_view->canvasSubject()->currentImg();
+    KisImageSP image = m_view->image();
     if (!image) return;
 
-    KisLayerSP src = image->activeLayer();
+    KisLayerSP src = m_view->activeLayer();
     if (!src) return;
 
-    KisPaintDeviceSP dev = image->activeDevice();
+    KisPaintDeviceSP dev = m_view->activeDevice();
     if (!dev) return;
 
     m_cancelRequested = false;
@@ -88,33 +86,36 @@ void KisDropshadow::dropshadow(KisProgressDisplayInterface * progress, Q_INT32 x
         image->undoAdapter()->beginMacro(i18n("Add Drop Shadow"));
     }
 
-    KisPaintDeviceSP shadowDev = new KisPaintDevice( KisMetaRegistry::instance()->csRegistry()->getColorSpace(KisID("RGBA",""),"" ), "Shadow");
+    KisPaintDeviceSP shadowDev = KisPaintDeviceSP(new KisPaintDevice( KoColorSpaceRegistry::instance()->colorSpace("RGBA",0 ), "Shadow"));
     KisPaintDeviceSP bShadowDev;
-    KisRgbColorSpace *rgb8cs = static_cast<KisRgbColorSpace *>(shadowDev->colorSpace());
+    KoColorSpace *rgb8cs = shadowDev->colorSpace();
 
     QRect rect = dev->exactBounds();
 
-    for (Q_INT32 row = 0; row < rect.height(); ++row)
+    KisHLineConstIteratorPixel srcIt = dev->createHLineConstIterator(rect.x(), rect.y(), rect.width());
+    KisHLineIteratorPixel dstIt = shadowDev->createHLineIterator(rect.x(), rect.y(), rect.width());
+
+    for (qint32 row = 0; row < rect.height(); ++row)
     {
-        KisHLineIteratorPixel srcIt = dev->createHLineIterator(rect.x(), rect.y() + row, rect.width(), false);
-        KisHLineIteratorPixel dstIt = shadowDev->createHLineIterator(rect.x(), rect.y() + row, rect.width(), true);
         while( ! srcIt.isDone() )
         {
             if (srcIt.isSelected())
             {
                 //set the shadow color
-                Q_UINT8 alpha = dev->colorSpace()->getAlpha(srcIt.rawData());
-                rgb8cs->setPixel(dstIt.rawData(), color.red(), color.green(), color.blue(), alpha);
+                quint8 alpha = dev->colorSpace()->alpha(srcIt.rawData());
+                rgb8cs->fromQColor(color, alpha, dstIt.rawData());
             }
             ++srcIt;
             ++dstIt;
         }
+        srcIt.nextRow();
+        dstIt.nextRow();
         emit notifyProgress((row * 100) / rect.height() );
     }
 
     if( blurradius > 0 )
     {
-        bShadowDev = new KisPaintDevice( KisMetaRegistry::instance()->csRegistry()->getColorSpace(KisID("RGBA",""),"" ), "bShadow");
+        bShadowDev = new KisPaintDevice( KoColorSpaceRegistry::instance()->colorSpace("RGBA",0 ), "bShadow");
         gaussianblur(shadowDev, bShadowDev, rect, blurradius, blurradius, BLUR_RLE, progress);
         shadowDev = bShadowDev;
     }
@@ -123,11 +124,11 @@ void KisDropshadow::dropshadow(KisProgressDisplayInterface * progress, Q_INT32 x
         shadowDev->move (xoffset,yoffset);
 
         KisGroupLayerSP parent = image->rootLayer();
-        if (image->activeLayer())
-            parent = image->activeLayer()->parent().data();
+        if (m_view->activeLayer())
+            parent = dynamic_cast<KisGroupLayer*>( m_view->activeLayer()->parentLayer().data() );
 
-        KisPaintLayerSP l = new KisPaintLayer(image, i18n("Drop Shadow"), opacity, shadowDev);
-        image->addLayer( l.data(), parent, src->siblingBelow() );
+        KisPaintLayerSP l = KisPaintLayerSP(new KisPaintLayer(image.data(), i18n("Drop Shadow"), opacity, shadowDev));
+        image->addNode( l.data(), parent.data(), src->nextSibling() );
 
         if (allowResize)
         {
@@ -140,8 +141,8 @@ void KisDropshadow::dropshadow(KisProgressDisplayInterface * progress, Q_INT32 x
 
                 if (shadowBounds.left() < 0 || shadowBounds.top() < 0) {
 
-                    Q_INT32 newRootX = image->rootLayer()->x();
-                    Q_INT32 newRootY = image->rootLayer()->y();
+                    qint32 newRootX = image->rootLayer()->x();
+                    qint32 newRootY = image->rootLayer()->y();
 
                     if (shadowBounds.left() < 0) {
                         newRootX += -shadowBounds.left();
@@ -150,22 +151,15 @@ void KisDropshadow::dropshadow(KisProgressDisplayInterface * progress, Q_INT32 x
                         newRootY += -shadowBounds.top();
                     }
 
-                    KCommand *moveCommand = image->rootLayer()->moveCommand(QPoint(image->rootLayer()->x(), image->rootLayer()->y()),
-                                                                            QPoint(newRootX, newRootY));
+                    QUndoCommand *moveCommand = new KisLayerMoveCommand(image->rootLayer(),
+                                   QPoint(image->rootLayer()->x(), image->rootLayer()->y()), QPoint(newRootX, newRootY));
                     Q_ASSERT(moveCommand != 0);
 
-                    if (moveCommand) {
-                        moveCommand->execute();
-                        if (image->undo()) {
-                            image->undoAdapter()->addCommand(moveCommand);
-                        } else {
-                            delete moveCommand;
-                        }
-                    }
+                    m_view->document()->addCommand(moveCommand);
                 }
             }
         }
-        m_view->canvasSubject()->document()->setModified(true);
+        m_view->image()->setModified();
     }
 
     if (image->undo()) {
@@ -177,39 +171,39 @@ void KisDropshadow::dropshadow(KisProgressDisplayInterface * progress, Q_INT32 x
 
 void KisDropshadow::gaussianblur (KisPaintDeviceSP srcDev, KisPaintDeviceSP dstDev, QRect& rect, double horz, double vert, BlurMethod method, KisProgressDisplayInterface *)
 {
-    Q_INT32 width, height;
-    Q_INT32 bytes;
-    Q_UINT8 *dest, *dp;
-    Q_UINT8 *src, *sp, *sp_p, *sp_m;
-    Q_INT32 *buf = NULL;
-    Q_INT32 *bb;
+    qint32 width, height;
+    qint32 bytes;
+    quint8 *dest, *dp;
+    quint8 *src, *sp, *sp_p, *sp_m;
+    qint32 *buf = NULL;
+    qint32 *bb;
     double n_p[5], n_m[5];
     double d_p[5], d_m[5];
     double bd_p[5], bd_m[5];
     double *val_p = NULL;
     double *val_m = NULL;
     double *vp, *vm;
-    Q_INT32 x1, y1, x2, y2;
-    Q_INT32 i, j;
-    Q_INT32 row, col, b;
-    Q_INT32 terms;
+    qint32 x1, y1, x2, y2;
+    qint32 i, j;
+    qint32 row, col, b;
+    qint32 terms;
     double progress, max_progress;
-    Q_INT32 initial_p[4];
-    Q_INT32 initial_m[4];
+    qint32 initial_p[4];
+    qint32 initial_m[4];
     double std_dev;
-    Q_INT32 pixels;
-    Q_INT32 total = 1;
-    Q_INT32 start, end;
-    Q_INT32 *curve;
-    Q_INT32 *sum = NULL;
-    Q_INT32 val;
-    Q_INT32 length;
-    Q_INT32 initial_pp, initial_mm;
+    qint32 pixels;
+    qint32 total = 1;
+    qint32 start, end;
+    qint32 *curve;
+    qint32 *sum = NULL;
+    qint32 val;
+    qint32 length;
+    qint32 initial_pp, initial_mm;
 
-    x1 = (Q_INT32)(rect.x() - horz);
-    y1 = (Q_INT32)(rect.y() - vert);
-    width = (Q_INT32)(rect.width() + 2 * horz);
-    height = (Q_INT32)(rect.height() + 2 * vert);
+    x1 = (qint32)(rect.x() - horz);
+    y1 = (qint32)(rect.y() - vert);
+    width = (qint32)(rect.width() + 2 * horz);
+    height = (qint32)(rect.height() + 2 * vert);
     x2 = x1 + width;
     y2 = y1 + height;
 
@@ -227,12 +221,12 @@ void KisDropshadow::gaussianblur (KisPaintDeviceSP srcDev, KisPaintDeviceSP dstD
         break;
 
     case BLUR_RLE:
-        buf = new Q_INT32[MAX (width, height) * 2];
+        buf = new qint32[MAX (width, height) * 2];
         break;
     }
 
-    src =  new Q_UINT8[MAX (width, height) * bytes];
-    dest = new Q_UINT8[MAX (width, height) * bytes];
+    src =  new quint8[MAX (width, height) * bytes];
+    dest = new quint8[MAX (width, height) * bytes];
 
     progress = 0.0;
     max_progress  = (horz <= 0.0 ) ? 0 : width * height * horz;
@@ -256,7 +250,7 @@ void KisDropshadow::gaussianblur (KisPaintDeviceSP srcDev, KisPaintDeviceSP dstD
 
         case BLUR_RLE:
             curve = make_curve (std_dev, &length);
-            sum = new Q_INT32[2 * length + 1];
+            sum = new qint32[2 * length + 1];
 
             sum[0] = 0;
 
@@ -382,7 +376,7 @@ void KisDropshadow::gaussianblur (KisPaintDeviceSP srcDev, KisPaintDeviceSP dstD
             dstDev->writeBytes(dest, col + x1, y1, 1, height);
 
             progress += height * vert;
-            if ((col % 5) == 0) emit notifyProgress( (Q_UINT32)((progress * 100) / max_progress));
+            if ((col % 5) == 0) emit notifyProgress( (quint32)((progress * 100) / max_progress));
         }
     }
 
@@ -406,7 +400,7 @@ void KisDropshadow::gaussianblur (KisPaintDeviceSP srcDev, KisPaintDeviceSP dstD
 
             case BLUR_RLE:
                 curve = make_curve (std_dev, &length);
-                sum = new Q_INT32[2 * length + 1];
+                sum = new qint32[2 * length + 1];
 
                 sum[0] = 0;
 
@@ -535,7 +529,7 @@ void KisDropshadow::gaussianblur (KisPaintDeviceSP srcDev, KisPaintDeviceSP dstD
 
             progress += width * horz;
             //if ((row % 5) == 0) gimp_progress_update (progress / max_progress);
-            if ((row % 5) == 0) emit notifyProgress( (Q_UINT32)((progress * 100) / max_progress ));
+            if ((row % 5) == 0) emit notifyProgress( (quint32)((progress * 100) / max_progress ));
         }
     }
 
@@ -558,11 +552,11 @@ void KisDropshadow::gaussianblur (KisPaintDeviceSP srcDev, KisPaintDeviceSP dstD
 
 void KisDropshadow::find_constants (double n_p[], double n_m[], double d_p[], double d_m[], double bd_p[], double bd_m[], double std_dev)
 {
-    Q_INT32    i;
+    qint32    i;
     double constants [8];
     double div;
 
-    /*  The constants used in the implemenation of a casual sequence
+    /*  The constants used in the implementation of a casual sequence
      *  using a 4th order approximation of the gaussian operator
      */
 
@@ -637,10 +631,10 @@ void KisDropshadow::find_constants (double n_p[], double n_m[], double d_p[], do
 }
 
 
-void KisDropshadow::transfer_pixels (double *src1, double *src2, Q_UINT8 *dest, Q_INT32 bytes, Q_INT32 width)
+void KisDropshadow::transfer_pixels (double *src1, double *src2, quint8 *dest, qint32 bytes, qint32 width)
 {
-    Q_INT32    b;
-    Q_INT32    bend = bytes * width;
+    qint32    b;
+    qint32    bend = bytes * width;
     double sum;
 
     for(b = 0; b < bend; b++)
@@ -649,12 +643,12 @@ void KisDropshadow::transfer_pixels (double *src1, double *src2, Q_UINT8 *dest,
         if (sum > 255) sum = 255;
         else if(sum < 0) sum = 0;
 
-        *dest++ = (Q_UINT8) sum;
+        *dest++ = (quint8) sum;
     }
 }
 
 //The equations: g(r) = exp (- r^2 / (2 * sigma^2)), r = sqrt (x^2 + y ^2)
-Q_INT32 * KisDropshadow::make_curve(double sigma, Q_INT32 *length)
+qint32 * KisDropshadow::make_curve(double sigma, qint32 *length)
 {
     int    *curve;
     double  sigma2;
@@ -669,7 +663,7 @@ Q_INT32 * KisDropshadow::make_curve(double sigma, Q_INT32 *length)
     if ((n % 2) == 0)
         n += 1;
 
-    curve = new Q_INT32[n];
+    curve = new qint32[n];
 
     *length = n / 2;
     curve += *length;
@@ -677,7 +671,7 @@ Q_INT32 * KisDropshadow::make_curve(double sigma, Q_INT32 *length)
 
     for (i = 1; i <= *length; i++)
     {
-        temp = (Q_INT32) (exp (- (i * i) / sigma2) * 255);
+        temp = (qint32) (exp (- (i * i) / sigma2) * 255);
         curve[-i] = temp;
         curve[i] = temp;
     }
@@ -685,12 +679,12 @@ Q_INT32 * KisDropshadow::make_curve(double sigma, Q_INT32 *length)
     return curve;
 }
 
-void KisDropshadow::run_length_encode (Q_UINT8 *src, Q_INT32 *dest, Q_INT32 bytes, Q_INT32 width)
+void KisDropshadow::run_length_encode (quint8 *src, qint32 *dest, qint32 bytes, qint32 width)
 {
-    Q_INT32   start;
-    Q_INT32   i;
-    Q_INT32   j;
-    Q_UINT8 last;
+    qint32   start;
+    qint32   i;
+    qint32   j;
+    quint8 last;
 
     last = *src;
     src += bytes;
@@ -718,9 +712,9 @@ void KisDropshadow::run_length_encode (Q_UINT8 *src, Q_INT32 *dest, Q_INT32 byte
     }
 }
 
-void KisDropshadow::multiply_alpha (Q_UINT8 *buf, Q_INT32 width, Q_INT32 bytes)
+void KisDropshadow::multiply_alpha (quint8 *buf, qint32 width, qint32 bytes)
 {
-    Q_INT32    i, j;
+    qint32    i, j;
     double alpha;
 
     for (i = 0; i < width * bytes; i += bytes)
@@ -728,17 +722,17 @@ void KisDropshadow::multiply_alpha (Q_UINT8 *buf, Q_INT32 width, Q_INT32 bytes)
         alpha = buf[i + bytes - 1] * (1.0 / 255.0);
         for (j = 0; j < bytes - 1; j++) {
             double a = (double)(buf[i + j]) * alpha;
-            buf[i + j] = (Q_UINT8)a;
+            buf[i + j] = (quint8)a;
         }
     }
 }
 
-void KisDropshadow::separate_alpha (Q_UINT8 *buf, Q_INT32 width, Q_INT32 bytes)
+void KisDropshadow::separate_alpha (quint8 *buf, qint32 width, qint32 bytes)
 {
-    Q_INT32   i, j;
-    Q_UINT8 alpha;
+    qint32   i, j;
+    quint8 alpha;
     double recip_alpha;
-    Q_UINT32    new_val;
+    quint32    new_val;
 
     for (i = 0; i < width * bytes; i += bytes)
     {
@@ -748,7 +742,7 @@ void KisDropshadow::separate_alpha (Q_UINT8 *buf, Q_INT32 width, Q_INT32 bytes)
             recip_alpha = 255.0 / alpha;
             for (j = 0; j < bytes - 1; j++)
             {
-                new_val = (Q_UINT32)(buf[i + j] * recip_alpha);
+                new_val = (quint32)(buf[i + j] * recip_alpha);
                 buf[i + j] = MIN (255, new_val);
             }
         }
