@@ -18,24 +18,23 @@
 #ifndef KIS_LABEL_CURSOR_POS_H_
 #define KIS_LABEL_CURSOR_POS_H_
 
-#include <qlabel.h>
+#include <QLabel>
 
 class KisLabelCursorPos : public QLabel {
     Q_OBJECT
-    typedef QLabel super;
 
 public:
-    KisLabelCursorPos(QWidget *parent, const char *name = 0, WFlags f = 0);
+    KisLabelCursorPos(QWidget *parent, const char *name = 0, Qt::WFlags f = 0);
     virtual ~KisLabelCursorPos();
 
 public slots:
-    void updatePos(Q_INT32 xpos, Q_INT32 ypos);
+    void updatePos(qint32 xpos, qint32 ypos);
     void enter();
     void leave();
 
 private:
     bool m_doUpdates;
-    Q_INT32 m_ypos;
+    qint32 m_ypos;
 };
 
 #endif // KIS_LABEL_CURSOR_POS_H_
