@@ -19,27 +19,42 @@
 #ifndef KIS_TOOL_PAINT_H_
 #define KIS_TOOL_PAINT_H_
 
-#include <qcursor.h>
-#include <qlayout.h>
+#include <QCursor>
+#include <QLayout>
+#include <QLabel>
+#include <QGridLayout>
+#include <QKeyEvent>
+#include <QEvent>
+#include <QPaintEvent>
+#include <QVariant>
 
-#include <koffice_export.h>
+#include <KoCanvasResourceProvider.h>
+#include <KoTool.h>
+
+#include <krita_export.h>
+
+#include <kis_types.h>
+#include <kis_image.h>
+
+#include <kis_brush.h>
+#include <kis_gradient.h>
+#include <kis_pattern.h>
 
 #include "kis_tool.h"
-#include "kis_composite_op.h"
+#include "KoCompositeOp.h"
 
-class QCheckBox;
 class QEvent;
 class QKeyEvent;
-class QComboBox;
 class QPaintEvent;
-class QRect;
 class QGridLayout;
-class KDialog;
-class KisCanvasSubject;
 class QLabel;
+
+
+class KoCanvasBase;
+
 class KisCmbComposite;
 class KisIntSpinbox;
-        
+
 enum enumBrushMode {
     PAINT,
     PAINT_STYLUS,
@@ -48,64 +63,54 @@ enum enumBrushMode {
     HOVER
 };
 
-class KRITACORE_EXPORT KisToolPaint : public KisTool {
+class KRITAUI_EXPORT KisToolPaint
+    : public KisTool
+{
 
     Q_OBJECT
-    typedef KisTool super;
 
 public:
-    KisToolPaint(const QString& UIName);
+    KisToolPaint(KoCanvasBase * canvas, const QCursor & cursor);
     virtual ~KisToolPaint();
 
+
 public:
-    virtual void update(KisCanvasSubject *subject);
 
-    virtual void paint(KisCanvasPainter& gc);
-    virtual void paint(KisCanvasPainter& gc, const QRect& rc);
+    virtual void resourceChanged( int key, const QVariant & v );
 
-    virtual void buttonPress(KisButtonPressEvent *e);
-    virtual void move(KisMoveEvent *e);
-    virtual void buttonRelease(KisButtonReleaseEvent *e);
-    virtual void doubleClick(KisDoubleClickEvent *e);
-    virtual void keyPress(QKeyEvent *e);
-    virtual void keyRelease(QKeyEvent *e);
+    virtual void paint(QPainter& gc, const KoViewConverter &converter);
 
-    virtual QCursor cursor();
-    virtual void setCursor(const QCursor& cursor);
-    virtual QWidget* createOptionWidget(QWidget* parent);
-    virtual QWidget* optionWidget();
-    virtual void addOptionWidgetOption(QWidget *control, QWidget *label = 0);
-
-public slots:
-    virtual void activate();
-    virtual void deactivate();
-
-    void slotSetOpacity(int opacityPerCent);
-    void slotSetCompositeMode(const KisCompositeOp& compositeOp);
-    void slotPopupQuickHelp();
+    virtual void mouseReleaseEvent( KoPointerEvent *event );
 
 protected:
-    void notifyModified() const;
 
-    // Add the tool-specific layout to the default option widget's layout.
+    /// Add the tool-specific layout to the default option widget layout.
     void addOptionWidgetLayout(QLayout *layout);
 
+    /// Add a widget and a label to the current option widget layout.
+    virtual void addOptionWidgetOption(QWidget *control, QWidget *label = 0);
+
+    virtual QWidget * createOptionWidget();
+
 private:
+
+    // XXX: Call this when the layer changes (this used to be called in KisCanvasObserver::update)
     void updateCompositeOpComboBox();
 
+private slots:
+
+    void slotPopupQuickHelp();
+    void slotSetOpacity(int opacityPerCent);
+    void slotSetCompositeMode(const KoCompositeOp* compositeOp);
+
 protected:
-    KisCanvasSubject *m_subject;
-    QRect m_dirtyRect;
-    Q_UINT8 m_opacity;
-    KisCompositeOp m_compositeOp;
+
+    quint8 m_opacity;
+    const KoCompositeOp * m_compositeOp;
     bool m_paintOutline;
 
 private:
-    QString m_UIName;
 
-    QCursor m_cursor;
-
-    QWidget *m_optionWidget;
     QGridLayout *m_optionWidgetLayout;
 
     QLabel *m_lbOpacity;
