@@ -25,36 +25,39 @@
 #include <QClipboard>
 #include <QHash>
 #include <QList>
+#include <QLinkedList>
+#include <QPen>
 #include <QPixmap>
 #include <QRect>
 //#include <QWidget>
 
 #include <KoDocument.h>
+#include <KoDocumentChild.h>
 #include <KoOasisSettings.h> // for KoOasisSettings::NamedMap
-#include <KoShapeControllerBase.h>
-#include <KoShapeUserData.h>
 #include <KoXmlReader.h>
 
 #include "Cell.h"
 #include "Style.h"
 #include "Global.h"
 
-#include "kspread_export.h"
-
 class QDomElement;
 class QUndoCommand;
 class QWidget;
 
-class KoDataCenter;
 class KoDocumentEntry;
 class KoStyleStack;
 class KoGenStyles;
+class KoOasisLoadingContext;
 class KoOasisSettings;
-class KoOdfStylesReader;
-class KoShape;
-class KoShapeSavingContext;
+class KoOasisStyles;
+class KoPicture;
 class KoXmlWriter;
 
+namespace KoChart
+{
+class Part;
+}
+
 namespace KSpread
 {
 class Cell;
@@ -63,35 +66,36 @@ class ColumnFormat;
 class CommentStorage;
 class ConditionsStorage;
 class FormulaStorage;
+class EmbeddedChart;
 class Doc;
 class FusionStorage;
+class GenValidationStyles;
 class LinkStorage;
 class Map;
-class OdfLoadingContext;
-class OdfSavingContext;
-class PrintManager;
-class PrintSettings;
 class Region;
 class RowFormat;
 class Selection;
 class Sheet;
 class SheetPrint;
+class SheetShapeContainer;
 class Style;
 class StyleStorage;
 class Validity;
 class ValidityStorage;
 class ValueStorage;
 class View;
+class EmbeddedKOfficeObject;
+class EmbeddedObject;
 
 /**
  * A sheet contains several cells.
  */
-class KSPREAD_EXPORT Sheet : public KoShapeUserData, public KoShapeControllerBase
+class KSPREAD_EXPORT Sheet : public QObject
 {
     Q_OBJECT
-    Q_PROPERTY(QString sheetName READ sheetName)
-    Q_PROPERTY(bool autoCalc READ isAutoCalculationEnabled WRITE setAutoCalculationEnabled)
-    Q_PROPERTY(bool showGrid READ getShowGrid WRITE setShowGrid)
+    Q_PROPERTY( QString sheetName READ sheetName )
+    Q_PROPERTY( bool autoCalc READ isAutoCalculationEnabled WRITE setAutoCalculationEnabled )
+    Q_PROPERTY( bool showGrid READ getShowGrid WRITE setShowGrid )
 
 public:
     enum ChangeRef       { ColumnInsert, ColumnRemove, RowInsert, RowRemove };
@@ -123,17 +127,10 @@ public:
      */
     Doc* doc() const;
 
-    // KoShapeControllerBase interface
-    virtual void addShape(KoShape* shape);
-    virtual void removeShape(KoShape* shape);
-    virtual QMap<QString, KoDataCenter*> dataCenterMap() const;
-
     /**
-     * \ingroup Embedding
-     * Returns the sheet's shapes.
-     * \return the shapes this sheet contains
+     * \return the shape container of this sheet
      */
-    QList<KoShape*> shapes() const;
+    SheetShapeContainer* shapeContainer() const;
 
     //////////////////////////////////////////////////////////////////////////
     //
@@ -181,7 +178,7 @@ public:
      * Sets the layout direction of the sheet. For example, for Arabic or Hebrew
      * documents, it is possibly to layout the sheet from right to left.
      */
-    void setLayoutDirection(Qt::LayoutDirection dir);
+    void setLayoutDirection( Qt::LayoutDirection dir );
 
     /**
      * Returns, if the grid shall be shown on the screen
@@ -191,7 +188,7 @@ public:
     /**
      * Sets, if the grid shall be shown on the screen
      */
-    void setShowGrid(bool _showGrid);
+    void setShowGrid( bool _showGrid );
 
     /**
      * Sets, if formula shall be shown instead of the result
@@ -216,7 +213,7 @@ public:
      * If b is true, comment indicator is visible, otherwise
      * it will be hidden.
      */
-    void setShowCommentIndicator(bool b);
+    void setShowCommentIndicator( bool b );
 
     bool getLcMode() const;
 
@@ -246,7 +243,7 @@ public:
     /**
      * Hides or shows this sheets
      */
-    void setHidden(bool hidden);
+    void setHidden( bool hidden );
 
     /**
      * @return a flag that indicates whether the sheet should paint the page breaks.
@@ -262,7 +259,7 @@ public:
      * @see isShowPageBorders
      * @see Sheet::Private::showPageBorders
      */
-    void setShowPageBorders(bool _b);
+    void setShowPageBorders( bool _b );
 
     //
     //END Methods related to sheet properties
@@ -276,25 +273,25 @@ public:
      * \ingroup NativeFormat
      * Saves the sheet and all it's children in XML format
      */
-    QDomElement saveXML(QDomDocument&);
+    QDomElement saveXML( QDomDocument& );
 
     /**
      * \ingroup NativeFormat
      * Loads the sheet and all it's children in XML format
      */
-    bool loadXML(const KoXmlElement&);
+    bool loadXML( const KoXmlElement& );
 
     /**
      * \ingroup NativeFormat
      * Saves a children
      */
-    bool saveChildren(KoStore* _store, const QString &_path);
+    bool saveChildren( KoStore* _store, const QString &_path );
 
     /**
      * \ingroup NativeFormat
      * Loads a children
      */
-    bool loadChildren(KoStore* _store);
+    bool loadChildren( KoStore* _store );
 
     //
     //END Methods related to KSpread's old file format
@@ -307,48 +304,159 @@ public:
     /**
      * \ingroup OpenDocument
      */
-    bool loadOdf(const KoXmlElement& sheet,
-                 OdfLoadingContext& odfContext,
-                 const Styles& autoStyles,
-                 const QHash<QString, Conditions>& conditionalStyles);
+    bool loadOasis( const KoXmlElement& sheet,
+                    KoOasisLoadingContext& oasisContext,
+                    const Styles& autoStyles,
+                    const QHash<QString, Conditions>& conditionalStyles );
 
     /**
      * \ingroup OpenDocument
      */
-    bool saveOdf(OdfSavingContext& tableContext);
+    bool saveOasis( KoXmlWriter& xmlWriter, KoGenStyles& mainStyles,
+                    GenValidationStyles& valStyle, KoStore* store,
+                    KoXmlWriter* manifestWriter,
+                    int& indexObj, int& partIndexObj );
 
     /**
      * \ingroup OpenDocument
      */
-    void saveOdfHeaderFooter(KoXmlWriter &xmlWriter) const;
+    void saveOasisHeaderFooter( KoXmlWriter &xmlWriter ) const;
 
     /**
      * \ingroup OpenDocument
      */
-    void loadOdfSettings(const KoOasisSettings::NamedMap &settings);
+    void loadOasisObjects( const KoXmlElement& e, KoOasisLoadingContext& oasisContext );
 
     /**
      * \ingroup OpenDocument
      */
-    void saveOdfSettings(KoXmlWriter &settingsWriter) const;
+    void loadOasisSettings( const KoOasisSettings::NamedMap &settings );
 
     /**
      * \ingroup OpenDocument
      */
-    void saveOdfPrintStyleLayout(KoGenStyle &style) const;
+    void saveOasisSettings( KoXmlWriter &settingsWriter ) const;
+
+    /**
+     * \ingroup OpenDocument
+     */
+    void saveOasisPrintStyleLayout( KoGenStyle &style ) const;
+
+    /**
+     * \ingroup OpenDocument
+     */
+    bool saveOasisObjects( KoStore *store, KoXmlWriter &xmlWriter, KoGenStyles& mainStyles, int & indexObj, int &partIndexObj );
 
     //
     //END Methods related to the OpenDocument file format
     //
     //////////////////////////////////////////////////////////////////////////
     //
+    //BEGIN Methods related to embedded objects
+    //
+
+    /**
+     * \ingroup Embedding
+     * @brief Get a list of all selected objects
+     *
+     * @return list of selected objets.
+     */
+    QList<EmbeddedObject*> getSelectedObjects();
+
+    /**
+     * \ingroup Embedding
+     * @brief get the rect for the objects
+     *
+     * @param all true if the rect for all objects should be returned
+     *        false if only the rect for selected objects sould be returned
+     *
+     * @return rect of the objects
+     */
+    QRectF getRealRect( bool all );
+
+    /**
+     * \ingroup Embedding
+     * Moves the selected object.
+     * \return command for undo
+     */
+    QUndoCommand *moveObject(View *_view, double diffx, double diffy);
+
+    /**
+     * \ingroup Embedding
+     * Moves the selected object.
+     * \return command for undo
+     */
+    QUndoCommand *moveObject(View *m_view,const QPointF &_move,bool key);
+
+    /**
+     * \ingroup Embedding
+     * @brief Create a unique name for an object.
+     *
+     * Create a unique name for the object. If no name is set for the object
+     * a name according to its type is created. If the name already exists
+     * append ' (x)'. // FIXME: not allowed by I18N
+     *
+     * @param object to work on
+     */
+    void unifyObjectName( EmbeddedObject *object );
+
+    /**
+     * \ingroup Embedding
+     */
+    bool insertChild( const QRectF& _geometry, KoDocumentEntry&, QWidget* );
+
+    /**
+     * \ingroup Embedding
+     */
+    bool insertChart( const QRectF& _geometry, KoDocumentEntry&, const QRect& _data, QWidget* );
+
+    /**
+     * \ingroup Embedding
+     * Creates a new embedded picture object and inserts it into the sheet next to the currently
+     * selected cell.
+     *
+     * TODO:  Remove this method in future and provide a better way of opening pictures and inserting
+     * them into the sheet.
+     *
+     * @param file The URL of the file to insert.
+     * @param point The the top-left point in the sheet where the picture should be inserted.
+     */
+    bool insertPicture( const QPointF& point , const KUrl& file );
+
+    /**
+     * \ingroup Embedding
+     * Creates a new embedded picture object and inserts it into the sheet at the specified position.
+     *
+     * @param point The top-left position for the new picture object in the sheet
+     * @param pixmap The source pixmap for the new picture
+     */
+    bool insertPicture( const QPointF& point, const QPixmap& pixmap );
+
+    /**
+     * \ingroup Embedding
+     */
+    void changeChildGeometry( EmbeddedKOfficeObject *_child, const QRectF& _geometry );
+
+    /**
+     * \ingroup Embedding
+     * @brief Get the amount of selected objects that belong to this sheet
+     *
+     * @return the amount of select objects in this sheet
+     */
+    int numberSelectedObjects() const;
+
+    //
+    //END Methods related to embedded objects
+    //
+    //////////////////////////////////////////////////////////////////////////
+    //
     //BEGIN Methods related to protection
     //
 
     /**
      * \ingroup Protection
      */
-    void password(QByteArray & passwd) const ;
+    void password( QByteArray & passwd ) const ;
 
     /**
      * \ingroup Protection
@@ -358,12 +466,12 @@ public:
     /**
      * \ingroup Protection
      */
-    void setProtected(QByteArray const & passwd);
+    void setProtected( QByteArray const & passwd );
 
     /**
      * \ingroup Protection
      */
-    bool checkPassword(QByteArray const & passwd) const;
+    bool checkPassword( QByteArray const & passwd ) const;
 
     //
     //END Methods related to protection
@@ -377,21 +485,21 @@ public:
      * \return the row format of row \p _row . The default row format,
      * if no special one exists.
      */
-    const RowFormat* rowFormat(int _row) const;
+    const RowFormat* rowFormat( int _row ) const;
 
     /**
      * If no special RowFormat exists for this row, then a new one is created.
      *
      * @return a non default RowFormat for this row.
      */
-    RowFormat* nonDefaultRowFormat(int _row, bool force_creation = true);
+    RowFormat* nonDefaultRowFormat( int _row, bool force_creation = true );
 
     /**
      * \return the first non-default row format
      */
     RowFormat* firstRow() const;
 
-    void setDefaultHeight(double height);
+    void setDefaultHeight( double height );
 
     //
     //END Methods related to row formats
@@ -405,21 +513,21 @@ public:
      * \return the column format of column \p _column . The default column format,
      * if no special one exists.
      */
-    const ColumnFormat* columnFormat(int _column) const;
+    const ColumnFormat* columnFormat( int _column ) const;
 
     /**
      * If no special ColumnFormat exists for this column, then a new one is created.
      *
      * @return a non default ColumnFormat for this column.
      */
-    ColumnFormat* nonDefaultColumnFormat(int _column, bool force_creation = true);
+    ColumnFormat* nonDefaultColumnFormat( int _column, bool force_creation = true );
 
     /**
      * \return the first non-default row format
      */
     ColumnFormat* firstCol() const;
 
-    void setDefaultWidth(double width);
+    void setDefaultWidth( double width );
 
     //
     //END Methods related to column formats
@@ -458,6 +566,12 @@ public:
     //BEGIN UNSORTED METHODS !!!
     //
 
+    /**
+     * Sets the contents of the cell at row,column to text
+     */
+    void setText( int row, int column, const QString& text,
+                  bool asString = false );
+
     /**
      * Determines the row for a given position \p _ypos . If the position is
      * on the border between two cells, the upper row is returned. Also, the offset
@@ -468,7 +582,7 @@ public:
      *
      * \return the row for the given position \p _ypos
      */
-    int topRow(double _ypos, double &_top) const;
+    int topRow( double _ypos, double &_top ) const;
 
     /**
      * Determines the row for a given position \p _ypos . If the position is
@@ -478,7 +592,7 @@ public:
      *
      * \return the row for the given position \p _ypos
      */
-    int bottomRow(double _ypos) const;
+    int bottomRow( double _ypos ) const;
 
     /**
      * Determines the column for a given position \p _xpos . If the position is
@@ -490,7 +604,7 @@ public:
      *
      * \return the column for the given position \p _xpos
      */
-    int leftColumn(double _xpos, double &_left) const;
+    int leftColumn( double _xpos, double &_left ) const;
 
     /**
      * Determines the column for a given position \p _xpos . If the position is
@@ -500,21 +614,7 @@ public:
      *
      * \return the column for the given position \p _xpos
      */
-    int rightColumn(double _xpos) const;
-
-    /**
-     * Calculates the region in document coordinates occupied by a range of cells.
-     * \param cellRange the range of cells
-     * \return the document area covered by the cells
-     */
-    QRectF cellCoordinatesToDocument(const QRect& cellRange) const;
-
-    /**
-     * Calculates the cell range covering a document area.
-     * \param area the document area
-     * \return the cell range covering the area
-     */
-    QRect documentToCellCoordinates(const QRectF& area) const;
+    int rightColumn( double _xpos ) const;
 
     /**
      * @return the left corner of the column as double.
@@ -522,7 +622,7 @@ public:
      * to avoid rounding problems
      * @param col the column's index
      */
-    double columnPosition(int col) const;
+    double columnPosition( int col ) const;
 
     /**
      * @return the top corner of the row as double.
@@ -530,7 +630,7 @@ public:
      * to avoid rounding problems
      * @param _row the row's index
      */
-    double rowPosition(int _row) const;
+    double rowPosition( int _row ) const;
 
     /**
      * \return the document size
@@ -541,13 +641,13 @@ public:
      * Adjusts the internal reference of the sum of the widths of all columns.
      * Used in resizing of columns.
      */
-    void adjustDocumentWidth(double deltaWidth);
+    void adjustDocumentWidth( double deltaWidth );
 
     /**
      * Adjusts the internal reference of the sum of the heights of all rows.
      * Used in resizing of rows.
      */
-    void adjustDocumentHeight(double deltaHeight);
+    void adjustDocumentHeight( double deltaHeight );
 
     /**
      * Attempts to guess the title (or 'header') of a column, within a given area of the sheet
@@ -579,11 +679,18 @@ public:
     /**
      * @param selection the selection of cells to work on
      */
-    void copySelection(Selection* selection);
+    void copySelection( Selection* selection );
     /**
      * @param selection the selection of cells to work on
      */
-    void cutSelection(Selection* selection);
+    void cutSelection( Selection* selection );
+
+    void setWordSpelling(Selection* selection, const QString& wordList);
+
+    /**
+     * @param selection the selection of cells to work on
+     */
+    QString wordSpelling( Selection* selection );
 
     /**
      * @return @c true if there are text value in cell
@@ -598,6 +705,14 @@ public:
      */
     QString copyAsText(Selection* selection);
 
+    /**
+     * @param region the region to merge
+     * @param hor merge horizontally
+     * @param ver merge vertically
+     */
+    void mergeCells( const Region& region, bool hor = false, bool ver = false );
+    void dissociateCells( const Region &region );
+
     bool areaIsEmpty(const Region& area, TestType _type = Text) ;
 
     /**
@@ -622,14 +737,14 @@ public:
      * A convenience function which retrieves the data to be pasted
      * from the clipboard.
      */
-    void paste(const QRect & pasteArea, bool makeUndo = true,
-               Paste::Mode = Paste::Normal, Paste::Operation = Paste::OverWrite,
-               bool insert = false, int insertTo = 0, bool pasteFC = false,
-               QClipboard::Mode clipboardMode = QClipboard::Clipboard);
+    void paste( const QRect & pasteArea, bool makeUndo = true,
+                Paste::Mode = Paste::Normal, Paste::Operation = Paste::OverWrite,
+                bool insert = false, int insertTo = 0, bool pasteFC = false,
+                QClipboard::Mode clipboardMode = QClipboard::Clipboard );
 
-    void paste(const QByteArray & data, const QRect & pasteArea,
-               bool makeUndo = false, Paste::Mode = Paste::Normal, Paste::Operation = Paste::OverWrite,
-               bool insert = false, int insertTo = 0, bool pasteFC = false);
+    void paste( const QByteArray & data, const QRect & pasteArea,
+                bool makeUndo = false, Paste::Mode= Paste::Normal, Paste::Operation = Paste::OverWrite,
+                bool insert = false, int insertTo = 0, bool pasteFC = false );
 
     /**
      * A function which allows to paste a text plain from the clipboard
@@ -648,25 +763,25 @@ public:
      * Helper method.
      * \see ShiftManipulator
      */
-    void insertShiftRight(const QRect& rect);
+    void insertShiftRight( const QRect& rect );
 
     /**
      * Helper method.
      * \see ShiftManipulator
      */
-    void insertShiftDown(const QRect& rect);
+    void insertShiftDown( const QRect& rect );
 
     /**
      * Helper method.
      * \see ShiftManipulator
      */
-    void removeShiftUp(const QRect& rect);
+    void removeShiftUp( const QRect& rect );
 
     /**
      * Helper method.
      * \see ShiftManipulator
      */
-    void removeShiftLeft(const QRect& rect);
+    void removeShiftLeft( const QRect& rect );
 
     /**
      * Helper method.
@@ -674,7 +789,7 @@ public:
      * Moves all columns which are >= \p col \p number positions to the right
      * and inserts a new and empty column.
      */
-    void insertColumns(int row, int numbers);
+    void insertColumns( int row, int numbers );
 
     /**
      * Helper method.
@@ -682,21 +797,21 @@ public:
      * Moves all rows which are >= \p row \p number positions down
      * and inserts a new and empty row.
      */
-    void insertRows(int row, int numbers);
+    void insertRows( int row, int numbers );
 
     /**
      * Helper method.
      * \see InsertDeleteColumnManipulator
      * Deletes \p number columns beginning at \p col .
      */
-    void removeColumns(int row, int numbers);
+    void removeColumns( int row, int numbers );
 
     /**
      * Helper method.
      * \see InsertDeleteRowManipulator
      * Deletes \p number rows beginning at \p row .
      */
-    void removeRows(int row, int numbers);
+    void removeRows( int row, int numbers );
 
     /**
      * Updates vertical border and view.
@@ -716,8 +831,12 @@ public:
     //BEGIN UNSORTED METHODS !!!
     //
 
+    void refreshPreference() ;
+
     void hideSheet(bool _hide);
 
+    void removeSheet();
+
     /**
      * Change name of reference when the user inserts or removes a column,
      * a row or a cell (= insertion of a row [or column] on a single column [or row]).
@@ -735,25 +854,42 @@ public:
     void changeNameCellRef(const QPoint& pos, bool fullRowOrColumn, ChangeRef ref,
                            const QString& sheetName, int number);
 
+
+    void refreshRemoveAreaName(const QString &_areaName);
+    void refreshChangeAreaName(const QString &_areaName);
+
+
+    /**
+     * Used by the 'chart' to get the sheet on which the chart is build.
+     * The cells we are interested in are in the rectangle '_range'.
+     * The cells are stored row after row in '_list'.
+     */
+    bool getCellRectangle( const QRect &_range, QList<Cell> &_list );
+
+    /**
+     * A convenience function that finds a sheet by its name.
+     */
+    Sheet *findSheet( const QString & _name );
+
     /**
      * Insert the non-default column format \p columnFormat.
      */
-    void insertColumnFormat(ColumnFormat* columnFormat);
+    void insertColumnFormat( ColumnFormat* columnFormat );
 
     /**
      * Inserts the non-default row format \p rowFormat.
      */
-    void insertRowFormat(RowFormat* rowFormat);
+    void insertRowFormat( RowFormat* rowFormat );
 
     /**
      * Deletes the column format at \p column.
      */
-    void deleteColumnFormat(int column);
+    void deleteColumnFormat( int column );
 
     /**
      * Deletes the row format at \p row.
      */
-    void deleteRowFormat(int row);
+    void deleteRowFormat( int row );
 
     /**
      * @param era set this to true if you want to encode relative references
@@ -769,13 +905,13 @@ public:
      * insertTo used just for insert/paste an area
      * @see paste
      */
-    bool loadSelection(const KoXmlDocument& doc, const QRect &pasteArea,
-                       int _xshift, int _yshift, bool makeUndo,
-                       Paste::Mode = Paste::Normal, Paste::Operation = Paste::OverWrite,
-                       bool insert = false, int insertTo = 0, bool paste = false);
+    bool loadSelection( const KoXmlDocument& doc, const QRect &pasteArea,
+                        int _xshift, int _yshift, bool makeUndo,
+                        Paste::Mode = Paste::Normal, Paste::Operation = Paste::OverWrite,
+                        bool insert = false, int insertTo = 0, bool paste = false );
 
-    void loadSelectionUndo(const KoXmlDocument & doc, const QRect &loadArea,
-                           int _xshift, int _yshift, bool insert, int insertTo);
+    void loadSelectionUndo( const KoXmlDocument & doc, const QRect &loadArea,
+                            int _xshift, int _yshift,bool insert,int insertTo);
 
     /**
      * Used when you insert and paste cell
@@ -804,6 +940,18 @@ public:
 
     void setRegionPaintDirty(const QRect & rect);
 
+    /**
+     * \ingroup Painting
+     * Remove all records of 'paint dirty' cells
+     */
+    void clearPaintDirtyData();
+
+    /**
+     * \ingroup Painting
+     * Test whether a cell needs repainted
+     */
+    const Region& paintDirtyData() const;
+
     /**
      * \ingroup Painting
      * repaints all visible cells
@@ -824,15 +972,19 @@ public:
     //BEGIN UNSORTED METHODS !!!
     //
 
-    void emit_updateRow(RowFormat* rowFormat, int _row, bool repaint = true);
-    void emit_updateColumn(ColumnFormat* columnFormat, int _column);
+    /**
+     * used to refresh cells when you make redodelete
+     * \note Deletes (!) the cells in the region.
+     */
+    void refreshView(const Region& region);
+
+    void emit_updateRow( RowFormat* rowFormat, int _row, bool repaint = true );
+    void emit_updateColumn( ColumnFormat* columnFormat, int _column );
 
     void updateLocale();
 
 
-    SheetPrint * print() const;
-    PrintSettings* printSettings() const;
-    void setPrintSettings(const PrintSettings& settings);
+  SheetPrint * print() const;
 
 #ifndef NDEBUG
     void printDebug();
@@ -845,21 +997,23 @@ public:
 
 signals:
     void sig_refreshView();
-    void sig_updateView(Sheet *_sheet);
-    void sig_updateView(Sheet *_sheet, const Region&);
-    void sig_updateColumnHeader(Sheet *_sheet);
-    void sig_updateRowHeader(Sheet *_sheet);
+    void sig_updateView( Sheet *_sheet );
+    void sig_updateView( Sheet *_sheet, const Region& );
+    void sig_updateView( EmbeddedObject *obj );
+    void sig_updateHBorder( Sheet *_sheet );
+    void sig_updateVBorder( Sheet *_sheet );
+    void sig_updateChildGeometry( EmbeddedKOfficeObject *_child );
     /**
      * @see setSheetName
      */
-    void sig_nameChanged(Sheet* sheet, const QString& old_name);
+    void sig_nameChanged( Sheet* sheet, const QString& old_name );
 
-    void sig_SheetHidden(Sheet* sheet);
-    void sig_SheetShown(Sheet* sheet);
-    void sig_SheetRemoved(Sheet* sheet);
-    void sig_SheetActivated(Sheet*);
-    void sig_RefreshView(Sheet*);
-    void documentSizeChanged(const QSizeF&);
+    void sig_SheetHidden( Sheet* sheet);
+    void sig_SheetShown( Sheet* sheet);
+    void sig_SheetRemoved( Sheet* sheet);
+    void sig_SheetActivated( Sheet* );
+    void sig_RefreshView( Sheet* );
+    void documentSizeChanged( const QSizeF& );
     void visibleSizeChanged();
 
 protected:
@@ -868,7 +1022,7 @@ protected:
      * When you change name sheet Sheet1 -> Price
      * for all cell which refere to Sheet1, this function changes the name.
      */
-    void changeCellTabName(QString const & old_name, QString const & new_name);
+    void changeCellTabName( QString const & old_name,QString const & new_name );
 
     //
     //////////////////////////////////////////////////////////////////////////
@@ -879,10 +1033,10 @@ protected:
     /**
      * \ingroup OpenDocument
      */
-    bool loadRowFormat(const KoXmlElement& row, int &rowIndex,
-                       OdfLoadingContext& odfContext,
-                       QHash<QString, QRegion>& rowStyleRegions,
-                       QHash<QString, QRegion>& cellStyleRegions);
+    bool loadRowFormat( const KoXmlElement& row, int &rowIndex,
+                        KoOasisLoadingContext& oasisContext,
+                        QHash<QString, QRegion>& rowStyleRegions,
+                        QHash<QString, QRegion>& cellStyleRegions );
 
     /**
      * \ingroup OpenDocument
@@ -890,8 +1044,8 @@ protected:
      * defaultColumnCellStyles is a map from column indicies to the default cell style for that column
      */
     bool loadColumnFormat(const KoXmlElement& row,
-                          const KoOdfStylesReader& stylesReader, int & indexCol,
-                          QHash<QString, QRegion>& columnStyleRegions);
+                          const KoOasisStyles& oasisStyles, int & indexCol,
+                          QHash<QString, QRegion>& columnStyleRegions );
 
     /**
      * \ingroup OpenDocument
@@ -900,62 +1054,63 @@ protected:
      * \p autoStyles , and custom styles in the StyleManager.
      * The region is restricted to \p usedArea .
      */
-    void loadOdfInsertStyles(const Styles& autoStyles,
-                             const QHash<QString, QRegion>& styleRegions,
-                             const QHash<QString, Conditions>& conditionalStyles,
-                             const QRect& usedArea);
+    void loadOasisInsertStyles( const Styles& autoStyles,
+                                const QHash<QString, QRegion>& styleRegions,
+                                const QHash<QString, Conditions>& conditionalStyles,
+                                const QRect& usedArea );
 
     /**
      * \ingroup OpenDocument
      */
-    bool loadSheetStyleFormat(KoXmlElement *style);
+    bool loadSheetStyleFormat( KoXmlElement *style );
 
     /**
      * \ingroup OpenDocument
      */
-    void loadOdfMasterLayoutPage(KoStyleStack &styleStack);
+    void loadOasisMasterLayoutPage( KoStyleStack &styleStack );
 
     /**
      * \ingroup OpenDocument
      */
-    QString saveOdfSheetStyleName(KoGenStyles &mainStyles);
+    QString saveOasisSheetStyleName( KoGenStyles &mainStyles );
 
     /**
      * \ingroup OpenDocument
      */
-    void saveOdfColRowCell(KoXmlWriter& xmlWriter, KoGenStyles &mainStyles,
-                           int maxCols, int maxRows, OdfSavingContext& tableContext);
+    void saveOasisColRowCell( KoXmlWriter& xmlWriter, KoGenStyles &mainStyles,
+                              int maxCols, int maxRows, GenValidationStyles &valStyle );
 
     /**
      * \ingroup OpenDocument
      */
-    void saveOdfCells(KoXmlWriter& xmlWriter, KoGenStyles &mainStyles, int row, int maxCols,
-                      OdfSavingContext& tableContext);
+    void saveOasisCells(KoXmlWriter& xmlWriter, KoGenStyles &mainStyles, int row, int maxCols,
+                        GenValidationStyles &valStyle, const QMap<int, Style>& columnDefaultStyles,
+                        const QMap<int, Style>& rowDefaultStyles);
 
     /**
      * \ingroup OpenDocument
      */
-    void convertPart(const QString & part, KoXmlWriter & writer) const;
+    void convertPart( const QString & part, KoXmlWriter & writer ) const;
 
     /**
      * \ingroup OpenDocument
      */
-    void addText(const QString & text, KoXmlWriter & writer) const;
+    void addText( const QString & text, KoXmlWriter & writer ) const;
 
     /**
      * \ingroup OpenDocument
      */
-    bool compareRows(int row1, int row2, int & maxCols, OdfSavingContext& tableContext) const;
+    bool compareRows( int row1, int row2, int & maxCols ) const;
 
     /**
      * \ingroup OpenDocument
      */
-    QString getPart(const KoXmlNode & part);
+    QString getPart( const KoXmlNode & part );
 
     /**
      * \ingroup OpenDocument
      */
-    void replaceMacro(QString & text, const QString & old, const QString & newS);
+    void replaceMacro( QString & text, const QString & old, const QString & newS );
 
     //
     //END Methods related to the OpenDocument file format
@@ -963,18 +1118,35 @@ protected:
     //////////////////////////////////////////////////////////////////////////
     //
 
+    /**
+     * \ingroup Embedding
+     */
+    void insertObject( EmbeddedObject *_obj );
+
     // helper function for areaIsEmpty
-    bool cellIsEmpty(const Cell& cell, TestType _type);
+    bool cellIsEmpty( const Cell& cell, TestType _type );
 
     QString changeNameCellRefHelper(const QPoint& pos, bool fullRowOrColumn, ChangeRef ref,
-                                    int NbCol, const QPoint& point, bool isColumnFixed,
+                                    int NbCol, const QPoint& pos, bool isColumnFixed,
                                     bool isRowFixed);
 
-    static Sheet* find(int _id);
+    static Sheet* find( int _id );
     static int s_id;
-    static QHash<int, Sheet*>* s_mapSheets;
+    static QHash<int,Sheet*>* s_mapSheets;
 
 private:
+    /**
+     * \ingroup Embedding
+     * Inserts a picture into the sheet and the given position.  The picture should be added to the
+     * document's picture collection before calling this method.
+     */
+    bool insertPicture( const QPointF& point, KoPicture& picture );
+
+    /**
+     * \ingroup Embedding
+     */
+    bool objectNameExists( EmbeddedObject *object, QList<EmbeddedObject*> &list );
+
     /**
      * \ingroup NativeFormat
      */
@@ -983,7 +1155,7 @@ private:
     /**
      * \ingroup NativeFormat
      */
-    void checkContentDirection(QString const & name);
+    void checkContentDirection( QString const & name );
 
     // disable assignment operator
     void operator=(const Sheet& other);
