@@ -33,7 +33,7 @@
 
 #include <kdebug.h>
 
-#include "Map.h"
+#include "Doc.h"
 #include "Sheet.h"
 #include "SheetPrint.h"
 #include "Region.h"
@@ -45,12 +45,12 @@
 
 using namespace KSpread;
 
-SheetAdaptor::SheetAdaptor(Sheet* t)
-        : QDBusAbstractAdaptor(t)
+SheetAdaptor::SheetAdaptor( Sheet* t )
+: QDBusAbstractAdaptor( t )
 {
     setAutoRelaySignals(false);
     m_sheet = t;
-    connect(t, SIGNAL(sig_nameChanged(Sheet*, QString)), this, SIGNAL(nameChanged()));
+    connect(t, SIGNAL(sig_nameChanged(Sheet*,QString)), this, SIGNAL(nameChanged()));
     connect(t, SIGNAL(sig_SheetShown(Sheet*)), this, SIGNAL(showChanged()));
     connect(t, SIGNAL(sig_SheetHidden(Sheet*)), this, SIGNAL(hideChanged()));
 }
@@ -59,7 +59,7 @@ SheetAdaptor::~SheetAdaptor()
 {
 }
 
-QString SheetAdaptor::cellName(int x, int y)
+QString SheetAdaptor::cellName( int x, int y )
 {
     /* sebsauer 20061206: commented out cause if someone starts to believe that
     counting starts by 0,0 then he may very surprised why the first col/row
@@ -72,54 +72,54 @@ QString SheetAdaptor::cellName(int x, int y)
     if ( x == 0 ) x = 1;
     if ( y == 0 ) y = 1;
     */
-    return Cell::name(x, y);
+    return Cell::name( x, y );
 }
 
-int SheetAdaptor::cellRow(const QString& cellname)
+int SheetAdaptor::cellRow( const QString& cellname )
 {
     return cellLocation(cellname).x();
 }
 
-int SheetAdaptor::cellColumn(const QString& cellname)
+int SheetAdaptor::cellColumn( const QString& cellname )
 {
     return cellLocation(cellname).y();
 }
 
-QPoint SheetAdaptor::cellLocation(const QString& cellname)
+QPoint SheetAdaptor::cellLocation( const QString& cellname )
 {
-    const Region region(cellname, m_sheet->map(), m_sheet);
-    if (region.firstRange().isNull())
+    const Region region(cellname, m_sheet->doc()->map(), m_sheet);
+    if ( region.firstRange().isNull() )
         return QPoint();
     return region.firstRange().topLeft();
 }
 
-QString SheetAdaptor::text(int x, int y)
+QString SheetAdaptor::text( int x, int y )
 {
-    Cell cell = Cell(m_sheet, x, y);
+    Cell cell = Cell( m_sheet, x, y);
     return cell.userInput();
 }
 
-QString SheetAdaptor::text(const QString& cellname)
+QString SheetAdaptor::text( const QString& cellname )
 {
     const QPoint location = cellLocation(cellname);
     return text(location.x(), location.y());
 }
 
-bool SheetAdaptor::setText(int x, int y, const QString& text, bool parse)
+bool SheetAdaptor::setText( int x, int y, const QString& text, bool parse )
 {
     //FIXME: there is some problem with asString parameter, when it's set
-    //to true KSpread says: ASSERT: "f" in Dependencies.cpp (621)
-    //kspread: Cell at row 6, col 1 marked as formula, but formula is NULL
+	//to true KSpread says: ASSERT: "f" in Dependencies.cpp (621)
+	//kspread: Cell at row 6, col 1 marked as formula, but formula is NULL
 
-    KSpread::DataManipulator *dm = new KSpread::DataManipulator();
-    dm->setSheet(m_sheet);
-    dm->setValue(Value(text));
-    dm->setParsing(parse);
-    dm->add(QPoint(x, y));
-    return dm->execute();
+	KSpread::DataManipulator *dm = new KSpread::DataManipulator();
+	dm->setSheet(m_sheet);
+	dm->setValue(Value(text));
+	dm->setParsing(parse);
+	dm->add(QPoint(x, y));
+	return dm->execute();
 }
 
-bool SheetAdaptor::setText(const QString& cellname, const QString& text, bool parse)
+bool SheetAdaptor::setText( const QString& cellname, const QString& text, bool parse )
 {
     const QPoint location = cellLocation(cellname);
     return setText(location.x(), location.y(), text, parse);
@@ -127,94 +127,93 @@ bool SheetAdaptor::setText(const QString& cellname, const QString& text, bool pa
 
 QVariant valueToVariant(const KSpread::Value& value, Sheet* sheet)
 {
-    //Should we use following value-format enums here?
-    //fmt_None, fmt_Boolean, fmt_Number, fmt_Percent, fmt_Money, fmt_DateTime, fmt_Date, fmt_Time, fmt_String
-    switch (value.type()) {
-    case KSpread::Value::Empty:
-        return QVariant();
-    case KSpread::Value::Boolean:
-        return QVariant(value.asBoolean());
-    case KSpread::Value::Integer:
-        return static_cast<qint64>(value.asInteger());
-    case KSpread::Value::Float:
-        return (double) numToDouble(value.asFloat());
-    case KSpread::Value::Complex:
-        return sheet->map()->converter()->asString(value).asString();
-    case KSpread::Value::String:
-        return value.asString();
-    case KSpread::Value::Array: {
-        QVariantList colarray;
-        for (uint j = 0; j < value.rows(); j++) {
-            QVariantList rowarray;
-            for (uint i = 0; i < value.columns(); i++) {
-                KSpread::Value v = value.element(i, j);
-                rowarray.append(valueToVariant(v, sheet));
-            }
-            colarray.append(rowarray);
-        }
-        return colarray;
-    }
-    break;
-    case KSpread::Value::CellRange:
-        //FIXME: not yet used
-        return QVariant();
-    case KSpread::Value::Error:
-        return QVariant();
-    }
-    return QVariant();
+	//Should we use following value-format enums here?
+	//fmt_None, fmt_Boolean, fmt_Number, fmt_Percent, fmt_Money, fmt_DateTime, fmt_Date, fmt_Time, fmt_String
+	switch(value.type()) {
+		case KSpread::Value::Empty:
+			return QVariant();
+		case KSpread::Value::Boolean:
+			return QVariant( value.asBoolean() );
+		case KSpread::Value::Integer:
+			return static_cast<qint64>(value.asInteger());
+		case KSpread::Value::Float:
+			return numToDouble (value.asFloat());
+		case KSpread::Value::Complex:
+			return sheet->doc()->converter()->asString(value).asString();
+		case KSpread::Value::String:
+			return value.asString();
+		case KSpread::Value::Array: {
+			QVariantList colarray;
+			for(uint j = 0; j < value.rows(); j++) {
+				QVariantList rowarray;
+				for( uint i = 0; i < value.columns(); i++) {
+					KSpread::Value v = value.element(i,j);
+					rowarray.append( valueToVariant(v, sheet) );
+				}
+				colarray.append(rowarray);
+			}
+			return colarray;
+		} break;
+		case KSpread::Value::CellRange:
+			//FIXME: not yet used
+			return QVariant();
+		case KSpread::Value::Error:
+			return QVariant();
+	}
+	return QVariant();
 }
 
-QVariant SheetAdaptor::value(int x, int y)
+QVariant SheetAdaptor::value( int x, int y )
 {
-    Cell cell = Cell(m_sheet, x, y);
-    return valueToVariant(cell.value(), m_sheet);
+    Cell cell = Cell( m_sheet, x, y);
+    return valueToVariant( cell.value(), m_sheet );
 }
 
-QVariant SheetAdaptor::value(const QString& cellname)
+QVariant SheetAdaptor::value( const QString& cellname )
 {
     const QPoint location = cellLocation(cellname);
     return value(location.x(), location.y());
 }
 
-bool SheetAdaptor::setValue(int x, int y, const QVariant& value)
+bool SheetAdaptor::setValue( int x, int y, const QVariant& value )
 {
-    Cell cell = Cell(m_sheet, x, y);
-    if (! cell) return false;
-    KSpread::Value v = cell.value();
-    switch (value.type()) {
-    case QVariant::Bool: v = Value(value.toBool()); break;
-    case QVariant::ULongLong: v = Value(value.toLongLong()); break;
-    case QVariant::Int: v = Value(value.toInt()); break;
-    case QVariant::Double: v = Value(value.toDouble()); break;
-    case QVariant::String: v = Value(value.toString()); break;
-        //case QVariant::Date: v = Value( value.toDate() ); break;
-        //case QVariant::Time: v = Value( value.toTime() ); break;
-        //case QVariant::DateTime: v = Value( value.toDateTime() ); break;
-    default: return false;
-    }
-    return true;
+	Cell cell = Cell( m_sheet, x, y);
+	if(! cell) return false;
+	KSpread::Value v = cell.value();
+	switch( value.type() ) {
+		case QVariant::Bool: v = Value( value.toBool() ); break;
+		case QVariant::ULongLong: v = Value( value.toLongLong() ); break;
+		case QVariant::Int: v = Value( value.toInt() ); break;
+		case QVariant::Double: v = Value( value.toDouble() ); break;
+		case QVariant::String: v = Value( value.toString() ); break;
+		//case QVariant::Date: v = Value( value.toDate() ); break;
+		//case QVariant::Time: v = Value( value.toTime() ); break;
+		//case QVariant::DateTime: v = Value( value.toDateTime() ); break;
+		default: return false;
+	}
+	return true;
 }
 
-bool SheetAdaptor::setValue(const QString& cellname, const QVariant& value)
+bool SheetAdaptor::setValue( const QString& cellname, const QVariant& value )
 {
     const QPoint location = cellLocation(cellname);
     return setValue(location.x(), location.y(), value);
 }
 
 #if 0
-QString SheetAdaptor::column(int _col)
+QString SheetAdaptor::column( int _col )
 {
     //First col number = 1
-    if (_col < 1)
+    if(_col <1)
         return QString();
     return "";//m_sheet->nonDefaultColumnFormat( _col )->getName/*objectName*/();/*dcopObject()->objId()*/
 
 }
 
-QString SheetAdaptor::row(int _row)
+QString SheetAdaptor::row( int _row )
 {
     //First row number = 1
-    if (_row < 1)
+    if(_row <1)
         return QString();
     return "";//m_sheet->nonDefaultRowFormat( _row )->/*dcopObject()->*/getName/*objectName*/();
 }
@@ -225,9 +224,9 @@ QString SheetAdaptor::sheetName() const
     return m_sheet->sheetName();
 }
 
-bool SheetAdaptor::setSheetName(const QString & name)
+bool SheetAdaptor::setSheetName( const QString & name)
 {
-    return m_sheet->setSheetName(name);
+    return m_sheet->setSheetName( name);
 }
 
 int SheetAdaptor::lastColumn() const
@@ -248,17 +247,17 @@ int SheetAdaptor::lastRow() const
 //     uint len = fun.length();
 //     if ( len < 3 )
 //         return false;
-//
+// 
 //     if ( fun[ len - 1 ] != ')' || fun[ len - 2 ] != '(' )
 //         return false;
-//
+// 
 //     // Is the function name a valid cell like "B5" ?
 //     Point p( fun.left( len - 2 ).data() );
 //     if ( !p.isValid() )
 //         return false;
-//
+// 
 //     DCOPCString str = objId() + '/' + fun.left( len - 2 );
-//
+// 
 //     replyType = "DCOPRef";
 //     QDataStream out( &replyData,QIODevice::WriteOnly );
 //     out.setVersion(QDataStream::Qt_3_1);
@@ -266,37 +265,37 @@ int SheetAdaptor::lastRow() const
 //     return true;
 // }
 
-void SheetAdaptor::insertColumn(int col, int nbCol)
+void SheetAdaptor::insertColumn( int col,int nbCol )
 {
     InsertDeleteColumnManipulator* manipulator = new InsertDeleteColumnManipulator();
-    manipulator->setSheet(m_sheet);
-    manipulator->add(Region(QRect(col, 1, nbCol, 1)));
+    manipulator->setSheet( m_sheet );
+    manipulator->add( Region(QRect(col, 1, nbCol, 1)) );
     manipulator->execute();
 }
 
-void SheetAdaptor::insertRow(int row, int nbRow)
+void SheetAdaptor::insertRow( int row,int nbRow)
 {
     InsertDeleteRowManipulator* manipulator = new InsertDeleteRowManipulator();
-    manipulator->setSheet(m_sheet);
-    manipulator->add(Region(QRect(1, row, 1, nbRow)));
+    manipulator->setSheet( m_sheet );
+    manipulator->add( Region(QRect(1, row, 1, nbRow)) );
     manipulator->execute();
 }
 
-void SheetAdaptor::removeColumn(int col, int nbCol)
+void SheetAdaptor::removeColumn( int col,int nbCol )
 {
     InsertDeleteColumnManipulator* manipulator = new InsertDeleteColumnManipulator();
-    manipulator->setSheet(m_sheet);
-    manipulator->setReverse(true);
-    manipulator->add(Region(QRect(col, 1, nbCol, 1)));
+    manipulator->setSheet( m_sheet );
+    manipulator->setReverse( true );
+    manipulator->add( Region(QRect(col, 1, nbCol, 1)) );
     manipulator->execute();
 }
 
-void SheetAdaptor::removeRow(int row, int nbRow)
+void SheetAdaptor::removeRow( int row,int nbRow )
 {
     InsertDeleteRowManipulator* manipulator = new InsertDeleteRowManipulator();
-    manipulator->setSheet(m_sheet);
-    manipulator->setReverse(true);
-    manipulator->add(Region(QRect(1, row, 1, nbRow)));
+    manipulator->setSheet( m_sheet );
+    manipulator->setReverse( true );
+    manipulator->add( Region(QRect(1, row, 1, nbRow)) );
     manipulator->execute();
 }
 
@@ -305,9 +304,9 @@ bool SheetAdaptor::isHidden() const
     return m_sheet->isHidden();
 }
 
-void SheetAdaptor::setHidden(bool hidden)
+void SheetAdaptor::setHidden( bool hidden )
 {
-    m_sheet->setHidden(hidden);
+    m_sheet->setHidden( hidden );
 }
 
 #if 0
@@ -346,57 +345,51 @@ bool SheetAdaptor::firstLetterUpper() const
     return m_sheet->getFirstLetterUpper();
 }
 
-void SheetAdaptor::setShowPageBorders(bool b)
+void SheetAdaptor::setShowPageBorders( bool b )
 {
-    m_sheet->setShowPageBorders(b);
+    m_sheet->setShowPageBorders( b );
     m_sheet->doc()->updateBorderButton();
 }
 #endif
 
 float SheetAdaptor::paperHeight()const
 {
-    return m_sheet->print()->settings()->pageLayout().height;
+    return m_sheet->print()->paperHeight();
 }
 
 void SheetAdaptor::setPrinterHeight(float height)
 {
-    KoPageLayout pageLayout = m_sheet->print()->settings()->pageLayout();
-    pageLayout.format = KoPageFormat::CustomSize;
-    pageLayout.height = MM_TO_POINT(height);
-    m_sheet->print()->settings()->setPageLayout(pageLayout);
+    m_sheet->print()->setPaperHeight(MM_TO_POINT(height));
 }
 
 float SheetAdaptor::paperWidth()const
 {
-    return m_sheet->print()->settings()->pageLayout().width;
+    return m_sheet->print()->paperWidth();
 }
 
 void SheetAdaptor::setPaperWidth(float width)
 {
-    KoPageLayout pageLayout = m_sheet->print()->settings()->pageLayout();
-    pageLayout.format = KoPageFormat::CustomSize;
-    pageLayout.width = MM_TO_POINT(width);
-    m_sheet->print()->settings()->setPageLayout(pageLayout);
+    m_sheet->print()->setPaperWidth(MM_TO_POINT(width));
 }
 
 float SheetAdaptor::paperLeftBorder()const
 {
-    return m_sheet->print()->settings()->pageLayout().leftMargin;
+    return m_sheet->print()->leftBorder();
 }
 
 float SheetAdaptor::paperRightBorder()const
 {
-    return m_sheet->print()->settings()->pageLayout().rightMargin;
+    return m_sheet->print()->rightBorder();
 }
 
 float SheetAdaptor::paperTopBorder()const
 {
-    return m_sheet->print()->settings()->pageLayout().topMargin;
+    return m_sheet->print()->topBorder();
 }
 
 float SheetAdaptor::paperBottomBorder()const
 {
-    return m_sheet->print()->settings()->pageLayout().bottomMargin;
+    return m_sheet->print()->bottomBorder();
 }
 
 QString SheetAdaptor::paperFormat() const
@@ -413,15 +406,9 @@ void SheetAdaptor::setPaperLayout(float leftBorder, float topBorder,
                                   float rightBorder, float bottomBoder,
                                   const QString& format, const QString& orientation)
 {
-    KoPageLayout pageLayout;
-    pageLayout.format = KoPageFormat::formatFromString(format);
-    pageLayout.orientation = (orientation  == "Portrait")
-                             ? KoPageFormat::Portrait : KoPageFormat::Landscape;
-    pageLayout.leftMargin   = leftBorder;
-    pageLayout.rightMargin  = rightBorder;
-    pageLayout.topMargin    = topBorder;
-    pageLayout.bottomMargin = bottomBoder;
-    m_sheet->print()->settings()->setPageLayout(pageLayout);
+    m_sheet->print()->setPaperLayout(MM_TO_POINT(leftBorder), MM_TO_POINT(topBorder),
+                                     MM_TO_POINT(rightBorder), MM_TO_POINT(bottomBoder),
+                                     format, orientation);
 }
 
 #if 0
@@ -457,39 +444,39 @@ QString SheetAdaptor::printFootRight()const
 
 void SheetAdaptor::setPrintHeaderLeft(const QString & text)
 {
-    m_sheet->print()->setHeadFootLine(text,       headMid(), headRight(),
-                                      footLeft(), footMid(), footRight());
+    m_sheet->print()->setHeadFootLine( text,       headMid(), headRight(),
+                                       footLeft(), footMid(), footRight() );
 }
 
 void SheetAdaptor::setPrintHeaderMiddle(const QString & text)
 {
-    m_sheet->print()->setHeadFootLine(headLeft(), text,      headRight(),
-                                      footLeft(), footMid(), footRight());
+    m_sheet->print()->setHeadFootLine( headLeft(), text,      headRight(),
+                                       footLeft(), footMid(), footRight() );
 
 }
 
 void SheetAdaptor::setPrintHeaderRight(const QString & text)
 {
-    m_sheet->print()->setHeadFootLine(headLeft(), headMid(), text,
-                                      footLeft(), footMid(), footRight());
+    m_sheet->print()->setHeadFootLine( headLeft(), headMid(), text,
+                                       footLeft(), footMid(), footRight() );
 }
 
 void SheetAdaptor::setPrintFooterLeft(const QString & text)
 {
-    m_sheet->print()->setHeadFootLine(headLeft(), headMid(), headRight(),
-                                      text,       footMid(), footRight());
+    m_sheet->print()->setHeadFootLine( headLeft(), headMid(), headRight(),
+                                       text,       footMid(), footRight() );
 }
 
 void SheetAdaptor::setPrintFooterMiddle(const QString & text)
 {
-    m_sheet->print()->setHeadFootLine(headLeft(), headMid(), headRight(),
-                                      footLeft(), text,      footRight());
+    m_sheet->print()->setHeadFootLine( headLeft(), headMid(), headRight(),
+                                       footLeft(), text,      footRight() );
 }
 
 void SheetAdaptor::setPrintFooterRight(const QString & text)
 {
-    m_sheet->print()->setHeadFootLine(headLeft(), headMid(), headRight(),
-                                      footLeft(), footMid(), text);
+    m_sheet->print()->setHeadFootLine( headLeft(), headMid(), headRight(),
+                                       footLeft(), footMid(), text );
 }
 #endif
 
