@@ -30,7 +30,11 @@ Dual-licensed under LGPL v2+higher and the BSD license.
 """
 
 import os, datetime, sys, traceback, urlparse
-import Kross
+
+try:
+    import Kross
+except:
+    raise "Failed to import the Kross module."
 
 class Config:
     """ Some configurations for the htmlexport.py script. """
@@ -379,7 +383,7 @@ class Dialog:
             w = self.infoswidget[i]
             w.setText( self.exporter.reader.infos[i] )
 
-        layoutpage = self.dialog.addPage("Styles","Style of the HTML Document","fill-color")
+        layoutpage = self.dialog.addPage("Styles","Style of the HTML Document","color-fill")
         layoutwidget = self.forms.createWidgetFromUI(layoutpage,
             '<ui version="4.0" >'
             ' <class>Form</class>'
