@@ -11,7 +11,7 @@
 #include "mpagecollection.h"
 #include "mreportengine.h"
 
-class KInstance;
+class KComponentData;
 class KugarBrowserExtension;
 
 class KugarPart: public KoDocument
@@ -19,26 +19,17 @@ class KugarPart: public KoDocument
     Q_OBJECT
 
 public:
-    KugarPart( QWidget *parentWidget = 0, const char *widgetName = 0, 
-               QObject* parent = 0,
-               const char* name = 0, bool singleViewMode = false );
+    KugarPart( QWidget *parentWidget = 0, QObject* parent = 0, bool singleViewMode = false );
     virtual ~KugarPart();
 
-    virtual bool initDoc( InitDocFlags flags, QWidget* parentWidget = 0 );
-
-    virtual bool loadOasis( const QDomDocument&, KoOasisStyles&, 
-                            const QDomDocument&, KoStore* );
+    virtual bool loadOasis( const KoXmlDocument&, KoOasisStyles&,
+                            const KoXmlDocument&, KoStore* );
     virtual bool saveOasis( KoStore*, KoXmlWriter* );
 
-    virtual bool loadXML( QIODevice *, const QDomDocument & );
+    virtual bool loadXML( QIODevice *, const KoXmlDocument & );
     //  virtual QDomDocument saveXML();
 
-    virtual void paintContent( QPainter&, const QRect&,
-                               bool /*transparent*/ = false,
-                               double /*zoomX*/ = 1.0, double /*zoomY*/ = 1.0 )
-    {
-        ;
-    }
+    virtual void paintContent( QPainter&, const QRect&) { }
 
     Kugar::MReportEngine *reportEngine()
     {
@@ -46,7 +37,7 @@ public:
     }
 
 protected:
-    virtual KoView* createViewInstance( QWidget* parent, const char* name );
+    virtual KoView* createViewInstance( QWidget* parent );
 
 public slots:
     void setForcedUserTemplate( const QString &/*name*/ )
@@ -61,7 +52,7 @@ private:
     QString m_reportData;
     Kugar::MReportEngine *m_reportEngine;
     bool m_templateOk;
-    KURL m_docURL;
+    KUrl m_docURL;
 };
 
 
