@@ -21,13 +21,13 @@
 
 #include "KoShapeBorderFactory.h"
 
-class KoLineBorderFactory : public KoShapeBorderFactory
-{
+class KoLineBorderFactory : public KoShapeBorderFactory {
 public:
     KoLineBorderFactory(QObject *parent);
 
     /// reimplemented
-    virtual KoShapeBorderModel *createBorder() const;
+    virtual KoShapeBorderModel * createBorder() const;
+
 };
 
 #endif
