@@ -1,8 +1,8 @@
 /* This file is part of the KDE project
-   Copyright (C) 2006-2008 Thorsten Zachmann <zachmann@kde.org>
-   Copyright (C) 2006, 2008 Casper Boemann <cbr@boemann.dk>
-   Copyright (C) 2006-2010 Thomas Zander <zander@kde.org>
-   Copyright (C) 2007-2009 Jan Hambrecht <jaham@gmx.net>
+   Copyright (C) 2006-2007 Thorsten Zachmann <zachmann@kde.org>
+   Copyright (C) 2006 Casper Boemann Rasmussen <cbr@boemann.dk>
+   Copyright (C) 2006 Thomas Zander <zander@kde.org>
+   Copyright (C) 2007 Jan Hambrecht <jaham@gmx.net>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -29,22 +29,19 @@
 #include <QMatrix>
 #include <QVector>
 #include <QSet>
-#include <QMap>
 #include <QBrush>
-#include <QMetaType>
+
+#include <flake_export.h>
 
 #include <KoXmlReaderForward.h>
-//#include <KoSnapData.h>
-
-#include "flake_export.h"
 
 class QPainter;
 class QRectF;
 class QPainterPath;
 
 class KoShapeContainer;
+class KoShapeConnection;
 class KoShapeBorderModel;
-class KoShapeBackground;
 class KoShapeManager;
 class KoShapeUserData;
 class KoViewConverter;
@@ -52,14 +49,6 @@ class KoShapeApplicationData;
 class KoShapeSavingContext;
 class KoCanvasBase;
 class KoShapeLoadingContext;
-class KoGenStyle;
-class KoShapeControllerBase;
-class KoDataCenterBase;
-class KoShapeShadow;
-class KoEventAction;
-class KoShapePrivate;
-class KoFilterEffectStack;
-class KoSnapData;
 
 /**
  *
@@ -89,20 +78,6 @@ class KoSnapData;
  *   <li>through an associated tool,
  *   <li>through a factory
  * </ul>
- *
- * <h1>Shape interaction notifications</h1>
- * We had several notification methods that allow your shape to be notified of changes in other
- * shapes positions or rotation etc.
- * <ol><li>The most general is KoShape::shapeChanged().<br>
- * a virtual method that you can use to check various changed to your shape made by tools or otherwise.</li>
- * <li>for shape hierarchies the parent may receive a notification when a child was modified.
- *  This is done though KoShapeContainerModel::childChanged()</li>
- * <li>any shape that is at a similar position as another shape there is collision detection.
- * You can register your shape to be sensitive to any changes like moving or whatever to
- * <b>other</b> shapes that intersect yours.
- * Such changes will then be notified to your shape using the method from (1) You should call
- * KoShape::setCollisionDetection(bool) to enable this.
- * </ol>
  */
 class FLAKE_EXPORT KoShape
 {
@@ -116,14 +91,7 @@ public:
         SizeChanged,    ///< used after a setSize()
         GenericMatrixChange,    ///< used after the matrix was changed without knowing which property explicitly changed
         ParentChanged,   ///< used after a setParent()
-        CollisionDetected, ///< used when another shape moved in our boundingrect
-        Deleted, ///< the shape was deleted
-        BorderChanged, ///< the shapes border has changed
-        BackgroundChanged, ///< the shapes background has changed
-        ShadowChanged, ///< the shapes shadow has changed
-        ParameterChanged, ///< the shapes parameter has changed (KoParameterShape only)
-        ContentChanged, ///< the content of the shape changed e.g. a new image inside a pixmap/text change inside a textshape
-        ChildChanged ///< a child of a container was changed/removed. This is propagated to all parents
+        CollisionDetected ///< used when another shape moved in our boundingrect
     };
 
     /**
@@ -160,7 +128,7 @@ public:
      * @param painter used for painting the shape
      * @param converter to convert between internal and view coordinates.
      * @param canvas the canvas that requested this paint.  This can be used to retrieve canvas specific properties
-     *      like selection and get a reference to the KoResourceManager.
+     *      like selection and get a reference to the KoCanvasResourceProvider.
      */
     virtual void paintDecorations(QPainter &painter, const KoViewConverter &converter, const KoCanvasBase *canvas);
 
@@ -172,32 +140,22 @@ public:
      *
      * @return false if loading failed
      */
-    virtual bool loadOdf(const KoXmlElement &element, KoShapeLoadingContext &context) = 0;
+    virtual bool loadOdf( const KoXmlElement & element, KoShapeLoadingContext &context ) = 0;
 
     /**
      * @brief store the shape data as ODF XML.
-     * This is the method that will be called when saving a shape as a described in
+     * This is the method that will be called when saving a shape as a described in¬
      * OpenDocument 9.2 Drawing Shapes.
      * @see saveOdfAttributes
      */
-    virtual void saveOdf(KoShapeSavingContext &context) const = 0;
+    virtual void saveOdf( KoShapeSavingContext & context ) const = 0;
 
     /**
-     * This method can be used while saving the shape as ODF to add the data
-     * stored on this shape to the current element.
-     *
-     * @param context the context for the current save.
-     * @param attributes a number of OdfAttribute items to state which attributes to save.
-     * @see saveOdf
+     * When saving this shape to ODF, you may nest it in a 'draw:frame' and shape properties should be
+     * saved as attributes on that element instead of on the normal shape.  After starting to write such
+     * an element you can call this method to write all relevant properties.
      */
-    void saveOdfAttributes(KoShapeSavingContext &context, int attributes) const;
-
-    /**
-     * This method can be used while saving the shape as Odf to add common child elements
-     *
-     * The office:event-listeners and draw:glue-point are saved.
-     */
-    void saveOdfCommonChildElements(KoShapeSavingContext &context) const;
+    void saveOdfFrameAttributes( KoShapeSavingContext & context ) const;
 
     /**
      * @brief Scale the shape using the zero-point which is the top-left corner.
@@ -206,7 +164,17 @@ public:
      * @param sx scale in x direction
      * @param sy scale in y direction
      */
-    void setScale(qreal sx, qreal sy);
+    void setScale( double sx, double sy );
+
+    /**
+     * Return the current scaling adjustment over the X axis.
+     */
+    KDE_DEPRECATED double scaleX() const;
+
+    /**
+     * Return the current scaling adjustment over the Y axis.
+     */
+    KDE_DEPRECATED double scaleY() const;
 
     /**
      * @brief Rotate the shape (relative)
@@ -215,13 +183,13 @@ public:
      *
      * @param angle change the angle of rotation increasing it with 'angle' degrees
      */
-    void rotate(qreal angle);
+    void rotate( double angle );
 
     /**
      * Return the current rotation in degrees.
      * It returns NaN if the shape has a shearing or scaling transformation applied.
      */
-    qreal rotation() const;
+    double rotation() const;
 
     /**
      * @brief Shear the shape
@@ -231,7 +199,19 @@ public:
      * @param sx shear in x direction
      * @param sy shear in y direction
      */
-    void setShear(qreal sx, qreal sy);
+    void setShear( double sx, double sy );
+
+    /**
+     * Return the current horizontal shearing angle for this shape.
+     * @return the current horizontal shearing angle for this shape.
+     */
+    KDE_DEPRECATED double shearX() const;
+
+    /**
+     * Return the current vertical shearing angle for this shape.
+     * @return the current vertical shearing angle for this shape.
+     */
+    KDE_DEPRECATED double shearY() const;
 
     /**
      * @brief Resize the shape
@@ -242,14 +222,14 @@ public:
      * Easiest example of this difference is that using this method will not distort the
      * size of pattern-fills and borders.
      */
-    virtual void setSize(const QSizeF &size);
+    virtual void setSize( const QSizeF &size );
 
     /**
      * @brief Get the size of the shape in pt.
      *
      * The size is in shape coordinates.
      *
-     * @return the size of the shape as set by setSize()
+     * @return the size of the shape as set by resize()
      */
     virtual QSizeF size() const;
 
@@ -258,21 +238,21 @@ public:
      *
      * @param position the new position of the shape
      */
-    virtual void setPosition(const QPointF &position);
+    virtual void setPosition( const QPointF &position );
 
     /**
      * @brief Get the position of the shape in pt
      *
      * @return the position of the shape
      */
-    QPointF position() const;
+    virtual QPointF position() const;
 
     /**
      * @brief Check if the shape is hit on position
      * @param position the position where the user clicked.
      * @return true when it hits.
      */
-    virtual bool hitTest(const QPointF &position) const;
+    virtual bool hitTest( const QPointF &position ) const;
 
     /**
      * @brief Get the bounding box of the shape
@@ -293,39 +273,24 @@ public:
      *   The point does not have to be inside the boundings rectangle.  The point is in pt,
      *   just like the rest of the KoShape class uses.
      */
-    void addConnectionPoint(const QPointF &point);
+    void addConnectionPoint( const QPointF &point );
 
     /**
-     * Return a list of the connection points that have been added to this shape.
-     * All the points are relative to the shape position, see absolutePosition().
+     * Return a list of the connectors that have been added to this shape.
+     * Note that altering the list or the points in there will not have any
+     * effect on the shape.
      * @return a list of the connectors that have been added to this shape.
      */
-    QList<QPointF> connectionPoints() const;
-
-    /**
-     * Add a event action
-     */
-    void addEventAction(KoEventAction *action);
-
-    /**
-     * Remove a event action
-     */
-    void removeEventAction(KoEventAction *action);
-
-    /**
-     * Get all event actions
-     */
-    QSet<KoEventAction *> eventActions() const;
+    QList<QPointF> connectors() const;
 
     /**
      * Set the background of the shape.
-     * A shape background can be a plain color, a gradient, a pattern, be fully transparent
-     * or have a complex fill.
-     * Setting such a background will allow the shape to be filled and will be able to tell
-     * if it is transparent or not.
-     * @param background the new shape background.
+     * A QBrush can have a plain color, be fully transparent or have a complex fill.
+     * setting such a brush will allow the shape to fill itself using that brush and
+     * will be able to tell if its transparent or not.
+     * @param brush the brush for the background.
      */
-    void setBackground(KoShapeBackground *background);
+    void setBackground ( const QBrush & brush );
 
     /**
      * return the brush used to paint te background of this shape with.
@@ -334,7 +299,7 @@ public:
      * will be able to tell if its transparent or not.
      * @return the background-brush
      */
-    KoShapeBackground *background() const;
+    QBrush background() const;
 
     /**
      * Returns true if there is some transparency, false if the shape is fully opaque.
@@ -344,18 +309,6 @@ public:
      */
     virtual bool hasTransparency();
 
-    /**
-     * Sets shape level transparency.
-     * @param transparency the new shape level transparency
-     */
-    void setTransparency(qreal transparency);
-
-    /**
-     * Returns the shape level transparency.
-     * @param recursive when true takes the parents transparency into account
-     */
-    qreal transparency(bool recursive=false) const;
-
     /**
      * Retrieve the z-coordinate of this shape.
      * The zIndex property is used to determine which shape lies on top of other objects.
@@ -380,89 +333,43 @@ public:
 
     /**
      * Changes the Shape to be visible or invisible.
-     * Being visible means being painted, as well as being used for
+     * Being visible means being painted and printed, as well as being used for
      *   things like guidelines or searches.
      * @param on when true; set the shape to be visible.
-     * @see setGeometryProtected(), setContentProtected(), setSelectable()
      */
     void setVisible(bool on);
     /**
      * Returns current visibility state of this shape.
-     * Being visible means being painted, as well as being used for
+     * Being visible means being painted and printed, as well as being used for
      *   things like guidelines or searches.
-     * @param recursive when true, checks visibility recursively
      * @return current visibility state of this shape.
-     * @see isGeometryProtected(), isContentProtected(), isSelectable()
      */
-    bool isVisible(bool recursive = false) const;
-
-    /**
-     * Changes the shape to be printable or not. The default is true.
-     *
-     * If a Shape's print flag is true, the shape will be printed. If
-     * false, the shape will not be printed. If a shape is not visible (@see isVisible),
-     * it isPrinted will return false, too.
-     */
-    void setPrintable(bool on);
-
-    /**
-     * Returns the current printable state of this shape.
-     *
-     * A shape can be visible but not printable, not printable and not visible
-     * or visible and printable, but not invisible and still printable.
-     *
-     * @return current printable state of this shape.
-     */
-    bool isPrintable() const;
+    bool isVisible() const;
 
     /**
      * Makes it possible for the user to select this shape.
      * This parameter defaults to true.
-     * @param selectable when true; set the shape to be selectable by the user.
-     * @see setGeometryProtected(), setContentProtected(), setVisible()
+     * @param selectable when true; set the shape to be selectable.
      */
     void setSelectable(bool selectable);
-
     /**
-     * Returns if this shape can be selected by the user.
+     * Returns wheather this shape can be selected by the user.
      * @return true only when the object is selectable.
-     * @see isGeometryProtected(), isContentProtected(), isVisible()
      */
     bool isSelectable() const;
 
     /**
-     * Tells the shape to have its position/rotation and size protected from user-changes.
-     * The geometry being protected means the user can not change shape or position of the
-     * shape. This includes any matrix operation such as rotation.
-     * @param on when true; set the shape to have its geometry protected.
-     * @see setContentProtected(), setSelectable(), setVisible()
+     * Changes the Shape to be locked in place.
+     * Being locked means the shape can no longer change shape or position.
+     * @param locked when true; set the shape to be locked.
      */
-    void setGeometryProtected(bool on);
-
+    void setLocked(bool locked);
     /**
-     * Returns current geometry protection state of this shape.
-     * The geometry being protected means the user can not change shape or position of the
-     * shape. This includes any matrix operation such as rotation.
-     * @return current geometry protection state of this shape.
-     * @see isContentProtected(), isSelectable(), isVisible()
+     * Returns current locked state of this shape.
+     * Being locked means the shape can no longer change shape or position.
+     * @return current locked state of this shape.
      */
-    bool isGeometryProtected() const;
-
-    /**
-     * Marks the shape to have its content protected against editing.
-     * Content protection is a hint for tools to disallow the user editing the content.
-     * @param protect when true set the shapes content to be protected from user modification.
-     * @see setGeometryProtected(), setSelectable(), setVisible()
-     */
-    void setContentProtected(bool protect);
-
-    /**
-     * Returns current content protection state of this shape.
-     * Content protection is a hint for tools to disallow the user editing the content.
-     * @return current content protection state of this shape.
-     * @see isGeometryProtected(), isSelectable(), isVisible()
-     */
-    bool isContentProtected() const;
+    bool isLocked() const;
 
     /**
      * Returns the parent, or 0 if there is no parent.
@@ -483,7 +390,7 @@ public:
      * <p>This method will return immediately and only request a repaint. Successive calls
      * will be merged into an appropriate repaint action.
      */
-    virtual void update() const;
+    virtual void repaint() const;
 
     /**
      * Request a repaint to be queued.
@@ -494,7 +401,7 @@ public:
      * will be merged into an appropriate repaint action.
      * @param shape the rectangle (in pt) to queue for repaint.
      */
-    virtual void update(const QRectF &shape) const;
+    void repaint(const QRectF &shape) const;
 
     /**
      * This is a method used to sort a list using the STL sorting methods.
@@ -510,7 +417,7 @@ public:
      * on, for example.
      * @returns the outline of the shape in the form of a path.
      */
-    virtual QPainterPath outline() const;
+    virtual const QPainterPath outline() const;
 
     /**
      * Returns the currently set border, or 0 if there is no border.
@@ -530,12 +437,6 @@ public:
      */
     KoInsets borderInsets() const;
 
-    /// Sets the new shadow, removing the old one
-    void setShadow(KoShapeShadow *shadow);
-
-    /// Returns the currently set shadow or 0 if there is now shadow set
-    KoShapeShadow *shadow() const;
-
     /**
      * Setting the shape to keep its aspect-ratio has the effect that user-scaling will
      * keep the width/hight ratio intact so as not to distort shapes that rely on that
@@ -558,7 +459,7 @@ public:
      * @param anchor The place on the (unaltered) shape that you want the position of.
      * @return the point that is the absolute, centered position of this shape.
      */
-    QPointF absolutePosition(KoFlake::Position anchor = KoFlake::CenteredPosition) const;
+    QPointF absolutePosition(KoFlake::Position anchor = KoFlake::CenteredPositon) const;
 
     /**
      * Move this shape to an absolute position where the end location will be the same
@@ -574,7 +475,7 @@ public:
      * @param newPosition the new absolute center of the shape.
      * @param anchor The place on the (unaltered) shape that you set the position of.
      */
-    void setAbsolutePosition(QPointF newPosition, KoFlake::Position anchor = KoFlake::CenteredPosition);
+    void setAbsolutePosition(QPointF newPosition, KoFlake::Position anchor = KoFlake::CenteredPositon);
 
     /**
      * Set a data object on the shape to be used by an application.
@@ -595,7 +496,6 @@ public:
      * @param applicationData the new application data, or 0 to delete the current one.
      */
     void setApplicationData(KoShapeApplicationData *applicationData);
-
     /**
      * Return the current applicationData.
      */
@@ -603,15 +503,14 @@ public:
 
     /**
      * Return the Id of this shape, identifying the type of shape by the id of the factory.
-     * @see KoShapeFactoryBase::shapeId()
+     * @see KoShapeFactory::shapeId()
      * @return the id of the shape-type
      */
-    QString shapeId() const;
-
+    const QString & shapeId() const;
     /**
      * Set the Id of this shape.  A shapeFactory is expected to set the Id at creation
      * so applications can find out what kind of shape this is.
-     * @see KoShapeFactoryBase::shapeId()
+     * @see KoShapeFactory::shapeId()
      * @param id the ID from the factory that created this shape
      */
     void setShapeId(const QString &id);
@@ -636,13 +535,13 @@ public:
      *
      * @param matrix the transformation matrix to apply
      */
-    void applyAbsoluteTransformation(const QMatrix &matrix);
+    void applyAbsoluteTransformation(const QMatrix &matrix );
 
     /**
      * Sets a new transformation matrix describing the local transformations on this shape.
      * @param matrix the new transformation matrix
      */
-    void setTransformation(const QMatrix &matrix);
+    void setTransformation( const QMatrix &matrix );
 
     /// Returns the shapes local transformation matrix
     QMatrix transformation() const;
@@ -654,7 +553,7 @@ public:
      *
      * @param matrix the transformation matrix to apply
      */
-    void applyTransformation(const QMatrix &matrix);
+    void applyTransformation( const QMatrix &matrix );
 
     /**
      * Copy all the settings from the parameter shape and apply them to this shape.
@@ -662,7 +561,7 @@ public:
      * is a notable exclusion.
      * @param shape the shape to use as original
      */
-    void copySettings(const KoShape *shape);
+    virtual void copySettings(const KoShape *shape);
 
     /**
      * Convenience method that allows people implementing paint() to use the shape
@@ -674,32 +573,9 @@ public:
     static void applyConversion(QPainter &painter, const KoViewConverter &converter);
 
     /**
-     * @brief Transforms point from shape coordinates to document coordinates
-     * @param point in shape coordinates
-     * @return point in document coordinates
+     * Return all the connections made to or from this shape.
      */
-    QPointF shapeToDocument(const QPointF &point) const;
-
-    /**
-     * @brief Transforms rect from shape coordinates to document coordinates
-     * @param rect in shape coordinates
-     * @return rect in document coordinates
-     */
-    QRectF shapeToDocument(const QRectF &rect) const;
-
-    /**
-     * @brief Transforms point from document coordinates to shape coordinates
-     * @param point in document coordinates
-     * @return point in shape coordinates
-     */
-    QPointF documentToShape(const QPointF &point) const;
-
-    /**
-     * @brief Transform rect from document coordinates to shape coordinates
-     * @param rect in document coordinates
-     * @return rect in shape coordinates
-     */
-    QRectF documentToShape(const QRectF &rect) const;
+    QList<KoShapeConnection*> connections() const;
 
     /**
      * Returns the name of the shape.
@@ -711,7 +587,7 @@ public:
      * Sets the name of the shape.
      * @param name the new shape name
      */
-    void setName(const QString &name);
+    void setName( const QString & name );
 
     /**
      * Update the position of the shape in the tree of the KoShapeManager.
@@ -719,177 +595,37 @@ public:
     void notifyChanged();
 
     /**
-     * A shape can be in a state that it is doing processing data like loading or text layout.
-     * In this case it can be shown on screen probably partially but it should really not be printed
-     * until it is fully done processing.
-     * Warning! This method can be blocking for a long time
-     * @param asynchronous If set to true the processing will can take place in a different thread and the 
-     *                     function will not block until the shape is finised. 
-     *                     In case of printing Flake will call this method from a non-main thread and only 
-     *                     start printing it when the in case of printing method returned.
-     *                     If set to false the processing needs to be done synchronously and will 
-     *                     block until the result is finished.
+     * A shape can be in a state that its doing loading or text layout or similar in which case
+     * it can be shown on screen just fine (probably partially) but it should really not be printed
+     * until its fully done.
+     * Flake will call this method from a non-main thread and only start printing it when the
+     * method returned.
+     * Warning!  This method can be blocking for a long time, never call it on the gui-thread!
      */
-    virtual void waitUntilReady(const KoViewConverter &converter, bool asynchronous = true) const;
+    virtual void waitUntilReady() const {}
 
     /**
      * Schedule the shape for thread-safe deletion.
      * After calling this method will self-delete in the main threads event loop.
-     * If your code deletes a shape and your code can possibly be running in a separate thread,
-     * you should use this method to delete the shape.
-     * The reason for this is that If you delete a shape from another thread then it is
-     * possible the main
+     * If deleting a shape can possibly be done in a separate thread, you should delete it
+     * using this method.  If you delete a shape from another thread then its possible the main
      * thread will use it after its been removed, while painting for example.
-     *
-     * Note that in contrary to the equivalent method on QObject, you can not call this more than once.
+     * Note that in contrary to the equivalent method on QObject, you can not call this more than ones!
      */
     void deleteLater();
 
-    /// checks recursively if the shape or one of its parents is not visible or locked
-    bool isEditable() const;
-
-    /// Removes connection point with given index
-    void removeConnectionPoint(int index);
-
-    /**
-     * Adds a shape which depends on this shape.
-     * Making a shape dependent on this one means it will get shapeChanged() called
-     * on each update of this shape.
-     *
-     * If this shape already depends on the given shape, establishing the
-     * dependency is refused to prevent circular dependencies.
-     *
-     * @param shape the shape which depends on this shape
-     * @return true if dependency could be established, otherwise false
-     * @see removeDependee(), hasDependee()
-     */
-    bool addDependee(KoShape *shape);
-
-    /**
-     * Removes as shape depending on this shape.
-     * @see addDependee(), hasDependee()
-     */
-    void removeDependee(KoShape *shape);
-
-    /// Returns if the given shape is dependent on this shape
-    bool hasDependee(KoShape *shape) const;
-
-    /// Returns additional snap data the shape wants to have snapping to
-    virtual KoSnapData snapData() const;
-
-    /**
-     * Set additional attribute
-     *
-     * This can be used to attach additional attributes to a shape for attributes
-     * that are application specific like presentation:placeholder
-     *
-     * @param name The name of the attribute in the following form prefix:tag e.g. presentation:placeholder
-     * @param value The value of the attribute
-     */
-    void setAdditionalAttribute(const char *name, const QString &value);
-
-    /**
-     * Remove additional attribute
-     *
-     * @param name The name of the attribute in the following form prefix:tag e.g. presentation:placeholder
-     */
-    void removeAdditionalAttribute(const char *name);
-
-    /**
-     * Check if additional attribute is set
-     *
-     * @param name The name of the attribute in the following form prefix:tag e.g. presentation:placeholder
-     *
-     * @return true if there is a attribute with prefix:tag set, false otherwise
-     */
-    bool hasAdditionalAttribute(const char *name) const;
-
-    /**
-     * Get additional attribute
-     *
-     * @param name The name of the attribute in the following form prefix:tag e.g. presentation:placeholder
-     *
-     * @return The value of the attribute if it exists or a null string if not found.
-     */
-    QString additionalAttribute(const char *name) const;
-
-    void setAdditionalStyleAttribute(const char *name, const QString &value);
-
-    void removeAdditionalStyleAttribute(const char *name);
-
-    /**
-     * Returns the filter effect stack of the shape
-     *
-     * @return the list of filter effects applied on the shape when rendering.
-     */
-    KoFilterEffectStack *filterEffectStack() const;
-
-    /// Sets the new filter effect stack, removing the old one
-    void setFilterEffectStack(KoFilterEffectStack *filterEffectStack);
-
-    /**
-     * Set the property collision detection.
-     * Setting this to true will result in calls to shapeChanged() with the CollisionDetected
-     * parameter whenever either this or another shape is moved/rotated etc and intersects this shape.
-     * @param detect if true detect collisions.
-     */
-    void setCollisionDetection(bool detect);
-
-    /**
-     * get the property collision detection.
-     * @returns true if collision detection is on.
-     */
-    bool collisionDetection();
-
-    /**
-     * Return the tool delegates for this shape.
-     * In Flake a shape being selected will cause the tool manager to make available all tools that
-     * can edit the selected shapes.  In some cases selecting one shape should allow the tool to
-     * edit a related shape be available too.  The tool delegates allows this to happen by taking
-     * all the shapes in the set into account on tool selection.
-     * Notice that if the set is non-empty 'this' shape is no longer looked at. You can choose
-     * to add itself to the set too.
-     */
-    QSet<KoShape*> toolDelegates() const;
-
-    /**
-     * Set the tool delegates.
-     * @param delegates the new delegates.
-     * @see toolDelegates()
-     */
-    void setToolDelegates(const QSet<KoShape*> &delegates);
-
-    /**
-     * \internal
-     * Returns the private object for use withing the flake lib
-     */
-    KoShapePrivate *priv();
-
 protected:
-    /// constructor
-    KoShape(KoShapePrivate &);
 
-    /* ** loading saving helper methods */
+/* ** loading saving helper methods */
     /// attributes from ODF 1.1 chapter 9.2.15 Common Drawing Shape Attributes
     enum OdfAttribute {
-        OdfTransformation = 1,       ///< Store transformation information
-        OdfSize = 2,                 ///< Store size information
-        OdfPosition = 8,             ///< Store position
-        OdfAdditionalAttributes = 4, ///< Store additional attributes of the shape
-        OdfCommonChildElements = 16, ///< Event actions and connection points
-        OdfLayer = 64,               ///< Store layer name
-        OdfStyle = 128,              ///< Store the style
-        OdfId = 256,                 ///< Store the unique ID
-        OdfName = 512,               ///< Store the name of the shape
-        OdfZIndex = 1024,            ///< This only loads the z-index; when saving, it is reflected by the order of the shapes.
-        OdfViewbox = 2048,           ///< Store the viewbox
+        OdfTransformation = 1,  ///< Store transformation information
+        OdfSize = 2,            ///< Store size information
+        OdfPosition = 4,        ///< Store position of shape
+        OdfMandatories = 8,     ///< Id, z-index, layer and style
 
-        /// A mask for all mandatory attributes
-        OdfMandatories = OdfLayer | OdfStyle | OdfId | OdfName | OdfZIndex,
-        /// A mask for geometry attributes
-        OdfGeometry = OdfPosition | OdfSize,
-        /// A mask for all the attributes
-        OdfAllAttributes = OdfTransformation | OdfGeometry | OdfAdditionalAttributes | OdfMandatories | OdfCommonChildElements
+        /// A mask for all the attributes a 'draw:frame' requires
+        FrameAttributes = OdfMandatories | OdfSize | OdfPosition | OdfTransformation
     };
 
     /**
@@ -899,60 +635,93 @@ protected:
      * @param element element which represents the shape in odf
      * @param attributes a number of OdfAttribute items to state which attributes to load.
      */
-    bool loadOdfAttributes(const KoXmlElement &element, KoShapeLoadingContext &context, int attributes);
+    bool loadOdfAttributes( const KoXmlElement & element, KoShapeLoadingContext &context, int attributes );
 
     /**
      * Parses the transformation attribute from the given string
      * @param transform the transform attribute string
      * @return the resulting transformation matrix
      */
-    QMatrix parseOdfTransform(const QString &transform);
+    QMatrix parseOdfTransform( const QString &transform );
 
     /**
-     * @brief Saves the style used for the shape
+     * This method can be used while saving the shape as ODF to add the data
+     * stored on this shape to the current element.
      *
-     * This method fills the given style object with the border and
-     * background properties and then adds the style to the context.
+     * @param context the context for the current save.
+     * @param attributes a number of OdfAttribute items to state which attributes to save.
+     * @see saveOdf
+     */
+    void saveOdfAttributes( KoShapeSavingContext &context, int attributes ) const;
+
+    /**
+     * Add a new draw-glue-point element for each connections() present on this shape.
+     */
+    void saveOdfConnections( KoShapeSavingContext &context ) const;
+
+    /**
+     * @brief Get the style used for the shape
+     *
+     * This method calls fillStyle and add then the style to the context
      *
-     * @param style the style object to fill
      * @param context used for saving
      * @return the name of the style
      * @see saveOdf
      */
-    virtual QString saveStyle(KoGenStyle &style, KoShapeSavingContext &context) const;
+    QString style( KoShapeSavingContext &context ) const;
 
-    /**
-     * Loads the stroke and fill style from the given element.
-     *
-     * @param element the xml element to  load the style from
-     * @param context the loading context used for loading
-     */
-    virtual void loadStyle(const KoXmlElement &element, KoShapeLoadingContext &context);
+    /// Loads the fill style
+    QBrush loadOdfFill( const KoXmlElement & element, KoShapeLoadingContext & context );
 
     /// Loads the stroke style
-    KoShapeBorderModel *loadOdfStroke(const KoXmlElement &element, KoShapeLoadingContext &context) const;
+    KoShapeBorderModel * loadOdfStroke( const KoXmlElement & element, KoShapeLoadingContext & context );
 
-    /// Loads the shadow style
-    KoShapeBackground *loadOdfFill(KoShapeLoadingContext &context) const;
+/* ** end loading saving */
 
-    /* ** end loading saving */
 
     /**
      * A hook that allows inheriting classes to do something after a KoShape property changed
      * This is called whenever the shape, position rotation or scale properties were altered.
      * @param type an indicator which type was changed.
      */
-    virtual void shapeChanged(ChangeType type, KoShape *shape = 0);
+    virtual void shapeChanged(ChangeType type) { Q_UNUSED(type); }
+
+    /**
+     * Set the property collision detection.
+     * Setting this to true will result in calls to shapeChanged() with the CollisionDetected
+     * parameter whenever either this or another shape is moved/rotated etc and intersects this shape.
+     * @param detect if true detect collisions.
+     */
+    void setCollisionDetection(bool detect);
+    /**
+     * get the property collision detection.
+     * @returns true if collision detection is on.
+     */
+    bool collisionDetection();
 
     /// return the current matrix that contains the rotation/scale/position of this shape
-    QMatrix matrix() const;
+    const QMatrix& matrix() const;
 
-    KoShapePrivate *d_ptr;
+    friend class KoShapeConnection;
+    /**
+     * Add a connection to the list of connections of this shape.
+     * This is typically called only from the constructor of the KoShapeConnection class.
+     */
+    void addConnection(KoShapeConnection *connection);
+    /**
+     * Remove a connection to the list of connections of this shape.
+     * This is typically called only from the destructor of the KoShapeConnection class.
+     */
+    void removeConnection(KoShapeConnection *connection);
 
 private:
-    Q_DECLARE_PRIVATE(KoShape)
+    friend class KoShapeManager;
+    void addShapeManager( KoShapeManager * manager );
+    void removeShapeManager( KoShapeManager * manager );
+
+    class Private;
+    friend class Private;
+    Private * const d;
 };
 
-Q_DECLARE_METATYPE(KoShape*)
-
 #endif
