@@ -20,27 +20,29 @@
 
 #include "KoShapeBorderFactory.h"
 
-class KoShapeBorderFactory::Private
-{
+class KoShapeBorderFactory::Private {
 public:
-    Private(const QString &i) : id(i) { }
+    Private( const QString &i, const QString &n ) : id(i), name(n) { }
     const QString id;
+    const QString name;
 };
 
-KoShapeBorderFactory::KoShapeBorderFactory(QObject *parent, const QString &id)
-        : QObject(parent),
-        d(new Private(id))
+KoShapeBorderFactory::KoShapeBorderFactory(QObject *parent, const QString &id, const QString &name)
+    : QObject(parent),
+    d(new Private(id, name))
 {
 }
 
-KoShapeBorderFactory::~KoShapeBorderFactory()
-{
+KoShapeBorderFactory::~KoShapeBorderFactory() {
     delete d;
 }
 
-QString KoShapeBorderFactory::id() const
-{
+QString KoShapeBorderFactory::name() const {
+    return d->name;
+}
+
+QString KoShapeBorderFactory::id() const {
     return d->id;
 }
 
-#include <KoShapeBorderFactory.moc>
+#include "KoShapeBorderFactory.moc"
