@@ -21,7 +21,6 @@
 #define KOPACANVAS_H
 
 #include <QWidget>
-#include <QList>
 #include <KoCanvasBase.h>
 
 #include "kopageapp_export.h"
@@ -37,11 +36,8 @@ public:
     explicit KoPACanvas( KoPAView * view, KoPADocument * doc );
     ~KoPACanvas();
 
-    /// Returns pointer to the KoPADocument
-    KoPADocument* document() const;
-
     /// reimplemented method
-    virtual void gridSize( qreal *horizontal, qreal *vertical ) const;
+    virtual void gridSize( double *horizontal, double *vertical ) const;
     /// reimplemented method
     virtual bool snapToGrid() const;
     /// reimplemented method
@@ -53,29 +49,13 @@ public:
     virtual void updateCanvas( const QRectF& rc );
     /// reimplemented method
     virtual void updateInputMethodInfo();
-    /// reimplemented from KoCanvasBase
-    virtual KoGuidesData * guidesData();
 
-    KoToolProxy * toolProxy() const;
+    KoToolProxy * toolProxy() const { return m_toolProxy; }
     const KoViewConverter *viewConverter() const;
-    QWidget* canvasWidget();
-    const QWidget* canvasWidget() const;
+    QWidget* canvasWidget() { return this; }
     KoUnit unit() const;
     const QPoint & documentOffset() const;
 
-    /// reimplemented in view coordinates
-    virtual QPoint documentOrigin() const;
-    /// Set the origin of the page inside the canvas in document coordinates
-    void setDocumentOrigin(const QPointF & origin);
-
-    KoPAView* koPAView () const;
-
-    /// translate widget coordinates to view coordinates
-    QPoint widgetToView(const QPoint& p) const;
-    QRect widgetToView(const QRect& r) const;
-    QPoint viewToWidget(const QPoint& p) const;
-    QRect viewToWidget(const QRect& r) const;
-
 public slots:
     /// Recalculates the size of the canvas (needed when zooming or changing pagelayout)
     void updateSize();
@@ -90,9 +70,6 @@ signals:
      */
     void sizeChanged( const QSize & size );
 
-    /// Emitted when updateCanvas has been called.
-    void canvasUpdated();
-
 protected:
     /// reimplemented method from superclass
     void paintEvent( QPaintEvent* event );
@@ -113,25 +90,20 @@ protected:
     /// reimplemented method from superclass
     void wheelEvent ( QWheelEvent * event );
     /// reimplemented method from superclass
-    void closeEvent( QCloseEvent * event );
+    bool event(QEvent *event);
     /// reimplemented method from superclass
     virtual QVariant inputMethodQuery(Qt::InputMethodQuery query) const;
     /// reimplemented method from superclass
     virtual void inputMethodEvent(QInputMethodEvent *event);
 
-    /// reimplemented method from superclass
-    virtual void resizeEvent( QResizeEvent * event );
+    void resizeEvent( QResizeEvent * event );
 
-    /**
-     * Shows the default context menu
-     * @param globalPos global position to show the menu at.
-     * @param actionList action list to be inserted into the menu
-     */
-    void showContextMenu( const QPoint& globalPos, const QList<QAction*>& actionList );
-
-private:
-    class Private;
-    Private * const d;
+    KoPAView * m_view;
+    KoPADocument * m_doc;
+    KoShapeManager * m_shapeManager;
+    KoShapeManager * m_masterShapeManager;
+    KoToolProxy * m_toolProxy;
+    QPoint m_documentOffset;
 };
 
 #endif /* KOPACANVAS_H */
