@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
- * Copyright (C) 2006-2007, 2009 Thomas Zander <zander@kde.org>
+ * Copyright (C) 2006-2007 Thomas Zander <zander@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -20,14 +20,12 @@
 #ifndef KOTEXTDOCUMENTLAYOUT_H
 #define KOTEXTDOCUMENTLAYOUT_H
 
-#include "kotext_export.h"
+#include <kotext_export.h>
 
 #include <QAbstractTextDocumentLayout>
 #include <QRectF>
 #include <QSizeF>
 #include <QList>
-#include <QTextFrame>
-#include <QTextTableCell>
 
 class KoTextDocumentLayout;
 class KoShape;
@@ -35,65 +33,62 @@ class KoStyleManager;
 class QTextLayout;
 class KoInlineTextObjectManager;
 class KoViewConverter;
-class KoImageCollection;
 
 /**
  * KWords text layouter that allows text to flow in multiple frames and around
  * other KWord objects.
  */
-class KOTEXT_EXPORT KoTextDocumentLayout : public QAbstractTextDocumentLayout
-{
+class KOTEXT_EXPORT KoTextDocumentLayout : public QAbstractTextDocumentLayout {
     Q_OBJECT
 public:
     class LayoutState;
 
     /// This struct is a helper for painting of kotext texts.
     struct PaintContext {
-        PaintContext() : viewConverter(0), imageCollection(0) { }
+        PaintContext() : viewConverter(0) { }
         /// the QText context
         QAbstractTextDocumentLayout::PaintContext textContext;
         /// A view converter, when set, is used to find out when the zoom is so low that painting of text is unneeded
         const KoViewConverter *viewConverter;
-
-        KoImageCollection *imageCollection;
     };
 
     /// constructor
     explicit KoTextDocumentLayout(QTextDocument *document, KoTextDocumentLayout::LayoutState *layout = 0);
     virtual ~KoTextDocumentLayout();
 
+    /**
+     * While the text document is standalone, the text can refer to the character
+     * and paragraph styles, and doing so is needed in doing proper text-layout.
+     * Setting the stylemanager on this layouter is therefor required if there is one.
+     */
+    void setStyleManager(KoStyleManager *sm);
+
     /// set the layoutState for this document layout
     void setLayout(LayoutState *layout);
-
     /// return if this document layout has a proper layoutState object.
     bool hasLayouter() const;
 
     /**
      * Register the manager for inline objects which is needed to notify variables of layout changes.
      */
-    void setInlineTextObjectManager(KoInlineTextObjectManager *manager);
-
+    void setInlineObjectTextManager(KoInlineTextObjectManager *iom);
     /// return the currently set manager, or 0 if none is set.
-    KoInlineTextObjectManager *inlineTextObjectManager();
+    KoInlineTextObjectManager *inlineObjectTextManager();
 
     /// Returns the bounding rectangle of block.
-    virtual QRectF blockBoundingRect(const QTextBlock & block) const;
+    virtual QRectF blockBoundingRect ( const QTextBlock & block ) const;
     /**
      * Returns the total size of the document. This is useful to display
      * widgets since they can use to information to update their scroll bars
      * correctly
      */
-    virtual QSizeF documentSize() const;
-
+    virtual QSizeF documentSize () const;
     /// Draws the layout on the given painter with the given context.
-    virtual void draw(QPainter * painter, const QAbstractTextDocumentLayout::PaintContext & context);
-
+    virtual void draw ( QPainter * painter, const QAbstractTextDocumentLayout::PaintContext & context );
     /// Draws the layout on the given painter with the given context, and pass the zoom.
-    void draw(QPainter * painter, const KoTextDocumentLayout::PaintContext & context);
-
+    void draw ( QPainter * painter, const KoTextDocumentLayout::PaintContext & context);
     /// Returns the bounding rectacle of frame. Returns the bounding rectangle of frame.
-    virtual QRectF frameBoundingRect(QTextFrame * frame) const;
-
+    virtual QRectF frameBoundingRect ( QTextFrame * frame ) const;
     /**
      * Returns the cursor postion for the given point with the accuracy
      * specified. Returns -1 to indicate failure if no valid cursor position
@@ -101,10 +96,9 @@ public:
      * @param point the point in the document
      * @param accuracy if Qt::ExactHit this method will return -1 when not actaully hitting any text
      */
-    virtual int hitTest(const QPointF & point, Qt::HitTestAccuracy accuracy) const;
-
+    virtual int hitTest ( const QPointF & point, Qt::HitTestAccuracy accuracy ) const;
     /// reimplemented to always return 1
-    virtual int pageCount() const;
+    virtual int pageCount () const;
 
     /**
      * Actually do the layout of the text.
@@ -122,12 +116,14 @@ public:
     /// return the list of shapes that will be used to run all the text into.
     virtual QList<KoShape*> shapes() const;
 
+    /// return the current styleManager.  Can be 0 if none set.
+    KoStyleManager *styleManager() const;
+
     /**
      * This inner class is an interface that allows the KoTextDocumentLayout to do rough layout
      * while the LayoutState implementation can do all the boring details.
      */
-    class KOTEXT_EXPORT LayoutState
-    {
+    class KOTEXT_EXPORT LayoutState {
     public:
         LayoutState() : shapeNumber(-1), shape(0), layout(0) {}
         virtual ~LayoutState() {}
@@ -139,20 +135,16 @@ public:
         virtual void reset() = 0;
         /// returns true if reset has been called.
         virtual bool interrupted() = 0;
-        /// return the number of columns of the line to be layouted
-        virtual int numColumns() {
-            return 0;
-        } // if numColumns() returns 0, use width() instead
         /// return the width of the line to be layouted
-        virtual qreal width() = 0;
+        virtual double width() = 0;
         /// return the x position of the line to be layouted
-        virtual qreal x() = 0;
+        virtual double x() = 0;
         /// return the y position (top of text) of the line to be layouted
-        virtual qreal y() = 0;
+        virtual double y() = 0;
         /// return the cursor position (in the document) of the last character that has been positioned in the lay-out
         virtual int cursorPosition() const = 0;
         /// return the y offset of the document at start of shape.
-        virtual qreal docOffsetInShape() const = 0;
+        virtual double docOffsetInShape() const = 0;
         /// when a line is added, update internal vars.  Return true if line does not fit in shape
         virtual bool addLine(QTextLine &line) = 0;
         /// prepare for next paragraph; return false if there is no next parag.
@@ -160,7 +152,7 @@ public:
         /// revert layout to the previous paragraph. Return false if there is no previous paragraph.
         virtual bool previousParag() = 0;
         /// Return the y position of the offset for the current shape (See KoTextShapeData::documentOffset() )
-        virtual qreal documentOffsetInShape() = 0;
+        virtual double documentOffsetInShape() = 0;
         /**
          * Paint the document.
          * Paint the whole document, at least within the cliprect as set on the painter.
@@ -179,15 +171,20 @@ public:
         virtual void clearTillEnd() = 0;
         /// called by the KoTextDocumentLayout to notify the LayoutState of a successfully resized inline object
         virtual void registerInlineObject(const QTextInlineObject &inlineObject) = 0;
-        /// called by the KoTextDocumentLayout to find out which if any table cell is hit. Returns 0 when no hit
-        virtual QTextTableCell hitTestTable(QTextTable *table, const QPointF &point) = 0;
 
         /// the index in the list of shapes (or frameset) of the shape we are currently layouting.
         int shapeNumber;
-        /// the shape that is currently being laid out
+        /// the currently layoute shape
         KoShape *shape;
         /// The current paragraph layout.
         QTextLayout *layout;
+
+    protected:
+        friend class KoTextDocumentLayout;
+        /// see KoTextDocumentLayout::setStyleManager()
+        virtual void setStyleManager(KoStyleManager *sm) = 0;
+        /// see KoTextDocumentLayout::styleManager()
+        virtual KoStyleManager *styleManager() const = 0;
     };
 
     /**
@@ -201,8 +198,7 @@ public:
     /// reimplemented from QAbstractTextDocumentLayout
     virtual void documentChanged(int position, int charsRemoved, int charsAdded);
 
-signals:
-    void shapeAdded(KoShape *shape);
+    static void updateTabsForLine(const QTextBlock &block, int lineNumber);
 
 public slots:
     /// make sure we start a layout run (returns immediately)
@@ -222,14 +218,6 @@ protected:
     /// reimplemented
     virtual void resizeInlineObject(QTextInlineObject item, int position, const QTextFormat &format);
 
-    /// make sure we start a layout run (returns immediately)
-    /// This method keeps the state data and does not interrupt a runnign layout.
-    void scheduleLayoutWithoutInterrupt();
-
-    /// same as hitTest but for a range specified by an iterator
-    int hitTestIterated(QTextFrame::iterator begin, QTextFrame::iterator end, const QPointF & point, Qt::HitTestAccuracy accuracy) const;
-
-
 private:
     Q_PRIVATE_SLOT(d, void relayoutPrivate())
 
