@@ -1,12 +1,9 @@
 /* This file is part of the KDE project
- * Copyright (C) 2006-2009 Thomas Zander <zander@kde.org>
- * Copyright (C) 2008 Thorsten Zachmann <zachmann@kde.org>
- * Copyright (C) 2008 Girish Ramakrishnan <girish@forwardbias.in>
+ * Copyright (C) 2006, 2007 Thomas Zander <zander@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * License as published by the Free Software Foundation; version 2.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -36,10 +33,6 @@ class KoListStyle;
 class QTextBlock;
 class KoStyleStack;
 class KoGenStyle;
-class KoGenStyles;
-#include "KoXmlReaderForward.h"
-class KoOdfLoadingContext;
-#include "KoBorder.h"
 
 /**
  * A container for all properties for the paragraph wide style.
@@ -49,12 +42,11 @@ class KoOdfLoadingContext;
  * a specific KoParagraphStyle.
  * @see KoStyleManager
  */
-class KOTEXT_EXPORT KoParagraphStyle : public QObject
-{
+class KOTEXT_EXPORT KoParagraphStyle : public QObject {
     Q_OBJECT
 public:
     enum Property {
-        StyleId = QTextFormat::UserProperty + 1,
+        StyleId = QTextFormat::UserProperty+1,
         // Linespacing properties
         PercentLineHeight,  ///< this propery is used for a percentage of the highest character on that line
         FixedLineHeight,    ///< this propery is used to use a non-default line height
@@ -68,8 +60,9 @@ public:
         DropCapsLength, ///< Number of glyphs to show as drop-caps
         DropCapsLines,  ///< Number of lines that the drop-caps span
         DropCapsDistance,   ///< Distance between drop caps and text
-        DropCapsTextStyle,  ///< Text style of dropped chars. Not supported yet.
         FollowDocBaseline,  ///< If true the baselines will be aligned with the doc-wide grid
+        BreakBefore,    ///< If true, insert a frame break before this paragraph
+        BreakAfter,     ///< If true, insert a frame break after this paragraph
 
         // border stuff
         HasLeftBorder,  ///< If true, paint a border on the left
@@ -105,41 +98,43 @@ public:
         BottomBorderColor,      ///< The border Color
 
         // lists
-        ListStyleId,            ///< Style Id of associated list style
-        ListStartValue,         ///< Int with the list-value that that parag will have. Ignored if this is not a list.
+        ExplicitListValue,      ///< Int with the list-value that that parag will have. Ignored if this is not a list.
         RestartListNumbering,   ///< boolean to indicate that this paragraph will have numbering restart at the list-start. Ignored if this is not a list.
-        ListLevel,               ///< int with the list-level that the paragraph will get when this is a list (numbered paragraphs)
+        ListLevel,               ///< int with the list-level that the paragraph will get when this is a list
         IsListHeader,           ///< bool, if true the paragraph shows up as a list item, but w/o a list label.
-        UnnumberedListItem,     ///< bool. if true this paragraph is part of a list but is not numbered
 
-        AutoTextIndent,         ///< bool, says whether the paragraph is auto-indented or not
-
-        TabStopDistance,        ///< Double, Length. specifies that there's a tab stop every n inches
-        ///< (after the last of the TabPositions, if any)
-        TabPositions,           ///< A list of tab positions
-        TextProgressionDirection,
-
-        MasterPageName,         ///< Optional name of the master-page
-
-        OutlineLevel,            ///< Outline level for headings
-        DefaultOutlineLevel
+        TabPositions,            ///< A list of tab positions
+        TextProgressionDirection
 // do 15.5.24
 // continue at 15.5.28
     };
 
+    /// The type of paragraph border
+    enum BorderStyle {
+        BorderNone,   ///< no border. This value forces the computed value of 'border-width' to be '0'.
+        BorderDotted,   ///< The border is a series of dots.
+        BorderDashed,   ///< The border is a series of short line segments.
+        BorderSolid,    ///< The border is a single line segment.
+        BorderDouble,   ///< The border is two solid lines. The sum of the two lines and the space between them equals the value of 'border-width'.
+        BorderGroove,   ///< The border looks as though it were carved into the canvas.
+        BorderRidge,    ///< The opposite of 'groove': the border looks as though it were coming out of the canvas.
+        BorderInset,    ///< The border makes the entire box look as though it were embedded in the canvas.
+        BorderOutset,   ///< The opposite of 'inset': the border makes the entire box look as though it were coming out of the canvas.
+
+        // kword legacy
+        BorderDashDotPattern,
+        BorderDashDotDotPattern
+    };
+
     /// Constructor
-    KoParagraphStyle(QObject *parent = 0);
-    /// Creates a KoParagraphStyle with the given block format, the block character format and \a parent
-    KoParagraphStyle(const QTextBlockFormat &blockFormat, const QTextCharFormat &blockCharFormat, QObject *parent = 0);
+    KoParagraphStyle();
+    /// Copy constructor
+    KoParagraphStyle(const KoParagraphStyle &orig);
+    /// Copy constructor
+    KoParagraphStyle(const QTextFormat &textFormat);
     /// Destructor
     ~KoParagraphStyle();
 
-    /// Creates a KoParagraphStyle that represents the formatting of \a block.
-    static KoParagraphStyle *fromBlock(const QTextBlock &block, QObject *parent = 0);
-
-    /// creates a clone of this style with the specified parent
-    KoParagraphStyle *clone(QObject *parent = 0);
-
     //  ***** Linespacing
     /**
      * Sets the line height as a percentage of the highest character on that line.
@@ -157,18 +152,18 @@ public:
      * Sets the line height to a specific pt-based height, ignoring the font size.
      * Setting this will ignore the lineHeightPercent() and lineSpacing() values.
      */
-    void setLineHeightAbsolute(qreal height);
+    void setLineHeightAbsolute(double height);
     /// @see setLineHeightAbsolute
-    qreal lineHeightAbsolute() const;
+    double lineHeightAbsolute() const;
 
     /**
      * Sets the line height to have a minimum height in pt.
      * You should consider doing a remove(KoParagraphStyle::FixedLineHeight); because if set, it will
      *  be used instead of this value.
      */
-    void setMinimumLineHeight(qreal height);
+    void setMinimumLineHeight(double height);
     /// @see setMinimumLineHeight
-    qreal minimumLineHeight() const;
+    double minimumLineHeight() const;
 
     /**
      * Sets the space between two lines to be a specific height. The total linespacing will become
@@ -176,9 +171,9 @@ public:
      * You should consider doing a remove(KoParagraphStyle::FixedLineHeight) and a
      * remove(KoParagraphStyle::PercentLineHeight); because if set, they will be used instead of this value.
      */
-    void setLineSpacing(qreal spacing);
+    void setLineSpacing(double spacing);
     /// @see setLineSpacing
-    qreal lineSpacing() const;
+    double lineSpacing() const;
 
     /**
      * If set to true the font-encoded height will be used instead of the font-size propery
@@ -199,7 +194,7 @@ public:
      * There are only 3 valid options, Left, Center and Justified. (where Left will
      * be right aligned for RTL text).
      */
-    void setAlignLastLine(Qt::Alignment alignment);
+    void setAlignLastLine(Qt::Alignment alignment );
     /**
      * @see setAlignLastLine
      */
@@ -271,12 +266,12 @@ public:
      * @see setDropCaps
      * @see setDropCapsLines
      */
-    void setDropCapsDistance(qreal distance);
+    void setDropCapsDistance(double distance);
     /**
      * Set dropCaps distance
      * @see setDropCapsDistance
      */
-    qreal dropCapsDistance() const;
+    double dropCapsDistance() const;
     /**
      * If true the baselines will be aligned with the doc-wide grid
      */
@@ -288,65 +283,65 @@ public:
     bool followDocBaseline() const;
 
     /// See similar named method on QTextBlockFormat
-    void setBackground(const QBrush &brush);
+    void setBackground (const QBrush &brush);
     /// See similar named method on QTextBlockFormat
-    QBrush background() const;
+    QBrush background () const;
     /// See similar named method on QTextBlockFormat
-    void clearBackground();
-
+    void clearBackground ();
+    
     void setBreakBefore(bool on);
     bool breakBefore();
     void setBreakAfter(bool on);
     bool breakAfter();
-    void setLeftPadding(qreal padding);
-    qreal leftPadding();
-    void setTopPadding(qreal padding);
-    qreal topPadding();
-    void setRightPadding(qreal padding);
-    qreal rightPadding();
-    void setBottomPadding(qreal padding);
-    qreal bottomPadding();
-    void setPadding(qreal padding);
+    void setLeftPadding(double padding);
+    double leftPadding();
+    void setTopPadding(double padding);
+    double topPadding();
+    void setRightPadding(double padding);
+    double rightPadding();
+    void setBottomPadding(double padding);
+    double bottomPadding();
+    void setPadding(double padding);
 
-    void setLeftBorderWidth(qreal width);
-    qreal leftBorderWidth();
-    void setLeftInnerBorderWidth(qreal width);
-    qreal leftInnerBorderWidth();
-    void setLeftBorderSpacing(qreal width);
-    qreal leftBorderSpacing();
-    void setLeftBorderStyle(KoBorder::BorderStyle style);
-    KoBorder::BorderStyle leftBorderStyle();
-    void setLeftBorderColor(const QColor &color);
+    void setLeftBorderWidth(double width);
+    double leftBorderWidth();
+    void setLeftInnerBorderWidth(double width);
+    double leftInnerBorderWidth();
+    void setLeftBorderSpacing(double width);
+    double leftBorderSpacing();
+    void setLeftBorderStyle(BorderStyle style);
+    BorderStyle leftBorderStyle();
+    void setLeftBorderColor(const QColor& color);
     QColor leftBorderColor();
-    void setTopBorderWidth(qreal width);
-    qreal topBorderWidth();
-    void setTopInnerBorderWidth(qreal width);
-    qreal topInnerBorderWidth();
-    void setTopBorderSpacing(qreal width);
-    qreal topBorderSpacing();
-    void setTopBorderStyle(KoBorder::BorderStyle style);
-    KoBorder::BorderStyle topBorderStyle();
-    void setTopBorderColor(const QColor &color);
+    void setTopBorderWidth(double width);
+    double topBorderWidth();
+    void setTopInnerBorderWidth(double width);
+    double topInnerBorderWidth();
+    void setTopBorderSpacing(double width);
+    double topBorderSpacing();
+    void setTopBorderStyle(BorderStyle style);
+    BorderStyle topBorderStyle();
+    void setTopBorderColor(const QColor& color);
     QColor topBorderColor();
-    void setRightBorderWidth(qreal width);
-    qreal rightBorderWidth();
-    void setRightInnerBorderWidth(qreal width);
-    qreal rightInnerBorderWidth();
-    void setRightBorderSpacing(qreal width);
-    qreal rightBorderSpacing();
-    void setRightBorderStyle(KoBorder::BorderStyle style);
-    KoBorder::BorderStyle rightBorderStyle();
-    void setRightBorderColor(const QColor &color);
+    void setRightBorderWidth(double width);
+    double rightBorderWidth();
+    void setRightInnerBorderWidth(double width);
+    double rightInnerBorderWidth();
+    void setRightBorderSpacing(double width);
+    double rightBorderSpacing();
+    void setRightBorderStyle(BorderStyle style);
+    BorderStyle rightBorderStyle();
+    void setRightBorderColor(const QColor& color);
     QColor rightBorderColor();
-    void setBottomBorderWidth(qreal width);
-    qreal bottomBorderWidth();
-    void setBottomInnerBorderWidth(qreal width);
-    qreal bottomInnerBorderWidth();
-    void setBottomBorderSpacing(qreal width);
-    qreal bottomBorderSpacing();
-    void setBottomBorderStyle(KoBorder::BorderStyle style);
-    KoBorder::BorderStyle bottomBorderStyle();
-    void setBottomBorderColor(const QColor &color);
+    void setBottomBorderWidth(double width);
+    double bottomBorderWidth();
+    void setBottomInnerBorderWidth(double width);
+    double bottomInnerBorderWidth();
+    void setBottomBorderSpacing(double width);
+    double bottomBorderSpacing();
+    void setBottomBorderStyle(BorderStyle style);
+    BorderStyle bottomBorderStyle();
+    void setBottomBorderColor(const QColor& color);
     QColor bottomBorderColor();
 
     KoText::Direction textProgressionDirection() const;
@@ -354,45 +349,41 @@ public:
 
     // ************ properties from QTextBlockFormat
     /// duplicated property from QTextBlockFormat
-    void setTopMargin(qreal topMargin);
+    void setTopMargin(double topMargin);
     /// duplicated property from QTextBlockFormat
-    qreal topMargin() const;
+    double topMargin() const;
     /// duplicated property from QTextBlockFormat
-    void setBottomMargin(qreal margin);
+    void setBottomMargin (double margin);
     /// duplicated property from QTextBlockFormat
-    qreal bottomMargin() const;
+    double bottomMargin () const;
     /// duplicated property from QTextBlockFormat
-    void setLeftMargin(qreal margin);
+    void setLeftMargin (double margin);
     /// duplicated property from QTextBlockFormat
-    qreal leftMargin() const;
+    double leftMargin () const;
     /// duplicated property from QTextBlockFormat
-    void setRightMargin(qreal margin);
+    void setRightMargin (double margin);
     /// duplicated property from QTextBlockFormat
-    qreal rightMargin() const;
+    double rightMargin () const;
     /// set the margin around the paragraph, making the margin on all sides equal.
-    void setMargin(qreal margin);
+    void setMargin (double margin);
 
     void setIsListHeader(bool on);
     bool isListHeader() const;
 
     /// duplicated property from QTextBlockFormat
-    void setAlignment(Qt::Alignment alignment);
+    void setAlignment (Qt::Alignment alignment);
     /// duplicated property from QTextBlockFormat
-    Qt::Alignment alignment() const;
+    Qt::Alignment alignment () const;
     /// duplicated property from QTextBlockFormat
-    void setTextIndent(qreal margin);
+    void setTextIndent (double margin);
     /// duplicated property from QTextBlockFormat
-    qreal textIndent() const;
-    /// Custom KoParagraphStyle property for auto-text-indent
-    void setAutoTextIndent(bool on);
-    bool autoTextIndent() const;
-
+    double textIndent () const;
 #if 0
-    as this is a duplicate of leftMargin, lets make it very clear we are using that one.
+as this is a duplicate of leftMargin, lets make it very clear we are using that one.
     /// duplicated property from QTextBlockFormat
-    void setIndent(int indent);
+    void setIndent (int indent);
     /// duplicated property from QTextBlockFormat
-    int indent() const;
+    int indent () const;
 #endif
     /// duplicated property from QTextBlockFormat
     void setNonBreakableLines(bool on);
@@ -400,10 +391,10 @@ public:
     bool nonBreakableLines() const;
 
     /// set the parent style this one inherits its unset properties from.
-    void setParentStyle(KoParagraphStyle *parent);
+    void setParent(KoParagraphStyle *parent);
 
     /// return the parent style
-    KoParagraphStyle *parentStyle() const;
+    KoParagraphStyle *parent() const;
 
     /// the 'next' style is the one used when the user creates a new paragrap after this one.
     void setNextStyle(int next);
@@ -412,7 +403,7 @@ public:
     int nextStyle() const;
 
     /// return the name of the style.
-    QString name() const;
+    const QString& name() const;
 
     /// set a user-visible name on the style.
     void setName(const QString &name);
@@ -423,26 +414,11 @@ public:
     /// each style has a unique ID (non persistent) given out by the styleManager
     void setStyleId(int id);
 
-    /// return the optional name of the master-page or a QString() if this paragraph isn't attached to a master-page.
-    QString masterPageName() const;
-    /// Set the name of the master-page.
-    void setMasterPageName(const QString &name);
-
-
-    /// Set the list start value
-    void setListStartValue(int value);
-    /// Returns the list start value
-    int listStartValue() const;
-
     /// Set to true if this paragraph is marked to start the list numbering from the first entry.
     void setRestartListNumbering(bool on);
     /// return if this paragraph is marked to start the list numbering from the first entry.
     bool restartListNumbering();
 
-    /// Set the tab stop distance for this paragraph style.
-    void setTabStopDistance(qreal value);
-    /// return the tab stop distance for this paragraph style
-    qreal tabStopDistance() const;
     /// Set the tab data for this paragraph style.
     void setTabPositions(const QList<KoText::Tab> &tabs);
     /// return the tabs data for this paragraph style
@@ -453,34 +429,9 @@ public:
     /// return the list level.
     int listLevel() const;
 
-    /**
-     * Return the outline level of this block, or 0 if it's not a heading.
-     * This information is here and not in the styles because the OpenDocument specification says so.
-     * See ODF Spec 1.1, §14.1, Outline Numbering Level, but also other parts of the specification.
-     */
-    int outlineLevel() const;
-
-    /**
-     * Change this block outline level
-     */
-    void setOutlineLevel(int outline);
-    
-    /**
-     * Return the default outline level of this style, or 0 if there is none.
-     */
-    int defaultOutlineLevel() const;
-
-    /**
-     * Change the default outline level for this style.
-     */
-    void setDefaultOutlineLevel(int outline);
-
-
     /// copy all the properties from the other style to this style, effectively duplicating it.
     void copyProperties(const KoParagraphStyle *style);
 
-    void unapplyStyle(QTextBlock &block) const;
-
     /**
      * Apply this style to a blockFormat by copying all properties from this, and parent
      * styles to the target block format.  Note that the character format will not be applied
@@ -492,7 +443,7 @@ public:
      * Apply this style to the textBlock by copying all properties from this, parent and
      * the character style (where relevant) to the target block formats.
      */
-    void applyStyle(QTextBlock &block, bool applyListStyle = true) const;
+    void applyStyle(QTextBlock &block) const;
 
     /// return the character style for this paragraph style
     KoCharacterStyle *characterStyle();
@@ -507,77 +458,45 @@ public:
      * @see setListStyle()
      * @see removeListStyle()
      */
-    KoListStyle *listStyle() const;
+    KoListStyle listStyle() const;
     /**
      * Set a new liststyle on this paragraph style, making all paragraphs that use this style
      *  automatically be part of the list.
      * @see setListStyle()
      * @see removeListStyle()
      */
-    void setListStyle(KoListStyle *style);
-
-    void remove(int key);
-
-    /// Compare the paragraph, character and list properties of this style with the other
-    bool operator==(const KoParagraphStyle &other) const;
-    /// Compare the paragraph properties of this style with other
-    bool compareParagraphProperties(const KoParagraphStyle &other) const;
-    /// Compare the character properties of this style with other
-    bool compareCharacterProperties(const KoParagraphStyle &other) const;
-
-    void removeDuplicates(const KoParagraphStyle &other);
-
+    void setListStyle(const KoListStyle &style);
     /**
-     * Load the style form the element
-     *
-     * @param context the odf loading context
-     * @param element the element containing the
+     * Remove any set list style on this paragraphs style.
+     * Stops all paragraphs that follow this style from being a list item.
      */
-    void loadOdf(const KoXmlElement *element, KoOdfLoadingContext &context);
+    void removeListStyle();
 
-    void saveOdf(KoGenStyle &style, KoGenStyles &mainStyles);
-
-    /**
-     * Returns true if this paragraph style has the property set.
-     * Note that this method does not delegate to the parent style.
-     * @param key the key as found in the Property enum
-     */
-    bool hasProperty(int key) const;
-
-    /**
-     * Set a property with key to a certain value, overriding the value from the parent style.
-     * If the value set is equal to the value of the parent style, the key will be removed instead.
-     * @param key the Property to set.
-     * @param value the new value to set on this style.
-     * @see hasProperty(), value()
-     */
-    void setProperty(int key, const QVariant &value);
-    /**
-     * Return the value of key as represented on this style, taking into account parent styles.
-     * You should consider using the direct accessors for individual properties instead.
-     * @param key the Property to request.
-     * @returns a QVariant which holds the property value.
-     */
-    QVariant value(int key) const;
-
-signals:
-    void nameChanged(const QString &newName);
-
-private:
     /**
      * Load the style from the \a KoStyleStack style stack using the
      * OpenDocument format.
      */
-    void loadOdfProperties(KoStyleStack &styleStack);
-    qreal propertyDouble(int key) const;
+    void loadOasis(KoStyleStack& styleStack);
+
+    static KoParagraphStyle *fromBlock(const QTextBlock &block);
+
+    void remove(int key);
+    
+    bool operator==( const KoParagraphStyle &other ) const;
+    
+    void removeDuplicates ( const KoParagraphStyle &other );
+    
+    void saveOdf ( KoGenStyle *target );
+private:
+    void setProperty(int key, const QVariant &value);
+    double propertyDouble(int key) const;
     int propertyInt(int key) const;
     bool propertyBoolean(int key) const;
     QColor propertyColor(int key) const;
+    QVariant value(int key) const;
 
     class Private;
     Private * const d;
-
-    bool normalLineHeight;
 };
 
 #endif
