@@ -1,7 +1,6 @@
 /* This file is part of the KDE project
    Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
    Copyright (C) 2000-2005 David Faure <faure@kde.org>
-   Copyright (C) 2007 Thorsten Zachmann <zachmann@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -22,35 +21,33 @@
 #ifndef KODOCUMENT_H
 #define KODOCUMENT_H
 
-#include <QtCore/QDateTime>
-#include <QtGui/QMatrix>
-#include <QList>
+#include <QDateTime>
+#include <QMatrix>
+#include <Q3PtrList>
 
 #include <kparts/part.h>
 #include <kservice.h>
 #include <kcomponentdata.h>
 
-#include <KoUnit.h>
-#include <KoPageLayout.h>
+#include "KoUnit.h"
+#include "KoPageLayout.h"
 #include "komain_export.h"
 #include "KoGridData.h"
 #include "KoGuidesData.h"
 #include <KoXmlReader.h>
-#include <KoOdfDocument.h>
 
+class QXmlSimpleReader;
 class QUndoCommand;
 
 class KoStore;
-class KoOdfReadStore;
-class KoOdfWriteStore;
 class KoMainWindow;
+class KoChild;
+class KoDocumentChild;
 class KoView;
 class KoDocumentInfo;
-class KoDocumentRdf;
-class KoDocumentRdfBase;
+class KoOasisStyles;
 class KoOpenPane;
-class KUndoStack;
-class KoTextEditor;
+
 
 class KoVersionInfo
 {
@@ -70,17 +67,17 @@ public:
  *
  *  @short The %KOffice document class
  */
-class KOMAIN_EXPORT KoDocument : public KParts::ReadWritePart, public KoOdfDocument
+class KOMAIN_EXPORT KoDocument : public KParts::ReadWritePart
 {
     Q_OBJECT
 //     Q_PROPERTY( QByteArray dcopObjectId READ dcopObjectId)
-    Q_PROPERTY(bool backupFile READ backupFile WRITE setBackupFile)
+    Q_PROPERTY( bool backupFile READ backupFile WRITE setBackupFile )
 
 public:
 
     /**
      *  Constructor.
-     * The first 3 arguments are the same as the ones passed to KParts::Factory::createPart.
+     * The first 4 arguments are the same as the ones passed to KParts::Factory::createPart.
      *
      * @param parentWidget the parent widget, in case we create a wrapper widget
      *        (in single view mode).
@@ -92,9 +89,9 @@ public:
      *        (KoViewWrapperWidget) which is a child of @p parentWidget.
      *        This widget can be retrieved by calling widget().
      */
-    KoDocument(QWidget* parentWidget,
-               QObject* parent,
-               bool singleViewMode = false);
+    KoDocument( QWidget* parentWidget,
+                QObject* parent,
+                bool singleViewMode = false );
 
     /**
      *  Destructor.
@@ -111,7 +108,7 @@ public:
     bool isSingleViewMode() const;
 
     /**
-     * @return true if the document is embedded in another odf document
+     * Is the document embedded?
      */
     bool isEmbedded() const;
 
@@ -130,7 +127,7 @@ public:
      * @see KXMLGUIClient::actionCollection
      * @see KoView::action
      */
-    virtual QAction *action(const QDomElement &element) const;
+    virtual QAction *action( const QDomElement &element ) const;
 
     /**
      * Returns the DOM document which describes the GUI of the
@@ -141,13 +138,13 @@ public:
     /**
      * @internal
      */
-    virtual void setManager(KParts::PartManager *manager);
+    virtual void setManager( KParts::PartManager *manager );
 
     /**
      * Reimplemented from KParts::ReadWritePart for internal reasons
      * (for the autosave functionality)
      */
-    virtual bool openUrl(const KUrl & url);
+    virtual bool openUrl( const KUrl & url );
 
     /**
      * Opens the document given by @p url, without storing the URL
@@ -159,7 +156,7 @@ public:
      *       Open operation (in any reimplementation of openUrl() or openFile())
      *       call isImporting().
      */
-    bool importDocument(const KUrl &url);
+    bool import( const KUrl &url );
 
     /**
      * Saves the document as @p url without changing the state of the
@@ -171,7 +168,7 @@ public:
      *       from an ordinary Save operation (in any reimplementation of
      *       saveFile()) call isExporting().
      */
-    bool exportDocument(const KUrl &url);
+    bool exp0rt( const KUrl &url );
 
     /**
      * @brief Sets whether the document can be edited or is read only.
@@ -180,7 +177,7 @@ public:
      * KoView::updateReadWrite is called for every attached
      * view.
      */
-    virtual void setReadWrite(bool readwrite = true);
+    virtual void setReadWrite( bool readwrite = true );
 
     /**
      * @brief Used by KoApplication, and by KoMainWindow, when no document exists yet.
@@ -192,7 +189,7 @@ public:
      * @see KService
      * @see KDesktopFile
      */
-    static QByteArray readNativeFormatMimeType(const KComponentData &instance = KComponentData());
+    static QByteArray readNativeFormatMimeType( const KComponentData &instance = KComponentData() );
 
     /**
      * Used by KoMainWindow, when no document exists yet.
@@ -204,14 +201,19 @@ public:
      * @see KService
      * @see KDesktopFile
      */
-    static QStringList readExtraNativeMimeTypes(const KComponentData &instance = KComponentData());
+    static QStringList readExtraNativeMimeTypes( const KComponentData &instance = KComponentData() );
 
     /**
      * With the help of @p instance or KApplication::componentData() this
      * method figures out which .desktop file matches this application,
      * and returns the KService instance for it.
      */
-    static KService::Ptr readNativeService(const KComponentData &instance = KComponentData());
+    static KService::Ptr readNativeService( const KComponentData &instance = KComponentData() );
+
+    /**
+     * setup the XML reader, so that we don't have to duplicate the code.
+     */
+    static void setupXmlReader( QXmlSimpleReader& reader, bool namespaceProcessing = false );
 
     /**
      * To be preferred when a document exists. It is fast when calling
@@ -224,32 +226,24 @@ public:
 
     /**
      * Returns the OASIS OpenDocument mimetype of the document, if supported
-     * This comes from the X-KDE-NativeOasisMimeType key in the
-     * desktop file
-     *
-     * @return the oasis mimetype or, if it hasn't one, the nativeformatmimetype.
+     * This comes from the X-KDE-NativeOasisMimeType key in the .desktop file
      */
     QByteArray nativeOasisMimeType() const;
 
-    enum ImportExportType {
-        ForExport,
-        ForImport
-    };
-
     /// Checks whether a given mimetype can be handled natively.
-    bool isNativeFormat(const QByteArray& mimetype, ImportExportType importExportType) const;
+    bool isNativeFormat( const QByteArray& mimetype ) const;
 
     /// Returns a list of the mimetypes considered "native", i.e. which can
     /// be saved by KoDocument without a filter, in *addition* to the main one
-    virtual QStringList extraNativeMimeTypes(ImportExportType importExportType) const;
+    virtual QStringList extraNativeMimeTypes() const;
 
     /// Enum values used by specialOutputFlag - note that it's a bitfield for supportedSpecialFormats
     enum { /*SaveAsKOffice1dot1 = 1,*/ // old and removed
-        SaveAsDirectoryStore = 2,
-        SaveAsFlatXML = 4,
-        SaveEncrypted = 8
-                        // bitfield! next value is 16
-    };
+           SaveAsDirectoryStore = 2,
+           SaveAsFlatXML = 4,
+           SaveEncrypted = 8
+           // bitfield! next value is 16
+         };
 
     /**
      * Return the set of SupportedSpecialFormats that the application wants to
@@ -268,7 +262,7 @@ public:
      * When choosing "save as" this is also the mime type
      * selected by default.
      */
-    void setMimeType(const QByteArray & mimeType);
+    void setMimeType( const QByteArray & mimeType );
 
     /**
      * @brief Set the format in which the document should be saved.
@@ -279,7 +273,7 @@ public:
      * @param mimeType the mime type (format) to use.
      * @param specialOutputFlag is for "save as older version" etc.
      */
-    void setOutputMimeType(const QByteArray & mimeType, int specialOutputFlag = 0);
+    void setOutputMimeType( const QByteArray & mimeType, int specialOutputFlag = 0 );
     QByteArray outputMimeType() const;
     int specialOutputFlag() const;
 
@@ -296,8 +290,8 @@ public:
      * @param exporting specifies whether this is the setting for a
      * File --> Export or File --> Save/Save As operation.
      */
-    bool confirmNonNativeSave(const bool exporting) const;
-    void setConfirmNonNativeSave(const bool exporting, const bool on);
+    bool confirmNonNativeSave( const bool exporting ) const;
+    void setConfirmNonNativeSave( const bool exporting, const bool on );
 
     virtual bool wantExportConfirmation() const;
 
@@ -307,7 +301,7 @@ public:
      * If you asked the user about something and he chose "Cancel",
      * set the message to the magic string "USER_CANCELED", to skip the error dialog.
      */
-    void setErrorMessage(const QString& errMsg);
+    void setErrorMessage( const QString& errMsg );
 
     /**
      * Return the last error message. Usually KoDocument takes care of
@@ -333,7 +327,7 @@ public:
     /**
      *  Create a new view for the document.
      */
-    KoView *createView(QWidget *parent = 0);
+    KoView *createView( QWidget *parent = 0 );
 
     /**
      * Adds a view to the document.
@@ -341,12 +335,12 @@ public:
      * This calls KoView::updateReadWrite to tell the new view
      * whether the document is readonly or not.
      */
-    virtual void addView(KoView *view);
+    virtual void addView( KoView *view );
 
     /**
      * Removes a view of the document.
      */
-    virtual void removeView(KoView *view);
+    virtual void removeView( KoView *view );
 
     /**
      * @return a list of views this document is displayed in
@@ -361,7 +355,26 @@ public:
     /**
      * Reimplemented from KParts::Part
      */
-    virtual KParts::Part *hitTest(QWidget *widget, const QPoint &globalPos);
+    virtual KParts::Part *hitTest( QWidget *widget, const QPoint &globalPos );
+
+    /**
+     *  Find the most nested child document which contains the
+     *  requested point. The point is in the coordinate system
+     *  of this part. If no child document contains this point, then
+     *  a pointer to this document is returned.
+     *
+     *  This method can to be reimplemented if the document features child documents.
+     *
+     *  @param pos is in (unzoomed) document coordinates
+     *  @param view the view in which we are testing for a hit. This is used to implement
+     *         logic like "only hit an embedded object if it's selected in the current view"
+     *  @param matrix transforms points from the documents coordinate system
+     *         to the coordinate system of the requested point. This is used by
+     *         transformed child documents, see KoDocumentChild/KoChild.
+     *
+     *  @return Pointer to the document under the mouse at that position
+     */
+    virtual KoDocument *hitTest( const QPoint &pos, KoView* view, const QMatrix& matrix = QMatrix() );
 
     /**
      *  Paints the whole document into the given painter object.
@@ -370,13 +383,35 @@ public:
      *  @param rect        The rect that should be used in the painter object.
      *  @param view        The KoView is needed to fiddle about with the active widget, when painting children.
      */
-    virtual void paintEverything(QPainter &painter, const QRect &rect, KoView *view = 0);
+    virtual void paintEverything( QPainter &painter, const QRect &rect, KoView *view = 0);
 
     /**
      * @brief Generates a preview picture of the document
      * @note The preview is used in the File Dialog and also to create the Thumbnail
      */
-    virtual QPixmap generatePreview(const QSize& size);
+    virtual QPixmap generatePreview( const QSize& size );
+
+    /**
+     *  Paints all of the documents children into the given painter object.
+     *
+     *  @param painter     The painter object onto which will be drawn.
+     *  @param rect        The rect that should be used in the painter object.
+     *  @param view        The KoView is needed to fiddle about with the active widget.
+     *
+     *  @see #paintChild #paintEverything #paintContent
+     */
+    virtual void paintChildren( QPainter &painter, const QRect &rect, KoView *view);
+
+    /**
+     *  Paint a given child. Normally called by paintChildren().
+     *
+     *  @param child       The child to be painted.
+     *  @param painter     The painter object onto which will be drawn.
+     *  @param view        The KoView is needed to fiddle about with the active widget.
+     *
+     *  @see #paintEverything #paintChildren #paintContent
+     */
+    virtual void paintChild( KoDocumentChild *child, QPainter &painter, KoView *view);
 
     /**
      *  Paints the data itself. Normally called by paintEverything(). It does not
@@ -388,7 +423,7 @@ public:
      *
      *  @see #paintEverything
      */
-    virtual void paintContent(QPainter &painter, const QRect &rect) = 0;
+    virtual void paintContent( QPainter &painter, const QRect &rect) = 0;
 
     /**
      * Called by koApplication to check for an autosave file in $HOME
@@ -412,7 +447,7 @@ public:
     /**
      *  @return true if the document is empty.
      */
-    virtual bool isEmpty() const;
+    virtual bool isEmpty() const { return m_bEmpty; }
 
     /**
      *  @brief Sets the document to empty.
@@ -422,7 +457,7 @@ public:
      *
      *  @see isEmpty()
      */
-    virtual void setEmpty();
+    virtual void setEmpty() { m_bEmpty = true; }
 
     /**
      *  @brief Loads a document from a store.
@@ -432,27 +467,45 @@ public:
      *  @param store The store to load from
      *  @param url An internal url, like tar:/1/2
      */
-    virtual bool loadFromStore(KoStore* store, const QString& url);
+    virtual bool loadFromStore( KoStore* store, const QString& url );
 
     /**
      *  @brief Loads an OASIS document from a store.
      *  This is used for both the main document and embedded objects.
      */
-    virtual bool loadOasisFromStore(KoStore* store);
+    virtual bool loadOasisFromStore( KoStore* store );
 
     /**
      *  @brief Saves a document to a store.
      *
      *  You should not have to reimplement this - but call it in saveChildren().
      */
-    virtual bool saveToStore(KoStore* store, const QString& path);
+    virtual bool saveToStore( KoStore* store, const QString& path );
 
     /**
-     *  Reimplement this method to load the contents of your KOffice document,
+     *  Reimplement this method to load the contents of your %KOffice document,
      *  from the XML document. This is for the pre-Oasis file format (maindoc.xml).
+     *
+     *  You are supposed to use the QDomDocument. The QIODevice is provided only
+     *  for the cases where some pre-processing is needed, like kpresenter's kprconverter.
+     *  Note that the QIODevice could be 0L, when called from an import filter.
      */
-    virtual bool loadXML(const KoXmlDocument & doc, KoStore * store) = 0;
+    virtual bool loadXML( QIODevice *, const KoXmlDocument & doc ) = 0;
 
+    /**
+     *  Reimplement this method to load the contents of your %KOffice document,
+     *  from the XML document ("content.xml"). The styles have been parsed already,
+     *  you can find them in the oasisStyles parameter. The store can be used
+     *  to load images and embedded documents.
+     */
+    virtual bool loadOasis( const KoXmlDocument & doc, KoOasisStyles& oasisStyles,
+                            const KoXmlDocument & settings, KoStore* store ) = 0;
+
+    /**
+     *  Reimplement this method to save the contents of your %KOffice document,
+     *  using the OASIS format.
+     */
+    virtual bool saveOasis( KoStore* store, KoXmlWriter* manifestWriter ) = 0;
 
     /**
      *  Reimplement this to save the contents of the %KOffice document into
@@ -465,9 +518,28 @@ public:
      *  including processing instruction, complete DOCTYPE tag (with systemId and publicId), and root element.
      *  @param tagName the name of the tag for the root element
      *  @param version the DTD version (usually the application's version).
-     *  @deprecated use KoOdfWriteStore::createOasisXmlWriter instead
+     *  @deprecated use createOasisXmlWriter instead
      */
-    KDE_DEPRECATED QDomDocument createDomDocument(const QString& tagName, const QString& version) const;
+    KDE_DEPRECATED QDomDocument createDomDocument( const QString& tagName, const QString& version ) const;
+
+    /**
+     *  Return an XML writer for saving Oasis XML into the device @p dev,
+     *  including the XML processing instruction,
+     *  and the root element with all its namespaces.
+     *  You can add more namespaces afterwards with addAttribute.
+     *
+     *  @param dev the device into which the XML will be written.
+     *  @param rootElementName the tag name of the root element.
+     *     This is either office:document, office:document-content,
+     *     office:document-styles, office:document-meta or office:document-settings
+     *  @return the KoXmlWriter instance. It becomes owned by the caller, which
+     *  must delete it at some point.
+     *
+     * Once done with writing the contents of the root element, you
+     * will need to call endElement(); endDocument(); before destroying the KoXmlWriter.
+     * @note OASIS-specific
+     */
+    static KoXmlWriter* createOasisXmlWriter( QIODevice* dev, const char* rootElementName );
 
     /**
      *  Return a correctly created QDomDocument for an old (1.3-style) %KOffice document,
@@ -477,7 +549,7 @@ public:
      *  @param tagName the name of the tag for the root element, e.g. DOC for kword/kpresenter.
      *  @param version the DTD version (usually the application's version).
      */
-    static QDomDocument createDomDocument(const QString& appName, const QString& tagName, const QString& version);
+    static QDomDocument createDomDocument( const QString& appName, const QString& tagName, const QString& version );
 
     /**
      *  The first thing to do in loadOasis is get hold of the office:body tag, then its child.
@@ -485,14 +557,14 @@ public:
      *  This method returns a translated name for the type of document,
      *  e.g. i18n("Word Processing") for office:text.
      */
-    static QString tagNameToDocumentType(const QString& localName);
+    static QString tagNameToDocumentType( const QString& localName );
 
     /**
      *  Save the document. The default implementation is to call
      *  saveXML(). This method exists only for applications that
      *  don't use QDomDocument for saving, i.e. kword and kpresenter.
      */
-    virtual bool saveToStream(QIODevice * dev);
+    virtual bool saveToStream( QIODevice * dev );
 
     /**
      *  Loads a document in the native format from a given URL.
@@ -500,22 +572,20 @@ public:
      *
      *  @param file the file to load - usually KReadOnlyPart::m_file or the result of a filter
      */
-    virtual bool loadNativeFormat(const QString & file);
+    virtual bool loadNativeFormat( const QString & file );
 
     /**
      *  Saves the document in native format, to a given file
      *  You should never have to reimplement.
      *  Made public for writing templates.
      */
-    virtual bool saveNativeFormat(const QString & file);
-
-public:
+    virtual bool saveNativeFormat( const QString & file );
 
     /**
      * Activate/deactivate/configure the autosave feature.
      * @param delay in seconds, 0 to disable
      */
-    void setAutoSave(int delay);
+    void setAutoSave( int delay );
 
     /**
      * Checks whether the document is currently in the process of autosaving
@@ -527,14 +597,14 @@ public:
      * and offer to open it. This is usually true, but can be turned off
      * (e.g. for the preview module).
      */
-    void setCheckAutoSaveFile(bool b);
+    void setCheckAutoSaveFile( bool b );
 
     /**
      * Set whether the next openUrl call should show error message boxes in case
      * of errors. This is usually the case, but e.g. not when generating thumbnail
      * previews.
      */
-    void setAutoErrorHandlingEnabled(bool b);
+    void setAutoErrorHandlingEnabled( bool b );
 
     /**
      * Checks whether error message boxes should be shown.
@@ -545,7 +615,22 @@ public:
      * Retrieve the default value for autosave in seconds.
      * Called by the applications to use the correct default in their config
      */
-    static int defaultAutoSave();
+    static int defaultAutoSave() { return s_defaultAutoSave; }
+
+    /**
+     * @return the list of all children. Do not modify the
+     *         returned list.
+     */
+    const Q3PtrList<KoDocumentChild>& children() const;
+
+    /**
+     * @return the KoDocumentChild associated with the given Document, but only if
+     *         @p doc is a direct child of this document.
+     *
+     * This is a convenience function. You could get the same result
+     * by traversing the list returned by children().
+     */
+    KoDocumentChild *child( KoDocument *doc );
 
     /**
      * @return the information concerning this document.
@@ -553,18 +638,8 @@ public:
      */
     KoDocumentInfo *documentInfo() const;
 
-    /**
-     * @return the Rdf metadata for this document.
-     * This method should only be used by code that links to
-     * the RDF system and needs full access to the KoDocumentRdf object.
-     * @see KoDocumentRdf
-     */
-    KoDocumentRdf *documentRdf() const;
-    /**
-     * @return the Rdf metadata for this document.
-     * @see KoDocumentRdf
-     */
-    KoDocumentRdfBase *documentRdfBase() const;
+    void setViewBuildDocument( KoView *view, const QDomDocument &doc );
+    QDomDocument viewBuildDocument( KoView *view );
 
     /**
      * Appends the shell to the list of shells which show this
@@ -573,18 +648,18 @@ public:
      * This method is automatically called from KoMainWindow::setRootDocument,
      * so you do not need to call it.
      */
-    virtual void addShell(KoMainWindow *shell);
+    virtual void addShell( KoMainWindow *shell );
 
     /**
      * Removes the shell from the list. That happens automatically if the shell changes its
      * root document. Usually you do not need to call this method.
      */
-    virtual void removeShell(KoMainWindow *shell);
+    virtual void removeShell( KoMainWindow *shell );
 
     /**
      * @return the list of shells for the main window
      */
-    const QList<KoMainWindow*>& shells() const;
+    const Q3PtrList<KoMainWindow>& shells() const;
 
     /**
      * @return the number of shells for the main window
@@ -594,16 +669,29 @@ public:
     /**
      * @return the list of all the currently opened documents
      */
-    static QList<KoDocument*> *documentList() {
-        return s_documentList;
-    }
+    static Q3PtrList<KoDocument> *documentList() { return s_documentList; }
+
+    /**
+     * @brief Return a DCOP interface for this document
+     *
+     * %KOffice parts are strongly recommended to reimplement this method,
+     * so that their DCOP interface provides more functionality than the basic KoDocumentIface
+     */
+//     virtual DCOPObject * dcopObject();
+
+    /**
+     * @return the ID of the DCOP interface for this document.
+     **/
+//     QByteArray dcopObjectId() const;
 
     /**
      * Signal the progress of operations such as loading or saving.
      */
-    void emitProgress(int value) {
-        emit sigProgress(value);
-    }
+    void emitProgress( int value ) { emit sigProgress( value ); }
+
+    bool isInOperation() const;
+    virtual void emitBeginOperation();
+    virtual void emitEndOperation();
 
     /**
      * Return true if url() is a real filename, false if url() is
@@ -618,14 +706,13 @@ public:
      * @see KoPageLayout
      */
     virtual KoPageLayout pageLayout(int pageNumber = 0) const;
-    virtual void setPageLayout(const KoPageLayout &pageLayout);
 
     /**
      * Performs a cleanup of unneeded backup files
      */
     void removeAutoSaveFiles();
 
-    void setBackupFile(bool _b);
+    void setBackupFile( bool _b );
 
     bool backupFile()const;
 
@@ -639,13 +726,28 @@ public:
      */
     bool isLoading() const;
 
+    int queryCloseExternalChildren();
     int queryCloseDia();
 
+    /**
+     * @brief Set when we do not want to save external children when saving our 'main' doc.
+     *
+     * This makes it possible to save 'main' doc + all its internal children first, then
+     * go on to save external children. Typically used by query close.
+     * Use:
+     * @code
+     *      doc->setDoNotSaveExtDoc();
+     *      doc->save();    // saves doc and its internal children,
+     *                            //also calls saveExternalChildren() which sets setDoNotSaveExtDoc(false)
+     *      doc->saveExternalChildren();
+     * @endcode
+     */
+    void setDoNotSaveExtDoc( bool on = true );
 
     /**
      * Sets the backup path of the document
      */
-    void setBackupPath(const QString & _path);
+    void setBackupPath( const QString & _path );
 
     /**
      * @return path to the backup document
@@ -657,25 +759,15 @@ public:
      * and thus should control the title caption.
      * Also resets current flag for all parents.
      */
-    void setCurrent(bool on = true);
+    void setCurrent( bool on = true );
 
     /**
      * Sets current flag for this document and all its parents
      */
-    void forceCurrent(bool on);
+    void forceCurrent( bool on );
     bool isCurrent() const;
 
-    void setTitleModified(const QString &caption, bool mod);
-
-    /**
-     * @return caption of the document
-     *
-     * Caption is of the form "[title] - [url]",
-     * built out of the document info (title) and pretty-printed
-     * document URL.
-     * If the title is not present, only the URL it returned.
-     */
-    QString caption() const;
+    void setTitleModified( const QString &caption, bool mod );
 
     /**
      * Sets the document URL to empty URL
@@ -683,14 +775,12 @@ public:
      * After using loadNativeFormat on a template, one wants
      * to set the url to KUrl()
      */
-    void resetURL() {
-        setUrl(KUrl()); setLocalFilePath(QString());
-    }
+    void resetURL() { setUrl(KUrl()); setLocalFilePath(QString()); }
 
     /**
      * Set when you want an external embedded document to be stored internally
      */
-    void setStoreInternal(bool i);
+    void setStoreInternal( bool i );
 
     /**
      * @return true when external embedded documents are stored internally
@@ -702,14 +792,12 @@ public:
     /**
      * @internal (public for KoMainWindow)
      */
-    void setMimeTypeAfterLoading(const QString& mimeType);
+    void setMimeTypeAfterLoading( const QString& mimeType );
 
     /**
      * @return returns the number of pages in the document.
      */
-    virtual int pageCount() const {
-        return 1;
-    }
+    virtual int pageCount() const { return 1; }
 
     /**
      * Returns the unit used to display all measures/distances.
@@ -719,14 +807,7 @@ public:
     /**
      * Sets the unit used to display all measures/distances.
      */
-    void setUnit(const KoUnit &unit);
-
-    /**
-     * Save the unit to the settings writer
-     *
-     * @param settingsWriter
-     */
-    void saveUnitOdf(KoXmlWriter* settingsWriter) const;
+    void setUnit( KoUnit u );
 
     /**
      * Returns the name of the unit used to display all measures/distances.
@@ -755,22 +836,18 @@ public:
 
     QList<KoVersionInfo> &versionList();
 
-    bool loadNativeFormatFromStore(QByteArray &data);
+    bool loadNativeFormatFromStore( QByteArray &data );
 
     /**
     Adds a new version and then saves the whole document.
     * @param comment the comment for the version
     * @return true on success, otherwise false
     */
-    bool addVersion(const QString& comment);
+    bool addVersion( const QString& comment );
 
-    /// return the grid data for this document.
-    KoGridData &gridData();
+    KoGridData &gridData() {return m_gridData;}
 
-    /// returns the guides data for this document.
-    KoGuidesData &guidesData();
-
-    void clearUndoHistory();
+    KoGuidesData &guidesData() {return m_guidesData;}
 
     using ReadWritePart::setUrl;
     using ReadWritePart::localFilePath;
@@ -782,10 +859,6 @@ public slots:
      */
     virtual void initEmpty();
 
-    /**
-     * Returns the global undo stack
-     */
-    KUndoStack *undoStack();
     /**
      * Adds a command to the undo stack and executes it by calling the redo() function.
      * @param command command to add to the undo stack
@@ -796,7 +869,7 @@ public slots:
      * Begins recording of a macro command. At the end endMacro needs to be called.
      * @param text command description
      */
-    virtual void beginMacro(const QString & text);
+    virtual void beginMacro( const QString & text );
 
     /**
      * Ends the recording of a macro command.
@@ -807,7 +880,7 @@ public slots:
      *  Sets the modified flag on the document. This means that it has
      *  to be saved or not before deleting it.
      */
-    virtual void setModified(bool _mod);
+    virtual void setModified( bool _mod );
 
     /**
      * Called by the undo stack when the document is saved or all changes has been undone
@@ -822,20 +895,30 @@ signals:
      * It is common to connect views to it, in order to change the displayed units
      * (e.g. in the rulers)
      */
-    void unitChanged(const KoUnit &unit);
+    void unitChanged(KoUnit);
+
+    /**
+     * This signal is emitted when a direct or indirect child document changes
+     * and needs to be updated in all views.
+     *
+     * If one of your child documents emits the childChanged signal, then you may
+     * usually just want to redraw this child. In this case you can ignore the parameter
+     * passed by the signal.
+     */
+    void childChanged( KoDocumentChild *child );
 
     /**
      * Progress info while loading or saving. The value is in percents (i.e. a number between 0 and 100)
      * Your KoDocument-derived class should emit the signal now and then during load/save.
      * KoMainWindow will take care of displaying a progress bar automatically.
      */
-    void sigProgress(int value);
+    void sigProgress( int value );
 
     /**
      * Emitted e.g. at the beginning of a save operation
      * This is emitted by KoDocument and used by KoView to display a statusbar message
      */
-    void statusBarMessage(const QString& text);
+    void statusBarMessage( const QString& text );
 
     /**
      * Emitted e.g. at the end of a save operation
@@ -843,10 +926,13 @@ signals:
      */
     void clearStatusBarMessage();
 
+    void beginOperation();
+    void endOperation();
+
     /**
     * Emitted when the document is modified
     */
-    void modified(bool);
+    void modified( bool );
 
     void closeEmbedInitDialog();
 
@@ -855,34 +941,25 @@ protected slots:
      * This slot loads an existing file and deletes the start up widget.
      * @param url the file to load
      */
-    virtual void openExistingFile(const KUrl& url);
+    virtual void openExistingFile( const KUrl& url );
     /**
      * This slot loads a template and deletes the start up widget.
      * @param url the template to load
      */
-    virtual void openTemplate(const KUrl& url);
+    virtual void openTemplate( const KUrl& url );
+
+    void deleteOpenPaneDelayed();
 
 protected:
-    /**
-     * Struct used in the list created by createCustomDocumentWidgets()
-     */
-    struct CustomDocumentWidgetItem {
-        /// Pointer to the custom document widget
-        QWidget* widget;
-        /// title used in the sidebar. If left empty it will be displayed as "Custom Document"
-        QString title;
-        /// icon used in the sidebar. If left empty it will use the unknown icon
-        QString icon;
-    };
 
     /**
         Generate a name for the document.
     */
     QString newObjectName();
 
-    QString autoSaveFile(const QString & path) const;
+    QString autoSaveFile( const QString & path ) const;
 
-    virtual KoView *createViewInstance(QWidget *parent) = 0;
+    virtual KoView *createViewInstance( QWidget *parent ) = 0;
 
     /**
      *  Loads a document from KReadOnlyPart::m_file (KParts takes care of downloading
@@ -890,8 +967,6 @@ protected:
      *  Applies a filter if necessary, and calls loadNativeFormat in any case
      *  You should not have to reimplement, except for very special cases.
      *
-     * NOTE: this method also creates a new KoView instance!
-     *
      * This method is called from the KReadOnlyPart::openUrl method.
      */
     virtual bool openFile();
@@ -908,21 +983,57 @@ protected:
      * Override this method in your derived class to show a widget in the startup 'dialog'.
      * This widget should allow the user to set settings for a custom document (i.e. one
      * not based on a template).
-     * The returned widget should provide its own button (preferably 'Create') and
+     * The returned widget should provide its own button (preferrably 'Create') and
      * implement the logic to implement the document instance correctly.
      * After initializing the widget should emit a signal called 'documentSelected()' which
      * will remove the startupWidget and show the document.
      * @param parent the parent of the to be created widget.
-     * @return a list of KoDocument::CustomDocumentWidgetItem.
      */
-    virtual QList<CustomDocumentWidgetItem> createCustomDocumentWidgets(QWidget *parent);
+    virtual QWidget* createCustomDocumentWidget(QWidget *parent);
+
+    /**
+     *  OLD XML method. For OASIS just call KoDocumentChild::loadOasisDocument
+     *  after KoDocumentChild::loadOasis.
+     *
+     *  You need to overload this function if your document may contain
+     *  embedded documents. This function is called to load embedded documents.
+     *
+     *  An example implementation may look like this:
+     *  @code
+     *  QPtrListIterator<KoDocumentChild> it( children() );
+     *  for( ; it.current(); ++it )
+     *  {
+     *    if ( !it.current()->loadDocument( _store ) )
+     *    {
+     *      return false;
+     *    }
+     *  }
+     *  return true;
+     *  @endcode
+     */
+    virtual bool loadChildren( KoStore* );
+
+    /**
+     *  Saves all internal children (only!).
+     *  @see saveExternalChildren if you have external children.
+     *  Returns true on success.
+     */
+    virtual bool saveChildren( KoStore* store );
+
+    /**
+     *  Saves all internal children (only!), to the store, using the OASIS format.
+     *  This is called automatically during saveNativeFormat.
+     *  @see saveExternalChildren if you have external children.
+     *  Returns true on success.
+     */
+    virtual bool saveChildrenOasis( KoStore* store, KoXmlWriter* manifestWriter );
 
     /**
      *  Overload this function if you have to load additional files
      *  from a store. This function is called after loadXML()
      *  and after loadChildren() have been called.
      */
-    virtual bool completeLoading(KoStore* store);
+    virtual bool completeLoading( KoStore* store );
 
     /**
      *  If you want to write additional files to a store,
@@ -934,13 +1045,32 @@ protected:
      *  But do this ONLY if the document is not stored extern (see isStoredExtern() ).
      *  If it is, then the pictures should be saved to tar:/pictures.
      */
-    virtual bool completeSaving(KoStore* store);
+    virtual bool completeSaving( KoStore* store );
 
+    /**
+     * Inserts the new child in the list of children and emits the
+     * childChanged() signal.
+     *
+     * At the same time this method marks this document as modified.
+     *
+     * To remove a child, just delete it. KoDocument will detect this
+     * and remove the child from its lists.
+     *
+     * @see #isModified
+     */
+    virtual void insertChild( KoDocumentChild *child );
 
     /** @internal */
-    virtual void setModified() {
-        KParts::ReadWritePart::setModified();
-    }
+    virtual void setModified() { KParts::ReadWritePart::setModified(); }
+
+    KoPageLayout m_pageLayout;
+
+    /**
+     *  Saves all externally stored children.
+     *  Returns true on success.
+     * @see #saveChildren for internal children
+     */
+    virtual bool saveExternalChildren();
 
     /**
      *  Returns whether or not the current openUrl() or openFile() call is
@@ -964,54 +1094,38 @@ protected:
      * @param instance the KComponentData to be used for KConfig data
      * @param templateType the template-type (group) that should be selected on creation.
      */
-    KoOpenPane* createOpenPane(QWidget* parent, const KComponentData &instance,
-                               const QString& templateType = QString());
-
-
-
-    /// to satisfy KoOdfDocument where it overlaps with kparts
-    virtual KUrl getOdfUrl() const {
-        return url();
-    }
-
-    virtual void setOdfUrl( const KUrl& url ) {
-        setUrl( url );
-    }
+    KoOpenPane* createOpenPane( QWidget* parent, const KComponentData &instance,
+                                const QString& templateType = QString());
 
 private slots:
-
+    void slotChildChanged( KoChild *c );
+    void slotChildDestroyed();
     void slotAutoSave();
-    void slotStarted(KIO::Job*);
+    void slotStarted( KIO::Job* );
     void startCustomDocument();
-
     /**
-     * Removes the open widget shown at application start up.
+     * Removes the open widget showed at application start up.
      */
     void deleteOpenPane();
 
 private:
-
-    bool saveNativeFormatODF(KoStore* store, const QByteArray &mimeType);
-    bool saveNativeFormatKOffice(KoStore* store);
-
-    /// @return the current KoMainWindow shell
-    KoMainWindow* currentShell();
+    virtual void insertChild(QObject *) { Q_ASSERT( 0 ); } // avoid compiler warning, but don't call deprecated insertChild() in QObject
 
     KService::Ptr nativeService();
-    bool oldLoadAndParse(KoStore* store, const QString& filename, KoXmlDocument& doc);
-    bool loadNativeFormatFromStore(const QString& file);
-    bool loadNativeFormatFromStoreInternal(KoStore * store);
-
-    bool savePreview(KoStore* store);
-    bool saveOasisPreview(KoStore* store, KoXmlWriter* manifestWriter);
-
-    QString prettyPathOrUrl() const;
+    bool oldLoadAndParse( KoStore* store, const QString& filename, KoXmlDocument& doc );
+    bool loadNativeFormatFromStore( const QString& file );
+    bool loadNativeFormatFromStoreInternal( KoStore * store );
 
+    bool savePreview( KoStore* store );
+    bool saveOasisPreview( KoStore* store, KoXmlWriter* manifestWriter );
     class Private;
     Private * const d;
-
-
-    static QList<KoDocument*> *s_documentList;
+    KService::Ptr m_nativeService;
+    bool m_bEmpty;
+    KoGridData m_gridData;
+    KoGuidesData m_guidesData;
+    static Q3PtrList<KoDocument> *s_documentList;
+    static const int s_defaultAutoSave;
 };
 
 #endif
