@@ -1,6 +1,7 @@
 /*
  *  Copyright (c) 2005 Boudewijn Rempt <boud@valdyas.org>
  *  Copyright (c) 2006-2007 Cyrille Berger <cberger@cberger.net>
+ *  Copyright (c) 2007 Emanuele Tamponi <emanuele@valinor.it>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,33 +23,28 @@
 
 #include <limits.h>
 
-#include <QtGui/QImage>
-#include <QtCore/QHash>
-#include <QtCore/QVector>
-#include <QtCore/QList>
-#include <QtCore/QBitArray>
+#include <QImage>
+#include <QHash>
+#include <QVector>
+#include <QList>
+#include <QBitArray>
 
 #include "KoColorSpaceConstants.h"
 #include "KoColorConversionTransformation.h"
 #include <KoChannelInfo.h>
-#include <KoColorSpace.h>
 #include <KoID.h>
-#include "pigment_export.h"
+#include <pigment_export.h>
+
+
+
 
-class QDomDocument;
-class QDomElement;
 class KoCompositeOp;
 class KoColorProfile;
+class KoColorSpaceRegistry;
 class KoColorTransformation;
-class KoColorConversionTransformationFactory;
+class KisFilter;
 class QBitArray;
 
-enum Deletability {
-    OwnedByRegistryDoNotDelete,
-    OwnedByRegistryRegistyDeletes,
-    NotOwnedByRegistry
-};
-
 enum ColorSpaceIndependence {
     FULLY_INDEPENDENT,
     TO_LAB16,
@@ -56,9 +52,53 @@ enum ColorSpaceIndependence {
     TO_RGBA16
 };
 
+/**
+ * Base class of the mix color operation. It's defined by
+ * sum(colors[i] * weights[i]) / 255. You access the KoConvolutionOp
+ *
+ * of a colorspace by calling KoColorSpace::mixColorsOp.
+ */
+class KoMixColorsOp {
+public:
+    virtual ~KoMixColorsOp() { }
+    /**
+     * Mix the colors.
+     * @param colors a pointer toward the source pixels
+     * @param weights the coeffient of the source pixels
+     * @param nColors the number of pixels in the colors array
+     * @param dst the destination pixel
+     */
+    virtual void mixColors(const quint8 * const*colors, const quint8 *weights, quint32 nColors, quint8 *dst) const = 0;
+};
 
-#include "KoMixColorsOp.h"
-#include "KoConvolutionOp.h"
+/**
+ * Base class of a convolution operation. A convolution operation is
+ * defined by sum(colors[i] * kernelValues[i]) / factor + offset). The
+ * most well known convolution is the gaussian blur.
+ *
+ * You access the KoConvolutionOp of a colorspace by calling
+ * KoColorSpace::convolutionOp.
+ */
+class KoConvolutionOp {
+public:
+    virtual ~KoConvolutionOp() { }
+    /**
+     * Convolve the colors.
+     *
+     * @param colors a pointer toward the source pixels
+     * @param kernelValues the coeffient of the source pixels
+     * @param dst the destination pixel
+     * @param factor usually the factor is equal to the sum of kernelValues
+     * @param offset the offset which is added to the result, useful
+     *        when the sum of kernelValues is equal to 0
+     * @param nColors the number of pixels in the colors array
+     * @param channelFlags determines which channels are affected
+     *
+     * This function is thread-safe.
+     *
+     */
+    virtual void convolveColors(const quint8* const* colors, const qint32* kernelValues, quint8 *dst, qint32 factor, qint32 offset, qint32 nColors, const QBitArray & channelFlags) const = 0;
+};
 
 /**
  * A KoColorSpace is the definition of a certain color space.
@@ -73,7 +113,7 @@ enum ColorSpaceIndependence {
  * number of specific color spaces. So RGB is the model and sRGB,
  * adobeRGB, etc are colorspaces.
  *
- * In Pigment KoColorSpace acts as both a color model and a color space.
+ * In Pigment KoColorSpace act as both a color model and a color space.
  * You can think of the class definition as the color model, but the
  * instance of the class as representing a colorspace.
  *
@@ -87,28 +127,24 @@ enum ColorSpaceIndependence {
  * Some subclasses implement only some parts and are named Traits
  *
  */
-class PIGMENTCMS_EXPORT KoColorSpace
-{
-    friend class KoColorSpaceRegistry;
+class PIGMENT_EXPORT KoColorSpace {
+
 protected:
     /// Only for use by classes that serve as baseclass for real color spaces
     KoColorSpace();
 
 public:
-
     /// Should be called by real color spaces
-    KoColorSpace(const QString &id, const QString &name, KoMixColorsOp* mixColorsOp, KoConvolutionOp* convolutionOp);
+    KoColorSpace(const QString &id, const QString &name, KoColorSpaceRegistry * parent, KoMixColorsOp* mixColorsOp, KoConvolutionOp* convolutionOp );
     virtual ~KoColorSpace();
 
-    virtual bool operator==(const KoColorSpace& rhs) const;
+    virtual bool operator==(const KoColorSpace& rhs) const {
+        return id() == rhs.id();
+    }
+
 
 public:
 
-    /**
-     * Use this function to create a cloned version of this color space,
-     * and of its profile.
-     */
-    virtual KoColorSpace* clone() const = 0;
     //========== Channels =====================================================//
 
     /// Return a list describing all the channels this color model has.
@@ -133,9 +169,6 @@ public:
      * @param alpha if true, set all alpha channels to true
      * @param substance if true, set all substance channels to true
      * @param substrate if true, set all substrate channels to true
-     *
-     * The order of channels is the colorspace descriptive order,
-     * not the pixel order.
      */
     QBitArray channelFlags(bool color = true, bool alpha = false, bool substance = false, bool substrate = false) const;
 
@@ -151,7 +184,7 @@ public:
      * channels are stored in the pixel to the order in which the
      * channels are defined in the olorspace. (for example, abgr->rgba)
      */
-    QBitArray setChannelFlagsToColorSpaceOrder(const QBitArray & origChannelFlags) const;
+    QBitArray setChannelFlagsToColorSpaceOrder( const QBitArray & origChannelFlags ) const;
 
     /**
      * The size in bytes of a single pixel in this color model
@@ -170,16 +203,12 @@ public:
      */
     virtual QString normalisedChannelValueText(const quint8 *pixel, quint32 channelIndex) const = 0;
 
-    /**
-     * Return a QVector of floats with channels' values normalized
-     * to floating point range 0 to 1.
-     */
-    virtual void normalisedChannelsValue(const quint8 *pixel, QVector<float> &channels) const = 0;
-
-    /**
-     * Write in the pixel the value from the normalized vector.
-     */
-    virtual void fromNormalisedChannelsValue(quint8 *pixel, const QVector<float> &values) const = 0;
+	/**
+	 * Return a QVector of floats with channels' values normalized
+	 * to floating point range 0 to 1.
+	 */
+	virtual void normalisedChannelsValue(const quint8 *pixel, QVector<float> &channels) const = 0;
+	virtual void fromNormalisedChannelsValue(quint8 *pixel, const QVector<float> &values) = 0;
 
     /**
      * Convert the value of the channel at the specified position into
@@ -205,33 +234,16 @@ public:
     //========== Identification ===============================================//
 
     /**
-     * ID for use in files and internally: unchanging name. As the id must be unique
-     * it is usually the concatenation of the id of the color model and of the color
-     * depth, for instance "RGBA8" or "CMYKA16" or "XYZA32f".
+     * ID for use in files and internally: unchanging name
      */
     virtual QString id() const;
 
     /**
-     * User visible name which contains the name of the color model and of the color depth.
-     * For intance "RGBA (8-bits)" or "CMYKA (16-bits)".
+     * i18n name.
      */
     virtual QString name() const;
 
-    /**
-     * @return a string that identify the color model (for instance "RGB" or "CMYK" ...)
-     * @see KoColorModelStandardIds.h
-     */
-    virtual KoID colorModelId() const = 0;
-    /**
-     * @return a string that identify the bit depth (for instance "U8" or "F16" ...)
-     * @see KoColorModelStandardIds.h
-     */
-    virtual KoID colorDepthId() const = 0;
-
-    /**
-     * @return true if the profile given in argument can be used by this color space
-     */
-    virtual bool profileIsCompatible(const KoColorProfile* profile) const = 0;
+    virtual bool profileIsCompatible(KoColorProfile* profile) const =0;
 
     /**
      * If false, images in this colorspace will degrade considerably by
@@ -250,7 +262,7 @@ public:
     /**
      * Returns the list of user-visible composite ops supported by this colorspace.
      */
-    virtual QList<KoCompositeOp*> compositeOps() const;
+    virtual QList<KoCompositeOp*> userVisiblecompositeOps() const;
 
     /**
      * Retrieve a single composite op from the ones this colorspace offers.
@@ -275,11 +287,7 @@ public:
     /**
      * Return the profile of this color space. This may be 0
      */
-    virtual const KoColorProfile * profile() const = 0;
-    /**
-     * Return the profile of this color space. This may be 0
-     */
-    virtual KoColorProfile * profile() = 0;
+    virtual KoColorProfile * profile() const = 0;
 
 //================= Conversion functions ==================================//
 
@@ -293,7 +301,19 @@ public:
      * @param dst a pointer to a pixel
      * @param profile the optional profile that describes the color values of QColor
      */
-    virtual void fromQColor(const QColor& color, quint8 *dst, const KoColorProfile * profile = 0) const = 0;
+    virtual void fromQColor(const QColor& color, quint8 *dst, KoColorProfile * profile = 0) const = 0;
+
+    /**
+     * The fromQColor methods take a given color defined as an RGB QColor
+     * and fills a byte array with the corresponding color in the
+     * the colorspace managed by this strategy.
+     *
+     * @param color the QColor that will be used to fill dst
+     * @param opacity the opacity of the color
+     * @param dst a pointer to a pixel
+     * @param profile the optional profile that describes the color values of QColor
+     */
+    virtual void fromQColor(const QColor& color, quint8 opacity, quint8 *dst, KoColorProfile * profile = 0) const = 0;
 
     /**
      * The toQColor methods take a byte array that is at least pixelSize() long
@@ -304,25 +324,43 @@ public:
      * @param c the QColor that will be filled with the color at src
      * @param profile the optional profile that describes the color in c, for instance the monitor profile
      */
-    virtual void toQColor(const quint8 *src, QColor *c, const KoColorProfile * profile = 0) const = 0;
+    virtual void toQColor(const quint8 *src, QColor *c, KoColorProfile * profile = 0) const = 0;
+
+    /**
+     * The toQColor methods take a byte array that is at least pixelSize() long
+     * and converts the contents to a QColor, using the given profile as a source
+     * profile and the option profile as a destination profile.
+     *
+     * @param src a pointer to the source pixel
+     * @param c the QColor that will be filled with the color at src
+     * @param opacity a pointer to a byte that will be filled with the opacity a src
+     * @param profile the optional profile that describes the color in c, for instance the monitor profile
+     */
+    virtual void toQColor(const quint8 *src, QColor *c, quint8 *opacity, KoColorProfile * profile = 0) const = 0;
 
     /**
      * Convert the pixels in data to (8-bit BGRA) QImage using the specified profiles.
+     * The pixels are supposed to be encoded in this color model. The default implementation
+     * will convert the pixels using either the profiles or the default profiles for the
+     * current colorstrategy and the RGBA colorstrategy. If that is not what you want,
+     * or if you think you can do better than lcms, reimplement this methods.
      *
      * @param data A pointer to a contiguous memory region containing width * height pixels
      * @param width in pixels
      * @param height in pixels
      * @param dstProfile destination profile
      * @param renderingIntent the rendering intent
+     * @param exposure The exposure setting for rendering a preview of a high dynamic range image.
      */
     virtual QImage convertToQImage(const quint8 *data, qint32 width, qint32 height,
-                                   const KoColorProfile *  dstProfile, KoColorConversionTransformation::Intent renderingIntent = KoColorConversionTransformation::IntentPerceptual) const ;
+                                   KoColorProfile *  dstProfile, KoColorConversionTransformation::Intent renderingIntent = KoColorConversionTransformation::IntentPerceptual,
+                                   float exposure = 0.0f) const = 0;
 
     /**
      * This functions allocates the ncessary memory for numPixels number of pixels.
      * It is your responsibility to delete[] it.
      */
-    quint8 *allocPixelBuffer(quint32 numPixels, bool clear = false, quint8 defaultvalue = 0) const;
+    quint8 *allocPixelBuffer(quint32 numPixels) const;
 
     /**
      * Convert the specified data to Lab (D50). All colorspaces are guaranteed to support this
@@ -331,7 +369,7 @@ public:
      * @param dst the destination data
      * @param nPixels the number of source pixels
      */
-    virtual void toLabA16(const quint8 * src, quint8 * dst, quint32 nPixels) const;
+    virtual void toLabA16(const quint8 * src, quint8 * dst, quint32 nPixels) const = 0;
 
     /**
      * Convert the specified data from Lab (D50). to this colorspace. All colorspaces are
@@ -341,7 +379,7 @@ public:
      * @param dst the destination data
      * @param nPixels the number of pixels in the array
      */
-    virtual void fromLabA16(const quint8 * src, quint8 * dst, quint32 nPixels) const;
+    virtual void fromLabA16(const quint8 * src, quint8 * dst, quint32 nPixels) const = 0;
 
     /**
      * Convert the specified data to sRGB 16 bits. All colorspaces are guaranteed to support this
@@ -350,7 +388,7 @@ public:
      * @param dst the destination data
      * @param nPixels the number of source pixels
      */
-    virtual void toRgbA16(const quint8 * src, quint8 * dst, quint32 nPixels) const;
+    virtual void toRgbA16(const quint8 * src, quint8 * dst, quint32 nPixels) const =0;
 
     /**
      * Convert the specified data from sRGB 16 bits. to this colorspace. All colorspaces are
@@ -360,22 +398,13 @@ public:
      * @param dst the destination data
      * @param nPixels the number of pixels in the array
      */
-    virtual void fromRgbA16(const quint8 * src, quint8 * dst, quint32 nPixels) const;
-
-    /**
-     * Create a color conversion transformation.
-     */
-    virtual KoColorConversionTransformation* createColorConverter(const KoColorSpace * dstColorSpace, KoColorConversionTransformation::Intent renderingIntent = KoColorConversionTransformation::IntentPerceptual) const;
+    virtual void fromRgbA16(const quint8 * src, quint8 * dst, quint32 nPixels) const =0;
 
     /**
      * Convert a byte array of srcLen pixels *src to the specified color space
      * and put the converted bytes into the prepared byte array *dst.
      *
      * Returns false if the conversion failed, true if it succeeded
-     *
-     * This function is not thread-safe. If you want to apply multiple conversion
-     * in different threads at the same time, you need to create one color converter
-     * per-thread using createColorConverter.
      */
     virtual bool convertPixelsTo(const quint8 * src,
                                  quint8 * dst, const KoColorSpace * dstColorSpace,
@@ -454,7 +483,8 @@ public:
      * the compensation factor will be used to limit the darkening.
      *
      */
-    virtual KoColorTransformation *createDarkenAdjustment(qint32 shade, bool compensate, qreal compensation) const = 0;
+    virtual KoColorTransformation *createDarkenAdjustement(qint32 shade, bool compensate, double compensation) const = 0;
+
 
     /**
      * Invert color channels of the given pixels
@@ -462,10 +492,9 @@ public:
      */
     virtual KoColorTransformation *createInvertTransformation() const = 0;
 
+    // XXX: What with alpha channels? YYY: Add an overloaded function that takes alpha into account?
     /**
-     * Get the difference between 2 colors, normalized in the range (0,255). Only completely
-     * opaque and completely transparent are taken into account when computing the different;
-     * other transparency levels are not regarded when finding the difference.
+     * Get the difference between 2 colors, normalized in the range (0,255)
      */
     virtual quint8 difference(const quint8* src1, const quint8* src2) const = 0;
 
@@ -487,7 +516,7 @@ public:
     /**
      * Create a mathematical toolbox compatible with this colorspace
      */
-    virtual KoID mathToolboxId() const = 0;
+    virtual KoID mathToolboxId() const =0;
 
     /**
      * Compose two arrays of pixels together. If source and target
@@ -496,119 +525,92 @@ public:
      * colorspace.
      *
      * @param dst pointer to the pixels onto which src will be composited. dst is "below" src.
-     * @param dststride the total number of bytes in one line in the dst paint device
+     * @param dststride skip in bytes to the starting point of the next row of dst pixels
      * @param srcSpace the colorspace of the source pixels that will be composited onto "us"
      * @param src pointer to the pixels that will be composited onto "us"
-     * @param srcRowStride the total number of bytes in one line in the src paint device
+     * @param srcRowStride skip in bytes to the starting point of the next row of src pixels
      * @param srcAlphaMask pointer to an alpha mask that determines whether and how much
      *        of src will be composited onto dst
-     * @param maskRowStride the total number of bytes in one line in the mask paint device
+     * @param maskRowStride skip in bytes to the starting point of the next row of mask pixels
      * @param rows the number of rows of pixels we'll be compositing
      * @param cols the length in pixels of a single row we'll be compositing.
      * @param op the composition operator to use, e.g. COPY_OVER
      * @param channelFlags a bit array reflecting which channels will be composited and which
-     *        channels won't. The order is pixel order, not colorspace order.
+     *        channels won't.
      */
     virtual void bitBlt(quint8 *dst,
-                        qint32 dststride,
-                        const KoColorSpace * srcSpace,
-                        const quint8 *src,
-                        qint32 srcRowStride,
-                        const quint8 *srcAlphaMask,
-                        qint32 maskRowStride,
-                        quint8 opacity,
-                        qint32 rows,
-                        qint32 cols,
-                        const KoCompositeOp * op,
+			qint32 dststride,
+			KoColorSpace * srcSpace,
+			const quint8 *src,
+			qint32 srcRowStride,
+			const quint8 *srcAlphaMask,
+			qint32 maskRowStride,
+			quint8 opacity,
+			qint32 rows,
+			qint32 cols,
+			const KoCompositeOp * op,
                         const QBitArray & channelFlags) const;
-
     /**
      * Convenience function for the above where all channels are turned on.
      */
     virtual void bitBlt(quint8 *dst,
-                        qint32 dststride,
-                        const KoColorSpace * srcSpace,
-                        const quint8 *src,
-                        qint32 srcRowStride,
-                        const quint8 *srcAlphaMask,
-                        qint32 maskRowStride,
-                        quint8 opacity,
-                        qint32 rows,
-                        qint32 cols,
+			qint32 dststride,
+			KoColorSpace * srcSpace,
+			const quint8 *src,
+			qint32 srcRowStride,
+			const quint8 *srcAlphaMask,
+			qint32 maskRowStride,
+			quint8 opacity,
+			qint32 rows,
+			qint32 cols,
                         const KoCompositeOp * op) const;
 
     /**
      * Convenience function for the above if you don't have the composite op object yet.
      */
     virtual void bitBlt(quint8 *dst,
-                        qint32 dststride,
-                        const KoColorSpace * srcSpace,
-                        const quint8 *src,
-                        qint32 srcRowStride,
-                        const quint8 *srcAlphaMask,
-                        qint32 maskRowStride,
-                        quint8 opacity,
-                        qint32 rows,
-                        qint32 cols,
-                        const QString & op,
+			qint32 dststride,
+			KoColorSpace * srcSpace,
+			const quint8 *src,
+			qint32 srcRowStride,
+			const quint8 *srcAlphaMask,
+			qint32 maskRowStride,
+			quint8 opacity,
+			qint32 rows,
+			qint32 cols,
+			const QString & op,
                         const QBitArray & channelFlags) const;
 
     /**
      * Convenience function for the above, if you simply want all channels composited
      */
     virtual void bitBlt(quint8 *dst,
-                        qint32 dststride,
-                        const KoColorSpace * srcSpace,
-                        const quint8 *src,
-                        qint32 srcRowStride,
-                        const quint8 *srcAlphaMask,
-                        qint32 maskRowStride,
-                        quint8 opacity,
-                        qint32 rows,
-                        qint32 cols,
+			qint32 dststride,
+			KoColorSpace * srcSpace,
+			const quint8 *src,
+			qint32 srcRowStride,
+			const quint8 *srcAlphaMask,
+			qint32 maskRowStride,
+			quint8 opacity,
+			qint32 rows,
+			qint32 cols,
                         const QString& op) const;
 
 
-    /**
-     * Serialize this color following Create's swatch color specification available
-     * at http://create.freedesktop.org/wiki/index.php/Swatches_-_colour_file_format
-     *
-     * This function doesn't create the <color /> element but rather the <CMYK />,
-     * <sRGB />, <RGB /> ... elements. It is assumed that colorElt is the <color />
-     * element.
-     *
-     * @param pixel buffer to serialized
-     * @param colorElt root element for the serialization, it is assumed that this
-     *                 element is <color />
-     * @param doc is the document containing colorElt
-     */
-    virtual void colorToXML(const quint8* pixel, QDomDocument& doc, QDomElement& colorElt) const = 0;
 
     /**
-     * Unserialize a color following Create's swatch color specification available
-     * at http://create.freedesktop.org/wiki/index.php/Swatches_-_colour_file_format
-     *
-     * @param pixel buffer where the color will be unserialized
-     * @param elt the element to unserialize (<CMYK />, <sRGB />, <RGB />)
-     * @return the unserialize color, or an empty color object if the function failed
-     *         to unserialize the color
+     * The backgroundfilters will be run periodically on the newly
+     * created paint device. XXX: Currently this uses times and not
+     * threads.
      */
-    virtual void colorFromXML(quint8* pixel, const QDomElement& elt) const = 0;
-
-    KoColorTransformation* createColorTransformation(const QString & id, const QHash<QString, QVariant> & parameters) const;
-
+    virtual QList<KisFilter*> createBackgroundFilters() const
+        { return QList<KisFilter*>(); }
 protected:
-
     /**
      * Use this function in the constructor of your colorspace to add the information about a channel.
      * @param ci a pointer to the information about a channel
      */
     virtual void addChannel(KoChannelInfo * ci);
-    const KoColorConversionTransformation* toLabA16Converter() const;
-    const KoColorConversionTransformation* fromLabA16Converter() const;
-    const KoColorConversionTransformation* toRgbA16Converter() const;
-    const KoColorConversionTransformation* fromRgbA16Converter() const;
-
 private:
 
     /**
@@ -621,4 +623,33 @@ private:
     Private * const d;
 };
 
+class KoColorSpaceFactory {
+public:
+    virtual ~KoColorSpaceFactory() {}
+    /**
+     * Return the unchanging name of this color space
+     */
+    virtual QString id() const = 0;
+
+    /**
+     * return the i18n'able description.
+     */
+    virtual QString name() const = 0;
+
+
+    virtual KoID colorModelId() const = 0;
+    virtual KoID colorDepthId() const = 0;
+
+    virtual bool profileIsCompatible(KoColorProfile* profile) const =0;
+    virtual KoColorSpace *createColorSpace(KoColorSpaceRegistry * parent, KoColorProfile *) = 0;
+
+    /**
+     * Returns the default icc profile for use with this colorspace. This may be ""
+     *
+     & @return the default icc profile name
+    */
+    virtual QString defaultProfile() = 0;
+
+};
+
 #endif // KOCOLORSPACE_H
