@@ -21,14 +21,13 @@
 
 #include <QWidget>
 
-#include <ui_FixedDateFormat.h>
+#include "ui_FixedDateFormat.h"
 
 class DateVariable;
 class QListWidgetItem;
 class QMenu;
 
-class FixedDateFormat : public QWidget
-{
+class FixedDateFormat : public QWidget {
     Q_OBJECT
 public:
     explicit FixedDateFormat(DateVariable *variable);
